package com.brilliance.swift;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.Mt2MxCreatorManager;
import com.brilliance.swift.mx2element.Mx2ElementCreatorManager;
import com.brilliance.swift.mx2map.Mx2MapCreatorManager;
import com.brilliance.swift.mx2mt.Mx2MtCreatorManager;
import com.brilliance.swift.util.*;
import com.brilliance.swift.vo.SwiftTranslationReport;
import com.prowidesoftware.swift.model.MxId;
import com.prowidesoftware.swift.model.mx.AbstractMX;
import com.prowidesoftware.swift.model.mx.NamespaceReader;
import org.apache.commons.io.FileUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import java.io.File;
import java.io.IOException;
import java.util.Map;
import java.util.Optional;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class SwiftTransfer {

    /**
     * MX TRANSFER MT
     */
    public static String mx2Mt(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String xmlStr = FileUtils.readFileToString(file);
            return mx2Mt(xmlStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }

    }

    public static String mx2Mt(String xmlStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        SwiftTranslationReport str = new Mx2MtCreatorManager().mx2Mt(xmlStr, outPutFilePath, extraMap);
        return str.getMessage();
    }

    public static String mx2Mt(String xmlFilePath, boolean filePathFlag, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        if (filePathFlag) {
            File file = new File(xmlFilePath);
            return mx2Mt(file, outPutFilePath, extraMap);
        } else {
            return mx2Mt(xmlFilePath, outPutFilePath, extraMap);
        }
    }

    public static SwiftTranslationReport mx2MtPlus(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String xmlStr = FileUtils.readFileToString(file);
            return mx2MtPlus(xmlStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }

    }

    public static SwiftTranslationReport mx2MtPlus(String xmlStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        return new Mx2MtCreatorManager().mx2Mt(xmlStr, outPutFilePath, extraMap);
    }

    public static SwiftTranslationReport mx2MtPlus(String xmlFilePath, boolean filePathFlag, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        if (filePathFlag) {
            File file = new File(xmlFilePath);
            return mx2MtPlus(file, outPutFilePath, extraMap);
        } else {
            return mx2MtPlus(xmlFilePath, outPutFilePath, extraMap);
        }
    }

    /**
     * MT TRANSFER MX
     */
    public static String mt2Mx(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String mtStr = FileUtils.readFileToString(file);
            return mt2Mx(mtStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public static String mt2Mx(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        SwiftTranslationReport str = new Mt2MxCreatorManager().mt2mx(mtStr, outPutFilePath, extraMap);
        return str.getMessage();
    }

    public static String mt2Mx(String mtFilePath, boolean filePathFlag, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        if (filePathFlag) {
            File file = new File(mtFilePath);
            return mt2Mx(file, outPutFilePath, extraMap);
        } else {
            return mt2Mx(mtFilePath, outPutFilePath, extraMap);
        }
    }

    public static SwiftTranslationReport mt2MxPlus(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String mtStr = FileUtils.readFileToString(file);
            return mt2MxPlus(mtStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public static SwiftTranslationReport mt2MxPlus(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        return new Mt2MxCreatorManager().mt2mx(mtStr, outPutFilePath, extraMap);
    }

    /**
     * swift xml输出mt 相关的map
     * 用于邮储版本
     * @param xmlStr
     * @param extraMap
     * @return
     * @throws SwiftException
     */
    public static Map<String, String> mx2MtMap(String xmlStr, Map<String, Object> extraMap) throws SwiftException {
        try {
            xmlStr = XmlUtil.handlingXml(xmlStr);
            SwiftTranslationReport str = mx2MtPlus(xmlStr, null, extraMap);
            Map<String, String> maps = MxMessageReader.getSwfMsgInfoViaMsg(str);
            AbstractMX abstractMx = AbstractMX.parse(xmlStr);
            if (abstractMx != null) {
                String messageType = abstractMx.getMxId().id();
                maps.put("xty", messageType);//ISO20022类型
                if (messageType.startsWith("pacs.008.001") || messageType.startsWith("pacs.009.001")) {
                    Document document = DocumentHelper.parseText(xmlStr);
                    Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
                    String bodyParentElementName = parentElementMaps.get("CdtTrfTxInf");
                    String endToEndId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".CdtTrfTxInf.PmtId.EndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                        maps.put("endToEndId", endToEndId);
                    }
                } else if (messageType.startsWith("camt.054.001")) {
                    Document document = DocumentHelper.parseText(xmlStr);
                    Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
                    String bodyParentElementName = parentElementMaps.get("Ntfctn");
                    String endToEndId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.Refs.EndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                        maps.put("endToEndId", endToEndId);
                    }
                } else if (messageType.startsWith("pacs.004.001")) {
                    Document document = DocumentHelper.parseText(xmlStr);
                    Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
                    String bodyParentElementName = parentElementMaps.get("TxInf");
                    String endToEndId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".TxInf.OrgnlEndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                        maps.put("endToEndId", endToEndId);
                    }
                }
            }
            return maps;
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public static SwiftTranslationReport mt2MxPlus(String mtFilePath, boolean filePathFlag, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        if (filePathFlag) {
            File file = new File(mtFilePath);
            return mt2MxPlus(file, outPutFilePath, extraMap);
        } else {
            return mt2MxPlus(mtFilePath, outPutFilePath, extraMap);
        }
    }

    public static String mx2Gson(File file) {
        try{
            String mtStr = FileUtils.readFileToString(file);
            return mx2Gson(mtStr);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }
    /**
     * 将MX xml转换成gson 字符串
     * @param xmlStr
     * @return
     */
    public static String mx2Gson(String xmlStr) {
        if (StringUtil.isEmpty(xmlStr)) return null;
        AbstractMX abstractMX = AbstractMX.parse(xmlStr);
        String gsonStr = abstractMX.toJson();
        return gsonStr;
    }

    public static String mx2Gson(String xmlFilePath, boolean filePathFlag) {
        if (filePathFlag) {
            File file = new File(xmlFilePath);
            return mx2Gson(file);
        } else {
            return mx2Gson(xmlFilePath);
        }
    }


    /**
     * 展示MX报文要素
     * @param xmlStr
     * @return
     */
    public static String showMxElement(String xmlStr, String localCode) {
        StringBuilder sb = new StringBuilder();
        Map<String, Object> maps = mx2Map(xmlStr, localCode);
        if (maps.size() > 0) {
            MessageUtil.showMaps(maps, sb);
        }
        return sb.toString();
    }
    /**
     * 将MX xml转换成Map<String, String>
     * 支持国际化 US CN
     * @param xmlStr
     * @return
     */
    public static Map<String, Object> mx2Map(String xmlStr, String localCode) {
        if (StringUtil.isEmpty(xmlStr)) return null;
        return new Mx2MapCreatorManager().mx2Map(xmlStr, localCode);
    }

    public static boolean validateMx(String xmlFilePath, boolean filePathFlag) {
        if (filePathFlag) {
            File file = new File(xmlFilePath);
            return validateMx(file);
        } else {
            return validateMx(xmlFilePath);
        }
    }

    public static boolean validateMx(File file) {
        try{
            String mtStr = FileUtils.readFileToString(file);
            return validateMx(mtStr);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }
    /**
     * 根据xml的内容获取对应的xsd文件并校验
     * 失败则抛出异常
     * @param xml
     * @return
     */
    public static boolean validateMx(String xml) {
        //1.获取AppHdr报文内容，根据@xmlns获取版本对应的xsd文件
        String regex = "(\\<([\\w]*:)?AppHdr[\\w\\W]*\\<\\/([\\w]*:)?AppHdr\\>)";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(xml);
        String appHdrXml = "";
        if (m.find()) {
            appHdrXml = m.group(1);
        }
        String appHdrXsdName = null;
        Optional<String> namespace = NamespaceReader.findAppHdrNamespace(xml);
        if (namespace.isPresent()) {
            MxId appHdrMxId = new MxId(namespace.get());
            appHdrXsdName = appHdrMxId.getBusinessProcess().name()
                    + appHdrMxId.getFunctionality()
                    + appHdrMxId.getVariant()
                    + appHdrMxId.getVersion();
        }
        if (StringUtil.isNotEmpty(appHdrXsdName) && StringUtil.isNotEmpty(appHdrXml)) {
            SwiftTransferUtil.schemaValidate(appHdrXsdName, appHdrXml);
        }
        //2.获取Document报文内容，根据@xmlns获取版本对应的xsd文件
        regex = "(\\<([\\w]*:)?Document[\\w\\W]*\\<\\/([\\w]*:)?Document\\>)";
        p = Pattern.compile(regex);
        m = p.matcher(xml);
        String documentXml = "";
        if (m.find()) {
            documentXml = m.group(1);
        }
        String documentXsdName = "";
        namespace = NamespaceReader.findDocumentNamespace(xml);
        if (namespace.isPresent()) {
            MxId documentMxId = new MxId(namespace.get());
            documentXsdName = documentMxId.getBusinessProcess().name()
                    + documentMxId.getFunctionality()
                    + documentMxId.getVariant()
                    + documentMxId.getVersion();
        }
        if (StringUtil.isNotEmpty(documentXsdName) && StringUtil.isNotEmpty(documentXml)) {
            SwiftTransferUtil.schemaValidate(documentXsdName, documentXml);
        }
        return true;
    }

    /**
     * MX 报文转json要素
     * @param xmlStr
     * @return
     */
    public static String mx2Element(String xmlStr) {
        return new Mx2ElementCreatorManager().mx2Element(xmlStr);
    }

    public static String mx2Element(File file) {
        try {
            String xmlStr = FileUtils.readFileToString(file);
            return mx2Element(xmlStr);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public static String mx2Element(String xmlFilePath, boolean filePathFlag) {
        if (filePathFlag) {
            File file = new File(xmlFilePath);
            return mx2Element(file);
        } else {
            return mx2Element(xmlFilePath);
        }
    }

    public static Map<String, Object> mx2ElementMaps(String xmlStr) {
        return new Mx2ElementCreatorManager().mx2ElementMaps(xmlStr);
    }

    /**
     * 从混合格式(MXMT)的报文中提取MX报文
     * @param mixStr
     * @return
     */
    public static String fetchXmlFromMixMessage(String mixStr) {
        String regex = "(\\<([\\w]*:)?AppHdr[\\w\\W]*\\<\\/([\\w]*:)?AppHdr\\>)";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(mixStr);
        String appHdrXml = "";
        if (m.find()) {
            appHdrXml = m.group(1);
        }
        regex = "(\\<([\\w]*:)?Document[\\w\\W]*\\<\\/([\\w]*:)?Document\\>)";
        p = Pattern.compile(regex);
        m = p.matcher(mixStr);
        String documentXml = "";
        if (m.find()) {
            documentXml = m.group(1);
        }
        return "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>"
                + Mx2MtConstants.NEW_LINE
                + "<RequestPayload>"
                + Mx2MtConstants.NEW_LINE
                + (StringUtil.isNotEmpty(appHdrXml) ? appHdrXml + Mx2MtConstants.NEW_LINE : "")
                + (StringUtil.isNotEmpty(documentXml) ? documentXml + Mx2MtConstants.NEW_LINE : "")
                + "</RequestPayload>";
    }

    public static String fetchXmlFromMixMessage(File mixFile) {
        try {
            String mixStr = FileUtils.readFileToString(mixFile);
            return fetchXmlFromMixMessage(mixStr);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public static String fetchXmlFromMixMessage(String mixFilePath, boolean filePathFlag) {
        if (filePathFlag) {
            File mixFile = new File(mixFilePath);
            return fetchXmlFromMixMessage(mixFile);
        } else {
            return fetchXmlFromMixMessage(mixFilePath);
        }
    }
    /**
     * 从混合格式(MXMT)的报文中提取MT报文
     * @param mixStr
     * @return
     */
    public static String fetchFinFromMixMessage(String mixStr) {
        String regex = "<!--(.*?)-->";
        Pattern p = Pattern.compile(regex, Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
        Matcher m = p.matcher(mixStr);
        String mt = "";
        while (m.find()) {
            String message = m.group(1);
            if (message.indexOf("{4:") > -1) {
                mt = message;
            }
        }
        mt = mt.trim().replace("^~", Mx2MtConstants.NEW_LINE);
        //去掉首行空格
        String[] mts = mt.split(Mx2MtConstants.NEW_LINE);
        mt = "";
        for (int i=0; i<mts.length; i++) {
            mt += mts[i].trim();
            if (i < (mts.length-1)) {
                mt += Mx2MtConstants.NEW_LINE;
            }
        }
        return mt;
    }

    public static String fetchFinFromMixMessage(File mixFile) {
        try {
            String mixStr = FileUtils.readFileToString(mixFile);
            return fetchFinFromMixMessage(mixStr);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public static String fetchFinFromMixMessage(String mixFilePath, boolean filePathFlag) {
        if (filePathFlag) {
            File mixFile = new File(mixFilePath);
            return fetchFinFromMixMessage(mixFile);
        } else {
            return fetchFinFromMixMessage(mixFilePath);
        }
    }
}
