package com.brilliance.swift.context;

import java.io.Serializable;
import java.util.*;

public class ContextImpl implements Context, Serializable {

    private static final long serialVersionUID = -4922248550014245078L;
    /**
     * The underlying container implementation
     */
    private Map<String, Object> map = new HashMap<String, Object>();

    @Override
    public Object get(String identifier) {
        Object obj = map.get(identifier);
        if (null == obj) {
            throw new RuntimeException("the context missing value for (" + identifier + "). Please join it first!");
        }
        return obj;
    }

    @Override
    public Object get(String identifier, boolean returnNull) {
        Object value = map.get(identifier);
        if(!returnNull) {
            throw new RuntimeException("the context missing value for (" + identifier + "). Please join it first!");
        }
        return value;
    }

    @Override
    public void set(String identifier, Object object) {
        map.put(identifier, object);
    }

    @Override
    public Context setDelegate(Context delegate) {
        if (delegate instanceof ContextImpl) {
            map.putAll(((ContextImpl)delegate).map);
        }
        return this;
    }

    @Override
    public void clear() {
        map.clear();
    }

    @Override
    public void remove(String identifier) {
        map.remove(identifier);
    }

    @Override
    public void set(Object object) {
        this.set(object.getClass(), object);
    }

    @Override
    public void set(Class<?> cls, Object object) {
        this.set(cls.getName(), object);
    }

    @Override
    public <T> T get(Class<T> cls) {
        return cls.cast(get(cls.getName()));
    }

    @Override
    public void setList(Class<?> objType, List<?> objects) {
        this.set(objType.getName() + "List", objects);
    }

    @Override
    public <T> List<T> getList(Class<T> objType) {
        @SuppressWarnings("unchecked")
        List<T> list = (List<T>)get(objType.getName() + "List");
        return list;
    }

    @Override
    public <T> List<T> getList(Class<T> objType, boolean returnNull) {
        @SuppressWarnings("unchecked")
        List<T> list = (List<T>)get(objType.getName() + "List", returnNull);
        return list;
    }
    /**
     * Copies every mapping in the specified <code>paramMap</code> to this Map.
     * @param paramMap
     *        - Map, the map to copy mappings from
     */
    public void putAll(Map<?, ?> paramMap) {
        if (null == paramMap || paramMap.isEmpty()) {
            return;
        }
        paramMap.forEach((key, value) -> map.put(key.toString(), value));
    }
}
