package com.brilliance.swift.element2mx;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Method;
import java.util.*;

public abstract class AbstractElement2MxCreator implements Element2MxCreator{

    protected Map<String, Object> jsonMaps = new HashMap<>();

    /**
     * 目标xml
     */
    protected String xmlStr;

    protected Properties properties;

    public String getXmlStr() {
        return xmlStr;
    }

    public void setXmlStr(String xmlStr) {
        this.xmlStr = xmlStr;
    }

    protected Map<String, Object> elementMaps = new HashMap<>();

    public Map<String, Object> getElementMaps() {
        return elementMaps;
    }

    public void setElementMaps(Map<String, Object> elementMaps) {
        this.elementMaps = elementMaps;
    }

    /**
     * 判断节点是否是数组，应用于putObj方法
     * @param key
     * @return
     */
    protected boolean isArray(String key) {
        return false;
    }

    /**
     * 重新build Properties文件
     */
    protected void rebuildProperties() {

    }

    /**
     * 反射方法逻辑
     * @param methodName
     * @param where
     * @param maps
     * @param value
     */
    private void invokeHere(String methodName, Object where, Map<String, Object> maps, Object value) {
        try {
            Method method = getClass().getMethod(methodName, maps.getClass(), new Object().getClass());
            method.invoke(where, maps, value);
        } catch (NoSuchMethodException e) {
            throw new SwiftException("Method " + methodName + " does not exist in " + getClass());
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    @Override
    public void preProcess() {
        String identifier = (String) elementMaps.get("messageType");
        jsonMaps.put("identifier", identifier);
        String fileName = "/template/"+identifier+".properties";
        InputStream resourceAsStream = AbstractElement2MxCreator.class.getResourceAsStream(fileName);
        if (resourceAsStream == null) {
            fileName = "/template/"+identifier.substring(0, 10)+".properties";
            resourceAsStream = AbstractElement2MxCreator.class.getResourceAsStream(fileName);
        }
        try {
            properties = new Properties();
            properties.load(resourceAsStream);
            //重新编辑配置文件
            rebuildProperties();
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    @Override
    public void build() {
        buildMap(jsonMaps, elementMaps, properties);
    }

    protected void buildMap(Map<String, Object> sourceMap, Map<String, Object> targetMap, Properties properties) {
        //循环遍历elementMaps
        Set<String> keys = targetMap.keySet();
        for (String key : keys) {
            if (properties.get(key) != null) {
                String keyPath = (String) properties.get(key);
                if (keyPath.startsWith("@")) {
                    String methodName = keyPath.substring(1);
                    String[] methodNames = methodName.split("&");
                    List<Object> obj = new ArrayList<>();
                    obj.add(targetMap.get(key));
                    if (methodNames.length > 1) {
                        for (int i=1; i<methodNames.length; i++) {
                            obj.add(methodNames[i]);
                        }
                    }
                    invokeHere(methodNames[0], this, sourceMap, obj);
                    continue;
                }
                //以 ？分隔
                String[] keyPaths = keyPath.split("\\?");
                for (String path : keyPaths) {
                    //过滤数据类型&
                    if (path.indexOf("&") > -1) {
                        path = path.substring(0, path.indexOf("&"));
                    }
                    if (path.indexOf("#") > -1) {
                        String[] paths = path.split("#");
                        String subPropName = paths[1];
                        String fileName = "/template/"+subPropName+".properties";
                        InputStream resourceAsStream = AbstractElement2MxCreator.class.getResourceAsStream(fileName);
                        if (resourceAsStream != null) { //读取子配置文件
                            try {
                                Properties subProperties = new Properties();
                                subProperties.load(resourceAsStream);
                                Object obj = processSubProperties(targetMap.get(key), subProperties);
                                if (obj != null) {
                                    putObj(sourceMap, paths[0], obj);
                                }
                            } catch (IOException e) {
                                throw new SwiftException(e.getMessage());
                            }
                        }
                    } else {
                        putObj(sourceMap, path, targetMap.get(key));
                    }
                }
            }
        }
    }
    /**
     * 处理子配置文件逻辑
     */
    protected Object processSubProperties(Object keyV, Properties subProperties) {
        if (keyV instanceof JSONArray) {
            JSONArray jsonArray = new JSONArray();
            JSONArray keyVJsonArray = (JSONArray)keyV;
            for (int i=0; i<keyVJsonArray.size(); i++) {
                Map<String, Object> map = new HashMap<>();
                Map<String, Object> keyVMap = (Map<String, Object>)keyVJsonArray.get(i);
                buildMap(map, keyVMap, subProperties);
                jsonArray.add(map);
            }
            return jsonArray;
        } else /*if (keyV instanceof JSONObject)*/ {
            Map<String, Object> map = new HashMap<>();
            Map<String, Object> keyVMap = (Map<String, Object>)keyV;
            buildMap(map, keyVMap, subProperties);
            return map;
        }
    }
    /**
     * 源map中通过指定的路径存放对象
     * @param fullPath - 全路径, 以 . 分隔
     * @param object - 目标对象
     */
    protected void putObj(Map<String, Object> sourceMap, String fullPath, Object object) {
        if (sourceMap == null || StringUtil.isEmpty(fullPath)) {
            return;
        }
        String[] fullPaths = fullPath.split("\\.");
        String parentPath = "";
        Map<String, Object> map = sourceMap;
        for (int i=0; i<fullPaths.length; i++) {
            if (i > 0) parentPath = fullPaths[i-1];
            String path = fullPaths[i];
            if (i == fullPaths.length-1) {
                map.put(path, object);
            } else {
                if (map.containsKey(path)) {
                    if (isArray(path) || isArray(parentPath+"."+path)) {
                        JSONArray jsonArray = (JSONArray)map.get(path);
                        map = (Map<String, Object>)jsonArray.get(0);
                    } else {
                        map = (Map<String, Object>)map.get(path);
                    }
                } else {
                    if (isArray(path)|| isArray(parentPath+"."+path)) {
                        JSONArray jsonArray = new JSONArray();
                        map.put(path, jsonArray);
                        Map<String, Object> subMap = new HashMap<>();
                        jsonArray.add(subMap);
                        map = subMap;
                    } else {
                        Map<String, Object> subMap = new HashMap<>();
                        map.put(path, subMap);
                        map = subMap;
                    }
                }
            }
        }
    }

    protected Object getObj(Map<String, Object> sourceMap, String fullPath) {
        if (sourceMap == null || StringUtil.isEmpty(fullPath)) {
            return null;
        }
        String[] fullPaths = fullPath.split("\\.");
        String parentPath = "";
        Map<String, Object> map = sourceMap;
        for (int i=0; i<fullPaths.length; i++) {
            if (i > 0) parentPath = fullPaths[i-1];
            String path = fullPaths[i];
            if (i == fullPaths.length-1) {
                return map.get(path);
            } else {
                if (map.containsKey(path)) {
                    if (isArray(path) || isArray(parentPath+"."+path)) {
                        JSONArray jsonArray = (JSONArray)map.get(path);
                        map = (Map<String, Object>)jsonArray.get(0);
                    } else {
                        map = (Map<String, Object>)map.get(path);
                    }
                } else {
                    if (isArray(path)|| isArray(parentPath+"."+path)) {
                        JSONArray jsonArray = new JSONArray();
                        map.put(path, jsonArray);
                        Map<String, Object> subMap = new HashMap<>();
                        jsonArray.add(subMap);
                        map = subMap;
                    } else {
                        Map<String, Object> subMap = new HashMap<>();
                        map.put(path, subMap);
                        map = subMap;
                    }
                }
            }
        }
        return null;
    }

    @Override
    public void postProcess() {
        String swiftGsonStr = new JSONObject(jsonMaps).toJSONString();
        AbstractMX abstractMX = AbstractMX.fromJson(swiftGsonStr);
        xmlStr = abstractMX.message();
    }
}
