package com.brilliance.swift.element2mx;

import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.element2mx.camt029001.Element2MxCamt029001Creator;
import com.brilliance.swift.element2mx.camt053001.Element2MxCamt053001Creator;
import com.brilliance.swift.element2mx.camt054001.Element2MxCamt054001Creator;
import com.brilliance.swift.element2mx.camt056001.Element2MxCamt056001Creator;
import com.brilliance.swift.element2mx.pacs008001.Element2MxPacs008001Creator;
import com.brilliance.swift.element2mx.pacs009001.Element2MxPacs009001Creator;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.StringUtil;

import java.util.Map;

public class Element2MxCreatorManager {

    public String element2Mx(String jsonStr) throws SwiftException {
        Map<String, Object> elementMaps = (Map<String, Object>)JSONObject.parse(jsonStr);
        String messageType = (String)elementMaps.get("messageType");
        if (StringUtil.isEmpty(messageType)) {
            throw new SwiftException("找不到MX类型");
        }
        AbstractElement2MxCreator creator = getCreator(messageType);
        creator.setElementMaps(elementMaps);
        creator.preProcess();
        creator.build();
        creator.postProcess();
        return creator.getXmlStr();
    }

    public AbstractElement2MxCreator getCreator(String messageType) {
        if (messageType.matches("pacs008001[0-9]{2}")) {
            return new Element2MxPacs008001Creator();
        } else if (messageType.matches("pacs009001[0-9]{2}")) {
            return new Element2MxPacs009001Creator();
        } else if (messageType.matches("camt053001[0-9]{2}")) {
            return new Element2MxCamt053001Creator();
        } else if (messageType.matches("camt054001[0-9]{2}")) {
            return new Element2MxCamt054001Creator();
        } else if (messageType.matches("camt029001[0-9]{2}")) {
            return new Element2MxCamt029001Creator();
        } else if (messageType.matches("camt056001[0-9]{2}")) {
            return new Element2MxCamt056001Creator();
        } else {
            throw new SwiftException("无效的MX类型:" + messageType);
        }
    }
}
