package com.brilliance.swift.mt2SwiftDto;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.camt053001.Mt2SwiftDtoPCamt053001Creator;
import com.brilliance.swift.mt2SwiftDto.camt054001.Mt2SwiftDtoPCamt054001Creator;
import com.brilliance.swift.mt2SwiftDto.pacs008001.Mt2SwiftDtoPacs008001Creator;
import com.brilliance.swift.mt2SwiftDto.pacs009001.Mt2SwiftDtoPacs009001Creator;
import com.brilliance.swift.vo.SwiftDto;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.List;
import java.util.Map;

public class Mt2SwiftDtoCreateManager {

    public AbstractMT abstractMT = null;

    public void init(String mtStr) {
        try {
            abstractMT = AbstractMT.parse(mtStr);
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public SwiftDto convert(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        init(mtStr);
        AbstractMt2SwiftDtoCreator creator = getMt2MxCreator();
        Mt2SwiftDtoContext context = new Mt2SwiftDtoContext();
        context.set(AbstractMT.class, abstractMT);
        context.set(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OUTPUT_FILE_PATH, outPutFilePath);
        context.putAll(extraMap);
        creator.setContext(context);
        creator.preProcess();
        List<Mt2SwiftDtoParseFields> parseFields = creator.getParseFieldsList();
        for (int i=0; i<parseFields.size(); i++) {
            AbstractMt2SwiftDtoParseFields parseField = (AbstractMt2SwiftDtoParseFields) parseFields.get(i);
            parseField.setContext(context);
            parseField.parseFields();
        }
        creator.postProcess();
        return (SwiftDto) context.get(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OBJ);
    }

    public AbstractMt2SwiftDtoCreator getMt2MxCreator() throws SwiftException {
        String messageType = abstractMT.getMessageType();
        if ("103".equals(messageType)) {
            return new Mt2SwiftDtoPacs008001Creator();
        } else if ("202".equals(messageType)) {
            return new Mt2SwiftDtoPacs009001Creator();
        } else if("900".equals(messageType)||"910".equals(messageType)){
            return new Mt2SwiftDtoPCamt054001Creator();
        } else if("940".equals(messageType)||"950".equals(messageType)){
            return new Mt2SwiftDtoPCamt053001Creator();
        } else {
            throw new SwiftException("Invalid message type");
        }
    }
}
