package com.brilliance.swift.mt2SwiftDto.camt053001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CashBalance;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.field.Field62F;
import com.prowidesoftware.swift.model.field.Field62M;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt9xx.MT940;
import com.prowidesoftware.swift.model.mt9xx.MT950;

/**
 * @author zh
 * @create 2022-04-24 14:59
 */
public class Camt053001Parse62aField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = context.get(BankToCustomerStatement.class);
            Field62F field62F = getField62F();
            if (field62F != null) {
                CashBalance cashBalance = new CashBalance();
                cashBalance.setCode(BalanceTypeCode.CLBD);
                cashBalance.setCdtDbtCode("D".equals(field62F.getDCMark())? CdtDbtCode.DBIT:CdtDbtCode.CRDT);
                cashBalance.setDate(DateUtil.parseDate("20"+field62F.getDate(), "yyyyMMdd"));
                CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                ccyFormatAmount.setCcy(field62F.getCurrency());
                ccyFormatAmount.setAmt(field62F.amount());
                cashBalance.setAmt(ccyFormatAmount);
                bankToCustomerStatement.setClosingBalance(cashBalance);
            } else {
                Field62M field62M = getField62M();
                if (field62M != null) {
                    CashBalance cashBalance = new CashBalance();
                    cashBalance.setCode(BalanceTypeCode.ITBD);
                    cashBalance.setCdtDbtCode("D".equals(field62M.getDCMark())? CdtDbtCode.DBIT:CdtDbtCode.CRDT);
                    cashBalance.setDate(DateUtil.parseDate("20"+field62M.getDate(), "yyyyMMdd"));
                    CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                    ccyFormatAmount.setCcy(field62M.getCurrency());
                    ccyFormatAmount.setAmt(field62M.amount());
                    cashBalance.setAmt(ccyFormatAmount);
                    bankToCustomerStatement.setClosingBalance(cashBalance);
                }
            }
        }catch (Exception e){
            throw new SwiftException(e.getMessage());
        }
    }

    private Field62F getField62F() {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if ("940".equals(abstractMT.getMessageType())) {
            MT940 mt940 = (MT940) context.get(AbstractMT.class);
            return mt940.getField62F();
        } else {
            MT950 mt950 = (MT950) context.get(AbstractMT.class);
            return mt950.getField62F();
        }
    }

    private Field62M getField62M() {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if ("940".equals(abstractMT.getMessageType())) {
            MT940 mt940 = (MT940) context.get(AbstractMT.class);
            return mt940.getField62M();
        } else {
            MT950 mt950 = (MT950) context.get(AbstractMT.class);
            return mt950.getField62M();
        }
    }
}
