package com.brilliance.swift.mt2SwiftDto.camt053001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CashBalance;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.field.Field64;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt9xx.MT940;
import com.prowidesoftware.swift.model.mt9xx.MT950;

/**
 * @author zh
 * @create 2022-04-24 14:59
 */
public class Camt053001Parse64Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = context.get(BankToCustomerStatement.class);
            Field64 field64 = getField64();
            if (field64 != null) {
                CashBalance cashBalance = new CashBalance();
                cashBalance.setCode(BalanceTypeCode.CLAV);
                cashBalance.setCdtDbtCode("D".equals(field64.getDCMark())? CdtDbtCode.DBIT:CdtDbtCode.CRDT);
                cashBalance.setDate(DateUtil.parseDate("20"+field64.getDate(), "yyyyMMdd"));
                CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                ccyFormatAmount.setCcy(field64.getCurrency());
                ccyFormatAmount.setAmt(field64.amount());
                cashBalance.setAmt(ccyFormatAmount);
                bankToCustomerStatement.setClosingAvailableBalance(cashBalance);
            }
        }catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private Field64 getField64() {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if ("940".equals(abstractMT.getMessageType())) {
            MT940 mt940 = (MT940) context.get(AbstractMT.class);
            return mt940.getField64();
        } else {
            MT950 mt950 = (MT950) context.get(AbstractMT.class);
            return mt950.getField64();
        }
    }
}
