package com.brilliance.swift.mt2SwiftDto.camt054001;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoCreator;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoContextIdentifier;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoParseFields;
import com.brilliance.swift.mt2SwiftDto.camt054001.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.BankToCustomerDebitCreditNotification;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.common.TransactionReference;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * @author zh
 * @create 2022-04-24 14:50
 */
public class Mt2SwiftDtoPCamt054001Creator extends AbstractMt2SwiftDtoCreator {

    @Override
    public void preProcess() throws SwiftException {
        SwiftHeader swiftHeader = buildSwiftHeader();
        swiftHeader.setMessageDefId("camt.054.001.09");
        swiftHeader.setBusinessService("swift.cbprplus.02");
        swiftHeader.setMessageType("camt.054.001");
        swiftHeader.setVersion("08");
        BankToCustomerDebitCreditNotification bankToCustomerDebitCreditNotification = new BankToCustomerDebitCreditNotification();
        bankToCustomerDebitCreditNotification.setSwiftHeader(swiftHeader);
        TransactionReference txnRef = buildTxnRef();
        bankToCustomerDebitCreditNotification.setTxnRef(txnRef);
        context.set(bankToCustomerDebitCreditNotification);
    }
    @Override
    public List<Mt2SwiftDtoParseFields> getParseFieldsList() throws SwiftException {
        List<Mt2SwiftDtoParseFields> list = new ArrayList<>();
        list.add(new Camt054001Parse13DField());
        list.add(new Camt054001Parse20Field());
        list.add(new Camt054001Parse21Field());
        list.add(new Camt054001Parse25aField());
        list.add(new Camt054001Parse32aField());
        list.add(new Camt054001Parse50aField());
        list.add(new Camt054001Parse52aField());
        list.add(new Camt054001Parse56aField());
        list.add(new Camt054001Parse72Field());
        return list;
    }

    @Override
    public void postProcess() throws SwiftException {
        try {
            String outputFilePath = (String)context.get(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OUTPUT_FILE_PATH, true);
            BankToCustomerDebitCreditNotification bankToCustomerDebitCreditNotification = context.get(BankToCustomerDebitCreditNotification.class);
            context.set(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OBJ, bankToCustomerDebitCreditNotification);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                bankToCustomerDebitCreditNotification.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
