package com.brilliance.swift.mt2SwiftDto.camt054001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.BankToCustomerDebitCreditNotification;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field52A;
import com.prowidesoftware.swift.model.field.Field52D;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt9xx.MT900;
import com.prowidesoftware.swift.model.mt9xx.MT910;

/**
 * @author zh
 * @create 2022-04-24 14:59
 */
public class Camt054001Parse52aField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            BankToCustomerDebitCreditNotification bankToCustomerDebitCreditNotification = context.get(BankToCustomerDebitCreditNotification.class);
            if(context.get(AbstractMT.class).getMessageType().equals("900")){
                MT900 mt900 = (MT900) context.get(AbstractMT.class);
                PartyDto partyDto = null;
                if(mt900.getField52A()!=null){
                    Field52A field52A = mt900.getField52A();
                    partyDto = new PartyDto();
                    if (StringUtil.isNotEmpty(field52A.getAccount())) {
                        partyDto = buildPartyAccount(partyDto, field52A.getLine(1));
                    }
                    partyDto.setPartyBic(field52A.getBIC());
                }else if (mt900.getField52D() != null) {
                    Field52D field52D = mt900.getField52D();
                    partyDto = new PartyDto();
                    if (StringUtil.isNotEmpty(field52D.getAccount())) {
                        partyDto = buildPartyAccount(partyDto, field52D.getLine(1));
                    }
                    partyDto.setPartyName(field52D.getNameAndAddressLine1());
                    if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine2())) {
                        partyDto.addAddress(field52D.getNameAndAddressLine2());
                    }
                    if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine3())) {
                        partyDto.addAddress(field52D.getNameAndAddressLine3());
                    }
                    if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine4())) {
                        partyDto.addAddress(field52D.getNameAndAddressLine4());
                    }
                }
                if (partyDto != null) {
                    bankToCustomerDebitCreditNotification.setDebitAgtParty(partyDto);
                }
            }else if((context.get(AbstractMT.class).getMessageType().equals("910"))){
                MT910 mt910 = (MT910) context.get(AbstractMT.class);
                PartyDto partyDto = null;
                if(mt910.getField52A()!=null){
                    Field52A field52A = mt910.getField52A();
                    partyDto = new PartyDto();
                    if (StringUtil.isNotEmpty(field52A.getAccount())) {
                        partyDto = buildPartyAccount(partyDto, field52A.getLine(1));
                    }
                    partyDto.setPartyBic(field52A.getBIC());
                }else if (mt910.getField52D() != null) {
                    Field52D field52D = mt910.getField52D();
                    partyDto = new PartyDto();
                    if (StringUtil.isNotEmpty(field52D.getAccount())) {
                        partyDto = buildPartyAccount(partyDto, field52D.getLine(1));
                    }
                    partyDto.setPartyName(field52D.getNameAndAddressLine1());
                    if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine2())) {
                        partyDto.addAddress(field52D.getNameAndAddressLine2());
                    }
                    if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine3())) {
                        partyDto.addAddress(field52D.getNameAndAddressLine3());
                    }
                    if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine4())) {
                        partyDto.addAddress(field52D.getNameAndAddressLine4());
                    }
                }
                if (partyDto != null) {
                    bankToCustomerDebitCreditNotification.setDebitAgtParty(partyDto);
                }
            }
        }catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
