package com.brilliance.swift.mt2SwiftDto.pacs008001;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoCreator;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoContextIdentifier;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoParseFields;
import com.brilliance.swift.mt2SwiftDto.pacs008001.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.common.TransactionReference;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

public class Mt2SwiftDtoPacs008001Creator extends AbstractMt2SwiftDtoCreator {



    @Override
    public void preProcess() throws SwiftException {
        SwiftHeader swiftHeader = buildSwiftHeader();
        swiftHeader.setMessageDefId("pacs.008.001.09");
        swiftHeader.setBusinessService("swift.cbprplus.02");
        swiftHeader.setMessageType("pacs.008.001");
        swiftHeader.setVersion("09");
        VoCustomerCreditTransfer customerCreditTransfer = new VoCustomerCreditTransfer();
        customerCreditTransfer.setSwiftHeader(swiftHeader);
        TransactionReference txnRef = buildTxnRef();
        customerCreditTransfer.setTxnRef(txnRef);
        context.set(customerCreditTransfer);
    }

    @Override
    public List<Mt2SwiftDtoParseFields> getParseFieldsList() throws SwiftException {
        List<Mt2SwiftDtoParseFields> list = new ArrayList<>();
        list.add(new Pacs00801Parse20Field());
        list.add(new Pacs00801Parse13CField());
        list.add(new Pacs00801Parse23BField());
        list.add(new Pacs00801Parse23EField());
        list.add(new Pacs00801Parse26TField());
        list.add(new Pacs00801Parse32AField());
        list.add(new Pacs00801Parse33BField());
        list.add(new Pacs00801Parse36Field());
        list.add(new Pacs00801Parse50Field());
        list.add(new Pacs00801Parse52Field());
        list.add(new Pacs00801Parse53Field());
        list.add(new Pacs00801Parse54Field());
        list.add(new Pacs00801Parse55Field());
        list.add(new Pacs00801Parse56Field());
        list.add(new Pacs00801Parse57Field());
        list.add(new Pacs00801Parse59Field());
        list.add(new Pacs00801Parse70Field());
        list.add(new Pacs00801Parse71Field());
        list.add(new Pacs00801Parse72Field());
        list.add(new Pacs00801Parse77BField());
        return list;
    }

    @Override
    public void postProcess() throws SwiftException {
        try {
            String outputFilePath = (String)context.get(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OUTPUT_FILE_PATH, true);
            VoCustomerCreditTransfer customerCreditTransfer = context.get(VoCustomerCreditTransfer.class);
            context.set(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OBJ, customerCreditTransfer);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                customerCreditTransfer.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
