package com.brilliance.swift.mt2SwiftDto.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.prowidesoftware.swift.model.field.Field13C;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.util.Date;
import java.util.List;

public class Pacs009001Parse13CField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            List<Field13C> field13CList = getField13CList();
            if (field13CList.size() > 0) {
                String dateStr = DateUtil.formatNow("yyyy-MM-dd'T'HH:mm:ss.SSS");
                for (int i=0; i<field13CList.size(); i++) {
                    Field13C field13C = field13CList.get(i);
                    String timeStr = dateStr.substring(0, 11)
                                    + field13C.getTime().substring(0,2)
                                    + ":" + field13C.getTime().substring(2,4)
                                    + ":00.000"
                                    + field13C.getSign()
                                    + field13C.getOffset().substring(0, 2)
                                    + ":" + field13C.getOffset().substring(2, 4);
                    XMLGregorianCalendar dateTime = DatatypeFactory.newInstance().newXMLGregorianCalendar(timeStr);
                    Date date = DateUtil.parseDate(dateTime);
                    if ("SNDTIME".equals(field13C.getCode())) {
                        financialInstitutionCreditTransfer.setDebitDate(date);
                    } else if ("RNCTIME".equals(field13C.getCode())) {
                        financialInstitutionCreditTransfer.setCreditDate(date);
                    } else if ("CLSTIME".equals(field13C.getCode())) {
                        financialInstitutionCreditTransfer.setClsDate(date);
                    }
                }
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private List<Field13C> getField13CList() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField13C();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField13C();
        }
    }
}
