package com.brilliance.swift.mt2SwiftDto.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.*;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse57Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField57A() != null) {
                Field57A field57A = getField57A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field57A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field57A.getLine(1));
                }
                partyDto.setPartyBic(field57A.getBIC());
            } else if (getField57B() != null) {
                Field57B field57B = getField57B();
                //TODO
            } else if (getField57D() != null) {
                Field57D field57D = getField57D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field57D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field57D.getLine(1));
                }
                partyDto.setPartyName(field57D.getName());
                if (StringUtil.isNotEmpty(field57D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field57D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field57D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field57D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field57D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field57D.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                financialInstitutionCreditTransfer.setCreditAgtParty(partyDto);
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private Field57A getField57A() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            Field57A field57A = null;
            if (mt202Cov.getSequenceA() != null) {
                field57A = (Field57A)mt202Cov.getSequenceA().getFieldByName("57A");
            }
            return field57A;
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField57A();
        }
    }

    private Field57B getField57B() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            Field57B field57B = null;
            if (mt202Cov.getSequenceA() != null) {
                field57B = (Field57B)mt202Cov.getSequenceA().getFieldByName("57B");
            }
            return field57B;
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField57B();
        }
    }

    private Field57D getField57D() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            Field57D field57D = null;
            if (mt202Cov.getSequenceA() != null) {
                field57D = (Field57D)mt202Cov.getSequenceA().getFieldByName("57D");
            }
            return field57D;
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField57D();
        }
    }
}
