package com.brilliance.swift.mt2SwiftDto.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field58A;
import com.prowidesoftware.swift.model.field.Field58D;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse58Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField58D() != null) {
                Field58D field58D = getField58D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field58D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field58D.getLine(1));
                }
                partyDto.setPartyName(field58D.getNameAndAddressLine1());
                if (StringUtil.isNotEmpty(field58D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field58D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field58D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field58D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field58D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field58D.getNameAndAddressLine4());
                }
            } else if (getField58A() != null) {
                Field58A field58A = getField58A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field58A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field58A.getLine(1));
                }
                partyDto.setPartyBic(field58A.getBIC());
            }
            if (partyDto != null) {
                financialInstitutionCreditTransfer.setCreditParty(partyDto);
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private Field58A getField58A() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField58A();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField58A();
        }
    }

    private Field58D getField58D() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField58D();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField58D();
        }
    }
}
