package com.brilliance.swift.mt2SwiftDto.pacs009001.impl.cov;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field52A;
import com.prowidesoftware.swift.model.field.Field52D;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse52BField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            if (!isCov()) return;
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField52A() != null) {
                Field52A field52A = getField52A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field52A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field52A.getLine(1));
                }
                partyDto.setPartyBic(field52A.getBIC());
            } else if (getField52D() != null) {
                Field52D field52D = getField52D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field52D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field52D.getLine(1));
                }
                partyDto.setPartyName(field52D.getNameAndAddressLine1());
                if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field52D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field52D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field52D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field52D.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                VoCustomerCreditTransfer customerCreditTransfer = financialInstitutionCreditTransfer.getUnderCustomerCreditTransfer();
                if (customerCreditTransfer == null) {
                    customerCreditTransfer = new VoCustomerCreditTransfer();
                }
                customerCreditTransfer.setDebitAgtParty(partyDto);
                financialInstitutionCreditTransfer.setUnderCustomerCreditTransfer(customerCreditTransfer);
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private Field52A getField52A() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field52A field52A = null;
        if (mt202Cov.getSequenceB() != null) {
            field52A = (Field52A)mt202Cov.getSequenceB().getFieldByName("52A");
        }
        return field52A;
    }

    private Field52D getField52D() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field52D field52D = null;
        if (mt202Cov.getSequenceB() != null) {
            field52D = (Field52D)mt202Cov.getSequenceB().getFieldByName("52D");
        }
        return field52D;
    }
}
