package com.brilliance.swift.mt2SwiftDto.pacs009001.impl.cov;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field56A;
import com.prowidesoftware.swift.model.field.Field56C;
import com.prowidesoftware.swift.model.field.Field56D;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse56BField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            if (!isCov()) return;
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField56A() != null) {
                Field56A field56A = getField56A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field56A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field56A.getLine(1));
                }
                partyDto.setPartyBic(field56A.getBIC());
            } else if (getField56C() != null) {
                Field56C field56C = getField56C();
                partyDto = new PartyDto();
                partyDto = buildPartyAccount(partyDto, field56C.getValue());
            } else if (getField56D() != null) {
                Field56D field56D = getField56D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field56D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field56D.getLine(1));
                }
                partyDto.setPartyName(field56D.getNameAndAddressLine1());
                if (StringUtil.isNotEmpty(field56D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field56D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field56D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field56D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field56D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field56D.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                VoCustomerCreditTransfer customerCreditTransfer = financialInstitutionCreditTransfer.getUnderCustomerCreditTransfer();
                if (customerCreditTransfer == null) {
                    customerCreditTransfer = new VoCustomerCreditTransfer();
                }
                customerCreditTransfer.setIntrmyAgtParty(partyDto);
                financialInstitutionCreditTransfer.setUnderCustomerCreditTransfer(customerCreditTransfer);
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private Field56A getField56A() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field56A field56A = null;
        if (mt202Cov.getSequenceB() != null) {
            field56A = (Field56A)mt202Cov.getSequenceB().getFieldByName("56A");
        }
        return field56A;
    }

    private Field56C getField56C() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field56C field56C = null;
        if (mt202Cov.getSequenceB() != null) {
            field56C = (Field56C)mt202Cov.getSequenceB().getFieldByName("56C");
        }
        return field56C;
    }

    private Field56D getField56D() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field56D field56D = null;
        if (mt202Cov.getSequenceB() != null) {
            field56D = (Field56D)mt202Cov.getSequenceB().getFieldByName("56D");
        }
        return field56D;
    }
}
