package com.brilliance.swift.mt2SwiftDto.pacs009001.impl.cov;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field57A;
import com.prowidesoftware.swift.model.field.Field57B;
import com.prowidesoftware.swift.model.field.Field57C;
import com.prowidesoftware.swift.model.field.Field57D;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse57BField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            if (!isCov()) return;
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField57A() != null) {
                Field57A field57A = getField57A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field57A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field57A.getLine(1));
                }
                partyDto.setPartyBic(field57A.getBIC());
            } else if (getField57B() != null) {
                Field57B field57B = getField57B();
                //TODO
            } else if (getField57C() != null) {
                Field57C field57C = getField57C();
                partyDto = new PartyDto();
                partyDto = buildPartyAccount(partyDto, field57C.getValue());
            } else if (getField57D() != null) {
                Field57D field57D = getField57D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field57D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field57D.getLine(1));
                }
                partyDto.setPartyName(field57D.getName());
                if (StringUtil.isNotEmpty(field57D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field57D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field57D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field57D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field57D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field57D.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                VoCustomerCreditTransfer customerCreditTransfer = financialInstitutionCreditTransfer.getUnderCustomerCreditTransfer();
                if (customerCreditTransfer == null) {
                    customerCreditTransfer = new VoCustomerCreditTransfer();
                }
                customerCreditTransfer.setCreditAgtParty(partyDto);
                financialInstitutionCreditTransfer.setUnderCustomerCreditTransfer(customerCreditTransfer);
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private Field57A getField57A() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field57A field57A = null;
        if (mt202Cov.getSequenceB() != null) {
            field57A = (Field57A)mt202Cov.getSequenceB().getFieldByName("57A");
        }
        return field57A;
    }

    private Field57B getField57B() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field57B field57B = null;
        if (mt202Cov.getSequenceB() != null) {
            field57B = (Field57B)mt202Cov.getSequenceB().getFieldByName("57B");
        }
        return field57B;
    }

    private Field57C getField57C() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field57C field57C = null;
        if (mt202Cov.getSequenceB() != null) {
            field57C = (Field57C)mt202Cov.getSequenceB().getFieldByName("57C");
        }
        return field57C;
    }

    private Field57D getField57D() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field57D field57D = null;
        if (mt202Cov.getSequenceB() != null) {
            field57D = (Field57D)mt202Cov.getSequenceB().getFieldByName("57D");
        }
        return field57D;
    }
}
