package com.brilliance.swift.mt2SwiftDto.pacs009001.impl.cov;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.InstructionForCreditAgent;
import com.brilliance.swift.vo.common.InstructionForNextAgent;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.Field72;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse72BField extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            if (!isCov()) return;
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            Field72 field72 = getField72();
            if (field72 != null) {
                VoCustomerCreditTransfer customerCreditTransfer = financialInstitutionCreditTransfer.getUnderCustomerCreditTransfer();
                if (customerCreditTransfer == null) {
                    customerCreditTransfer = new VoCustomerCreditTransfer();
                }
                String field72Value = field72.getValue().replace("\r\n//", "");
                String[] lines = field72Value.split("\r\n");
                for (int i=0; i<lines.length; i++) {
                    String line = lines[i];
                    if (line.startsWith("/INS/")) {
                        PartyDto party = new PartyDto();
                        String lineStr = line.substring(5);
                        if (SwiftTransferUtil.isBIC(lineStr)) {
                            party.setPartyBic(lineStr);
                        } else {
                            party.setPartyName(lineStr);
                        }
                        customerCreditTransfer.setPreInstgAgtParty(party);
                    }
                    if (line.startsWith("/ACC/")) {
                        InstructionForCreditAgent instForCrdAgt = new InstructionForCreditAgent();
                        instForCrdAgt.setInstrInf(line.substring(5));
                        customerCreditTransfer.setInstForCrdAgt(instForCrdAgt);
                    }
                    if (line.startsWith("/REC/")) {
                        InstructionForNextAgent instForNxtAgt = new InstructionForNextAgent();
                        instForNxtAgt.setInstrInf(line.substring(5));
                        customerCreditTransfer.setInstForNxtAgt(instForNxtAgt);
                    }
                }
                financialInstitutionCreditTransfer.setUnderCustomerCreditTransfer(customerCreditTransfer);
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private Field72 getField72() {
        MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
        Field72 field72 = null;
        if (mt202Cov.getSequenceB() != null) {
            field72 = (Field72)mt202Cov.getSequenceB().getFieldByName("72");
        }
        return field72;
    }
}
