package com.brilliance.swift.mt2mx;

import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.vo.SwiftTranslationErrorInfo;
import com.brilliance.swift.vo.SwiftTranslationReport;
import com.brilliance.swift.vo.common.MessagePriority;
import com.prowidesoftware.swift.model.SwiftBlock5;
import com.prowidesoftware.swift.model.SwiftBlock5Field;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import javax.xml.datatype.DatatypeConfigurationException;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.ParseException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public abstract class AbstractMt2MxCreator implements Mt2MxCreator{

    protected Mt2MxContext context;

    public Mt2MxContext getContext() {
        return context;
    }

    public void setContext(Mt2MxContext context) {
        this.context = context;
    }

    protected Map<String, Object> jsonMaps = new HashMap<>();

    @Override
    public void preProcess() {
        SwiftTranslationReport str = new SwiftTranslationReport();
        context.set(str);
        context.set(Mt2MxContextIdentifier.MT_TO_MX_JSON_MAP, jsonMaps);
        Map<String, Object> appHdrMaps = new HashMap<>();
        jsonMaps.put("appHdr", appHdrMaps);
        AbstractMT abstractMT = context.get(AbstractMT.class);
        String senderBic = abstractMT.getSender();
        senderBic = senderBic.substring(0, 8) + senderBic.substring(9, 12);
        context.set(Mt2MxContextIdentifier.MT_SEND_BIC, senderBic);
        Map<String, Object> frMaps = new HashMap<>();
        appHdrMaps.put("fr", frMaps);
        Map<String, Object> frFiIdMaps = new HashMap<>();
        frMaps.put("fiId", frFiIdMaps);
        Map<String, Object> frFiIdFinInstnIdMaps = new HashMap<>();
        frFiIdMaps.put("finInstnId", frFiIdFinInstnIdMaps);
        frFiIdFinInstnIdMaps.put("bicfi", senderBic);
        String receiverBic = abstractMT.getReceiver();
        receiverBic = receiverBic.substring(0, 8) + receiverBic.substring(9, 12);
        context.set(Mt2MxContextIdentifier.MT_RECEIVE_BIC, receiverBic);
        Map<String, Object> toMaps = new HashMap<>();
        appHdrMaps.put("to", toMaps);
        Map<String, Object> toFiIdMaps = new HashMap<>();
        toMaps.put("fiId", toFiIdMaps);
        Map<String, Object> toFiIdFinInstnIdMaps = new HashMap<>();
        toFiIdMaps.put("finInstnId", toFiIdFinInstnIdMaps);
        toFiIdFinInstnIdMaps.put("bicfi", receiverBic);
        String createDateStr = getCreateDateStr();
        appHdrMaps.put("creDt", createDateStr);
        boolean covFlag = abstractMT.getSwiftMessage().isCOV();
        if (covFlag) {
            appHdrMaps.put("bizSvc", "swift.cbprplus.cov.02");
        } else {
            appHdrMaps.put("bizSvc", "swift.cbprplus.02");
        }
        String priority = abstractMT.getMessagePriority();
        if  ("U".equals(priority)) {
            appHdrMaps.put("prty", MessagePriority.HIGH.value());
        } else { // "N".equals(priority)
            appHdrMaps.put("prty", MessagePriority.NORM.value());
        }
        SwiftBlock5 block5 = abstractMT.getSwiftMessage().getBlock5();
        if (block5 != null && block5.containsTag(SwiftBlock5Field.PDE.name())) {
            appHdrMaps.put("pssblDplct", Boolean.TRUE);
        } else {
            appHdrMaps.put("pssblDplct", Boolean.FALSE);
        }
    }

    @Override
    public void postProcess() {
        String swiftGsonStr = new JSONObject(jsonMaps).toJSONString();
        AbstractMX abstractMX = AbstractMX.fromJson(swiftGsonStr);
        String xml = abstractMX.message();
        SwiftTranslationReport str = context.get(SwiftTranslationReport.class);
        str.setMessage(xml);
        try {
            String outputFilePath = (String)context.get(Mt2MxContextIdentifier.MT_TO_MX_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                File file = new File(outputFilePath);
                if (!file.exists()) {
                    file.createNewFile();
                }
                FileOutputStream stream = new FileOutputStream(file.getAbsoluteFile());
                stream.write(xml.getBytes("UTF-8"));
                stream.close();
            }
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }
    /**
     * 公共方法
     */
    /**
     * FinInstnId.BICFI = mtBicCode
     * @param mtBicCode
     * @param maps
     */
    protected void mt_to_mxBICFI(String mtBicCode, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtBicCode)) {
            return;
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        finInstnIdMaps.put("bicfi", mtBicCode);
    }

    protected String getCreateDateStr() {
        String createDateStr = (String) context.get(Mt2MxContextIdentifier.EXTERNAL_PARAMETERS_CREATION_DATE, true);
        if (StringUtil.isEmpty(createDateStr)) {
            try {
                Date now = (Date)context.get(Mt2MxContextIdentifier.MT_TO_MX_NOW, true);
                if (now == null) {
                    now = new Date();
                    context.set(Mt2MxContextIdentifier.MT_TO_MX_NOW, now);
                }
                createDateStr = DateUtil.parseXMLGregorianCalendar(now).toXMLFormat();
            } catch (DatatypeConfigurationException e) {
                throw new SwiftException(e.getMessage());
            } catch (ParseException e) {
                throw new SwiftException(e.getMessage());
            }
        }
        return createDateStr;
    }

    /**
     * 封装报文转换详细报告
     * @param errorCode
     * @param location
     * @param originalValue
     * @return
     */
    protected void buildSTErrorInfo(String errorCode, String location, String originalValue) {
        SwiftTranslationReport str = context.get(SwiftTranslationReport.class);
        SwiftTranslationErrorInfo errorInfo = SwiftTransferUtil.getSwiftTranslationErrorInfoByErrorCode(errorCode);
        errorInfo.setLocation(location);
        errorInfo.setOriginalValue(originalValue);
        List<SwiftTranslationErrorInfo> errorInfos = str.getErrorInfos();
        boolean existFlag = false;
        for (int i=0; i<errorInfos.size(); i++) {
            if (SwiftTransferUtil.compareStErrorInfo(errorInfo, errorInfos.get(i))) {
                existFlag = true;
                break;
            }
        }
        if (!existFlag) {
            str.addErrorInfo(errorInfo);
            if ("FAILURE".equalsIgnoreCase(errorInfo.getErrorType())) {
                throw new SwiftException(location + Mx2MtConstants.NEW_LINE + "-" + errorInfo.getErrorType() + ":" + errorInfo.getDescription());
            }
        }
    }
}
