package com.brilliance.swift.mt2mx;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.constants.ERROR;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.vo.MxMtReasonCodeInfo;
import com.brilliance.swift.vo.SwiftTranslationErrorInfo;
import com.brilliance.swift.vo.SwiftTranslationReport;
import com.brilliance.swift.vo.VoSettlementMethodHelper;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.field.Field23E;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.text.ParseException;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractMt2MxParseField implements Mt2MxParseField {

    protected Mt2MxContext context;

    public Mt2MxContext getContext() {
        return context;
    }

    public AbstractMt2MxParseField setContext(Mt2MxContext context) {
        this.context = context;
        return this;
    }

    protected Map<String, Object> jsonMaps = null;

    public void initJsonMaps() {
        jsonMaps = (Map<String, Object>)context.get(Mt2MxContextIdentifier.MT_TO_MX_JSON_MAP, true);
    }

    /**
     * 封装报文转换详细报告
     * @param errorCode
     * @param location
     * @param originalValue
     * @return
     */
    protected void buildSTErrorInfo(String errorCode, String location, String originalValue) {
        SwiftTranslationReport str = context.get(SwiftTranslationReport.class);
        SwiftTranslationErrorInfo errorInfo = SwiftTransferUtil.getSwiftTranslationErrorInfoByErrorCode(errorCode);
        errorInfo.setLocation(location);
        errorInfo.setOriginalValue(originalValue);
        List<SwiftTranslationErrorInfo> errorInfos = str.getErrorInfos();
        boolean existFlag = false;
        for (int i=0; i<errorInfos.size(); i++) {
            if (SwiftTransferUtil.compareStErrorInfo(errorInfo, errorInfos.get(i))) {
                existFlag = true;
                break;
            }
        }
        if (!existFlag) {
            str.addErrorInfo(errorInfo);
            if ("FAILURE".equalsIgnoreCase(errorInfo.getErrorType())) {
                throw new SwiftException(location + Mx2MtConstants.NEW_LINE + "-" + errorInfo.getErrorType() + ":" + errorInfo.getDescription());
            }
        }
    }
    /**
     * MT 转 MX 转换函数开始
     */

    /**
     * 如果下一行是以continuePattern开始的
     * 此行不够指定长度需要后面加空格
     * @param value
     * @param maxLength
     * @return
     */
    protected String refreshValue(String value, String continuePattern, int maxLength) {
        if (StringUtil.isEmpty(value)) {
            return "";
        }
        String regex = "(.*)\\\r\\\n"+continuePattern;
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(value);
        while (m.find()) {
            String findStr = m.group(1);
            if (findStr.length() < maxLength) {
                value = value.replace(findStr, findStr+" ");
            }
        }
        return value;
    }
    /**
     * 1.如果 mtAccount 以//CH开始,Id.Othr.SchmeNm.Cd = CUID,Id.Othr.Id=mtAccount.subString(5)
     * 2.如果 mtAccount 是IBAN账户，Id.IBAN = mtAccount
     * 3.否则 Id.Othr.Id=mtAccount
     * @param mtAccount
     * @param maps(account对应的map对象)
     */
    protected void mt_to_mxPartyAccount(String mtAccount, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtAccount)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (mtAccount.startsWith("//CH") && mtAccount.length() > 4) {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtAccount.substring(4));
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>)othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", "CUID");
        } else if (mtAccount.length() > 1) {
            mtAccount = mtAccount.substring(1);
            if (SwiftTransferUtil.checkIbanAccount(mtAccount)){
                idMaps.put("iban", mtAccount);
            } else {
                Map<String, Object> othrMaps = null;
                if (idMaps.containsKey("othr")) {
                    othrMaps = (Map<String, Object>)idMaps.get("othr");
                } else {
                    othrMaps = new HashMap<>();
                    idMaps.put("othr", othrMaps);
                }
                othrMaps.put("id", mtAccount);
            }
        }
    }

    /**
     * 1.如果 mtAccount 以//CH开始,Id.Othr.SchmeNm.Cd = CUID,Id.Othr.Id=mtAccount.subString(5)
     * 2.如果长度大于34，Id.Othr.Id=mtAccount截取33位，最后一位给+
     * 3.如果 mtAccount 是IBAN账户，Id.IBAN = mtAccount
     * 4.否则 Id.Othr.Id=mtAccount
     * @param mtAccount
     * @param maps(account对应的map对象)
     */
    protected void mt_to_mxAccount35(String mtAccount, Map<String, Object> maps,String path) {
        if (StringUtil.isEmpty(mtAccount)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (mtAccount.startsWith("//CH") && mtAccount.length() > 4) {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtAccount.substring(4));
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>)othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", "CUID");
        } else if (mtAccount.length() > 34) {
            mtAccount = mtAccount.substring(1);
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            buildSTErrorInfo(ERROR.T0000T, path, null);
            othrMaps.put("id", mtAccount.substring(0, 33) + "+");
        } else {
            if (SwiftTransferUtil.checkIbanAccount(mtAccount)){
                idMaps.put("iban", mtAccount);
            } else {
                Map<String, Object> othrMaps = null;
                if (idMaps.containsKey("othr")) {
                    othrMaps = (Map<String, Object>)idMaps.get("othr");
                } else {
                    othrMaps = new HashMap<>();
                    idMaps.put("othr", othrMaps);
                }
                othrMaps.put("id", mtAccount);
            }
        }
    }
    /**
     * Id.OrgId.AnyBIC = mtBicCode
     * @param mtBicCode
     * @param maps
     */
    protected void mt_to_mxAnyBIC(String mtBicCode, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtBicCode)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        Map<String, Object> orgIdMaps = null;
        if (idMaps.containsKey("orgId")) {
            orgIdMaps = (Map<String, Object>)idMaps.get("orgId");
        } else {
            orgIdMaps = new HashMap<>();
            idMaps.put("orgId", orgIdMaps);
        }
        orgIdMaps.put("anyBIC", mtBicCode);
    }

    /**
     * FinInstnId.BICFI = mtBicCode
     * @param mtBicCode
     * @param maps
     */
    protected void mt_to_mxBICFI(String mtBicCode, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtBicCode)) {
            return;
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        finInstnIdMaps.put("bicfi", mtBicCode);
    }

    /**
     * nameAndAddress 通过回车换行切割成数组 nameAndAddress[]
     * Nm = nameAndAddress[0]
     * PstlAdr.AdrLine = 剩余的 nameAndAddress[]
     * @param nameAndAddress
     * @param maps
     */
    protected void mt_to_mxPartyNameAndAddress(String nameAndAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(nameAndAddress)) {
            return;
        }
        String[] nameAndAddresses = nameAndAddress.split(Mx2MtConstants.NEW_LINE);
        String name = "";
        List<String> addressList = new ArrayList<>();
        for (int i=0; i<nameAndAddresses.length; i++) {
            if (i == 0) {
                name = nameAndAddresses[i];
            } else {
                addressList.add(nameAndAddresses[i]);
            }
        }
        maps.put("nm", name);
        if (addressList.size() > 0) {
            Map<String, Object> pstlAdrMaps = null;
            if (maps.containsKey("pstlAdr")) {
                pstlAdrMaps = (Map<String, Object>)maps.get("pstlAdr");
            } else {
                pstlAdrMaps = new HashMap<>();
                maps.put("pstlAdr", pstlAdrMaps);
            }
            pstlAdrMaps.put("adrLine", addressList);
        }
    }

    /**
     * 1/ 开头的给name
     * 2/ 开头的给adrLine
     * 3/[A-Z]{2}/LEIC/([A-Z0-9]{18,18}[0-9]{2,2}) 括号里面的内容给LEI
     * 否则 给 adrLine
     * @param nameAndAddress
     * @param maps
     */
    protected void mt_to_mxPartyNameAndStructuredAddress(String nameAndAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(nameAndAddress)) {
            return;
        }
        String[] nameAndAddresses = nameAndAddress.split(Mx2MtConstants.NEW_LINE);
        String name = "";
        String lei = "";
        List<String> addressList = new ArrayList<>();
        for (int i=0; i<nameAndAddresses.length; i++) {
            String tmpNameAndAddress = nameAndAddresses[i];
            if (tmpNameAndAddress.startsWith("1/")) {
                name += tmpNameAndAddress.substring(2);
            }
            if (tmpNameAndAddress.startsWith("2/")) {
                addressList.add(tmpNameAndAddress);
            }
            if (tmpNameAndAddress.startsWith("3/")) {
                String regex = "3/[A-Z]{2}/LEIC/([A-Z0-9]{18,18}[0-9]{2,2})";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(tmpNameAndAddress);
                if (m.find()) {
                    /**
                     * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                     */
                    lei = m.group(1);
                } else {
                    addressList.add(tmpNameAndAddress);
                }
            }
        }
        if (name.length() > 0) {
            maps.put("nm", name);
        }
        if (lei.length() > 0) {
            Map<String, Object> idMaps = null;
            if (maps.containsKey("id")) {
                idMaps = (Map<String, Object>)maps.get("id");
            } else {
                idMaps = new HashMap<>();
                maps.put("id", idMaps);
            }
            Map<String, Object> orgIdMaps = null;
            if (idMaps.containsKey("orgId")) {
                orgIdMaps = (Map<String, Object>) idMaps.get("orgId");
            } else {
                orgIdMaps = new HashMap<>();
                idMaps.put("orgId", orgIdMaps);
            }
            orgIdMaps.put("lei", lei);
        }
        if (addressList.size() > 0) {
            Map<String, Object> pstlAdrMaps = null;
            if (maps.containsKey("pstlAdr")) {
                pstlAdrMaps = (Map<String, Object>)maps.get("pstlAdr");
            } else {
                pstlAdrMaps = new HashMap<>();
                maps.put("pstlAdr", pstlAdrMaps);
            }
            pstlAdrMaps.put("adrLine", addressList);
        }
    }

    /**
     * ① //RT//([A-Z]{5})(.*)
     * ② //([A-Z]{5})(.*)
     * ③ //RT//([A-Z]{2})(.*)
     * ④ //([A-Z]{2})(.*)
     * 第一个括号内容给mxSystemCode
     * 第二个括号内容给mxMemberId
     * @param mtPartyIdentifier
     * @param maps
     */
    protected void mt_to_mxClearingIdentifier(String mtPartyIdentifier, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        String mxClearingSystem = "";
        String mxClearingCode = "";
        String regex1 = "//RT//([A-Z]{5})(.*)";
        Pattern p1 = Pattern.compile(regex1);
        Matcher m1 = p1.matcher(mtPartyIdentifier);
        if (m1.find()) {
            mxClearingSystem = m1.group(1);
            mxClearingCode = m1.group(2);
        }
        String regex2 = "//([A-Z]{5})(.*)";
        Pattern p2 = Pattern.compile(regex2);
        Matcher m2 = p2.matcher(mtPartyIdentifier);
        if (m2.find()) {
            mxClearingSystem = m2.group(1);
            mxClearingCode = m2.group(2);
        }
        ClearingSystemMemberCode code = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystem);
        if (mxClearingCode.length() > 0 && code != null) {
            Map<String, Object> clrSysIdMaps = null;
            if (maps.containsKey("clrSysId")) {
                clrSysIdMaps = (Map<String, Object>) maps.get("clrSysId");
            } else {
                clrSysIdMaps = new HashMap<>();
                maps.put("clrSysId", clrSysIdMaps);
            }
            clrSysIdMaps.put("cd", mxClearingSystem);
            maps.put("mmbId", mxClearingCode);
            return;
        }
        /**
         * 第2种情况
         */
        String mtClearingSystem = "";
        String mtClearingCode = "";
        String regex3 = "//RT//([A-Z]{2})(.*)";
        Pattern p3 = Pattern.compile(regex3);
        Matcher m3 = p3.matcher(mtPartyIdentifier);
        if (m3.find()) {
            mtClearingSystem = m3.group(1);
            mtClearingCode = m3.group(2);
        }
        String regex4 = "//([A-Z]{2})(.*)";
        Pattern p4 = Pattern.compile(regex4);
        Matcher m4 = p4.matcher(mtPartyIdentifier);
        if (m4.find()) {
            mtClearingSystem = m4.group(1);
            mtClearingCode = m4.group(2);
        }
        code = SwiftTransferUtil.getClsSysMemberByDesc(mtClearingSystem);
        if (mtClearingCode.length() > 0 && code != null) {
            if ("SW".equals(mtClearingSystem)){
                if (mtClearingCode.length() > 5) {
                    mxClearingSystem = ClearingSystemMemberCode.CHSIC.value();
                } else {
                    mxClearingSystem = ClearingSystemMemberCode.CHBCC.value();
                }
            } else {
                mxClearingSystem = code.value();
            }
            mxClearingCode = mtClearingCode;
            Map<String, Object> clrSysIdMaps = null;
            if (maps.containsKey("clrSysId")) {
                clrSysIdMaps = (Map<String, Object>) maps.get("clrSysId");
            } else {
                clrSysIdMaps = new HashMap<>();
                maps.put("clrSysId", clrSysIdMaps);
            }
            clrSysIdMaps.put("cd", mxClearingSystem);
            maps.put("mmbId", mxClearingCode);
        }
    }

    /**
     * 判断 mt systemcode 在不在 MTClearingSystemCodeList 里面
     * 存在返回true
     * 不在返回false
     * @param mtPartyIdentifier
     */
    protected boolean isMTClearingSystemCodeInList(String mtPartyIdentifier) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return false;
        }
        boolean flag = false;
        String mxClearingSystem = "";
        String regex1 = "//RT//([A-Z]{5})(.*)";
        Pattern p1 = Pattern.compile(regex1);
        Matcher m1 = p1.matcher(mtPartyIdentifier);
        if (m1.find()) {
            mxClearingSystem = m1.group(1);
        }
        String regex2 = "//([A-Z]{5})(.*)";
        Pattern p2 = Pattern.compile(regex2);
        Matcher m2 = p2.matcher(mtPartyIdentifier);
        if (m2.find()) {
            mxClearingSystem = m2.group(1);
        }
        ClearingSystemMemberCode code = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystem);
        if (code != null) {
            flag = true;
        } else {
            /**
             * 第2种情况
             */
            String mtClearingSystem = "";
            String regex3 = "//RT//([A-Z]{2})(.*)";
            Pattern p3 = Pattern.compile(regex3);
            Matcher m3 = p3.matcher(mtPartyIdentifier);
            if (m3.find()) {
                mtClearingSystem = m3.group(1);
            }
            String regex4 = "//([A-Z]{2})(.*)";
            Pattern p4 = Pattern.compile(regex4);
            Matcher m4 = p4.matcher(mtPartyIdentifier);
            if (m4.find()) {
                mtClearingSystem = m4.group(1);
            }
            code = SwiftTransferUtil.getClsSysMemberByDesc(mtClearingSystem);
            if (code != null) {
                flag = true;
            }
        }
        return flag;
    }

    protected void mt_to_mxClearingSystemToNameAndAddressLine(String mtPartyIdentifier, String location, Map<String, Object> maps, String path) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        String nameAddress = "";
        String regex1 = "//RT//(.*)";
        Pattern p1 = Pattern.compile(regex1);
        Matcher m1 = p1.matcher(mtPartyIdentifier);
        if (m1.find()) {
            nameAddress = m1.group(1);
        }
        String regex2 = "//(.*)";
        Pattern p2 = Pattern.compile(regex2);
        Matcher m2 = p2.matcher(mtPartyIdentifier);
        if (m2.find()) {
            nameAddress = m2.group(1);
        }
        if (StringUtil.isNotEmpty(nameAddress) && !"RT".equals(nameAddress)) {
            nameAddress = "//" + nameAddress;
            buildSTErrorInfo(ERROR.T20033, path, null);
        } else {
            buildSTErrorInfo(ERROR.T20034, path, null);
            nameAddress = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        maps.put("nm", nameAddress);
        List<String> addressList = new ArrayList<>();
        addressList.add(nameAddress);
        if (StringUtil.isNotEmpty(location)) {
            addressList.add(location);
        }
        Map<String, Object> pstlAdrMaps = null;
        if (maps.containsKey("pstlAdr")) {
            pstlAdrMaps = (Map<String, Object>)maps.get("pstlAdr");
        } else {
            pstlAdrMaps = new HashMap<>();
            maps.put("pstlAdr", pstlAdrMaps);
        }
        pstlAdrMaps.put("adrLine", addressList);
    }

    protected void mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(String nameAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(nameAddress)) {
            return;
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        String[] nameAddresses = nameAddress.split(Mx2MtConstants.NEW_LINE);
        String name = "";
        List<String> addressList = new ArrayList<>();
        for (int i=0; i<nameAddresses.length; i++) {
            if (i == 0) {
                name = nameAddresses[i];
            } else {
                addressList.add(nameAddresses[i]);
            }
        }
        finInstnIdMaps.put("nm", name);
        if (addressList.size() == 0) {
            addressList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
        }
        Map<String, Object> pstlAdrMaps = null;
        if (finInstnIdMaps.containsKey("pstlAdr")) {
            pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
        } else {
            pstlAdrMaps = new HashMap<>();
            finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
        }
        pstlAdrMaps.put("adrLine", addressList);
    }

    /**
     *
     * @param mt72
     * @param maps
     */
    protected void mt72_to_mxNextAgent(String mt72, List<String> excludeCodeList, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mt72Value = refreshValue(mt72, "//", 35).replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        String nextAgtInfo = "";
        for (int i=0; i<lines.length; i++) {
            boolean found = false;
            for (String excludeCode : excludeCodeList) {
                if (lines[i].startsWith(excludeCode)) {
                    found = true;
                    break;
                }
            }
            if (!found) {
                nextAgtInfo += lines[i];
            }
        }
        VoSettlementMethodHelper setlMtdHelper = context.get(VoSettlementMethodHelper.class);
        String nextAgeFin53 = setlMtdHelper.getInstructionForNextAgent();
        if (StringUtil.isNotEmpty(nextAgeFin53)) {
            nextAgtInfo = nextAgeFin53 + nextAgtInfo;
        }
        if (StringUtil.isNotEmpty(nextAgtInfo)) {
            if (nextAgtInfo.length() > 210) {
                buildSTErrorInfo(ERROR.T0000T, "InstrForNxtAgt/InstrInf", nextAgtInfo);
                nextAgtInfo = nextAgtInfo.substring(0, 209) + "+";
            }
            JSONArray instrForNxtAgtJsonArray = null;
            if (maps.containsKey("instrForNxtAgt")) {
                instrForNxtAgtJsonArray = (JSONArray)maps.get("instrForNxtAgt");
            } else {
                instrForNxtAgtJsonArray = new JSONArray();
                maps.put("instrForNxtAgt", instrForNxtAgtJsonArray);
            }
            List<String> nextAgtInfoList = StringUtil.outStringList(nextAgtInfo, 35, "");
            for (int i=0; i<nextAgtInfoList.size(); i++) {
                Map<String, Object> instrForNxtAgtMaps = new HashMap<>();
                instrForNxtAgtMaps.put("instrInf", nextAgtInfoList.get(i));
                instrForNxtAgtJsonArray.add(instrForNxtAgtMaps);
            }
        }
    }
    /**
     *
     * @param mt72
     * @param maps
     */
    protected void mt72ins_to_mxAgent(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mt72Value = refreshValue(mt72, "//", 35).replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        List<String> insList = new ArrayList<>();
        for (int i=0; i<lines.length; i++) {
            if (lines[i].startsWith("/INS/")) {
                insList.add(lines[i]);
            }
        }
        for (int i=0; i<insList.size(); i++) {
            String insLine = insList.get(i);
            insLine = insLine.substring(5);
            if (i == 3) break;
            String key = "prvsInstgAgt" + (i+1);
            Map<String, Object> prvsInstgAgt1Maps = null;
            if (maps.containsKey(key)) {
                prvsInstgAgt1Maps = (Map<String, Object>)maps.get(key);
            } else {
                prvsInstgAgt1Maps = new HashMap<>();
                maps.put(key, prvsInstgAgt1Maps);
            }
            Map<String, Object> finInstnIdMaps = null;
            if (prvsInstgAgt1Maps.containsKey("finInstnId")) {
                finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
            } else {
                finInstnIdMaps = new HashMap<>();
                prvsInstgAgt1Maps.put("finInstnId", finInstnIdMaps);
            }
            if (SwiftTransferUtil.isBIC(insLine)) {
                finInstnIdMaps.put("bicfi", insLine);
            } else {
                if (insLine.length() > 140){
                    buildSTErrorInfo(ERROR.T0000T, "PrvsInstgAgt" + (i+1) + "/FinInstnId/Nm", insLine);
                    insLine = insLine.substring(0, 139) + "+";
                }
                finInstnIdMaps.put("nm", insLine);
                Map<String, Object> pstlAdrMaps = null;
                List<String> addressList = new ArrayList<>();
                addressList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                if (finInstnIdMaps.containsKey("pstlAdr")) {
                    pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                } else {
                    pstlAdrMaps = new HashMap<>();
                    finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                }
                pstlAdrMaps.put("adrLine", addressList);
            }
        }
    }

    /**
     *
     * @param mtPartyIdentifier
     * @param maps
     */
    protected void mt_to_mxFinancialInstitutionAccount(String mtPartyIdentifier, Map<String, Object> maps, String path) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>)maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (mtPartyIdentifier.startsWith("//CH") && mtPartyIdentifier.length() > 4) {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtPartyIdentifier.substring(4));
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>)othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", "CUID");
            return;
        } else if ((mtPartyIdentifier.startsWith("/C/") || mtPartyIdentifier.startsWith("/D/")) && mtPartyIdentifier.length() > 3) {
            buildSTErrorInfo(ERROR.T20086, path, null);
            mtPartyIdentifier = mtPartyIdentifier.substring(3);
        } else if (mtPartyIdentifier.length() > 1) {
            mtPartyIdentifier = mtPartyIdentifier.substring(1);
        }
        if (SwiftTransferUtil.checkIbanAccount(mtPartyIdentifier)){
            idMaps.put("iban", mtPartyIdentifier);
        } else {
            Map<String, Object> othrMaps = null;
            if (idMaps.containsKey("othr")) {
                othrMaps = (Map<String, Object>)idMaps.get("othr");
            } else {
                othrMaps = new HashMap<>();
                idMaps.put("othr", othrMaps);
            }
            othrMaps.put("id", mtPartyIdentifier);
        }
    }

    protected void mt_to_mxRemittanceInformation(String mt70, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt70)) {
            return;
        }
        String[] mt70Lines = mt70.split(Mx2MtConstants.NEW_LINE);
        String ustrd = "";
        for (int i=0; i<mt70Lines.length; i++) {
            String mt70Line = mt70Lines[i];
            if (mt70Line.length() < 35 && i < (mt70Lines.length-1)) {
                ustrd += mt70Line + " ";
            } else {
                ustrd += mt70Line;
            }
        }
        List<String> ustrdList = new ArrayList<>();
        ustrdList.add(ustrd);
        maps.put("ustrd", ustrdList);
    }

    /**
     * 获取 EndToEndId
     * @param mt70Value
     * @return
     */
    protected String mt70roc_to_mx35Text(String mt70Value) {
        if (StringUtil.isEmpty(mt70Value)) {
            return null;
        }
        String endToEndId = "";
        String tmpMtValue = mt70Value.replace(Mx2MtConstants.NEW_LINE, "");
        String regex = "/ROC/(.*)///";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(tmpMtValue);
        if (m.find()) {
            endToEndId = m.group(1);
        } else {
            regex = "/ROC/(.*)";
            p = Pattern.compile(regex);
            m = p.matcher(tmpMtValue);
            if (m.find()) {
                endToEndId = m.group(1);
            }
        }
        if (endToEndId.length() > 35) {
            buildSTErrorInfo(ERROR.T0000T, "PmtId/EndToEndId", endToEndId);
            endToEndId = endToEndId.substring(0, 34) + "+";
        }
        return endToEndId;
    }

    /**
     * 提取72域中指定mtcode的值
     * @param mt72
     * @param mtCode
     * @param maxLength
     * @return
     */
    protected String mt72_to_mxText(String mt72, String mtCode, int maxLength) {
        if (StringUtil.isEmpty(mt72)) {
            return "";
        }
        String mxCode = "";
        String mt72Value = refreshValue(mt72, "//", 35).replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        for (int i=0; i<lines.length; i++) {
            if (lines[i].startsWith(mtCode)) {
                mxCode = lines[i];
            }
        }
        if (StringUtil.isNotEmpty(mxCode)) {
            mxCode = mxCode.substring(mtCode.length());
            if (mxCode.length() > maxLength) {
                mxCode = mxCode.substring(0, maxLength-1) + "+";
            }
        }
        return mxCode;
    }

    /**
     * 23E 72 转换成 Instruction For Creditor Agent
     * @param field23EList (HOLD, PHOB, CHQB,TELB)
     * @param mt72
     * @param maps
     */
    protected void mt_to_mxInstructionForCreditorAgent(List<Field23E> field23EList, String mt72, Map<String, Object> maps) {
        if (field23EList.size() == 0 && StringUtil.isEmpty(mt72)) {
            return;
        }
        Map<String, Object> instrForCdtrAgt1 = new HashMap<>();
        Map<String, Object> instrForCdtrAgt2 = new HashMap<>();
        String mxText = mt72_to_mxText(mt72, "/ACC/", 205);
        String configIndicator = "";
        if (mxText.length() > 0 && field23EList.size() > 0) {
            configIndicator = "ACCCode";
        } else if (mxText.length() > 0) {
            configIndicator = "ACCOnly";
        } else if (field23EList.size() > 0) {
            configIndicator = "CodeOnly";
        }
        if ("ACCOnly".equals(configIndicator)) {
            if (mxText.length() > 140) {
                instrForCdtrAgt1.put("instrInf", mxText.substring(0, 140));
                instrForCdtrAgt2.put("instrInf", mxText.substring(140));
            } else {
                instrForCdtrAgt1.put("instrInf", mxText);
            }
        } else if ("ACCCode".equals(configIndicator)) {
            if (mxText.length() > 140) {
                buildSTErrorInfo(ERROR.T0000T, "InstrForCdtrAgt/InstrInf", mxText);
                instrForCdtrAgt1.put("instrInf", mxText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt1.put("instrInf", mxText);
            }
            String instructionCode = "";
            String instructionInfo = "";
            for (int i=0; i<field23EList.size(); i++) {
                Field23E field23E = field23EList.get(i);
                String code = field23E.getCode();
                String info = field23E.getAdditionalInformation();
                if (i == 0) {
                    instructionCode = code;
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                } else {
                    instructionInfo += "/" + code + "/";
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                }
            }
            instrForCdtrAgt2.put("cd", instructionCode);
            if (StringUtil.isNotEmpty(instructionInfo)) {
                instrForCdtrAgt2.put("instrInf", instructionInfo);
            }
        } else if ("CodeOnly".equals(configIndicator)) {
            String instructionCode = "";
            String instructionInfo = "";
            for (int i=0; i<field23EList.size(); i++) {
                Field23E field23E = field23EList.get(i);
                String code = field23E.getCode();
                String info = field23E.getAdditionalInformation();
                if (i == 0) {
                    instrForCdtrAgt1.put("cd", code);
                    if (StringUtil.isNotEmpty(info)) {
                        instrForCdtrAgt1.put("instrInf", info);
                    }
                } else if (i == 1){
                    instructionCode = code;
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                } else {
                    instructionInfo += "/" + code + "/";
                    if (StringUtil.isNotEmpty(info)) {
                        instructionInfo += info;
                    }
                }
            }
            if (StringUtil.isNotEmpty(instructionCode)) {
                instrForCdtrAgt2.put("cd", instructionCode);
            }
            if (StringUtil.isNotEmpty(instructionInfo)) {
                instrForCdtrAgt2.put("instrInf", instructionInfo);
            }
        }
        JSONArray instrForCdtrAgtJsonArray = null;
        if (maps.containsKey("instrForCdtrAgt")) {
            instrForCdtrAgtJsonArray = (JSONArray)maps.get("instrForCdtrAgt");
        } else {
            instrForCdtrAgtJsonArray = new JSONArray();
            maps.put("instrForCdtrAgt", instrForCdtrAgtJsonArray);
        }
        if (instrForCdtrAgt1.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt1);
        }
        if (instrForCdtrAgt2.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt2);
        }
    }


    protected void mt_to_mxInstructionForCreditorAgent2(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mxUdlcText = mt72_to_mxText(mt72, "/UDLC/", 204);
        String mxAccText = mt72_to_mxText(mt72, "/ACC/", 205);
        String mxPhobText = mt72_to_mxText(mt72, "/PHONBEN/", 140);
        String mxTelbText = mt72_to_mxText(mt72, "/TELEBEN/", 140);
        Map<String, Object> instrForCdtrAgt1 = new HashMap<>();
        Map<String, Object> instrForCdtrAgt2 = new HashMap<>();
        String configIndicator = "";
        if (StringUtil.isEmpty(mxUdlcText)) {  //不包含UDLC
            if (StringUtil.isEmpty(mxAccText)) { //不包含ACC
                if (StringUtil.isNotEmpty(mxPhobText) || StringUtil.isNotEmpty(mxTelbText)) {
                    configIndicator = "CodeOnly";
                } else {
                    return;
                }
            } else { // 包含ACC
                if (StringUtil.isNotEmpty(mxPhobText) || StringUtil.isNotEmpty(mxTelbText)) {
                    configIndicator = "ACCCode";
                } else {
                    configIndicator = "ACCOnly";
                }
            }
        } else {
            if (StringUtil.isEmpty(mxAccText)) {
                configIndicator = "UDLC";
            } else {
                configIndicator = "UDLCACC";
            }
        }
        if ("ACCOnly".equals(configIndicator)) {
            if (mxAccText.length() > 140) {
                instrForCdtrAgt1.put("instrInf", mxAccText.substring(0, 140));
                instrForCdtrAgt2.put("instrInf", mxAccText.substring(140));
            } else {
                instrForCdtrAgt1.put("instrInf", mxAccText);
            }
        } else if ("ACCCode".equals(configIndicator)) {
            if (mxAccText.length() > 140) {
                buildSTErrorInfo(ERROR.T0000T, "InstrForCdtrAgt/InstrInf", mxAccText);
                instrForCdtrAgt1.put("instrInf", mxAccText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt1.put("instrInf", mxAccText);
            }
            if (StringUtil.isNotEmpty(mxPhobText)) {
                String instructionInfo = mxPhobText;
                int remainLength = 140 - instructionInfo.length();
                if (StringUtil.isNotEmpty(mxTelbText) && remainLength >= 7) {
                    String tmpInstructionInfo = "/TELB/" + mxTelbText;
                    if (tmpInstructionInfo.length() > remainLength) {
                        buildSTErrorInfo(ERROR.T0000T, "InstrForCdtrAgt/InstrInf", tmpInstructionInfo);
                        tmpInstructionInfo = tmpInstructionInfo.substring(0, remainLength-1) + "+";
                    }
                    instructionInfo += tmpInstructionInfo;
                }
                instrForCdtrAgt2.put("cd", "PHOB");
                instrForCdtrAgt2.put("instrInf", instructionInfo);
            } else { // /PHONBEN/不存在,/TELEBEN/必须存在
                instrForCdtrAgt2.put("cd", "TELB");
                instrForCdtrAgt2.put("instrInf", mxTelbText);
            }
        } else if ("CodeOnly".equals(configIndicator)) {
            if (StringUtil.isNotEmpty(mxPhobText)) {
                instrForCdtrAgt1.put("cd", "PHOB");
                instrForCdtrAgt1.put("instrInf", mxPhobText);
            }
            if (StringUtil.isNotEmpty(mxTelbText)) {
                if (instrForCdtrAgt1.size() == 0) {
                    instrForCdtrAgt1.put("cd", "TELB");
                    instrForCdtrAgt1.put("instrInf", mxTelbText);
                } else {
                    instrForCdtrAgt2.put("cd", "TELB");
                    instrForCdtrAgt2.put("instrInf", mxTelbText);
                }
            }
        } else if ("UDLCACC".equals(configIndicator)) {
            if (mxAccText.length() > 140) {
                buildSTErrorInfo(ERROR.T0000T, "InstrForCdtrAgt/InstrInf", mxAccText);
                instrForCdtrAgt1.put("instrInf", mxAccText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt1.put("instrInf", mxAccText);
            }
            mxUdlcText = "/UDLC/" + mxUdlcText;
            if (mxUdlcText.length() > 140) {
                buildSTErrorInfo(ERROR.T0000T, "InstrForCdtrAgt/InstrInf", mxUdlcText);
                instrForCdtrAgt2.put("instrInf", mxUdlcText.substring(0, 139) + "+");
            } else {
                instrForCdtrAgt2.put("instrInf", mxUdlcText);
            }
        } else if ("UDLC".equals(configIndicator)) {
            mxUdlcText = "/UDLC/" + mxUdlcText;
            if (mxUdlcText.length() > 140) {
                buildSTErrorInfo(ERROR.T0000T, "InstrForCdtrAgt/InstrInf", mxUdlcText);
                mxUdlcText = mxUdlcText.substring(0, 139) + "+";
            }
            if (StringUtil.isNotEmpty(mxPhobText) || StringUtil.isNotEmpty(mxTelbText)) {
                if (StringUtil.isNotEmpty(mxPhobText)) {
                    String instructionInfo = mxPhobText;
                    int remainLength = 140 - instructionInfo.length();
                    if (StringUtil.isNotEmpty(mxTelbText) && remainLength >= 7) {
                        String tmpInstructionInfo = "/TELB/" + mxTelbText;
                        if (tmpInstructionInfo.length() > remainLength) {
                            buildSTErrorInfo(ERROR.T0000T, "InstrForCdtrAgt/InstrInf", tmpInstructionInfo);
                            tmpInstructionInfo = tmpInstructionInfo.substring(0, remainLength-1) + "+";
                        }
                        instructionInfo += tmpInstructionInfo;
                    }
                    instrForCdtrAgt1.put("cd", "PHOB");
                    instrForCdtrAgt1.put("instrInf", instructionInfo);
                } else { // /PHONBEN/不存在,/TELEBEN/必须存在
                    instrForCdtrAgt1.put("cd", "TELB");
                    instrForCdtrAgt1.put("instrInf", mxTelbText);
                }
                instrForCdtrAgt2.put("instrInf", mxUdlcText);
            } else {
                instrForCdtrAgt1.put("instrInf", mxUdlcText);
            }
        }
        JSONArray instrForCdtrAgtJsonArray = null;
        if (maps.containsKey("instrForCdtrAgt")) {
            instrForCdtrAgtJsonArray = (JSONArray)maps.get("instrForCdtrAgt");
        } else {
            instrForCdtrAgtJsonArray = new JSONArray();
            maps.put("instrForCdtrAgt", instrForCdtrAgtJsonArray);
        }
        if (instrForCdtrAgt1.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt1);
        }
        if (instrForCdtrAgt2.size() > 0) {
            instrForCdtrAgtJsonArray.add(instrForCdtrAgt2);
        }
    }

    protected void mt_to_mxBNF_TSU_RI(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        String mxBnfText = mt72_to_mxText(mt72, "/BNF/", 135);
        int remainLength = 140; //初始长度140
        String mxUnstructuredRemittanceInformation = "";
        if (StringUtil.isNotEmpty(mxBnfText)) {
            mxUnstructuredRemittanceInformation = "/BNF/" + mxBnfText;
            remainLength = 140 - mxUnstructuredRemittanceInformation.length();
        }
        String mxTsuText = mt72_to_mxText(mt72, "/TSU/", 135);
        if (StringUtil.isNotEmpty(mxTsuText) && remainLength >= 6) {
            mxTsuText = "/TSU/" + mxTsuText;
            if (mxTsuText.length() > remainLength) {
                buildSTErrorInfo(ERROR.T0000T, "RmtInf/Ustrd", mxTsuText);
                mxUnstructuredRemittanceInformation += mxTsuText.substring(0, remainLength-1) + "+";
            }
        }
        if (StringUtil.isNotEmpty(mxUnstructuredRemittanceInformation)) {
            List<String> ustrdList = new ArrayList<>();
            ustrdList.add(mxUnstructuredRemittanceInformation);
            Map<String, Object> rmtInfMaps = null;
            if (maps.containsKey("rmtInf")) {
                rmtInfMaps = (Map<String, Object>)maps.get("rmtInf");
            } else {
                rmtInfMaps = new HashMap<>();
                maps.put("rmtInf", rmtInfMaps);
            }
            rmtInfMaps.put("ustrd", ustrdList);
        }
    }
    /**
     * 前提条件是 mtPartyIdentifier 不以/开始
     * @param mtPartyIdentifier
     * @param nameAddress
     * @param maps
     */
    protected void mt_to_mxFATFIdentification(String mtPartyIdentifier, String nameAddress, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mtPartyIdentifier)) {
            return;
        }
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(nameAddress)) {
            String[] nameAndAddresses = nameAddress.split(Mx2MtConstants.NEW_LINE);
            for (int i=0; i<nameAndAddresses.length; i++) {
                if (nameAndAddresses[i].startsWith("8/")) {
                    mtCode8 = nameAndAddresses[i].substring(2);
                }
            }
        }
        String mtFullId = mtPartyIdentifier;
        if (mtPartyIdentifier.length() == 35) {
            mtFullId += mtCode8;
        }
        //格式类似 mtSchemeCode + "/" + mtCountryCode + "/" + mtIssuer + "/" + mtIdentifier
        String mtFATFCode = mtFullId.substring(0, 4);
        String mtFATFId = mtFullId.substring(5);
        String mtCountry = "";
        String mtIssuer = "";
        String mtId = "";
        Boolean flagOrgId = false;
        String mxOrgSchemeCode = "";
        if ("CUST".equals(mtFATFCode) || "EMPL".equals(mtFATFCode) || "DRLC".equals(mtFATFCode)) {
            mtCountry = mtFATFId.substring(0, 2);
            String regex = "(.*)/(.*)";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mtFATFId.substring(3));
            if (m.find()) {
                mtIssuer = m.group(1);
                mtId = m.group(2);
                if (StringUtil.isEmpty(mtId)) {
                    mtId = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                if (mtIssuer.length() > 4 && "CUST".equals(mtFATFCode)) {
                    OrganisationIdentificationCode code = SwiftTransferUtil.getOrganisationIdentificationCodeByCode(mtIssuer.substring(0, 4));
                    if (code != null
                            && !OrganisationIdentificationCode.CUST.equals(code)
                            && !OrganisationIdentificationCode.TXID.equals(code)
                            && !OrganisationIdentificationCode.EMPL.equals(code)) {
                        mxOrgSchemeCode = code.value();
                        mtIssuer = mtIssuer.substring(5);
                        flagOrgId = true;
                    }
                }
            } else {
                mtId = mtFATFId.substring(3);
            }
            if (mtId.length() > 35) mtId = mtId.substring(0, 34) + "+";
        } else { //MTFATFCode 不在 {EMPL, CUST, DRLC}
            mtCountry = mtFATFId.substring(0, 2);
            mtId = mtFATFId.substring(3);
            if (StringUtil.isEmpty(mtId)) {
                mtId = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            }
            if (mtId.length() > 35) mtId = mtId.substring(0, 34) + "+";
        }
        String mxIssuer = mtCountry;
        if (StringUtil.isNotEmpty(mtIssuer)) {
            mxIssuer += "/" + mtIssuer;
        }
        //开始转换
        Map<String, Object> orgIdMaps = null;
        if (maps.containsKey("orgId")) {
            orgIdMaps = (Map<String, Object>) maps.get("orgId");
        } else {
            orgIdMaps = new HashMap<>();
            //如果orgIdMaps 长度大于0,put到maps
        }
        Map<String, Object> prvtIdMaps = null;
        if (maps.containsKey("prvtId")) {
            prvtIdMaps = (Map<String, Object>) maps.get("prvtId");
        } else {
            prvtIdMaps = new HashMap<>();
            //如果prvtIdMaps 长度大于0,put到maps
        }
        if (PersonIdentificationCode.ARNU.value().equals(mtFATFCode)
                || PersonIdentificationCode.CCPT.value().equals(mtFATFCode)
                || PersonIdentificationCode.DRLC.value().equals(mtFATFCode)
                || PersonIdentificationCode.EMPL.value().equals(mtFATFCode)
                || PersonIdentificationCode.NIDN.value().equals(mtFATFCode)
                || PersonIdentificationCode.SOSE.value().equals(mtFATFCode)
                || PersonIdentificationCode.TXID.value().equals(mtFATFCode)
                || (PersonIdentificationCode.CUST.value().equals(mtFATFCode) && !flagOrgId)) {
            JSONArray othrJsonArray = null;
            if (prvtIdMaps.containsKey("othr")) {
                othrJsonArray = (JSONArray) prvtIdMaps.get("othr");
            } else {
                othrJsonArray = new JSONArray();
                prvtIdMaps.put("othr", othrJsonArray);
            }
            Map<String, Object> othrMaps = new HashMap<>();
            othrJsonArray.add(othrMaps);
            othrMaps.put("id", mtId);
            othrMaps.put("issr", mxIssuer);
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", mtFATFCode);
        } else if (PersonIdentificationCode.CUST.value().equals(mtFATFCode) && flagOrgId) {
            JSONArray othrJsonArray = null;
            if (orgIdMaps.containsKey("othr")) {
                othrJsonArray = (JSONArray) orgIdMaps.get("othr");
            } else {
                othrJsonArray = new JSONArray();
                orgIdMaps.put("othr", othrJsonArray);
            }
            Map<String, Object> othrMaps = new HashMap<>();
            othrJsonArray.add(othrMaps);
            othrMaps.put("id", mtId);
            othrMaps.put("issr", mxIssuer);
            Map<String, Object> schmeNmMaps = null;
            if (othrMaps.containsKey("schmeNm")) {
                schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
            } else {
                schmeNmMaps = new HashMap<>();
                othrMaps.put("schmeNm", schmeNmMaps);
            }
            schmeNmMaps.put("cd", mxOrgSchemeCode);
        }
        if (orgIdMaps.size() > 0) {
            maps.put("orgId", orgIdMaps);
        }
        if (prvtIdMaps.size() > 0) {
            maps.put("prvtId", prvtIdMaps);
        }
    }

    /**
     *
     * @param mtPartyIdentifier
     * @param nameAddress
     * @param maps
     */
    protected void mt_to_mxFATFNameAndAddress(String mtPartyIdentifier, String nameAddress, Map<String, Object> maps) {
        mt_to_mxPartyNameAndStructuredAddress(nameAddress, maps);
        String mtCode4 = "";
        String mtCode5 = "";
        String mtCode6 = "";
        String mtCode7 = "";
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(nameAddress)) {
            String[] nameAndAddresses = nameAddress.split(Mx2MtConstants.NEW_LINE);
            for (int i=0; i<nameAndAddresses.length; i++) {
                if (nameAndAddresses[i].startsWith("4/")) {
                    mtCode4 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("5/")) {
                    mtCode5 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("6/")) {
                    mtCode6 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("7/")) {
                    mtCode7 = nameAndAddresses[i].substring(2);
                }
                if (nameAndAddresses[i].startsWith("8/")) {
                    mtCode8 = nameAndAddresses[i].substring(2);
                }
            }
        }
        if (StringUtil.isEmpty(mtCode4)
                && StringUtil.isEmpty(mtCode5)
                && StringUtil.isEmpty(mtCode6)
                && StringUtil.isEmpty(mtCode7)) {
            return;  //找不到mtcode4 5 6 7，终止转换
        }
        Map<String, Object> idMaps = null;
        if (maps.containsKey("id")) {
            idMaps = (Map<String, Object>) maps.get("id");
        } else {
            idMaps = new HashMap<>();
            maps.put("id", idMaps);
        }
        if (StringUtil.isNotEmpty(mtCode6)) {
            boolean flagOrgId = false;
            String regex = "[A-Z]{2}/LEIC/([A-Z0-9]{18,18}[0-9]{2,2})";
            String lei = "";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mtCode6);
            if (m.find()) {
                lei = m.group(1);
                if (mtPartyIdentifier.startsWith("/")) {
                    flagOrgId = true;
                } else {
                    String regex1 = "CUST/[A-Z]{2}/([A-Z0-9]{4})";
                    Pattern p1 = Pattern.compile(regex1);
                    Matcher m1 = p1.matcher(mtPartyIdentifier);
                    if (m1.find()) {
                        String orgIdCode = m1.group(1);
                        OrganisationIdentificationCode code = SwiftTransferUtil.getOrganisationIdentificationCodeByCode(orgIdCode);
                        if (code != null
                                && !OrganisationIdentificationCode.CUST.equals(code)
                                && !OrganisationIdentificationCode.TXID.equals(code)
                                && !OrganisationIdentificationCode.EMPL.equals(code)) {
                            flagOrgId = true;
                        }
                    }
                }
            }
            if (flagOrgId) {
                Map<String, Object> orgIdMaps = null;
                if (idMaps.containsKey("orgId")) {
                    orgIdMaps = (Map<String, Object>)idMaps.get("orgId");
                } else {
                    orgIdMaps = new HashMap<>();
                    idMaps.put("orgId", orgIdMaps);
                }
                orgIdMaps.put("lei", lei);
                return;  //组织信息转换了,私人信息将不会转换.
            }
        }
        Map<String, Object> prvtIdMaps = null;
        if (idMaps.containsKey("prvtId")) {
            prvtIdMaps = (Map<String, Object>) idMaps.get("prvtId");
        } else {
            prvtIdMaps = new HashMap<>();
            //idMaps.put("prvtId", prvtIdMaps);
        }
        if (StringUtil.isNotEmpty(mtCode4) && StringUtil.isNotEmpty(mtCode5)) {
            try {
                Map<String, Object> dtAndPlcOfBirthMaps = null;
                if (prvtIdMaps.containsKey("dtAndPlcOfBirth")) {
                    dtAndPlcOfBirthMaps = (Map<String, Object>) prvtIdMaps.get("dtAndPlcOfBirth");
                } else {
                    dtAndPlcOfBirthMaps = new HashMap<>();
                    prvtIdMaps.put("dtAndPlcOfBirth", dtAndPlcOfBirthMaps);
                }
                Date brithDate = DateUtil.parseDate(mtCode4, "yyyyMMdd");
                String brithDateStr = DateUtil.format(brithDate, "yyyy-MM-dd");
                dtAndPlcOfBirthMaps.put("birthDt", brithDateStr);
                String regex = "([A-Z]{2})/(.*)";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(mtCode5);
                if (m.find()) {
                    dtAndPlcOfBirthMaps.put("ctryOfBirth", m.group(1));
                    dtAndPlcOfBirthMaps.put("cityOfBirth", m.group(2));
                }
            } catch (ParseException e) {
                throw new SwiftException(e.getMessage());
            }
        }
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && !mtPartyIdentifier.startsWith("CUST")) {
            if (StringUtil.isNotEmpty(mtCode6)) {
                String mtFullId = mtCode6;
                if ((mtPartyIdentifier.startsWith("/") || mtPartyIdentifier.length() < 35) && mtCode8.length() > 0 && mtCode6.length() == 33) {
                    mtFullId += mtCode8;
                }
                String regex = "(.*)/(.*)";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(mtFullId.substring(3));
                String mtCountry = mtFullId.substring(0,2);
                String mtIssuer = "";
                String mtNum = "";
                if (m.find()) {
                    mtIssuer = m.group(1);
                    mtNum = m.group(2);
                    if (StringUtil.isEmpty(mtNum)) {
                        mtNum = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                } else {
                    mtNum = mtFullId.substring(3);
                }
                if (mtNum.length() > 35) {
                    mtNum = mtNum.substring(0, 34) + "+";
                }
                JSONArray othrJsonArray = null;
                if (prvtIdMaps.containsKey("othr")) {
                    othrJsonArray = (JSONArray) prvtIdMaps.get("othr");
                } else {
                    othrJsonArray = new JSONArray();
                    prvtIdMaps.put("othr", othrJsonArray);
                }
                Map<String, Object> othrMaps = new HashMap<>();
                othrJsonArray.add(othrMaps);
                othrMaps.put("id", mtNum);
                Map<String, Object> schmeNmMaps = null;
                if (othrMaps.containsKey("schmeNm")) {
                    schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
                } else {
                    schmeNmMaps = new HashMap<>();
                    othrMaps.put("schmeNm", schmeNmMaps);
                }
                schmeNmMaps.put("cd", "CUST");
                if (StringUtil.isNotEmpty(mtIssuer)) {
                    mtCountry += "/" + mtIssuer;
                }
                othrMaps.put("issr", mtCountry);
            }
        }
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && !mtPartyIdentifier.startsWith("NIDN")) {
            if (StringUtil.isNotEmpty(mtCode7)) {
                JSONArray othrJsonArray = null;
                if (prvtIdMaps.containsKey("othr")) {
                    othrJsonArray = (JSONArray) prvtIdMaps.get("othr");
                } else {
                    othrJsonArray = new JSONArray();
                    prvtIdMaps.put("othr", othrJsonArray);
                }
                if (othrJsonArray.size() >= 2) {
                    return;
                }
                String mtFullId = mtCode7;
                if ((mtPartyIdentifier.startsWith("/") || mtPartyIdentifier.length() < 35) && mtCode8.length() > 0
                        && mtCode6.length() != 33 && mtCode7.length() == 33) {
                    mtFullId += mtCode8;
                }
                if (mtFullId.length() > 3 && mtFullId.indexOf("/") == 2) {
                    String mtNum = mtFullId.substring(3);
                    if (mtNum.length() > 35) {
                        mtNum = mtNum.substring(0, 34) + "+";
                    }
                    Map<String, Object> othrMaps = new HashMap<>();
                    othrJsonArray.add(othrMaps);
                    othrMaps.put("id", mtNum);
                    Map<String, Object> schmeNmMaps = null;
                    if (othrMaps.containsKey("schmeNm")) {
                        schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
                    } else {
                        schmeNmMaps = new HashMap<>();
                        othrMaps.put("schmeNm", schmeNmMaps);
                    }
                    schmeNmMaps.put("cd", "NIDN");
                    othrMaps.put("issr", mtFullId.substring(0, 2));
                }
            }
        }
        if (prvtIdMaps.size() > 0) {
            idMaps.put("prvtId", prvtIdMaps);
        }
    }

    /**
     * /INTA/ -> MXIntermediaryAgent2, MXIntermediaryAgent3
     * /SVCLVL/ ->  Payment Type Information/Service Level
     * /LOCINS/ ->  Payment Type Information/Local Instrument
     * /CATPURP/ -> Payment Type Information/Category Purpose
     * @param mt72
     * @param maps
     */
    protected void mt_to_mxField72NewCodeWords(String mt72, boolean pacs009001Flag, Map<String, Object> maps) {
        //长度不足不加空格
        String mt72Value = mt72.replace("\r\n//", "");
        String[] lines = mt72Value.split("\r\n");
        List<String> intermediaryAgentLines = new ArrayList<>();
        List<String> serviceLevelLines = new ArrayList<>();
        List<String> localInstrumentLines = new ArrayList<>();
        List<String> categoryPurposeLines = new ArrayList<>();
        List<String> purposeLines = new ArrayList<>();
        //长度不足需要加空格
        String refreshMt72Value = refreshValue(mt72, "//", 35).replace("\r\n//", "");
        String[] refreshLines = refreshMt72Value.split("\r\n");
        for (int i=0; i<refreshLines.length; i++) {
            if (refreshLines[i].startsWith("/INTA/")) {
                String line = refreshLines[i].substring(6);
                if (StringUtil.isNotEmpty(line)) {
                    intermediaryAgentLines.add(line);
                }
            }
        }
        for (int i=0; i<lines.length; i++) {
            if (lines[i].startsWith("/SVCLVL/")) {
                String line = lines[i].substring(8);
                if (StringUtil.isNotEmpty(line)) {
                    serviceLevelLines.add(line);
                }
            }
            if (lines[i].startsWith("/LOCINS/")) {
                String line = lines[i].substring(8);
                if (StringUtil.isNotEmpty(line)) {
                    localInstrumentLines.add(line);
                }
            }
            if (lines[i].startsWith("/CATPURP/")) {
                String line = lines[i].substring(9);
                if (StringUtil.isNotEmpty(line)) {
                    categoryPurposeLines.add(line);
                }
            }
            if (lines[i].startsWith("/PURP/")) {
                String line = lines[i].substring(6);
                if (StringUtil.isNotEmpty(line)) {
                    purposeLines.add(line);
                }
            }
        }
        //开始转换
        if (intermediaryAgentLines.size() > 0) {
            for (int i=0; i<intermediaryAgentLines.size(); i++) {
                if (i == 2) break; //最多转换2次 IntermediaryAgent2, IntermediaryAgent3
                String line = intermediaryAgentLines.get(i);
                Map<String, Object> intrmyAgtMaps = new HashMap<>();
                mt_to_mxIntermediaryAgent(line, intrmyAgtMaps, "intrmyAgt"+(i+2));
                maps.put("intrmyAgt"+(i+2), intrmyAgtMaps);
            }
        }
        Map<String, Object> pmtTpInfMaps = null;
        if (maps.containsKey("pmtTpInf")) {
            pmtTpInfMaps = (Map<String, Object>) maps.get("pmtTpInf");
        } else {
            pmtTpInfMaps = new HashMap<>();
        }
        if (serviceLevelLines.size() > 0) {
            JSONArray svcLvlJsonArray = null;
            if (pmtTpInfMaps.containsKey("svcLvl")) {
                svcLvlJsonArray = (JSONArray) pmtTpInfMaps.get("svcLvl");
            } else {
                svcLvlJsonArray = new JSONArray();
            }
            for (int i=0; i<serviceLevelLines.size(); i++) {
                if (svcLvlJsonArray.size() >= 3) break; //Service Level 最多转换3次
                String line = serviceLevelLines.get(i);
                if (ServiceLevelCode.SDVA.value().equals(line)) {
                    continue;
                }
                if (line.matches("G00[1-9]{1}")) {
                    continue;
                }
                Map<String, Object> svcLvlMaps = new HashMap<>();
                ServiceLevelCode code = SwiftTransferUtil.getServiceLevelByValue(line);
                if (code != null) {
                    svcLvlMaps.put("cd", code.value());
                } else {
                    if (line.length() > 35) {
                        buildSTErrorInfo(ERROR.T0000T, "PmtTpInf/SvcLvl/Prtry", line);
                        line = line.substring(0, 34) + "+";
                    }
                    svcLvlMaps.put("prtry", line);
                }
                svcLvlJsonArray.add(svcLvlMaps);
            }
            if (svcLvlJsonArray.size() > 0) {
                pmtTpInfMaps.put("svcLvl", svcLvlJsonArray);
            }
        }
        //NOT IsInList {CRED,CRTS,SPAY, SPRI, SSTD}
        if (localInstrumentLines.size() > 0 && !pmtTpInfMaps.containsKey("lclInstrm")) {
            Map<String, Object> lclInstrmMaps = new HashMap<>();
            for (int i=0; i<localInstrumentLines.size(); i++) {
                if (lclInstrmMaps.size() == 1) break; //只取第一条
                String line = localInstrumentLines.get(i);
                if ("CRED".equals(line) || "CRTS".equals(line)
                        || "SPAY".equals(line) || "SPRI".equals(line) || "SSTD".equals(line)) {
                    continue;
                }
                LocalInstrumentCode code = SwiftTransferUtil.getLocalInstrumentByValue(line);
                if (code != null) {
                    lclInstrmMaps.put("cd", code.value());
                } else {
                    if (line.length() > 35) {
                        buildSTErrorInfo(ERROR.T0000T, "PmtTpInf/LclInstrm/Prtry", line);
                        line = line.substring(0, 34) + "+";
                    }
                    lclInstrmMaps.put("prtry", line);
                }
            }
            if (lclInstrmMaps.size() > 0) {
                pmtTpInfMaps.put("lclInstrm", lclInstrmMaps);
            }
        }
        if (categoryPurposeLines.size() > 0 && !pmtTpInfMaps.containsKey("ctgyPurp")) {
            Map<String, Object> ctgyPurpMaps = new HashMap<>();
            for (int i=0; i<localInstrumentLines.size(); i++) {
                if (ctgyPurpMaps.size() == 1) break; //只取第一条
                String line = localInstrumentLines.get(i);
                if (CategoryPurposeCode.INTC.value().equals(line)
                        || CategoryPurposeCode.CORT.value().equals(line)) {
                    continue;
                }
                CategoryPurposeCode code = SwiftTransferUtil.getCategoryPurposeByValue(line);
                if (code != null) {
                    ctgyPurpMaps.put("cd", code.value());
                } else {
                    if (line.length() > 35) {
                        buildSTErrorInfo(ERROR.T0000T, "PmtTpInf/CtgyPurp/Prtry", line);
                        line = line.substring(0, 34) + "+";
                    }
                    ctgyPurpMaps.put("prtry", line);
                }
            }
            if (ctgyPurpMaps.size() > 0) {
                pmtTpInfMaps.put("ctgyPurp", ctgyPurpMaps);
            }
        }
        if (pmtTpInfMaps.size() > 0) {
            maps.put("pmtTpInf", pmtTpInfMaps);
        }
        if (purposeLines.size() > 0 && pacs009001Flag) {
            Map<String, Object> purpMaps = null;
            if (maps.containsKey("purp")) {
                purpMaps = (Map<String, Object>)maps.get("purp");
            } else {
                purpMaps = new HashMap<>();
                maps.put("purp", purpMaps);
            }
            String purpCode = purposeLines.get(0);
            PurposeCode code = SwiftTransferUtil.getPurposeByValue(purpCode);
            if (code != null) {
                purpMaps.put("cd", purpCode);
            } else {
                if (purpCode.length() > 35) {
                    buildSTErrorInfo(ERROR.T0000T, "Purp/Prtry", purpCode);
                    purpCode = purpCode.substring(0, 34) + "+";
                }
                purpMaps.put("prtry", purpCode);
            }
        }
    }
    /**
     *
     * @param mtAgent
     * @param maps
     */
    protected void mt_to_mxIntermediaryAgent(String mtAgent, Map<String, Object> maps, String path) {
        if (StringUtil.isEmpty(mtAgent)) {
            return;
        }
        if (SwiftTransferUtil.isBIC(mtAgent)) {
            mt_to_mxBICFI(mtAgent, maps);
            return;
        }
        String regex = "([A-Z]{5})(.*)";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(mtAgent);
        if (m.find()) {
            String mxCode = m.group(1);
            String mxMemId = m.group(2);
            if (SwiftTransferUtil.getClsSysMemberByValue(mxCode) != null) {
                Map<String, Object> finInstnIdMaps = null;
                if (maps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    maps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                if (mxMemId.length() > 28) {
                    buildSTErrorInfo(ERROR.T0000T, path + "/FinInstnId/ClrSysMmbId/MmbId", mxMemId);
                    mxMemId = mxMemId.substring(0, 27) + "+";
                }
                clrSysMmbIdMaps.put("mmbId", mxMemId);
                Map<String, Object> clrSysIdMaps = null;
                if (clrSysMmbIdMaps.containsKey("clrSysId")) {
                    clrSysIdMaps = (Map<String, Object>)clrSysMmbIdMaps.get("clrSysId");
                } else {
                    clrSysIdMaps = new HashMap<>();
                    clrSysMmbIdMaps.put("clrSysId", clrSysIdMaps);
                }
                clrSysMmbIdMaps.put("cd", mxCode);
                return;
            }
        }
        String mxName = "";
        String mxCountryCode = "";
        String mxTownName = "";
        regex = "(.*)\\(([A-Z]{2})\\((.*)";
        p = Pattern.compile(regex);
        m = p.matcher(mtAgent);
        if (m.find()) {
            mxName = m.group(1);
            mxCountryCode = m.group(2);
            mxTownName = m.group(3);
        } else {
            regex = "(.*)\\(([A-Z]{2})";
            p = Pattern.compile(regex);
            m = p.matcher(mtAgent);
            if (m.find()) {
                mxName = m.group(1);
                mxCountryCode = m.group(2);
            } else {
                mxName = mtAgent;
            }
        }
        Map<String, Object> finInstnIdMaps = null;
        if (maps.containsKey("finInstnId")) {
            finInstnIdMaps = (Map<String, Object>)maps.get("finInstnId");
        } else {
            finInstnIdMaps = new HashMap<>();
            maps.put("finInstnId", finInstnIdMaps);
        }
        finInstnIdMaps.put("nm", mxName);
        Map<String, Object> pstlAdrMaps = null;
        if (finInstnIdMaps.containsKey("pstlAdr")) {
            pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
        } else {
            pstlAdrMaps = new HashMap<>();
            finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
        }
        if (StringUtil.isEmpty(mxCountryCode) && StringUtil.isEmpty(mxTownName)) {
            List<String> adrLineList = new ArrayList<>();
            adrLineList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
            pstlAdrMaps.put("adrLine", adrLineList);
            buildSTErrorInfo(ERROR.T20030, path, null);
        } else {
            if (StringUtil.isNotEmpty(mxCountryCode)) {
                pstlAdrMaps.put("ctry", mxCountryCode);
            }
            if (StringUtil.isNotEmpty(mxTownName)) {
                pstlAdrMaps.put("twnNm", mxTownName);
            }
        }
    }

    protected void mt_To_mxField76(List<String> lines, Map<String, Object> maps,Map<String, Object> stsMaps){
        if(lines==null){
            return;
        }
        String line1 = "";
        String statusCode = "";
        String reason = "";
        String additionalInformation = "";
        String statusCodeList = "{CNCL,PDCR,RJCR}";
        if(lines.get(0).length()>4){
            statusCode = lines.get(0).substring(1,5);
        }
        if(statusCodeList.indexOf(statusCode)>0){
            stsMaps.put("conf",statusCode);
        }else {
            buildSTErrorInfo(ERROR.T20093, "Block4:76:", null);
        }
        StringBuilder mt76ValueBuilder = new StringBuilder();
        for (int i = 1; i < lines.size(); i++) {
            if(i<lines.size()-1){
                if(lines.get(i).length()<35&&lines.get(i+1).startsWith("//")){
                    mt76ValueBuilder.append(lines.get(i)).append(" ");
                }else {
                    mt76ValueBuilder.append(lines.get(i));
                }
            }else {
                mt76ValueBuilder.append(lines.get(i));
            }
        }
        String mt76Value = mt76ValueBuilder.toString().replace("//","");
        if(lines.get(0).length()>9){
            String MXReasonList = "{AC04, AGNT, AM04, ARDT, CUST, INDM, LEGL, NOAS, NOOR, PTNA, RQDA}";
            reason = lines.get(0).substring(6,10);
            if(MXReasonList.indexOf(reason)>0){
                if(lines.get(0).length()>11){
                    if(lines.get(0).charAt(10) == '/'){
                        line1 = lines.get(0).substring(11);
                    }else {
                        line1 = lines.get(0).substring(10);
                    }
                }
            }else {
                if(lines.get(0).length()>6){
                    line1 = lines.get(0).substring(6);
                }
            }
        }
        additionalInformation = line1 + mt76Value;
        if ("RJCR".equals(statusCode)){
            reason = "NARR";
        }
        List<String> list = new ArrayList<>();
        if(additionalInformation.length()>210){
            buildSTErrorInfo(ERROR.T0000T, "CxlDtls/TxInfAndSts/CxlStsRsnInf/AddtlInf", additionalInformation);
            additionalInformation = additionalInformation.substring(0,209) + "+";
        }
        if (additionalInformation.length()>105){
            list.add(additionalInformation.substring(0,105));
            list.add(additionalInformation.substring(105));
        }else if(additionalInformation.length()>0){
            list.add(additionalInformation);
        }
        Map<String, Object> cxlStsRsnInfMaps = new HashMap<>();
        JSONArray cxlStsRsnInfJsonArray = new JSONArray();
        cxlStsRsnInfJsonArray.add(cxlStsRsnInfMaps);
        if(StringUtil.isNotEmpty(reason)){
            Map<String, Object> rsnMaps = new HashMap<>();
            cxlStsRsnInfMaps.put("rsn",rsnMaps);
            rsnMaps.put("cd",reason);
        }
        JSONArray addtlInfJsonArray = new JSONArray();
        cxlStsRsnInfMaps.put("addtlInf",addtlInfJsonArray);
        addtlInfJsonArray.addAll(list);
        if(cxlStsRsnInfJsonArray.size()>0){
            maps.put("cxlStsRsnInf",cxlStsRsnInfJsonArray);
        }
    }
    protected String getMxType(String mtType){
        String mxType = "";
        if("103".equals(mtType)){
            mxType = "pacs.008";
        }else if("104".equals(mtType)){
            mxType = "pacs.003";
        }else if("202".equals(mtType)||"205".equals(mtType)){
            mxType = "pacs.009";
        }else if("204".equals(mtType)){
            mxType = "pacs.010";
        }else if(mtType.matches("10[0-9]{1}")||mxType.matches("20[0-9]{1}")){
            mxType = "MT" + mtType;
        }else {
            mxType = "MT" + mtType;
            buildSTErrorInfo(ERROR.T20089, "Undrlyg/TxInf/OrgnlGrpInf/OrgnlMsgId", null);
        }
        return mxType;
    }
    //79域不存在则给取消原因代码默认值NARR，附加信息NOTPROVIDED
    //79域存在但是code为NARR，给附加信息默认值NOTPROVIDED
    //79域存在并且code不为NARR,或者code不存在，将附加信息存入map集合中，code存在也存到map集合中
    protected void mt_To_mxField79(List<String> lines, Map<String, Object> maps){
        JSONArray cxlRsnInfJSONArray = new JSONArray();
        Map<String,Object> cxlRsnInfMaps = new HashMap<>();
        Map<String,Object> rsnMaps = new HashMap<>();
        JSONArray addtlInfJSONArray = new JSONArray();
        if(lines==null){
            maps.put("cxlRsnInf",cxlRsnInfJSONArray);
            cxlRsnInfJSONArray.add(cxlRsnInfMaps);
            cxlRsnInfMaps.put("rsn",rsnMaps);
            rsnMaps.put("cd","NARR");
            cxlRsnInfMaps.put("addtlInf",addtlInfJSONArray);
            addtlInfJSONArray.add(Mx2MtConstants.MT_TO_MX_DEFAULT_VALUE);
        }else {
            StringBuilder mt79ValueBuilder = null;
            String mtCode = "";
            String mxCode = "";
            String line1 = "";
            String additionalInformation = "";
            if(lines.get(0).length()>5){
                mtCode = lines.get(0).substring(0,6);
            }
            String ListOfCode = "{AGNT, AM09, COVR, CURR, CUST, CUTA, DUPL, FRAD, TECH, UPAY,NARR}";
            if(mtCode.startsWith("/")&&mtCode.endsWith("/")&&ListOfCode.contains(mtCode.substring(1,5))){
                mxCode = mtCode.substring(1, 5);
                if(lines.get(0).length()>6){
                    line1 = lines.get(0).substring(6);
                }
            }
            mt79ValueBuilder = new StringBuilder(line1);
            for (int i = 1; i < lines.size(); i++) {
                if(i<lines.size()-1){
                    if(lines.get(i).length()<50&&lines.get(i+1).startsWith("//")){
                        mt79ValueBuilder.append(lines.get(i)).append(" ");
                    }else {
                        mt79ValueBuilder.append(lines.get(i));
                    }
                }else {
                    mt79ValueBuilder.append(lines.get(i));
                }
            }
            String mt76Value = mt79ValueBuilder.toString().replace("//","");
            if(mt76Value.indexOf("/UETR/")>0){
                maps.put("orgnlUETR",mt76Value.substring(mt76Value.indexOf("/UETR/")+6));
                additionalInformation = mt76Value.substring(0,mt76Value.indexOf("/UETR/"));
            }else {
                AbstractMT abstractMT = context.get(AbstractMT.class);
                String orgnlUETR = abstractMT.getSwiftMessage().getUETR();
                if(StringUtil.isNotEmpty(orgnlUETR)){
                    maps.put("orgnlUETR",orgnlUETR);
                }else {
                    buildSTErrorInfo(ERROR.T20087, "Block3/UETR", null);
                }
            }
            if(additionalInformation.length()>210){
                buildSTErrorInfo(ERROR.T0000T, "FIToFIPmtCxlReq/Undrlyg/TxInf/CxlRsnInf/AddtlInf", additionalInformation);
                additionalInformation = additionalInformation.substring(0,209) + "+";
            }
            List<String> list = new ArrayList<>();
            if (additionalInformation.length()>105){
                list.add(additionalInformation.substring(0,105));
                list.add(additionalInformation.substring(105));
            }else if(additionalInformation.length()>0){
                list.add(additionalInformation);
            }else {
                if("NARR".equals(mxCode)){
                    additionalInformation = Mx2MtConstants.MT_TO_MX_DEFAULT_VALUE;
                    list.add(additionalInformation);
                }
            }
            maps.put("cxlRsnInf",cxlRsnInfJSONArray);
            cxlRsnInfJSONArray.add(cxlRsnInfMaps);
            cxlRsnInfMaps.put("rsn",rsnMaps);
            rsnMaps.put("cd",mxCode);
            cxlRsnInfMaps.put("addtlInf",addtlInfJSONArray);
            addtlInfJSONArray.addAll(list);
        }
    }

    protected void mt_to_mxReject72(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        JSONArray stsRsnInfJsonArray = null;
        if (maps.containsKey("stsRsnInf")) {
            stsRsnInfJsonArray = (JSONArray)maps.get("stsRsnInf");
        } else {
            stsRsnInfJsonArray = new JSONArray();
        }
        Map<String, Object> stsRsnInfMap = new HashMap<>();

        String mxReasonCodeOrProprietary = "";
        String additionalInformation = "";
        int maxLength = 0;
        String mtReasonCode = "";
        String[] mt72s = mt72.split(Mx2MtConstants.NEW_LINE);
        String line2 = "";
        if (mt72s.length >= 2) {
            line2 = mt72s[1];
        }
        String regex = "/XT99/(.*)/(.*)";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(line2);
        if (m.find()) {
            mxReasonCodeOrProprietary = m.group(1);
            additionalInformation = m.group(2);
            maxLength = 35 - 6 - mxReasonCodeOrProprietary.length() - 1;
        } else {
            regex = "/([0-9A-Z]{2}[0-9]{2})/(.*)";
            p = Pattern.compile(regex);
            m = p.matcher(line2);
            if (m.find()) {
                mtReasonCode = m.group(1);
                additionalInformation = m.group(2);
                maxLength = 29;
            } else {
                additionalInformation = line2;
                maxLength = 35;
            }
        }
        String line6 = "";
        String refreshMt72 = refreshValue(mt72, "//", 35).replace(Mx2MtConstants.NEW_LINE + "//", "");
        String[] refreshMt72s = refreshMt72.split(Mx2MtConstants.NEW_LINE);
        for (int i=0; i<refreshMt72s.length; i++) {
            if (refreshMt72s[i].startsWith("/TEXT/")) {
                line6 = refreshMt72s[i].substring(6);
                break;
            }
        }
        if (line6.length() > 0) {
            if (additionalInformation.length() > 0) {
                if (additionalInformation.length() < maxLength) {
                    additionalInformation += " " + line6;
                } else {
                    additionalInformation += line6;
                }
            } else {
                additionalInformation = line6;
            }
        }
        Map<String, Object> rsnMaps = new HashMap<>();
        if (mxReasonCodeOrProprietary.length() > 0) {
            StatusReasonCode code = SwiftTransferUtil.getStatusReasonCodeByCode(mxReasonCodeOrProprietary);
            if (code != null) {
                rsnMaps.put("cd", mxReasonCodeOrProprietary);
            } else {
                rsnMaps.put("cd", StatusReasonCode.NARR.value());
                if (additionalInformation.length() > 0) {
                    additionalInformation = mxReasonCodeOrProprietary + "/" + additionalInformation;
                } else {
                    additionalInformation = mxReasonCodeOrProprietary;
                }
            }
        } else if (mtReasonCode.length() > 0) {
            List<MxMtReasonCodeInfo> mxMtReasonCodeInfos = SwiftTransferUtil.getMxMtReasonCodes();
            String mxReasonCode = "";
            boolean isMxErrorCodePresent = false;
            if (mxMtReasonCodeInfos != null && mxMtReasonCodeInfos.size() > 0) {
                for (int i=0; i<mxMtReasonCodeInfos.size(); i++) {
                    MxMtReasonCodeInfo mxMtReasonCodeInfo = mxMtReasonCodeInfos.get(i);
                    if (mtReasonCode.equals(mxMtReasonCodeInfo.getMtCode())) {
                        isMxErrorCodePresent = mxMtReasonCodeInfo.isMxErrorCodePresent();
                        mxReasonCode = mxMtReasonCodeInfo.getIsoCode();
                        break;
                    }
                }
            }
            if (!isMxErrorCodePresent) {
                rsnMaps.put("prtry", mtReasonCode);
            } else {
                rsnMaps.put("cd", mxReasonCode);
            }
        } else {
            rsnMaps.put("cd", ReturnReasonCode.NARR.value());
        }
        if (additionalInformation.length() > 0) {
            if (additionalInformation.length() > 210) {
                buildSTErrorInfo(ERROR.T0000T, "TxInfAndSts/StsRsnInf/AddtlInf", additionalInformation);
                additionalInformation = additionalInformation.substring(0, 209) + "+";
            }
            List<String> list = new ArrayList<>();
            if (additionalInformation.length() > 105) {
                String addInf1 = additionalInformation.substring(0, 105);
                String addInf2 = additionalInformation.substring(105);
                list.add(addInf1);
                list.add(addInf2);
            } else {
                list.add(additionalInformation);
            }
            stsRsnInfMap.put("addtlInf", list);
        }
        if (rsnMaps.size() > 0) {
            stsRsnInfMap.put("rsn", rsnMaps);
        }
        if (stsRsnInfMap.size() > 0) {
            stsRsnInfJsonArray.add(stsRsnInfMap);
        }
        if (stsRsnInfJsonArray.size() > 0) {
            maps.put("stsRsnInf", stsRsnInfJsonArray);
        }
    }

    protected void mt_to_mxUltimateParty(String mt70, Map<String, Object> maps, String pattern) {
        if (StringUtil.isEmpty(mt70)) {
            return;
        }
        String[] patternTable = new String[]{"/ULTB/", "/ULTD/", "/PURP/", "/ROC/", "/URI/",
                            "/RELID/", "/SRI/", "/INV/", "/IPI/", "/RFB/", "/ROC/", "/TSU/"};
        mt70 = mt70.replace(Mx2MtConstants.NEW_LINE, "");
        String patternString = "";
        for (int i=0; i<patternTable.length; i++) {
            String regex = "(.*)"+pattern+"(.*)//"+patternTable[i]+"(.*)";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mt70);
            if (m.find()) {
                patternString = m.group(2);
                break;
            } else {
                regex = "(.*)"+pattern+"(.*)"+patternTable[i]+"(.*)";
                p = Pattern.compile(regex);
                m = p.matcher(mt70);
                if (m.find()) {
                    patternString = m.group(2);
                    break;
                }
            }
        }
        if (StringUtil.isEmpty(patternString)) {
            String regex = "(.*)"+pattern+"(.*)";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mt70);
            if (m.find()) {
                patternString = m.group(2);
            }
        }
        //处理pattern string
        if (StringUtil.isNotEmpty(patternString)) {
            if (SwiftTransferUtil.isBIC(patternString)) {
                mt_to_mxAnyBIC(patternString, maps);
            } else {
                String mxName = "";
                String mxCountry = "";
                String mxTownName = "";
                String mxOther = "";
                String regex = "(.*)/([A-Z]{2})/(.*)";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(patternString);
                if (m.find()) {
                    mxName = m.group(1);
                    mxCountry = m.group(2);
                    mxTownName = m.group(3);
                } else {
                    regex = "(.*)/(.*)";
                    p = Pattern.compile(regex);
                    m = p.matcher(patternString);
                    if (m.find()) {
                        mxName = m.group(1);
                        mxOther = m.group(2);
                        if (mxOther.matches("[A-Z]{2}")) {
                            mxCountry = mxOther;
                            mxOther = "";
                        }
                    } else {
                        mxName = patternString;
                    }
                }
                if (mxName.length() > 140) {
                    buildSTErrorInfo(ERROR.T0000T, "Pty/Nm", mxName);
                    mxName = mxName.substring(0, 139) + "+";
                }
                maps.put("nm", mxName);
                if (mxCountry.length() > 0) {
                    Map<String, Object> pstlAdrMaps = null;
                    if (maps.containsKey("pstlAdr")) {
                        pstlAdrMaps = (Map<String, Object>)maps.get("pstlAdr");
                    } else {
                        pstlAdrMaps = new HashMap<>();
                        maps.put("pstlAdr", pstlAdrMaps);
                    }
                    pstlAdrMaps.put("ctry", mxCountry);
                    if (mxTownName.length() > 0) {
                        if (mxTownName.length() > 35) {
                            buildSTErrorInfo(ERROR.T0000T, "Pty/PstlAdr/TwnNm", mxTownName);
                            mxTownName = mxTownName.substring(0, 34) + "+";
                        }
                        pstlAdrMaps.put("twnNm", mxTownName);
                    }
                }
                if (mxOther.length() > 0) {
                    if (mxOther.length() > 35) {
                        buildSTErrorInfo(ERROR.T0000T, "Pty/Id/PrvtId/Othr/Id", mxOther);
                        mxOther = mxOther.substring(0, 34) + "+";
                    }
                    Map<String, Object> idMaps = null;
                    if (maps.containsKey("id")) {
                        idMaps = (Map<String, Object>)maps.get("id");
                    } else {
                        idMaps = new HashMap<>();
                        maps.put("id", idMaps);
                    }
                    Map<String, Object> prvtIdMaps = null;
                    if (idMaps.containsKey("prvtId")) {
                        prvtIdMaps = (Map<String, Object>)idMaps.get("prvtId");
                    } else {
                        prvtIdMaps = new HashMap<>();
                        idMaps.put("prvtId", prvtIdMaps);
                    }
                    Map<String, Object> othrMaps = null;
                    if (prvtIdMaps.containsKey("othr")) {
                        othrMaps = (Map<String, Object>)prvtIdMaps.get("othr");
                    } else {
                        othrMaps = new HashMap<>();
                        prvtIdMaps.put("othr", othrMaps);
                    }
                    othrMaps.put("id", mxOther);
                }
            }
        }
    }

    protected void mt_to_mxReturn72(String mt72, Map<String, Object> maps) {
        if (StringUtil.isEmpty(mt72)) {
            return;
        }
        JSONArray rtrRsnInfJsonArray = null;
        if (maps.containsKey("rtrRsnInf")) {
            rtrRsnInfJsonArray = (JSONArray)maps.get("rtrRsnInf");
        } else {
            rtrRsnInfJsonArray = new JSONArray();
        }
        Map<String, Object> rtrRsnInfMap = new HashMap<>();

        String mxReasonCodeOrProprietary = "";
        String additionalInformation = "";
        int maxLength = 0;
        String mtReasonCode = "";
        String[] mt72s = mt72.split(Mx2MtConstants.NEW_LINE);
        String line2 = "";
        if (mt72s.length >= 2) {
            line2 = mt72s[1];
        }
        String regex = "/XT99/(.*)/(.*)";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(line2);
        if (m.find()) {
            mxReasonCodeOrProprietary = m.group(1);
            additionalInformation = m.group(2);
            maxLength = 35 - 6 - mxReasonCodeOrProprietary.length() - 1;
        } else {
            regex = "/([0-9A-Z]{2}[0-9]{2})/(.*)";
            p = Pattern.compile(regex);
            m = p.matcher(line2);
            if (m.find()) {
                mtReasonCode = m.group(1);
                additionalInformation = m.group(2);
                maxLength = 29;
            } else {
                additionalInformation = line2;
                maxLength = 35;
            }
        }
        String line6 = "";
        String refreshMt72 = refreshValue(mt72, "//", 35).replace(Mx2MtConstants.NEW_LINE + "//", "");
        String[] refreshMt72s = refreshMt72.split(Mx2MtConstants.NEW_LINE);
        for (int i=0; i<refreshMt72s.length; i++) {
            if (refreshMt72s[i].startsWith("/TEXT/")) {
                line6 = refreshMt72s[i].substring(6);
                break;
            }
        }
        if (line6.length() > 0) {
            if (additionalInformation.length() > 0) {
                if (additionalInformation.length() < maxLength) {
                    additionalInformation += " " + line6;
                } else {
                    additionalInformation += line6;
                }
            } else {
                additionalInformation = line6;
            }
        }
        Map<String, Object> rsnMaps = new HashMap<>();
        if (mxReasonCodeOrProprietary.length() > 0) {
            ReturnReasonCode code = SwiftTransferUtil.getReturnReasonCodeByCode(mxReasonCodeOrProprietary);
            if (code != null) {
                rsnMaps.put("cd", mxReasonCodeOrProprietary);
            } else {
                rsnMaps.put("cd", ReturnReasonCode.NARR.value());
                if (additionalInformation.length() > 0) {
                    additionalInformation = mxReasonCodeOrProprietary + "/" + additionalInformation;
                } else {
                    additionalInformation = mxReasonCodeOrProprietary;
                }
            }
        } else if (mtReasonCode.length() > 0) {
            List<MxMtReasonCodeInfo> mxMtReasonCodeInfos = SwiftTransferUtil.getMxMtReasonCodes();
            String mxReasonCode = "";
            boolean isMxErrorCodePresent = false;
            if (mxMtReasonCodeInfos != null && mxMtReasonCodeInfos.size() > 0) {
                for (int i=0; i<mxMtReasonCodeInfos.size(); i++) {
                    MxMtReasonCodeInfo mxMtReasonCodeInfo = mxMtReasonCodeInfos.get(i);
                    if (mtReasonCode.equals(mxMtReasonCodeInfo.getMtCode())) {
                        isMxErrorCodePresent = mxMtReasonCodeInfo.isMxErrorCodePresent();
                        mxReasonCode = mxMtReasonCodeInfo.getIsoCode();
                        break;
                    }
                }
            }
            if (!isMxErrorCodePresent) {
                if (additionalInformation.length() > 0) {
                    additionalInformation = mtReasonCode + "/" + additionalInformation;
                } else {
                    additionalInformation = mtReasonCode;
                }
            }
            if (StringUtil.isEmpty(mxReasonCode)) {
                mxReasonCode = ReturnReasonCode.NARR.value();
            }
            rsnMaps.put("cd", mxReasonCode);
        } else {
            rsnMaps.put("cd", ReturnReasonCode.NARR.value());
        }
        if (additionalInformation.length() > 0) {
            if (additionalInformation.length() > 210) {
                buildSTErrorInfo(ERROR.T0000T, "TxInf/RtrRsnInf/AddtlInf", additionalInformation);
                additionalInformation = additionalInformation.substring(0, 209) + "+";
            }
            List<String> list = new ArrayList<>();
            if (additionalInformation.length() > 105) {
                String addInf1 = additionalInformation.substring(0, 105);
                String addInf2 = additionalInformation.substring(105);
                list.add(addInf1);
                list.add(addInf2);
            } else {
                list.add(additionalInformation);
            }
            rtrRsnInfMap.put("addtlInf", list);
        }
        if (rsnMaps.size() > 0) {
            rtrRsnInfMap.put("rsn", rsnMaps);
        }
        if (rtrRsnInfMap.size() > 0) {
            rtrRsnInfJsonArray.add(rtrRsnInfMap);
        }
        if (rtrRsnInfJsonArray.size() > 0) {
            maps.put("rtrRsnInf", rtrRsnInfJsonArray);
        }
    }

    /**
     * MT 转 MX 转换函数结束
     */

}
