package com.brilliance.swift.mt2mx;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.camt029001.Mt2MxCamt029001Creator;
import com.brilliance.swift.mt2mx.camt052001.Mt2MxCamt052001Creator;
import com.brilliance.swift.mt2mx.camt053001.Mt2MxCamt053001Creator;
import com.brilliance.swift.mt2mx.camt054001.Mt2MxCamt054001Creator;
import com.brilliance.swift.mt2mx.camt056001.Mt2MxCamt056001Creator;
import com.brilliance.swift.mt2mx.camt057001.Mt2MxCamt057001Creator;
import com.brilliance.swift.mt2mx.camt060001.Mt2MxCamt060001Creator;
import com.brilliance.swift.mt2mx.pacs002001.Mt2MxPacs002001Creator;
import com.brilliance.swift.mt2mx.pacs004001.Mt2MxPacs004001Creator;
import com.brilliance.swift.mt2mx.pacs008001.Mt2MxPacs008001Creator;
import com.brilliance.swift.mt2mx.pacs009001.Mt2MxPacs009001Creator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftTranslationReport;
import com.prowidesoftware.swift.model.SwiftTagListBlock;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.List;
import java.util.Map;

public class Mt2MxCreatorManager {

    public AbstractMT abstractMT = null;

    public void init(String mtStr) {
        try {
            abstractMT = AbstractMT.parse(mtStr);
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public SwiftTranslationReport mt2mx(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        init(mtStr);
        AbstractMt2MxCreator creator = getMt2MxCreator();
        Mt2MxContext context = new Mt2MxContext();
        context.set(AbstractMT.class, abstractMT);
        context.set(Mt2MxContextIdentifier.MT_TO_MX_OUTPUT_FILE_PATH, outPutFilePath);
        context.putAll(extraMap);
        creator.setContext(context);
        creator.preProcess();
        List<Mt2MxParseField> parseFields = creator.getParseFieldList();
        for (int i=0; i<parseFields.size(); i++) {
            AbstractMt2MxParseField parseField = (AbstractMt2MxParseField) parseFields.get(i);
            parseField.setContext(context).initJsonMaps();
            parseField.parseField();
        }
        creator.postProcess();
        SwiftTranslationReport str = context.get(SwiftTranslationReport.class);
        return str;
    }

    public AbstractMt2MxCreator getMt2MxCreator() throws SwiftException {
        String messageType = processMessageType(abstractMT.getMessageType());
        if ("103".equals(messageType)) {
            return new Mt2MxPacs008001Creator();
        } else if ("202".equals(messageType) || "205".equals(messageType)) {
            return new Mt2MxPacs009001Creator();
        } else if ("103REJT".equals(messageType) || "202REJT".equals(messageType) || "205REJT".equals(messageType)) {
            return new Mt2MxPacs002001Creator();
        } else if ("103RETN".equals(messageType) || "202RETN".equals(messageType) || "205RETN".equals(messageType)) {
            return new Mt2MxPacs004001Creator();
        } else if("196".equals(messageType) || "296".equals(messageType)) {
            return new Mt2MxCamt029001Creator();
        } else if("192".equals(messageType)||"292".equals(messageType)) {
            return new Mt2MxCamt056001Creator();
        } else if("900".equals(messageType)||"910".equals(messageType)) {
            return new Mt2MxCamt054001Creator();
        } else if("940".equals(messageType)||"950".equals(messageType)) {
            return new Mt2MxCamt053001Creator();
        } else if("942".equals(messageType)){
            return new Mt2MxCamt052001Creator();
        } else if("210".equals(messageType)){
            return new Mt2MxCamt057001Creator();
        } else if ("920".equals(messageType)) {
            return new Mt2MxCamt060001Creator();
        } else {
            throw new SwiftException("Invalid message type");
        }
    }

    /**
     * mt103 202 205 可能会转pacs008/pacs009,pacs004,pacs002
     * 根据72域值判断
     * @param messageType
     * @return
     */
    public String processMessageType(String messageType) {
        if ("103".equals(messageType) || "202".equals(messageType) || "205".equals(messageType)) {
            Tag tag72 = null;
            boolean isCov = abstractMT.getSwiftMessage().isCOV();
            if (isCov) {
                SwiftTagListBlock swiftTagListBlock = abstractMT.getSequence("A");
                if (swiftTagListBlock != null) {
                    tag72 = swiftTagListBlock.getTagByName("72");
                }
            } else {
                tag72 = abstractMT.getSwiftMessage().getBlock4().getTagByName("72");
            }
            if (tag72 != null && StringUtil.isNotEmpty(tag72.getValue())) {
                if (tag72.getValue().startsWith("/REJT/")) {
                    messageType += "REJT";
                } else if (tag72.getValue().startsWith("/RETN/")) {
                    messageType += "RETN";
                }
            }
        }
        return messageType;

    }
}
