package com.brilliance.swift.mt2mx.camt052001;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.mt2mx.AbstractMt2MxCreator;
import com.brilliance.swift.mt2mx.Mt2MxParseField;
import com.brilliance.swift.mt2mx.camt052001.impl.*;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field90C;
import com.prowidesoftware.swift.model.field.Field90D;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mx.dic.CreditDebitCode;
import com.prowidesoftware.swift.utils.SwiftFormatUtils;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Mt2MxCamt052001Creator extends AbstractMt2MxCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        //将报文类型放入jsonMaps集合中，这个maps集合是最上层
        jsonMaps.put("identifier", "camt.052.001.08");
        Map<String, Object> appHdrMaps = (Map<String, Object>)jsonMaps.get("appHdr");
        //将消息头中的消息名放入头部的map集合中
        appHdrMaps.put("msgDefIdr", "camt.052.001.08");
        //得到AbstractMT这个对象用来解析mt文件
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Map<String, Object> bkToCstmrAcctRptMaps = new HashMap<>();
        jsonMaps.put("bkToCstmrAcctRpt", bkToCstmrAcctRptMaps);
        Map<String, Object> grpHdrMaps = new HashMap<>();
        bkToCstmrAcctRptMaps.put("grpHdr", grpHdrMaps);
        //将当前的时间存入这个map集合中
        grpHdrMaps.put("creDtTm", getCreateDateStr());
        //在sts中存入默认值BOOK,bkTxCd下cd,issr取初始值NOTPROVIDED
        Map<String, Object> rptMaps = new HashMap<>();
        JSONArray rptJsonArray = new JSONArray();
        rptJsonArray.add(rptMaps);
        bkToCstmrAcctRptMaps.put("rpt", rptJsonArray);
        JSONArray ntryJsonArray = new JSONArray();
        Map<String, Object> ntryMaps = new HashMap<>();
        rptMaps.put("ntry",ntryJsonArray);
        ntryJsonArray.add(ntryMaps);
        Map<String, Object> stsMaps = new HashMap<>();
        ntryMaps.put("sts",stsMaps);
        stsMaps.put("cd","BOOK");
        Map<String, Object> bkTxCdMaps = new HashMap<>();
        ntryMaps.put("bkTxCd",bkTxCdMaps);
        Map<String, Object> prtryMaps = new HashMap<>();
        bkTxCdMaps.put("prtry",prtryMaps);
        prtryMaps.put("cd", Mx2MtConstants.MT_TO_MX_DEFAULT_VALUE);
        prtryMaps.put("issr",Mx2MtConstants.MT_TO_MX_DEFAULT_VALUE);
        //这个操作是将借记和贷记的笔数和金额进行计算
        Tag tag90C = abstractMT.getSwiftMessage().getBlock4().getTagByName("90C");
        Tag tag90D = abstractMT.getSwiftMessage().getBlock4().getTagByName("90D");
        if(tag90C!=null||tag90D!=null){
            Map<String, Object> txsSummryMaps = null;
            if (rptMaps.containsKey("txsSummry")) {
                txsSummryMaps = (Map<String, Object>) rptMaps.get("txsSummry");
            } else {
                txsSummryMaps = new HashMap<>();
                rptMaps.put("txsSummry",txsSummryMaps);
            }
            int field90CNumber = 0;
            BigDecimal field90CSum = BigDecimal.valueOf(0);
            if(tag90C!=null){
                Field90C field90C = (Field90C)tag90C.asField();
                field90CNumber = Integer.parseInt(field90C.getNumber());
                Number number = SwiftFormatUtils.getNumber(field90C.getAmount());
                field90CSum = new BigDecimal(number.toString()).stripTrailingZeros();
            }
            int field90DNumber = 0;
            BigDecimal field90DSum = BigDecimal.valueOf(0);
            if(tag90D!=null){
                Field90D field90D = (Field90D)tag90D.asField();
                field90DNumber = Integer.parseInt(field90D.getNumber());
                Number number = SwiftFormatUtils.getNumber(field90D.getAmount());
                field90DSum = new BigDecimal(number.toString()).stripTrailingZeros();
            }
            Map<String, Object> ttlNtriesMaps = new HashMap<>();
            txsSummryMaps.put("ttlNtries",ttlNtriesMaps);
            ttlNtriesMaps.put("nbOfNtries",field90CNumber+field90DNumber);
            ttlNtriesMaps.put("sum",field90CSum.add(field90DSum));
            Map<String, Object> ttlNetNtryMaps = new HashMap<>();
            ttlNtriesMaps.put("ttlNetNtry",ttlNetNtryMaps);
            BigDecimal subtract = field90CSum.subtract(field90DSum);
            int i = subtract.compareTo(BigDecimal.ZERO);
            if(i>=0){
                ttlNetNtryMaps.put("cdtDbtInd", CreditDebitCode.CRDT.value());
                ttlNetNtryMaps.put("amt", subtract);
            }else {
                ttlNetNtryMaps.put("cdtDbtInd", CreditDebitCode.DBIT.value());
                ttlNetNtryMaps.put("amt", subtract.negate());
            }
        }

    }

    @Override
    public List<Mt2MxParseField> getParseFieldList() {
        List<Mt2MxParseField> list = new ArrayList<>();
        list.add(new Camt052001Parse13DField());
        list.add(new Camt052001Parse20Field());
        list.add(new Camt052001Parse21Field());
        list.add(new Camt052001Parse25Field());
        list.add(new Camt052001Parse28CField());
        list.add(new Camt052001Parse34FField());
        list.add(new Camt052001Parse61Field());
        list.add(new Camt052001Parse90CField());
        list.add(new Camt052001Parse90DField());
        return list;
    }
}
