package com.brilliance.swift.mt2mx.camt053001.impl;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.camt053001.AbstractMt2MxCamt053001ParseField;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.common.BalanceSubTypeCode;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field60F;
import com.prowidesoftware.swift.model.field.Field60M;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.text.ParseException;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
//起始余额
public class Camt053001Parse60Field extends AbstractMt2MxCamt053001ParseField {

    private static final String NAME_F = "60F";

    private static final String NAME_M = "60M";

    @Override
    public void parseField() throws SwiftException {
        try {
            Field60F field60F = null;
            Field60M field60M = null;
            AbstractMT abstractMT = context.get(AbstractMT.class);
            Tag tag60 = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_F);
            if (tag60 != null) {
                field60F = (Field60F) tag60.asField();
            }
            tag60 = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_M);
            if (tag60 != null) {
                field60M = (Field60M) tag60.asField();
            }
            Map<String, Object> balMaps = null;
            JSONArray balJsonArray = null;
            if(stmtMaps.containsKey("bal")){
                balJsonArray = (JSONArray) stmtMaps.get("bal");
                balMaps = new HashMap<>();
                balJsonArray.add(balMaps);
            }else {
                balJsonArray = new JSONArray();
                balMaps = new HashMap<>();
                stmtMaps.put("bal",balJsonArray);
                balJsonArray.add(balMaps);
            }
            Map<String, Object> tpMaps = new HashMap<>();
            balMaps.put("tp",tpMaps);
            Map<String, Object> cdOrPrtryMaps = new HashMap<>();
            tpMaps.put("cdOrPrtry",cdOrPrtryMaps);
            cdOrPrtryMaps.put("cd", BalanceTypeCode.OPBD.value());
            Map<String, Object> dtMaps = null;
            if(balMaps.containsKey("dt")){
                dtMaps = (Map<String, Object>)balMaps.get("dt");
            }else {
                dtMaps = new HashMap<>();
                balMaps.put("dt",dtMaps);
            }
            Map<String, Object> amtMaps = null;
            if(balMaps.containsKey("amt")){
                amtMaps = (Map<String, Object>)balMaps.get("amt");
            }else {
                amtMaps = new HashMap<>();
                balMaps.put("amt",amtMaps);
            }
            if (field60F != null) {
                if ("D".equals(field60F.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.DBIT.value());
                } else if ("C".equals(field60F.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.CRDT.value());
                }
                Date date = DateUtil.parseDate("20" + field60F.getDate(), "yyyyMMdd");
                String dateStr = DateUtil.format(date, "yyyy-MM-dd");
                dtMaps.put("dt",dateStr);
                amtMaps.put("value",field60F.amount());
                amtMaps.put("ccy",field60F.getCurrency());
            }
            if (field60M != null) {
                Map<String, Object> subTpMaps = new HashMap<>();
                tpMaps.put("subTp",subTpMaps);
                subTpMaps.put("cd", BalanceSubTypeCode.INTM.value());
                if ("D".equals(field60M.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.DBIT.value());
                } else if ("C".equals(field60M.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.CRDT.value());
                }
                Date date = DateUtil.parseDate("20" + field60M.getDate(), "yyyyMMdd");
                String dateStr = DateUtil.format(date, "yyyy-MM-dd");
                dtMaps.put("dt",dateStr);
                amtMaps.put("value",field60M.amount());
                amtMaps.put("ccy",field60M.getCurrency());
            }
        } catch (ParseException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
