package com.brilliance.swift.mt2mx.camt053001.impl;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.camt053001.AbstractMt2MxCamt053001ParseField;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.common.BalanceSubTypeCode;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field62F;
import com.prowidesoftware.swift.model.field.Field62M;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.text.ParseException;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
//结束余额
public class Camt053001Parse62Field extends AbstractMt2MxCamt053001ParseField {

    private static final String NAME_F = "62F";

    private static final String NAME_M = "62M";

    @Override
    public void parseField() throws SwiftException {
        try {
            Field62F field62F = null;
            Field62M field62M = null;
            AbstractMT abstractMT = context.get(AbstractMT.class);
            Tag tag62 = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_F);
            if (tag62 != null) {
                field62F = (Field62F) tag62.asField();
            }
            tag62 = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_M);
            if (tag62 != null) {
                field62M = (Field62M) tag62.asField();
            }
            Map<String, Object> balMaps = null;
            JSONArray balJsonArray = null;
            if(stmtMaps.containsKey("bal")){
                balJsonArray = (JSONArray) stmtMaps.get("bal");
                balMaps = new HashMap<>();
                balJsonArray.add(balMaps);
            }else {
                balJsonArray = new JSONArray();
                balMaps = new HashMap<>();
                stmtMaps.put("bal",balJsonArray);
                balJsonArray.add(balMaps);
            }
            Map<String, Object> tpMaps = new HashMap<>();
            balMaps.put("tp",tpMaps);
            Map<String, Object> cdOrPrtryMaps = new HashMap<>();
            tpMaps.put("cdOrPrtry",cdOrPrtryMaps);

            cdOrPrtryMaps.put("cd", BalanceTypeCode.CLBD.value());
            Map<String, Object> dtMaps = null;
            if(balMaps.containsKey("dt")){
                dtMaps = (Map<String, Object>)balMaps.get("dt");
            }else {
                dtMaps = new HashMap<>();
                balMaps.put("dt",dtMaps);
            }
            Map<String, Object> amtMaps = null;
            if(balMaps.containsKey("amt")){
                amtMaps = (Map<String, Object>)balMaps.get("amt");
            }else {
                amtMaps = new HashMap<>();
                balMaps.put("amt",amtMaps);
            }
            Map<String, Object> stmtPgntnMaps = null;
            if (stmtMaps.containsKey("stmtPgntn")) {
                stmtPgntnMaps = (Map<String, Object>) stmtMaps.get("stmtPgntn");
            } else {
                stmtPgntnMaps = new HashMap<>();
                stmtMaps.put("stmtPgntn",stmtPgntnMaps);
            }
            if (field62F != null) {
                stmtPgntnMaps.put("lastPgInd",Boolean.TRUE);
                if ("D".equals(field62F.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.DBIT.value());
                } else if ("C".equals(field62F.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.CRDT.value());
                }
                Date date = DateUtil.parseDate("20" + field62F.getDate(), "yyyyMMdd");
                String dateStr = DateUtil.format(date, "yyyy-MM-dd");
                dtMaps.put("dt",dateStr);
                amtMaps.put("value",field62F.amount());
                amtMaps.put("ccy",field62F.getCurrency());
            }
            if (field62M != null) {
                stmtPgntnMaps.put("lastPgInd",Boolean.FALSE);
                Map<String, Object> subTpMaps = new HashMap<>();
                tpMaps.put("subTp",subTpMaps);
                subTpMaps.put("cd", BalanceSubTypeCode.INTM.value());
                if ("D".equals(field62M.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.DBIT.value());
                } else if ("C".equals(field62M.getDCMark())) {
                    balMaps.put("cdtDbtInd", CdtDbtCode.CRDT.value());
                }
                Date date = DateUtil.parseDate("20" + field62M.getDate(), "yyyyMMdd");
                String dateStr = DateUtil.format(date, "yyyy-MM-dd");
                dtMaps.put("dt",dateStr);
                amtMaps.put("value",field62M.amount());
                amtMaps.put("ccy",field62M.getCurrency());
            }
        } catch (ParseException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
