package com.brilliance.swift.mt2mx.camt054001;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.mt2mx.AbstractMt2MxCreator;
import com.brilliance.swift.mt2mx.Mt2MxContextIdentifier;
import com.brilliance.swift.mt2mx.Mt2MxParseField;
import com.brilliance.swift.mt2mx.camt054001.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mx.dic.CreditDebitCode;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Mt2MxCamt054001Creator extends AbstractMt2MxCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        //将报文类型放入jsonMaps集合中，这个maps集合是最上层
        jsonMaps.put("identifier", "camt.054.001.08");
        Map<String, Object> appHdrMaps = (Map<String, Object>)jsonMaps.get("appHdr");
        //将消息头中的消息名放入头部的map集合中
        appHdrMaps.put("msgDefIdr", "camt.054.001.08");
        //得到AbstractMT这个对象用来解析mt文件
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Map<String, Object> bkToCstmrDbtCdtNtfctnMaps = new HashMap<>();
        jsonMaps.put("bkToCstmrDbtCdtNtfctn", bkToCstmrDbtCdtNtfctnMaps);
        Map<String, Object> grpHdrMaps = new HashMap<>();
        bkToCstmrDbtCdtNtfctnMaps.put("grpHdr", grpHdrMaps);
        grpHdrMaps.put("creDtTm", getCreateDateStr());
        //将当前的时间存入这个map集合中
        grpHdrMaps.put("nbOfTxs", "1");
        //存储初始值，sts为BOOK,cd,issr,ntryRef的值为NOTPROVIDED
        //cdtDbtInd中存储DBIT，CRDT,借记和贷记
        Map<String, Object> ntfctnMaps = new HashMap<>();
        JSONArray ntfctnJsonArray = new JSONArray();
        ntfctnJsonArray.add(ntfctnMaps);
        bkToCstmrDbtCdtNtfctnMaps.put("ntfctn", ntfctnJsonArray);
        Map<String, Object> ntryMaps = new HashMap<>();
        JSONArray ntryJsonArray = new JSONArray();
        ntryJsonArray.add(ntryMaps);
        ntfctnMaps.put("ntry",ntryJsonArray);
        Map<String, Object> ntryDtlsMaps = new HashMap<>();
        JSONArray ntryDtlsJsonArray = new JSONArray();
        ntryDtlsJsonArray.add(ntryDtlsMaps);
        ntryMaps.put("ntryDtls",ntryDtlsJsonArray);
        Map<String, Object> txDtlsMaps = new HashMap<>();
        JSONArray txDtlsJsonArray = new JSONArray();
        txDtlsJsonArray.add(txDtlsMaps);
        ntryDtlsMaps.put("txDtls",txDtlsJsonArray);
        Map<String, Object> stsMaps = new HashMap<>();
        ntryMaps.put("sts",stsMaps);
        Map<String, Object> bkTxCdMaps = new HashMap<>();
        stsMaps.put("cd","BOOK");
        ntryMaps.put("bkTxCd",bkTxCdMaps);
        Map<String, Object> prtryMaps = new HashMap<>();
        bkTxCdMaps.put("prtry",prtryMaps);
        prtryMaps.put("cd",Mx2MtConstants.MT_TO_MX_DEFAULT_VALUE);
        prtryMaps.put("issr",Mx2MtConstants.MT_TO_MX_DEFAULT_VALUE);
        ntryMaps.put("ntryRef",Mx2MtConstants.MT_TO_MX_DEFAULT_VALUE);
        if("900".equals(abstractMT.getMessageType())){
            ntryMaps.put("cdtDbtInd", CreditDebitCode.DBIT.value());
            txDtlsMaps.put("cdtDbtInd",CreditDebitCode.DBIT.value());
        } else if("910".equals(abstractMT.getMessageType())){
            ntryMaps.put("cdtDbtInd", CreditDebitCode.CRDT.value());
            txDtlsMaps.put("cdtDbtInd",CreditDebitCode.CRDT.value());
        }
        String uetr = abstractMT.getSwiftMessage().getUETR();
        if (StringUtil.isNotEmpty(uetr)) {
            Map<String, Object> refsMaps = new HashMap<>();
            txDtlsMaps.put("refs",refsMaps);
            refsMaps.put("uetr",uetr);
        }
        context.set(Mt2MxContextIdentifier.MT_TO_MX_FLAG_50,"false");
    }

    @Override
    public List<Mt2MxParseField> getParseFieldList() {
        List<Mt2MxParseField> list = new ArrayList<>();
        list.add(new Camt054001Parse13DField());
        list.add(new Camt054001Parse20Field());
        list.add(new Camt054001Parse21Field());
        list.add(new Camt054001Parse25Field());
        list.add(new Camt054001Parse32AField());
        list.add(new Camt054001Parse50Field());
        list.add(new Camt054001Parse52For900Field());
        list.add(new Camt054001Parse52For910Field());
        list.add(new Camt054001Parse56Field());
        list.add(new Camt054001Parse72Field());
        return list;
    }
}
