package com.brilliance.swift.mt2mx.camt054001.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.Mt2MxContextIdentifier;
import com.brilliance.swift.mt2mx.camt054001.AbstractMt2MxCamt054001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field50A;
import com.prowidesoftware.swift.model.field.Field50F;
import com.prowidesoftware.swift.model.field.Field50K;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
//汇款人信息
public class Camt054001Parse50Field extends AbstractMt2MxCamt054001ParseField {

    private static final String NAME_A = "50A";

    private static final String NAME_F = "50F";

    private static final String NAME_K = "50K";

    @Override
    public void parseField() throws SwiftException {
        Field50A field50A = null;
        Field50F field50F = null;
        Field50K field50K = null;
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if("900".equals(abstractMT.getMessageType())){
            return;
        }
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_A);
        if (tag != null) {
            field50A = (Field50A)tag.asField();
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_F);
        if (tag != null) {
            field50F = (Field50F)tag.asField();
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_K);
        if (tag != null) {
            field50K = (Field50K)tag.asField();
        }
        if(field50A!=null||field50F!=null||field50K!=null){
            context.set(Mt2MxContextIdentifier.MT_TO_MX_FLAG_50,"true");
        }
        Map<String, Object> rltdPtiesMaps = null;
        if (txDtlsMaps.containsKey("rltdPties")) {
            rltdPtiesMaps = (Map<String, Object>) txDtlsMaps.get("rltdPties");
        } else {
            rltdPtiesMaps = new HashMap<>();
            txDtlsMaps.put("rltdPties",rltdPtiesMaps);
        }
        Map<String, Object> dbtrMaps = null;
        if (rltdPtiesMaps.containsKey("dbtr")) {
            dbtrMaps = (Map<String, Object>) rltdPtiesMaps.get("dbtr");
        } else {
            dbtrMaps = new HashMap<>();
            rltdPtiesMaps.put("dbtr",dbtrMaps);
        }
        Map<String, Object> ptyMaps = null;
        if (dbtrMaps.containsKey("pty")) {
            ptyMaps = (Map<String, Object>) dbtrMaps.get("pty");
        } else {
            ptyMaps = new HashMap<>();
        }
        Map<String, Object> dbtrAcctMaps = null;
        if (rltdPtiesMaps.containsKey("dbtrAcct")) {
            dbtrAcctMaps = (Map<String, Object>) rltdPtiesMaps.get("dbtrAcct");
        } else {
            dbtrAcctMaps = new HashMap<>();
        }
        String account = "";
        if (field50A != null) {
            String bicCode = field50A.getBIC();
            if (StringUtil.isNotEmpty(field50A.getComponent1())) {
                account += "/" + field50A.getComponent1();
            }
            mt_to_mxAnyBIC(bicCode, ptyMaps);
            mt_to_mxPartyAccount(account, dbtrAcctMaps);
        }
        if (field50F != null) {
            String partyIdentifier = field50F.getPartyIdentifier();
            String nameAddress = "";
            List<String> lines = field50F.getLines();
            for (int i=0; i<lines.size(); i++) {
                if (i == 0) {
                    continue;
                }
                if (i == lines.size()-1) {
                    nameAddress += lines.get(i);
                } else {
                    nameAddress += lines.get(i) + Mx2MtConstants.NEW_LINE;
                }
            }
            if (partyIdentifier.startsWith("/")) {
                mt_to_mxPartyAccount(partyIdentifier, dbtrAcctMaps);
            } else {
                Map<String, Object> idMaps = null;
                if (ptyMaps.containsKey("id")) {
                    idMaps = (Map<String, Object>) ptyMaps.get("id");
                } else {
                    idMaps = new HashMap<>();
                    ptyMaps.put("id", idMaps);
                }
                mt_to_mxFATFIdentification(partyIdentifier, nameAddress, idMaps);
            }
            mt_to_mxFATFNameAndAddress(partyIdentifier, nameAddress, ptyMaps);
        }
        if (field50K != null) {
            String nameAddress = field50K.getNameAndAddress();
            if (StringUtil.isNotEmpty(field50K.getComponent1())) {
                account += "/" + field50K.getComponent1();
            }
            mt_to_mxPartyNameAndAddress(nameAddress, ptyMaps);
            mt_to_mxPartyAccount(account, dbtrAcctMaps);
        }
        if(ptyMaps.size()>0){
            dbtrMaps.put("pty",ptyMaps);
        }
        if(dbtrAcctMaps.size()>0){
            rltdPtiesMaps.put("dbtrAcct",dbtrAcctMaps);
        }
    }
}
