package com.brilliance.swift.mt2mx.pacs004001;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.constants.ERROR;
import com.brilliance.swift.mt2mx.AbstractMt2MxCreator;
import com.brilliance.swift.mt2mx.Mt2MxContextIdentifier;
import com.brilliance.swift.mt2mx.Mt2MxParseField;
import com.brilliance.swift.mt2mx.pacs004001.mt103retn.*;
import com.brilliance.swift.mt2mx.pacs004001.mt202retn.Pacs004001Parse21Field;
import com.brilliance.swift.mt2mx.pacs004001.mt202retn.Pacs004001Parse58Field;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.ChargeForEnum;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Mt2MxPacs004001Creator extends AbstractMt2MxCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        jsonMaps.put("identifier", "pacs.004.001.09");
        Map<String, Object> appHdrMaps = (Map<String, Object>)jsonMaps.get("appHdr");
        appHdrMaps.put("msgDefIdr", "pacs.004.001.09");
        AbstractMT abstractMT = context.get(AbstractMT.class);

        //初始化转换和不需要BLOCK4的转换
        Map<String, Object> pmtRtrMaps = new HashMap<>();
        jsonMaps.put("pmtRtr", pmtRtrMaps);
        Map<String, Object> grpHdrMaps = new HashMap<>();
        pmtRtrMaps.put("grpHdr", grpHdrMaps);
        grpHdrMaps.put("creDtTm", getCreateDateStr());
        grpHdrMaps.put("nbOfTxs", "1");

        Map<String, Object> txInfMaps = new HashMap<>();
        JSONArray txInfJsonArray = new JSONArray();
        txInfJsonArray.add(txInfMaps);
        pmtRtrMaps.put("txInf", txInfJsonArray);
        String uetr = abstractMT.getSwiftMessage().getUETR();
        if (StringUtil.isNotEmpty(uetr)) {
            txInfMaps.put("orgnlUETR", uetr);
        } else {
            buildSTErrorInfo(ERROR.T20087, "Block3/{121}", null);
        }
        //设置InstructingAgent InstructedAgent 取值从sendbic receivebic
        String sendBic = (String) context.get(Mt2MxContextIdentifier.MT_SEND_BIC, true);
        if (StringUtil.isNotEmpty(sendBic)) {
            Map<String, Object> instgAgtMaps = new HashMap<>();
            txInfMaps.put("instgAgt", instgAgtMaps);
            mt_to_mxBICFI(sendBic, instgAgtMaps);
        }
        String receiverBic = (String) context.get(Mt2MxContextIdentifier.MT_RECEIVE_BIC, true);
        if (StringUtil.isNotEmpty(receiverBic)) {
            Map<String, Object> instdAgtMaps = new HashMap<>();
            txInfMaps.put("instdAgt", instdAgtMaps);
            mt_to_mxBICFI(receiverBic, instdAgtMaps);
        }

        //设置Service Level 取值从block3 {111:00[0-9]}
        Tag tag111 = abstractMT.getSwiftMessage().getBlock3().getTagByName("111");
        if (tag111 != null) {
            String svcLvlCode = "";
            String value = tag111.getValue();
            if (value.matches("00[0-9]{1}")) {
                svcLvlCode = value;
            }
            if (StringUtil.isNotEmpty(svcLvlCode)) {
                Map<String, Object> orgnlTxRefMaps = new HashMap<>();
                txInfMaps.put("orgnlTxRef", orgnlTxRefMaps);
                Map<String, Object> pmtTpInfMaps = new HashMap<>();
                orgnlTxRefMaps.put("pmtTpInf", pmtTpInfMaps);
                JSONArray svcLvlJsonArray = new JSONArray();
                pmtTpInfMaps.put("svcLvl", svcLvlJsonArray);
                Map<String, Object> svcLvlMaps = new HashMap<>();
                svcLvlJsonArray.add(svcLvlMaps);
                svcLvlMaps.put("cd", "G" + svcLvlCode);
            }
        }
        //202 205,ChargerBearer 默认值是SHAR
        if ("202".equals(abstractMT.getMessageType()) || "205".equals(abstractMT.getMessageType())) {
            txInfMaps.put("chrgBr", ChargeForEnum.SHAR.value());
            buildSTErrorInfo(ERROR.T20096, "PmtRtr/TxInf/ChrgBr", null);
        }
    }

    @Override
    public List<Mt2MxParseField> getParseFieldList() {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        List<Mt2MxParseField> list = new ArrayList<>();
        if ("103".equals(abstractMT.getMessageType())) {
            list.add(new Pacs004001Parse20Field());
            list.add(new Pacs004001Parse13CField());
            list.add(new Pacs004001Parse23BField());
            list.add(new Pacs004001Parse23EField());
            list.add(new Pacs004001Parse26TField());
            list.add(new Pacs004001Parse32AField());
            list.add(new Pacs004001Parse33BField());
            list.add(new Pacs004001Parse36Field());
            list.add(new Pacs004001Parse50Field());
            list.add(new Pacs004001Parse52Field());
            list.add(new Pacs004001ParseSetlMtdField());
            list.add(new Pacs004001ParseSetlAcctField());
            list.add(new Pacs004001Parse53Field());
            list.add(new Pacs004001Parse54Field());
            list.add(new Pacs004001Parse55Field());
            list.add(new Pacs004001Parse56Field());
            list.add(new Pacs004001Parse57Field());
            list.add(new Pacs004001Parse59Field());
            list.add(new Pacs004001Parse70Field());
            list.add(new Pacs004001Parse71Field());
            list.add(new Pacs004001Parse72Field());
            list.add(new Pacs004001Parse77BField());
        } else if ("202".equals(abstractMT.getMessageType())
                || "205".equals(abstractMT.getMessageType())) {
            list.add(new Pacs004001Parse20Field());
            list.add(new Pacs004001Parse21Field());
            list.add(new Pacs004001Parse13CField());
            list.add(new Pacs004001Parse32AField());
            list.add(new com.brilliance.swift.mt2mx.pacs004001.mt202retn.Pacs004001Parse52Field());
            list.add(new Pacs004001ParseSetlMtdField());
            list.add(new Pacs004001ParseSetlAcctField());
            list.add(new Pacs004001Parse53Field());
            list.add(new Pacs004001Parse54Field());
            list.add(new Pacs004001Parse56Field());
            list.add(new Pacs004001Parse57Field());
            list.add(new Pacs004001Parse58Field());
            list.add(new Pacs004001Parse72Field());
        }
        return list;
    }
}
