package com.brilliance.swift.mt2mx.pacs004001.mt103retn;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.constants.ERROR;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs004001.AbstractMt2MxPacs004001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.OrganisationIdentificationCode;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field50A;
import com.prowidesoftware.swift.model.field.Field50F;
import com.prowidesoftware.swift.model.field.Field50K;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Pacs004001Parse50Field extends AbstractMt2MxPacs004001ParseField {

    private static final String NAME_A = "50A";

    private static final String NAME_F = "50F";

    private static final String NAME_K = "50K";

    @Override
    public void parseField() throws SwiftException {
        Field50A field50A = null;
        Field50F field50F = null;
        Field50K field50K = null;
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_A);
        if (tag != null) {
            field50A = (Field50A)tag.asField();
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_F);
        if (tag != null) {
            field50F = (Field50F)tag.asField();
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_K);
        if (tag != null) {
            field50K = (Field50K)tag.asField();
        }
        Map<String, Object> rtrChainMaps = null;
        if (txInfMaps.containsKey("rtrChain")) {
            rtrChainMaps = (Map<String, Object>) txInfMaps.get("rtrChain");
        } else {
            rtrChainMaps = new HashMap<>();
        }
        Map<String, Object> dbtrMaps = null;
        if (rtrChainMaps.containsKey("dbtr")) {
            dbtrMaps = (Map<String, Object>) rtrChainMaps.get("dbtr");
        } else {
            dbtrMaps = new HashMap<>();
        }
        Map<String, Object> ptyMaps = null;
        if (dbtrMaps.containsKey("pty")) {
            ptyMaps = (Map<String, Object>) dbtrMaps.get("pty");
        } else {
            ptyMaps = new HashMap<>();
        }
        if (field50A != null) {
            String bicCode = field50A.getBIC();
            mt_to_mxAnyBIC(bicCode, ptyMaps);
            if (StringUtil.isEmpty(field50A.getComponent1())) {
                buildDefaultValue(ptyMaps);
            }
        }
        if (field50F != null) {
            String partyIdentifier = field50F.getPartyIdentifier();
            String nameAddress = "";
            List<String> lines = field50F.getLines();
            for (int i=0; i<lines.size(); i++) {
                if (i == 0) {
                    continue;
                }
                if (i == lines.size()-1) {
                    nameAddress += lines.get(i);
                } else {
                    nameAddress += lines.get(i) + Mx2MtConstants.NEW_LINE;
                }
            }
            if (partyIdentifier.startsWith("/")) {
                buildDefaultValue(ptyMaps);
            } else {
                Map<String, Object> idMaps = null;
                if (ptyMaps.containsKey("id")) {
                    idMaps = (Map<String, Object>) ptyMaps.get("id");
                } else {
                    idMaps = new HashMap<>();
                    ptyMaps.put("id", idMaps);
                }
                mt_to_mxFATFIdentification(partyIdentifier, nameAddress, idMaps);
            }
            mt_to_mxFATFNameAndAddress(partyIdentifier, nameAddress, ptyMaps);
        }
        if (field50K != null) {
            String account = "";
            if (StringUtil.isNotEmpty(field50K.getComponent1())) {
                account += "/" + field50K.getComponent1();
            }
            String nameAddress1 = field50K.getNameAndAddressLine1();
            if (("/"+Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE).equals(account) && StringUtil.isNotEmpty(nameAddress1) && nameAddress1.startsWith("//")) {
                Map<String, Object> agtMaps = null;
                if (dbtrMaps.containsKey("agt")) {
                    agtMaps = (Map<String, Object>) dbtrMaps.get("agt");
                } else {
                    agtMaps = new HashMap<>();
                    dbtrMaps.put("agt", agtMaps);
                }
                Map<String, Object> finInstnIdMaps = null;
                if (agtMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)agtMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    agtMaps.put("finInstnId", finInstnIdMaps);
                }
                if (isMTClearingSystemCodeInList(nameAddress1)) {
                    Map<String, Object> clrSysMmbIdMaps = null;
                    if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                        clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                    } else {
                        clrSysMmbIdMaps = new HashMap<>();
                        finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                    }
                    mt_to_mxClearingIdentifier(nameAddress1, clrSysMmbIdMaps);
                } else {
                    String nameAddress = field50K.getNameAndAddress();
                    mt_to_mxPartyNameAndAddress(nameAddress, finInstnIdMaps);
                    buildSTErrorInfo(ERROR.T20126, "PmtRtr/TxInf/RtrChain/Dbtr/Agt/FinInstnId", null);
                }
            } else {
                String nameAddress = field50K.getNameAndAddress();
                mt_to_mxPartyNameAndAddress(nameAddress, ptyMaps);
                if (StringUtil.isEmpty(account)) {
                    buildDefaultValue(ptyMaps);
                }
            }
        }
        if (ptyMaps.size() > 0) {
            dbtrMaps.put("pty", ptyMaps);
        }
        if (dbtrMaps.size() > 0) {
            rtrChainMaps.put("dbtr", dbtrMaps);
        }
        if (rtrChainMaps.size() > 0) {
            txInfMaps.put("rtrChain", rtrChainMaps);
        }
    }

    /**
     * IF 50A/Account 50K/Account IsAbsent
     * THEN Copy "NOTPROVIDED" to Debtor/Id/OrgID/Other/ID
     * and "TXID" to SchemeName/Code
     * @param dbtrMaps
     */
    private void buildDefaultValue(Map<String, Object> dbtrMaps) {
        Map<String, Object> idMaps = null;
        if (dbtrMaps.containsKey("id")) {
            idMaps = (Map<String, Object>)dbtrMaps.get("id");
        } else {
            idMaps = new HashMap<>();
            dbtrMaps.put("id", idMaps);
        }
        Map<String, Object> idOrgMaps = null;
        if (idMaps.containsKey("orgId")) {
            idOrgMaps = (Map<String, Object>)idMaps.get("orgId");
        } else {
            idOrgMaps = new HashMap<>();
            idMaps.put("orgId", idOrgMaps);
        }
        JSONArray othrJsonArray = null;
        if (idOrgMaps.containsKey("othr")) {
            othrJsonArray = (JSONArray) idOrgMaps.get("othr");
        } else {
            othrJsonArray = new JSONArray();
            idOrgMaps.put("othr", othrJsonArray);
        }
        Map<String, Object> othrMaps = new HashMap<>();
        othrJsonArray.add(othrMaps);
        othrMaps.put("id", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
        Map<String, Object> schmeNmMaps = null;
        if (othrMaps.containsKey("schmeNm")) {
            schmeNmMaps = (Map<String, Object>) othrMaps.get("schmeNm");
        } else {
            schmeNmMaps = new HashMap<>();
            othrMaps.put("schmeNm", schmeNmMaps);
        }
        schmeNmMaps.put("cd", OrganisationIdentificationCode.TXID.value());
    }
}
