package com.brilliance.swift.mt2mx.pacs004001.mt103retn;

import com.alibaba.fastjson.JSONArray;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs004001.AbstractMt2MxPacs004001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field72;
import com.prowidesoftware.swift.model.field.SwiftParseUtils;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.utils.SwiftFormatUtils;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Pacs004001Parse72Field extends AbstractMt2MxPacs004001ParseField {

    private static final String NAME = "72";

    @Override
    public void parseField() throws SwiftException {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME);
        if (tag != null) {
            Field72 field72 = (Field72)tag.asField();
            String mt72 = field72.getValue();
            String[] mt72s = mt72.split(Mx2MtConstants.NEW_LINE);
            String mRef = "";
            String tRef = "";
            String chgs = "";
            for (String value : mt72s) {
                if (value.startsWith("/MREF/")) {
                    mRef = value.substring(6);
                }
                if (value.startsWith("/TREF/")) {
                    tRef = value.substring(6);
                }
                if (value.startsWith("/CHGS/")) {
                    chgs = value.substring(6);
                }
            }
            if (StringUtil.isNotEmpty(mRef)) {
                txInfMaps.put("orgnlInstrId", mRef);
            }
            if (!"202".equals(abstractMT.getMessageType())
                    && !"205".equals(abstractMT.getMessageType())) {
                if (StringUtil.isNotEmpty(tRef)) {
                    txInfMaps.put("orgnlEndToEndId", tRef);
                } else {
                    txInfMaps.put("orgnlEndToEndId", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                }
            }
            if (StringUtil.isNotEmpty(chgs)) {
                Tag tag71G = abstractMT.getSwiftMessage().getBlock4().getTagByName("71G");
                Tag[] tag71Fs = abstractMT.getSwiftMessage().getBlock4().getTagsByName("71F");
                if (tag71G == null && tag71Fs.length == 0) {
                    String ccy = SwiftParseUtils.getAlphaPrefix(chgs);
                    String amtStr = SwiftParseUtils.getNumericSuffix(chgs);
                    Number number = SwiftFormatUtils.getNumber(amtStr);
                    BigDecimal amt = new BigDecimal(number.toString()).stripTrailingZeros();

                    JSONArray jsonArray = new JSONArray();
                    txInfMaps.put("chrgsInf", jsonArray);
                    Map<String, Object> chrgsInfMaps = new HashMap<>();
                    jsonArray.add(chrgsInfMaps);
                    Map<String, Object> amtMaps = new HashMap<>();
                    amtMaps.put("value", amt);
                    amtMaps.put("ccy", ccy);
                    chrgsInfMaps.put("amt", amtMaps);

                    Map<String, Object> agtMaps = new HashMap<>();
                    chrgsInfMaps.put("agt", agtMaps);
                    Map<String, Object> finInstnIdMaps = null;
                    if (agtMaps.containsKey("finInstnId")) {
                        finInstnIdMaps = (Map<String, Object>)agtMaps.get("finInstnId");
                    } else {
                        finInstnIdMaps = new HashMap<>();
                        agtMaps.put("finInstnId", finInstnIdMaps);
                    }
                    //name address 设置NOTPROVIDED
                    finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    Map<String, Object> pstlAdrMaps = null;
                    if (finInstnIdMaps.containsKey("pstlAdr")) {
                        pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                    } else {
                        pstlAdrMaps = new HashMap<>();
                        finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                    }
                    List<String> adrLineList = new ArrayList<>();
                    adrLineList.add(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    pstlAdrMaps.put("adrLine", adrLineList);
                }
            }
            mt_to_mxReturn72(mt72, txInfMaps);
        }
    }
}
