package com.brilliance.swift.mt2mx.pacs004001.mt103retn;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs004001.AbstractMt2MxPacs004001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field77B;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class Pacs004001Parse77BField extends AbstractMt2MxPacs004001ParseField {

    private static final String NAME = "77B";

    @Override
    public void parseField() throws SwiftException {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME);
        if (tag != null) {
            String creditorCountryCode = "";
            String debtorCountryCode = "";
            Map<String, Object> rtrChainMaps = null;
            if (txInfMaps.containsKey("rtrChain")) {
                rtrChainMaps = (Map<String, Object>)txInfMaps.get("rtrChain");
            } else {
                rtrChainMaps = new HashMap<>();
            }
            Field77B field77B = (Field77B)tag.asField();
            List<String> lines = field77B.getLines();
            for (int i=0; i<lines.size();i++) {
                String line = lines.get(i);
                String regex = "/BENEFRES/([A-Z]{2})";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(line);
                if (m.find()) {
                    creditorCountryCode = m.group(1);
                    break;
                }
            }
            if (StringUtil.isNotEmpty(creditorCountryCode)) {
                Map<String, Object> cdtrMaps = null;
                if (rtrChainMaps.containsKey("cdtr")) {
                    cdtrMaps = (Map<String, Object>) rtrChainMaps.get("cdtr");
                } else {
                    cdtrMaps = new HashMap<>();
                    rtrChainMaps.put("cdtr", cdtrMaps);
                }
                Map<String, Object> ptyMaps = null;
                if (cdtrMaps.containsKey("pty")) {
                    ptyMaps = (Map<String, Object>) cdtrMaps.get("pty");
                } else {
                    ptyMaps = new HashMap<>();
                    cdtrMaps.put("pty", ptyMaps);
                }
                ptyMaps.put("ctryOfRes", creditorCountryCode);
            }
            for (int i=0; i<lines.size();i++) {
                String line = lines.get(i);
                String regex = "/ORDERRES/([A-Z]{2})";
                Pattern p = Pattern.compile(regex);
                Matcher m = p.matcher(line);
                if (m.find()) {
                    debtorCountryCode = m.group(1);
                    break;
                }
            }
            if (StringUtil.isNotEmpty(debtorCountryCode)) {
                Map<String, Object> dbtrMaps = null;
                if (rtrChainMaps.containsKey("dbtr")) {
                    dbtrMaps = (Map<String, Object>) rtrChainMaps.get("dbtr");
                } else {
                    dbtrMaps = new HashMap<>();
                    rtrChainMaps.put("dbtr", dbtrMaps);
                }
                Map<String, Object> ptyMaps = null;
                if (dbtrMaps.containsKey("pty")) {
                    ptyMaps = (Map<String, Object>) dbtrMaps.get("pty");
                } else {
                    ptyMaps = new HashMap<>();
                    dbtrMaps.put("pty", ptyMaps);
                }
                ptyMaps.put("ctryOfRes", debtorCountryCode);
            }
        }
    }
}
