package com.brilliance.swift.mt2mx.pacs004001.mt202retn;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.Mt2MxContextIdentifier;
import com.brilliance.swift.mt2mx.pacs004001.AbstractMt2MxPacs004001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field52A;
import com.prowidesoftware.swift.model.field.Field52D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.Map;

public class Pacs004001Parse52Field extends AbstractMt2MxPacs004001ParseField {

    private static final String NAME_A = "52A";

    private static final String NAME_D = "52D";

    @Override
    public void parseField() throws SwiftException {
        Field52A field52A = null;
        Field52D field52D = null;
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_A);
        if (tag != null) {
            field52A = (Field52A)tag.asField();
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_D);
        if (tag != null) {
            field52D = (Field52D)tag.asField();
        }
        Map<String, Object> rtrChainMaps = null;
        if (txInfMaps.containsKey("rtrChain")) {
            rtrChainMaps = (Map<String, Object>) txInfMaps.get("rtrChain");
        } else {
            rtrChainMaps = new HashMap<>();
        }
        Map<String, Object> dbtrMaps = null;
        if (rtrChainMaps.containsKey("dbtr")) {
            dbtrMaps = (Map<String, Object>) rtrChainMaps.get("dbtr");
        } else {
            dbtrMaps = new HashMap<>();
        }
        Map<String, Object> agtMaps = null;
        if (dbtrMaps.containsKey("agt")) {
            agtMaps = (Map<String, Object>) dbtrMaps.get("agt");
        } else {
            agtMaps = new HashMap<>();
        }
        String account = "";
        if (field52A != null) {
            String bicCode = field52A.getBIC();
            mt_to_mxBICFI(bicCode, agtMaps);
            if (StringUtil.isNotEmpty(field52A.getComponent1())) {
                account += "/" + field52A.getComponent1();
            }
            if (StringUtil.isNotEmpty(field52A.getComponent2())) {
                account += "/" + field52A.getComponent2();
            }
        } else if (field52D != null) {
            if (StringUtil.isNotEmpty(field52D.getComponent1())) {
                account += "/" + field52D.getComponent1();
            }
            if (StringUtil.isNotEmpty(field52D.getComponent2())) {
                account += "/" + field52D.getComponent2();
            }
            String nameAddress = field52D.getNameAndAddress();
            mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, agtMaps);
        } else {
            String sendBic = (String) context.get(Mt2MxContextIdentifier.MT_SEND_BIC, true);
            mt_to_mxBICFI(sendBic, agtMaps);
        }
        if (StringUtil.isNotEmpty(account)) {
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                Map<String, Object> finInstnIdMaps = null;
                if (agtMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)agtMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    agtMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            }
        }
        if (agtMaps.size() > 0) {
            dbtrMaps.put("agt", agtMaps);
        }
        if (dbtrMaps.size() > 0) {
            rtrChainMaps.put("dbtr", dbtrMaps);
        }
        if (rtrChainMaps.size() > 0) {
            txInfMaps.put("rtrChain", rtrChainMaps);
        }
    }
}
