package com.brilliance.swift.mt2mx.pacs004001.mt202retn;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs004001.AbstractMt2MxPacs004001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field58A;
import com.prowidesoftware.swift.model.field.Field58D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.Map;

public class Pacs004001Parse58Field extends AbstractMt2MxPacs004001ParseField {

    private static final String NAME_A = "58A";

    private static final String NAME_D = "58D";

    @Override
    public void parseField() throws SwiftException {
        Field58A field58A = null;
        Field58D field58D = null;
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_A);
        if (tag != null) {
            field58A = (Field58A)tag.asField();
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_D);
        if (tag != null) {
            field58D = (Field58D)tag.asField();
        }
        Map<String, Object> rtrChainMaps = null;
        if (txInfMaps.containsKey("rtrChain")) {
            rtrChainMaps = (Map<String, Object>) txInfMaps.get("rtrChain");
        } else {
            rtrChainMaps = new HashMap<>();
        }
        Map<String, Object> cdtrMaps = null;
        if (rtrChainMaps.containsKey("cdtr")) {
            cdtrMaps = (Map<String, Object>) rtrChainMaps.get("cdtr");
        } else {
            cdtrMaps = new HashMap<>();
        }
        Map<String, Object> agtMaps = null;
        if (cdtrMaps.containsKey("agt")) {
            agtMaps = (Map<String, Object>) cdtrMaps.get("agt");
        } else {
            agtMaps = new HashMap<>();
        }
        String account = "";
        if (field58A != null) {
            String bicCode = field58A.getBIC();
            mt_to_mxBICFI(bicCode, agtMaps);
            if (StringUtil.isNotEmpty(field58A.getComponent1())) {
                account += "/" + field58A.getComponent1();
            }
            if (StringUtil.isNotEmpty(field58A.getComponent2())) {
                account += "/" + field58A.getComponent2();
            }
        } else if (field58D != null) {
            if (StringUtil.isNotEmpty(field58D.getComponent1())) {
                account += "/" + field58D.getComponent1();
            }
            if (StringUtil.isNotEmpty(field58D.getComponent2())) {
                account += "/" + field58D.getComponent2();
            }
            String nameAddress = field58D.getNameAndAddress();
            mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, agtMaps);
        }
        if (StringUtil.isNotEmpty(account)) {
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                Map<String, Object> finInstnIdMaps = null;
                if (agtMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)agtMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    agtMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            }
        }
        if (agtMaps.size() > 0) {
            cdtrMaps.put("agt", agtMaps);
        }
        if (cdtrMaps.size() > 0) {
            rtrChainMaps.put("cdtr", cdtrMaps);
        }
        if (rtrChainMaps.size() > 0) {
            txInfMaps.put("rtrChain", rtrChainMaps);
        }
    }
}
