package com.brilliance.swift.mt2mx.pacs008001.impl;

import com.brilliance.swift.constants.ERROR;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs008001.AbstractMt2MxPacs008001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoSettlementMethodHelper;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field55A;
import com.prowidesoftware.swift.model.field.Field55B;
import com.prowidesoftware.swift.model.field.Field55D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 如果55存在，那么53 54必须同时存在
 */
public class Pacs00801Parse55Field extends AbstractMt2MxPacs008001ParseField {

    private static final String NAME_A = "55A";

    private static final String NAME_B = "55B";

    private static final String NAME_D = "55D";

    @Override
    public void parseField() throws SwiftException {
        VoSettlementMethodHelper setlMtdHelper = context.get(VoSettlementMethodHelper.class);
        if (setlMtdHelper.isTranslate55Flag()) {
            Field55A field55A = null;
            Field55B field55B = null;
            Field55D field55D = null;
            AbstractMT abstractMT = context.get(AbstractMT.class);
            Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_A);
            if (tag != null) {
                field55A = (Field55A)tag.asField();
            }
            tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_B);
            if (tag != null) {
                field55B = (Field55B)tag.asField();
            }
            tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_D);
            if (tag != null) {
                field55D = (Field55D)tag.asField();
            }
            Map<String, Object> sttlmInfMaps = null;
            if (grpHdrMaps.containsKey("sttlmInf")) {
                sttlmInfMaps = (Map<String, Object>) grpHdrMaps.get("sttlmInf");
            } else {
                sttlmInfMaps = new HashMap<>();
                grpHdrMaps.put("sttlmInf", sttlmInfMaps);
            }
            Map<String, Object> thrdRmbrsmntAgtMaps = null;
            if (sttlmInfMaps.containsKey("thrdRmbrsmntAgt")) {
                thrdRmbrsmntAgtMaps = (Map<String, Object>) sttlmInfMaps.get("thrdRmbrsmntAgt");
            } else {
                thrdRmbrsmntAgtMaps = new HashMap<>();
            }
            Map<String, Object> thrdRmbrsmntAgtAcctMaps = null;
            if (sttlmInfMaps.containsKey("thrdRmbrsmntAgtAcct")) {
                thrdRmbrsmntAgtAcctMaps = (Map<String, Object>) sttlmInfMaps.get("thrdRmbrsmntAgtAcct");
            } else {
                thrdRmbrsmntAgtAcctMaps = new HashMap<>();
            }
            String account = "";
            if (field55A != null) {
                String bicCode = field55A.getBIC();
                mt_to_mxBICFI(bicCode, thrdRmbrsmntAgtMaps);
                if (StringUtil.isNotEmpty(field55A.getComponent1())) {
                    account += "/" + field55A.getComponent1();
                }
                if (StringUtil.isNotEmpty(field55A.getComponent2())) {
                    account += "/" + field55A.getComponent2();
                }
                if (account.startsWith("//") && !account.startsWith("//CH")) {
                    Map<String, Object> finInstnIdMaps = null;
                    if (thrdRmbrsmntAgtMaps.containsKey("finInstnId")) {
                        finInstnIdMaps = (Map<String, Object>)thrdRmbrsmntAgtMaps.get("finInstnId");
                    } else {
                        finInstnIdMaps = new HashMap<>();
                        thrdRmbrsmntAgtMaps.put("finInstnId", finInstnIdMaps);
                    }
                    Map<String, Object> clrSysMmbIdMaps = null;
                    if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                        clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                    } else {
                        clrSysMmbIdMaps = new HashMap<>();
                        finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                    }
                    mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
                } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                    mt_to_mxFinancialInstitutionAccount(account, thrdRmbrsmntAgtAcctMaps, "ThrdRmbrsmntAgtAcct/Id");
                }
            } else if (field55B != null) {
                if (StringUtil.isNotEmpty(field55B.getComponent1())) {
                    account += "/" + field55B.getComponent1();
                }
                if (StringUtil.isNotEmpty(field55B.getComponent2())) {
                    account += "/" + field55B.getComponent2();
                }
                String location = field55B.getLocation();
                Map<String, Object> finInstnIdMaps = null;
                if (thrdRmbrsmntAgtMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)thrdRmbrsmntAgtMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    thrdRmbrsmntAgtMaps.put("finInstnId", finInstnIdMaps);
                }
                if (account.startsWith("//") && !account.startsWith("//CH")) {
                    if (isMTClearingSystemCodeInList(account)) {
                        Map<String, Object> clrSysMmbIdMaps = null;
                        if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                            clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                        } else {
                            clrSysMmbIdMaps = new HashMap<>();
                            finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                        }
                        mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
                        //name address 设置NOTPROVIDED
                        finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                        Map<String, Object> pstlAdrMaps = null;
                        if (finInstnIdMaps.containsKey("pstlAdr")) {
                            pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                        } else {
                            pstlAdrMaps = new HashMap<>();
                            finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                        }
                        List<String> adrLineList = new ArrayList<>();
                        adrLineList.add(StringUtil.isEmpty(location)?Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE:location);
                        pstlAdrMaps.put("adrLine", adrLineList);
                    } else {
                        mt_to_mxClearingSystemToNameAndAddressLine(account, location, finInstnIdMaps, "ThrdRmbrsmntAgt/FinInstnId");
                    }
                } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                    mt_to_mxFinancialInstitutionAccount(account, thrdRmbrsmntAgtAcctMaps, "ThrdRmbrsmntAgtAcct/Id");
                    if (StringUtil.isEmpty(account)) {
                        buildSTErrorInfo(ERROR.T20005, "Block4/:55B:", null);
                    }
                    //name address 设置NOTPROVIDED
                    finInstnIdMaps.put("nm", Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE);
                    Map<String, Object> pstlAdrMaps = null;
                    if (finInstnIdMaps.containsKey("pstlAdr")) {
                        pstlAdrMaps = (Map<String, Object>)finInstnIdMaps.get("pstlAdr");
                    } else {
                        pstlAdrMaps = new HashMap<>();
                        finInstnIdMaps.put("pstlAdr", pstlAdrMaps);
                    }
                    List<String> adrLineList = new ArrayList<>();
                    adrLineList.add(StringUtil.isEmpty(location)?Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE:location);
                    pstlAdrMaps.put("adrLine", adrLineList);
                }
            } else if (field55D != null) {
                if (StringUtil.isNotEmpty(field55D.getComponent1())) {
                    account += "/" + field55D.getComponent1();
                }
                if (StringUtil.isNotEmpty(field55D.getComponent2())) {
                    account += "/" + field55D.getComponent2();
                }
                String nameAddress = field55D.getNameAndAddress();
                mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, thrdRmbrsmntAgtMaps);
                if (account.startsWith("//") && !account.startsWith("//CH")) {
                    Map<String, Object> finInstnIdMaps = null;
                    if (thrdRmbrsmntAgtMaps.containsKey("finInstnId")) {
                        finInstnIdMaps = (Map<String, Object>)thrdRmbrsmntAgtMaps.get("finInstnId");
                    } else {
                        finInstnIdMaps = new HashMap<>();
                        thrdRmbrsmntAgtMaps.put("finInstnId", finInstnIdMaps);
                    }
                    Map<String, Object> clrSysMmbIdMaps = null;
                    if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                        clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                    } else {
                        clrSysMmbIdMaps = new HashMap<>();
                        finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                    }
                    mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
                } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                    mt_to_mxFinancialInstitutionAccount(account, thrdRmbrsmntAgtAcctMaps, "ThrdRmbrsmntAgtAcct/Id");
                }
            }
            if (thrdRmbrsmntAgtMaps.size() > 0) {
                sttlmInfMaps.put("thrdRmbrsmntAgt", thrdRmbrsmntAgtMaps);
            }
            if (thrdRmbrsmntAgtAcctMaps.size() > 0) {
                sttlmInfMaps.put("thrdRmbrsmntAgtAcct", thrdRmbrsmntAgtAcctMaps);
            }
        }
    }
}
