package com.brilliance.swift.mt2mx.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.Mt2MxContextIdentifier;
import com.brilliance.swift.mt2mx.pacs009001.AbstractMt2MxPacs009001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field52A;
import com.prowidesoftware.swift.model.field.Field52D;

import java.util.HashMap;
import java.util.Map;

public class Pacs009001Parse52Field extends AbstractMt2MxPacs009001ParseField {

    private static final String NAME_A = "52A";

    private static final String NAME_D = "52D";

    private static final String SEQUENCE_A = "A";

    @Override
    public void parseField() throws SwiftException {
        Field52A field52A = null;
        Field52D field52D = null;
        Tag tag = getTagByName(NAME_A, SEQUENCE_A);
        if (tag != null) {
            field52A = (Field52A)tag.asField();
        }
        tag = getTagByName(NAME_D, SEQUENCE_A);
        if (tag != null) {
            field52D = (Field52D)tag.asField();
        }
        Map<String, Object> dbtrMaps = null;
        if (cdtTrfTxInfMaps.containsKey("dbtr")) {
            dbtrMaps = (Map<String, Object>) cdtTrfTxInfMaps.get("dbtr");
        } else {
            dbtrMaps = new HashMap<>();
        }
        Map<String, Object> dbtrAcctMaps = null;
        if (cdtTrfTxInfMaps.containsKey("dbtrAcct")) {
            dbtrAcctMaps = (Map<String, Object>) cdtTrfTxInfMaps.get("dbtrAcct");
        } else {
            dbtrAcctMaps = new HashMap<>();
        }
        String account = "";
        if (field52A != null) {
            String bicCode = field52A.getBIC();
            mt_to_mxBICFI(bicCode, dbtrMaps);
            if (StringUtil.isNotEmpty(field52A.getComponent1())) {
                account += "/" + field52A.getComponent1();
            }
            if (StringUtil.isNotEmpty(field52A.getComponent2())) {
                account += "/" + field52A.getComponent2();
            }
        } else if (field52D != null) {
            if (StringUtil.isNotEmpty(field52D.getComponent1())) {
                account += "/" + field52D.getComponent1();
            }
            if (StringUtil.isNotEmpty(field52D.getComponent2())) {
                account += "/" + field52D.getComponent2();
            }
            String nameAddress = field52D.getNameAndAddress();
            mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, dbtrMaps);
        } else {
            String sendBic = (String) context.get(Mt2MxContextIdentifier.MT_SEND_BIC, true);
            mt_to_mxBICFI(sendBic, dbtrMaps);
        }
        if (StringUtil.isNotEmpty(account)) {
            if (account.startsWith("//") && !account.startsWith("//CH")) {
                Map<String, Object> finInstnIdMaps = null;
                if (dbtrMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)dbtrMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    dbtrMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, dbtrAcctMaps, "DbtrAcct/Id");
            }
        }
        if (dbtrMaps.size() > 0) {
            cdtTrfTxInfMaps.put("dbtr", dbtrMaps);
        }
        if (dbtrAcctMaps.size() > 0) {
            cdtTrfTxInfMaps.put("dbtrAcct", dbtrAcctMaps);
        }
    }
}
