package com.brilliance.swift.mt2mx.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.pacs009001.AbstractMt2MxPacs009001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field58A;
import com.prowidesoftware.swift.model.field.Field58D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.Map;

public class Pacs009001Parse58Field extends AbstractMt2MxPacs009001ParseField {

    private static final String NAME_A = "58A";

    private static final String NAME_D = "58D";

    @Override
    public void parseField() throws SwiftException {
        Field58A field58A = null;
        Field58D field58D = null;
        AbstractMT abstractMT = context.get(AbstractMT.class);
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_A);
        if (tag != null) {
            field58A = (Field58A)tag.asField();
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName(NAME_D);
        if (tag != null) {
            field58D = (Field58D)tag.asField();
        }
        Map<String, Object> cdtrMaps = null;
        if (cdtTrfTxInfMaps.containsKey("cdtr")) {
            cdtrMaps = (Map<String, Object>) cdtTrfTxInfMaps.get("cdtr");
        } else {
            cdtrMaps = new HashMap<>();
        }
        Map<String, Object> cdtrAcctMaps = null;
        if (cdtTrfTxInfMaps.containsKey("cdtrAcct")) {
            cdtrAcctMaps = (Map<String, Object>) cdtTrfTxInfMaps.get("cdtrAcct");
        } else {
            cdtrAcctMaps = new HashMap<>();
        }
        boolean clearingChannelRTGSFlag = false;
        String account = "";
        if (field58A != null) {
            String bicCode = field58A.getBIC();
            mt_to_mxBICFI(bicCode, cdtrMaps);
            if (StringUtil.isNotEmpty(field58A.getComponent1())) {
                account += "/" + field58A.getComponent1();
            }
            if (StringUtil.isNotEmpty(field58A.getComponent2())) {
                account += "/" + field58A.getComponent2();
            }
            if (account.startsWith("//RT") || account.startsWith("//FW")) {
                clearingChannelRTGSFlag = true;
            }
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW") && !account.startsWith("//RT")) {
                Map<String, Object> finInstnIdMaps = null;
                if (cdtrMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)cdtrMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    cdtrMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, cdtrAcctMaps, "CdtrAcct/Id");
            }
        } else if (field58D != null) {
            if (StringUtil.isNotEmpty(field58D.getComponent1())) {
                account += "/" + field58D.getComponent1();
            }
            if (StringUtil.isNotEmpty(field58D.getComponent2())) {
                account += "/" + field58D.getComponent2();
            }
            if (account.startsWith("//RT")) {
                clearingChannelRTGSFlag = true;
            }
            String nameAddress = field58D.getNameAndAddress();
            mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, cdtrMaps);
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                Map<String, Object> finInstnIdMaps = null;
                if (cdtrMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)cdtrMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    cdtrMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, cdtrAcctMaps, "CdtrAcct/Id");
            }
        }
        if (cdtrMaps.size() > 0) {
            cdtTrfTxInfMaps.put("cdtr", cdtrMaps);
        }
        if (cdtrAcctMaps.size() > 0) {
            cdtTrfTxInfMaps.put("cdtrAcct", cdtrAcctMaps);
        }
        if (clearingChannelRTGSFlag) {
            Map<String, Object> pmtTpInfMaps = null;
            if (cdtTrfTxInfMaps.containsKey("pmtTpInf")) {
                pmtTpInfMaps = (Map<String, Object>)cdtTrfTxInfMaps.get("pmtTpInf");
            } else {
                pmtTpInfMaps = new HashMap<>();
                cdtTrfTxInfMaps.put("pmtTpInf", pmtTpInfMaps);
            }
            pmtTpInfMaps.put("clrChanl", "RTGS");
        }
    }
}
