package com.brilliance.swift.mt2mx.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2mx.Mt2MxContextIdentifier;
import com.brilliance.swift.mt2mx.pacs009001.AbstractMt2MxPacs009001ParseField;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field52A;
import com.prowidesoftware.swift.model.field.Field52D;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.util.HashMap;
import java.util.Map;

public class Pacs009001ParseSeqB52Field extends AbstractMt2MxPacs009001ParseField {

    private static final String NAME_A = "52A";

    private static final String NAME_D = "52D";

    private static final String SEQUENCE_A = "A";

    private static final String SEQUENCE_B = "B";

    @Override
    public void parseField() throws SwiftException {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        if (!abstractMT.getSwiftMessage().isCOV()) {
            return;
        }
        Field52A field52A = null;
        Field52D field52D = null;
        Tag tag = getTagByName(NAME_A, SEQUENCE_B);
        if (tag != null) {
            field52A = (Field52A)tag.asField();
        }
        tag = getTagByName(NAME_D, SEQUENCE_B);
        if (tag != null) {
            field52D = (Field52D)tag.asField();
        }
        if (field52A == null && field52D == null) {
            tag = getTagByName(NAME_A, SEQUENCE_A);
            if (tag != null) {
                field52A = (Field52A)tag.asField();
            }
            tag = getTagByName(NAME_D, SEQUENCE_A);
            if (tag != null) {
                field52D = (Field52D)tag.asField();
            }
        }
        Map<String, Object> dbtrAgtMaps = null;
        if (undrlygCstmrCdtTrfMaps.containsKey("dbtrAgt")) {
            dbtrAgtMaps = (Map<String, Object>) undrlygCstmrCdtTrfMaps.get("dbtrAgt");
        } else {
            dbtrAgtMaps = new HashMap<>();
        }
        Map<String, Object> dbtrAgtAcctMaps = null;
        if (undrlygCstmrCdtTrfMaps.containsKey("dbtrAgtAcct")) {
            dbtrAgtAcctMaps = (Map<String, Object>) undrlygCstmrCdtTrfMaps.get("dbtrAgtAcct");
        } else {
            dbtrAgtAcctMaps = new HashMap<>();
        }
        String account = "";
        if (field52A != null) {
            String bicCode = field52A.getBIC();
            mt_to_mxBICFI(bicCode, dbtrAgtMaps);
            if (StringUtil.isNotEmpty(field52A.getComponent1())) {
                account += "/" + field52A.getComponent1();
            }
            if (StringUtil.isNotEmpty(field52A.getComponent2())) {
                account += "/" + field52A.getComponent2();
            }
        } else if (field52D != null) {
            if (StringUtil.isNotEmpty(field52D.getComponent1())) {
                account += "/" + field52D.getComponent1();
            }
            if (StringUtil.isNotEmpty(field52D.getComponent2())) {
                account += "/" + field52D.getComponent2();
            }
            String nameAddress = field52D.getNameAndAddress();
            mt_to_mxFinancialInstitutionNameAndUnstructuredAddress(nameAddress, dbtrAgtMaps);
        } else {
            String sendBic = (String) context.get(Mt2MxContextIdentifier.MT_SEND_BIC, true);
            mt_to_mxBICFI(sendBic, dbtrAgtMaps);
        }
        if (StringUtil.isNotEmpty(account)) {
            if (account.startsWith("//") && !account.startsWith("//CH") && !account.startsWith("//FW")) {
                Map<String, Object> finInstnIdMaps = null;
                if (dbtrAgtMaps.containsKey("finInstnId")) {
                    finInstnIdMaps = (Map<String, Object>)dbtrAgtMaps.get("finInstnId");
                } else {
                    finInstnIdMaps = new HashMap<>();
                    dbtrAgtMaps.put("finInstnId", finInstnIdMaps);
                }
                Map<String, Object> clrSysMmbIdMaps = null;
                if (finInstnIdMaps.containsKey("clrSysMmbId")) {
                    clrSysMmbIdMaps = (Map<String, Object>)finInstnIdMaps.get("clrSysMmbId");
                } else {
                    clrSysMmbIdMaps = new HashMap<>();
                    finInstnIdMaps.put("clrSysMmbId", clrSysMmbIdMaps);
                }
                mt_to_mxClearingIdentifier(account, clrSysMmbIdMaps);
            } else if (!account.startsWith("//") || account.startsWith("//CH")) {
                mt_to_mxFinancialInstitutionAccount(account, dbtrAgtAcctMaps, "DbtrAgtAcct/Id");
            }
        }
        if (dbtrAgtMaps.size() > 0) {
            undrlygCstmrCdtTrfMaps.put("dbtrAgt", dbtrAgtMaps);
        }
        if (dbtrAgtAcctMaps.size() > 0) {
            undrlygCstmrCdtTrfMaps.put("dbtrAgtAcct", dbtrAgtAcctMaps);
        }
    }
}
