package com.brilliance.swift.mx2element;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import java.io.InputStream;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractMx2ElementCreator implements Mx2ElementCreator{
    private static final Pattern PATTERN_CURVE = Pattern.compile("\\(([\\.\\:-]?\\w+)+\\)");

    protected AbstractMX abstractMX;

    protected String xmlStr;

    protected Map<String, Object> maps = new LinkedHashMap<>();

    protected String messageType;

    public AbstractMX getAbstractMX() {
        return abstractMX;
    }

    public void setAbstractMX(AbstractMX abstractMX) {
        this.abstractMX = abstractMX;
    }

    public String getXmlStr() {
        return xmlStr;
    }

    public void setXmlStr(String xmlStr) {
        this.xmlStr = xmlStr;
    }

    public String getMessageType() {
        return messageType;
    }

    public void setMessageType(String messageType) {
        this.messageType = messageType;
    }

    private Object invokeHere(String methodName, Object where) {
        try {
            Method method = getClass().getMethod(methodName);
            return method.invoke(where);
        } catch (NoSuchMethodException e) {
            throw new SwiftException("Method " + methodName + " does not exist in " + getClass());
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }

    @Override
    public Map<String, Object> buildElement() {
        maps.put("messageType", messageType);
        String gsonStr = abstractMX.toJson();
        Map<String, Object> mxGsonMaps = JSON.parseObject(gsonStr);
        String fileName = "/template/"+messageType+".properties";
        InputStream resourceAsStream = AbstractMx2ElementCreator.class.getResourceAsStream(fileName);
        if (resourceAsStream == null) {
            int versionLength = abstractMX.getMxId().getVersion().length();
            fileName = "/template/"+messageType.substring(0, messageType.length()-versionLength)+".properties";
            resourceAsStream = AbstractMx2ElementCreator.class.getResourceAsStream(fileName);

        }
        List<String> properties = StringUtil.inputStreamToLines(resourceAsStream);
        readPropertyFile(mxGsonMaps, maps, properties);
        return maps;
    }

    protected Object getXmlValue(Map<String, Object> jsonMaps, String path) {
        Object value = null;
        if (path.startsWith("@")) { //如果以@开始 表示取值规则采用的函数
            return invokeHere(path.substring(1), this);
        }
        if (path.indexOf("?") > 0) {
            String[] childPaths = path.split("\\?");
            for (String childPath : childPaths) {
                value = getXmlValue(jsonMaps, childPath);
                if (value != null) {
                    return value;
                }
            }
        }
        //获取数据类型，&分隔，默认是string
        String type = "string";
        if (path.indexOf("&") > -1) {
            type = path.substring(path.indexOf("&")+1);
            path = path.substring(0, path.indexOf("&"));
        }
        //处理括号
        StringBuffer sb = new StringBuffer();
        Matcher matcher = PATTERN_CURVE.matcher(path);
        while (matcher.find()) {
            String replace = matcher.group().replaceAll("\\.", "-");
            matcher.appendReplacement(sb, replace);
        }
        path = matcher.appendTail(sb).toString();
        //需要用. split,然后循环遍历json获取值
        String[] paths = path.split("\\.");
        Map<String, Object> tmpMaps = jsonMaps;
        for (int i=0; i<paths.length; i++) {
            String p = paths[i];
            String subPropName = "";
            String[] condition = null;
            if (p.indexOf("#") > -1) { //判断是否存在子配置文件的引用
                int symbolIndex = p.indexOf("#");
                subPropName = p.substring(symbolIndex + 1);
                p = p.substring(0, symbolIndex);
            }
            Matcher pMatch = PATTERN_CURVE.matcher(p);
            if (pMatch.find()) { //判断是否含有括号过滤表达式
                condition = p.substring(pMatch.start() + 1, pMatch.end() - 1).split(":");
                p = p.substring(0, pMatch.start());
            }
            Object obj = tmpMaps.get(p);
            if (obj == null) return null;
            if (StringUtil.isNotEmpty(subPropName)) {
                return readSubProp(obj, subPropName);
            } else {
                if (obj instanceof JSONArray) {
                    JSONArray jsonArray = (JSONArray) obj;
                    if (i == paths.length - 1) {
                        return jsonArray;
                    } else { //不是最后一层
                        if (Objects.nonNull(condition)) {
                            for (int j = 0; j < jsonArray.size(); j++) {
                                Object xmlValue = getXmlValue((Map<String, Object>) jsonArray.get(j), condition[0].replaceAll("-", "."));
                                if (Objects.equals(condition[1], xmlValue)) {
                                    obj = jsonArray.get(j); break;
                                }
                                if (j == jsonArray.size() - 1) {
                                    return null;
                                }
                            }
                        } else {
                            obj = jsonArray.get(0);
                        }
                        if (obj instanceof JSONObject) {
                            tmpMaps = (Map<String, Object>) obj;
                        } else {
                            return jsonArray;
                        }
                    }
                } else if (obj instanceof JSONObject) {
                    if (Objects.nonNull(condition)) {
                        Object xmlValue = getXmlValue((Map<String, Object>) obj, condition[0].replaceAll("-", "."));
                        if (!Objects.equals(condition[1], xmlValue)) {
                            return null;
                        }
                    }
                    tmpMaps = (Map<String, Object>) obj;
                } else {
                    if ("bigdecimal".equals(type)) {
                        value = new BigDecimal(String.valueOf(obj));
                    } else if ("boolean".equals(type)) {
                        value = Boolean.valueOf(String.valueOf(obj));
                    } else {
                        value = String.valueOf(obj);
                    }
                    break;
                }
            }
        }
        return value;
    }

    /**
     * 根据子配置文件名称读取相应的配置文件
     * @param obj
     * @param subPropName
     * @return
     */
    protected Object readSubProp(Object obj, String subPropName) {
        String fileName = "/template/"+subPropName+".properties";
        InputStream resourceAsStream = AbstractMx2ElementCreator.class.getResourceAsStream(fileName);
        if (resourceAsStream == null) {
            //找不到子配置文件 默认取subPropName节点的值
            if (obj instanceof JSONArray) { //当前obj是JSONARRAY，需要循环获取subPropName节点值
                JSONArray jsonArray = (JSONArray)obj;
                List<String> list = new ArrayList<>();
                for (int i=0; i<jsonArray.size(); i++) {
                    Object jsonObj = jsonArray.get(i);
                    if (jsonObj instanceof JSONObject) {
                        obj = ((Map<String, Object>)jsonObj).get(subPropName);
                        if (obj instanceof String) {
                            list.add(String.valueOf(obj));
                        }
                    }
                }
                return list;
            }
            return null;
        }
        List<String> properties = StringUtil.inputStreamToLines(resourceAsStream);
        if (obj instanceof JSONArray) { //当前obj是JSONARRAY，需要循环获取子配置文件
            JSONArray jsonArray = (JSONArray)obj;
            List<Map<String, Object>> subMapList = new ArrayList<>();
            for (int i=0; i<jsonArray.size(); i++) {
                Object jsonObj = jsonArray.get(i);
                if (jsonObj instanceof JSONObject) {
                    Map<String, Object> subMaps = new LinkedHashMap<>();
                    readPropertyFile((Map<String, Object>)jsonObj, subMaps, properties);
                    if (subMaps.size() > 0) {
                        subMapList.add(subMaps);
                    }
                }
            }
            return subMapList;
        } else if (obj instanceof JSONObject) { //当前对象是JSONOBJECT
            Map<String, Object> subMaps = new LinkedHashMap<>();
            readPropertyFile((Map<String, Object>)obj, subMaps, properties);
            return subMaps;
        }
        return null;

    }

    protected void readPropertyFile(Map<String, Object> mxGsonMaps, Map<String, Object> targetMaps, List<String> properties) {
        if (properties != null && properties.size() > 0) {
            for (String property : properties) {
                if (property.startsWith("#")) {
                    continue;//过滤注释
                }
                String[] strArr = property.split("=");
                if (strArr.length != 2) {
                    continue;//过滤掉不符合规则的配置
                }
                String key = strArr[0].trim();
                String path = strArr[1].trim();
                Object value = getXmlValue(mxGsonMaps, path);
                if (value != null) {
                    targetMaps.put(key, value);
                }
            }
        }
    }
}
