package com.brilliance.swift.mx2element;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2element.camt029001.Mx2ElementCamt029001Creator;
import com.brilliance.swift.mx2element.camt053001.Mx2ElementCamt053001Creator;
import com.brilliance.swift.mx2element.camt054001.Mx2ElementCamt054001Creator;
import com.brilliance.swift.mx2element.camt056001.Mx2ElementCamt056001Creator;
import com.brilliance.swift.mx2element.pacs008001.Mx2ElementPacs008001Creator;
import com.brilliance.swift.mx2element.pacs009001.Mx2ElementPacs009001Creator;
import com.brilliance.swift.util.XmlUtil;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.prowidesoftware.swift.model.MxId;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import java.util.LinkedHashMap;
import java.util.Map;

public class Mx2ElementCreatorManager {

    public String mx2Element(String xmlStr) throws SwiftException {
        Map<String, Object> maps = mx2ElementMaps(xmlStr);
        Gson gson = new GsonBuilder().setPrettyPrinting().create();
        return gson.toJson(maps, LinkedHashMap.class);
    }

    public Map<String, Object> mx2ElementMaps(String xmlStr) throws SwiftException {
        xmlStr = XmlUtil.handlingXml(xmlStr);
        MxId mxId = XmlUtil.getMxMessageType(xmlStr);
        String messageType = mxId.getBusinessProcess().name()
                + mxId.getFunctionality()
                + mxId.getVariant()
                + mxId.getVersion();
        if (mxId == null) {
            throw new SwiftException("找不到MX报文类型");
        }
        xmlStr = XmlUtil.clearXmlNamespacePrefix(xmlStr);
        AbstractMX abstractMX = AbstractMX.parse(xmlStr, mxId);
        AbstractMx2ElementCreator creator = getCreator(messageType);
        creator.setAbstractMX(abstractMX);
        creator.setXmlStr(xmlStr);
        creator.setMessageType(messageType);
        return creator.buildElement();
    }

    public AbstractMx2ElementCreator getCreator(String messageType) {
        if (messageType.matches("pacs008001[0-9]{2}")) {
            return new Mx2ElementPacs008001Creator();
        } else if (messageType.matches("pacs009001[0-9]{2}")) {
            return new Mx2ElementPacs009001Creator();
        } else if (messageType.matches("camt054001[0-9]{2}")) {
            return new Mx2ElementCamt054001Creator();
        } else if (messageType.matches("camt053001[0-9]{2}")) {
            return new Mx2ElementCamt053001Creator();
        } else if (messageType.matches("camt029001[0-9]{2}")) {
            return new Mx2ElementCamt029001Creator();
        } else if (messageType.matches("camt056001[0-9]{2}")) {
            return new Mx2ElementCamt056001Creator();
        } else {
            throw new SwiftException("无效的MX报文类型");
        }
    }
}
