package com.brilliance.swift.mx2element.camt054001;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2element.AbstractMx2ElementCreator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.common.CdtDbtCode;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2ElementCamt054001Creator extends AbstractMx2ElementCreator {
    @Override
    public Map<String, Object> buildElement() {
        return super.buildElement();
    }

    public Object buildDbtrInfo() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("Ntfctn");
            String cdtDbtInd = XmlUtil.getXmlNodeValue(document, bodyParentPath + ".Ntfctn.Ntry.CdtDbtInd");
            if (!CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                return null;
            }
            int partyCount = XmlUtil.getChildrenCount(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty", null);
            if (partyCount > 0) { //Debtor.Party
                String nm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Nm");
                if (StringUtil.isNotEmpty(nm)) {
                    maps.put("dbtrNm", nm);
                }
                String anyBic = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Id.OrgId.AnyBIC");
                if (StringUtil.isNotEmpty(anyBic)) {
                    maps.put("dbtrOrgAnyBIC", anyBic);
                }
                String lei = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Id.OrgId.LEI");
                if (StringUtil.isNotEmpty(lei)) {
                    maps.put("dbtrOrgLei", lei);
                }
                String othrId = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Id.OrgId.Othr.Id");
                if (StringUtil.isNotEmpty(othrId)) {
                    maps.put("dbtrOrgOthrId", othrId);
                }
                String othrIdType = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Id.OrgId.Othr.SchmeNm.Cd");
                if (StringUtil.isNotEmpty(othrIdType)) {
                    maps.put("dbtrOrgOthrIdType", othrIdType);
                }
                String othrIdTypePrtry = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Id.OrgId.Othr.SchmeNm.Prtry");
                if (StringUtil.isNotEmpty(othrIdTypePrtry)) {
                    maps.put("dbtrOrgOthrIdTypePrtry", othrIdTypePrtry);
                }

                String orgIdOthrIssr = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Id.OrgId.Othr.Issr");
                if (StringUtil.isNotEmpty(orgIdOthrIssr)) {
                    maps.put("dbtrOrgOthrIssr", orgIdOthrIssr);
                }

                String adrType = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.AdrTp");
                if (StringUtil.isNotEmpty(adrType)) {
                    maps.put("dbtrPstlAdrType", adrType);
                }
                String adrCtry = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.Ctry");
                if (StringUtil.isNotEmpty(adrCtry)) {
                    maps.put("dbtrPstlAdrCtry", adrCtry);
                }
                String adrDept = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.Dept");
                if (StringUtil.isNotEmpty(adrDept)) {
                    maps.put("dbtrPstlAdrDept", adrDept);
                }
                String adrSubDept = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.SubDept");
                if (StringUtil.isNotEmpty(adrSubDept)) {
                    maps.put("dbtrPstlAdrSubDept", adrSubDept);
                }
                String adrStrtNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.StrtNm");
                if (StringUtil.isNotEmpty(adrStrtNm)) {
                    maps.put("dbtrPstlAdrStrtNm", adrStrtNm);
                }
                String adrBldgNb = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.BldgNb");
                if (StringUtil.isNotEmpty(adrBldgNb)) {
                    maps.put("dbtrPstlAdrBldgNb", adrBldgNb);
                }
                String adrBldgNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.BldgNm");
                if (StringUtil.isNotEmpty(adrBldgNm)) {
                    maps.put("dbtrPstlAdrBldgNm", adrBldgNm);
                }
                String adrFlr = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.Flr");
                if (StringUtil.isNotEmpty(adrFlr)) {
                    maps.put("dbtrPstlAdrFlr", adrFlr);
                }
                String adrRoom = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.Room");
                if (StringUtil.isNotEmpty(adrRoom)) {
                    maps.put("dbtrPstlAdrRoom", adrRoom);
                }
                String adrTwnNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.TwnNm");
                if (StringUtil.isNotEmpty(adrTwnNm)) {
                    maps.put("dbtrPstlAdrTwnNm", adrTwnNm);
                }
                String adrPstBx = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.PstBx");
                if (StringUtil.isNotEmpty(adrPstBx)) {
                    maps.put("dbtrPstlAdrPstBx", adrPstBx);
                }
                String adrPstCd = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.PstCd");
                if (StringUtil.isNotEmpty(adrPstCd)) {
                    maps.put("dbtrPstlAdrPstCd", adrPstCd);
                }
                String adrCtrySubDvsn = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.CtrySubDvsn");
                if (StringUtil.isNotEmpty(adrCtrySubDvsn)) {
                    maps.put("dbtrPstlAdrCtrySubDvsn", adrCtrySubDvsn);
                }
                String adrDstrctNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.DstrctNm");
                if (StringUtil.isNotEmpty(adrDstrctNm)) {
                    maps.put("dbtrPstlAdrDstrctNm", adrDstrctNm);
                }
                String adrTwnLctnNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.TwnLctnNm");
                if (StringUtil.isNotEmpty(adrTwnLctnNm)) {
                    maps.put("dbtrPstlAdrTwnLctnNm", adrTwnLctnNm);
                }

                int adrLineCount = XmlUtil.getChildrenCount(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.AdrLine", null);
                if (adrLineCount > 0) {
                    List<String> list = new ArrayList<>();
                    for (int i=0; i<adrLineCount; i++) {
                        String adrLine = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.AdrLine("+i+")");
                        list.add(adrLine);
                    }
                    maps.put("dbtrAdrLines", list);
                }
            } else {//Debtor.Agent
                String nm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.Nm");
                if (StringUtil.isNotEmpty(nm)) {
                    maps.put("dbtrNm", nm);
                }
                String anyBic = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.BICFI");
                if (StringUtil.isNotEmpty(anyBic)) {
                    maps.put("dbtrOrgAnyBIC", anyBic);
                }
                String lei = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.LEI");
                if (StringUtil.isNotEmpty(lei)) {
                    maps.put("dbtrOrgLei", lei);
                }
                String othrId = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.Othr.Id");
                if (StringUtil.isNotEmpty(othrId)) {
                    maps.put("dbtrOrgOthrId", othrId);
                }
                String othrIdType = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.Othr.SchmeNm.Cd");
                if (StringUtil.isNotEmpty(othrIdType)) {
                    maps.put("dbtrOrgOthrIdType", othrIdType);
                }
                String othrIdTypePrtry = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.Othr.SchmeNm.Prtry");
                if (StringUtil.isNotEmpty(othrIdTypePrtry)) {
                    maps.put("dbtrOrgOthrIdTypePrtry", othrIdTypePrtry);
                }
                String othrIssr = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.Othr.Issr");
                if (StringUtil.isNotEmpty(othrIssr)) {
                    maps.put("dbtrOrgOthrIssr", othrIssr);
                }
                String adrType = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.AdrTp");
                if (StringUtil.isNotEmpty(adrType)) {
                    maps.put("dbtrPstlAdrType", adrType);
                }
                String adrCtry = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.Ctry");
                if (StringUtil.isNotEmpty(adrCtry)) {
                    maps.put("dbtrPstlAdrCtry", adrCtry);
                }
                String adrDept = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.Dept");
                if (StringUtil.isNotEmpty(adrDept)) {
                    maps.put("dbtrPstlAdrDept", adrDept);
                }
                String adrSubDept = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.SubDept");
                if (StringUtil.isNotEmpty(adrSubDept)) {
                    maps.put("dbtrPstlAdrSubDept", adrSubDept);
                }
                String adrStrtNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.StrtNm");
                if (StringUtil.isNotEmpty(adrStrtNm)) {
                    maps.put("dbtrPstlAdrStrtNm", adrStrtNm);
                }
                String adrBldgNb = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.BldgNb");
                if (StringUtil.isNotEmpty(adrBldgNb)) {
                    maps.put("dbtrPstlAdrBldgNb", adrBldgNb);
                }
                String adrBldgNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.BldgNm");
                if (StringUtil.isNotEmpty(adrBldgNm)) {
                    maps.put("dbtrPstlAdrBldgNm", adrBldgNm);
                }
                String adrFlr = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.Flr");
                if (StringUtil.isNotEmpty(adrFlr)) {
                    maps.put("dbtrPstlAdrFlr", adrFlr);
                }
                String adrRoom = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.Room");
                if (StringUtil.isNotEmpty(adrRoom)) {
                    maps.put("dbtrPstlAdrRoom", adrRoom);
                }
                String adrTwnNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.TwnNm");
                if (StringUtil.isNotEmpty(adrTwnNm)) {
                    maps.put("dbtrPstlAdrTwnNm", adrTwnNm);
                }
                String adrPstBx = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.PstBx");
                if (StringUtil.isNotEmpty(adrPstBx)) {
                    maps.put("dbtrPstlAdrPstBx", adrPstBx);
                }
                String adrPstCd = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.PstCd");
                if (StringUtil.isNotEmpty(adrPstCd)) {
                    maps.put("dbtrPstlAdrPstCd", adrPstCd);
                }
                String adrCtrySubDvsn = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.CtrySubDvsn");
                if (StringUtil.isNotEmpty(adrCtrySubDvsn)) {
                    maps.put("dbtrPstlAdrCtrySubDvsn", adrCtrySubDvsn);
                }
                String adrDstrctNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.DstrctNm");
                if (StringUtil.isNotEmpty(adrDstrctNm)) {
                    maps.put("dbtrPstlAdrDstrctNm", adrDstrctNm);
                }
                String adrTwnLctnNm = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.TwnLctnNm");
                if (StringUtil.isNotEmpty(adrTwnLctnNm)) {
                    maps.put("dbtrPstlAdrTwnLctnNm", adrTwnLctnNm);
                }
                int adrLineCount = XmlUtil.getChildrenCount(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.AdrLine", null);
                if (adrLineCount > 0) {
                    List<String> list = new ArrayList<>();
                    for (int i=0; i<adrLineCount; i++) {
                        String adrLine = XmlUtil.getXmlNodeValue(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.AdrLine("+i+")");
                        list.add(adrLine);
                    }
                    maps.put("dbtrAdrLines", list);
                }
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }


        return null;
    }

    public Object buildDbtrAgtInfo() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("Ntfctn");
            String cdtDbtInd = XmlUtil.getXmlNodeValue(document, bodyParentPath + ".Ntfctn.Ntry.CdtDbtInd");
            if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) { //910
                buildDbtrAgt(bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdAgts.DbtrAgt");
            } else { //900
                int dbtrAgtCount = XmlUtil.getChildrenCount(document, bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdAgts.DbtrAgt", null);
                if (dbtrAgtCount > 0) {
                    buildDbtrAgt(bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdAgts.DbtrAgt");
                } else {
                    buildDbtrAgt(bodyParentPath+".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt");
                }
            }
            return null;
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    private void buildDbtrAgt(String path) {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            String bicfi = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.BICFI");
            if (StringUtil.isNotEmpty(bicfi)) {
                maps.put("dbtrAgtBicfi", bicfi);
            }
            String clrSysId = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.ClrSysMmbId.MmbId");
            if (StringUtil.isNotEmpty(clrSysId)) {
                maps.put("dbtrAgtClrSysId", clrSysId);
            }
            String clrSysType = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
            if (StringUtil.isNotEmpty(clrSysType)) {
                maps.put("dbtrAgtClrSysIdType", clrSysType);
            }
            String clrSysTypePrtry = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.ClrSysMmbId.ClrSysId.Prtry");
            if (StringUtil.isNotEmpty(clrSysTypePrtry)) {
                maps.put("dbtrAgtClrSysIdTypePrtry", clrSysTypePrtry);
            }
            String lei = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.LEI");
            if (StringUtil.isNotEmpty(lei)) {
                maps.put("dbtrAgtLei", lei);
            }
            String nm = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.Nm");
            if (StringUtil.isNotEmpty(nm)) {
                maps.put("dbtrAgtNm", nm);
            }
            String adrType = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.AdrTp");
            if (StringUtil.isNotEmpty(adrType)) {
                maps.put("dbtrAgtPstlAdrType", adrType);
            }
            String adrCtry = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.Ctry");
            if (StringUtil.isNotEmpty(adrCtry)) {
                maps.put("dbtrAgtPstlAdrCtry", adrCtry);
            }
            String adrDept = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.Dept");
            if (StringUtil.isNotEmpty(adrDept)) {
                maps.put("dbtrAgtPstlAdrDept", adrDept);
            }
            String adrSubDept = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.SubDept");
            if (StringUtil.isNotEmpty(adrSubDept)) {
                maps.put("dbtrAgtPstlAdrSubDept", adrSubDept);
            }
            String adrStrtNm = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.StrtNm");
            if (StringUtil.isNotEmpty(adrStrtNm)) {
                maps.put("dbtrAgtPstlAdrStrtNm", adrStrtNm);
            }
            String adrBldgNb = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.BldgNb");
            if (StringUtil.isNotEmpty(adrBldgNb)) {
                maps.put("dbtrAgtPstlAdrBldgNb", adrBldgNb);
            }
            String adrBldgNm = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.BldgNm");
            if (StringUtil.isNotEmpty(adrBldgNm)) {
                maps.put("dbtrAgtPstlAdrBldgNm", adrBldgNm);
            }
            String adrFlr = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.Flr");
            if (StringUtil.isNotEmpty(adrFlr)) {
                maps.put("dbtrAgtPstlAdrFlr", adrFlr);
            }
            String adrRoom = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.Room");
            if (StringUtil.isNotEmpty(adrRoom)) {
                maps.put("dbtrAgtPstlAdrRoom", adrRoom);
            }
            String adrTwnNm = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.TwnNm");
            if (StringUtil.isNotEmpty(adrTwnNm)) {
                maps.put("dbtrAgtPstlAdrTwnNm", adrTwnNm);
            }
            String adrPstBx = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.PstBx");
            if (StringUtil.isNotEmpty(adrPstBx)) {
                maps.put("dbtrAgtPstlAdrPstBx", adrPstBx);
            }
            String adrPstCd = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.PstCd");
            if (StringUtil.isNotEmpty(adrPstCd)) {
                maps.put("dbtrAgtPstlAdrPstCd", adrPstCd);
            }
            String adrCtrySubDvsn = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.CtrySubDvsn");
            if (StringUtil.isNotEmpty(adrCtrySubDvsn)) {
                maps.put("dbtrAgtPstlAdrCtrySubDvsn", adrCtrySubDvsn);
            }
            String adrDstrctNm = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.DstrctNm");
            if (StringUtil.isNotEmpty(adrDstrctNm)) {
                maps.put("dbtrAgtPstlAdrDstrctNm", adrDstrctNm);
            }
            String adrTwnLctnNm = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.TwnLctnNm");
            if (StringUtil.isNotEmpty(adrTwnLctnNm)) {
                maps.put("dbtrAgtPstlAdrTwnLctnNm", adrTwnLctnNm);
            }
            int adrLineCount = XmlUtil.getChildrenCount(document, path+".FinInstnId.PstlAdr.AdrLine", null);
            if (adrLineCount > 0) {
                List<String> list = new ArrayList<>();
                for (int i=0; i<adrLineCount; i++) {
                    String adrLine = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.PstlAdr.AdrLine("+i+")");
                    list.add(adrLine);
                }
                maps.put("dbtrAgtAdrLines", list);
            }
            String othrId = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.Othr.Id");
            if (StringUtil.isNotEmpty(othrId)) {
                maps.put("dbtrAgtOthrId", othrId);
            }
            String othrIdType = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.Othr.SchmeNm.Cd");
            if (StringUtil.isNotEmpty(othrIdType)) {
                maps.put("dbtrAgtOthrIdType", othrIdType);
            }
            String othrIdTypePrtry = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.Othr.SchmeNm.Prtry");
            if (StringUtil.isNotEmpty(othrIdTypePrtry)) {
                maps.put("dbtrAgtOthrIdTypePrtry", othrIdTypePrtry);
            }
            String othrIssr = XmlUtil.getXmlNodeValue(document, path+".FinInstnId.Othr.Issr");
            if (StringUtil.isNotEmpty(othrIssr)) {
                maps.put("dbtrAgtOthrIssr", othrIssr);
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
