package com.brilliance.swift.mx2element.pacs008001;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2element.AbstractMx2ElementCreator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import java.math.BigDecimal;
import java.util.*;

public class Mx2ElementPacs008001Creator extends AbstractMx2ElementCreator {
    @Override
    public Map<String, Object> buildElement() {
        return super.buildElement();
    }

    public Object buildChrgInfo() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
            int chrgsInfCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.ChrgsInf", null);
            if (chrgsInfCount > 0) {
                List<Map<String, Object>> list = new ArrayList<>();
                for (int i=0; i<chrgsInfCount; i++) {
                    String amt = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.ChrgsInf("+i+").Amt");
                    String ccy = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.ChrgsInf("+i+").Amt@Ccy");
                    if (StringUtil.isNotEmpty(ccy) && StringUtil.isNotEmpty(amt)) {
                        Map<String, Object> maps = new LinkedHashMap<>();
                        maps.put("ccy", ccy);
                        maps.put("amt", new BigDecimal(amt));
                        list.add(maps);
                    }
                }
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public Object buildRgltryRptg() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
            List<String> list = new ArrayList<>();
            int mxRegulatoryReportingCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg", null);
            if (mxRegulatoryReportingCount > 0) {
                for (int i=0; i<mxRegulatoryReportingCount; i++) {
                    int mxRegulatoryReportingDetailCount = XmlUtil.getChildrenCount(document,bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls", null);
                    if (mxRegulatoryReportingDetailCount > 0) {
                        for (int j=0; j<mxRegulatoryReportingDetailCount; j++) {
                            int mxRegulatoryReportingDetailInfCount = XmlUtil.getChildrenCount(document,bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Inf", null);
                            if (mxRegulatoryReportingDetailInfCount > 0) {
                                for (int k=0; k<mxRegulatoryReportingDetailInfCount; k++) {
                                    String inf = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Inf("+k+")");
                                    list.add(inf);
                                }
                            }
                        }
                    }
                }
            }
            if (list.size() > 0) {
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public Object buildRltdRmtInf() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
            int rltdRmtInfCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.RltdRmtInf", null);
            List<String> list = new ArrayList<>();
            if (rltdRmtInfCount > 0) {
                for (int i=0; i<rltdRmtInfCount; i++) {
                    String rmtId = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RltdRmtInf("+i+").RmtId");
                    if (StringUtil.isNotEmpty(rmtId)) {
                        list.add(rmtId);
                    }
                }
            }
            if (list.size() > 0) {
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public Object buildStrdAddtlRmtInf() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
            List<String> list = new ArrayList<>();
            int strdCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.RmtInf.Strd", null);
            if (strdCount > 0) {
                for (int i=0; i<strdCount; i++) {
                    int addtlRmtInfCount = XmlUtil.getChildrenCount(document,bodyParentPath+".CdtTrfTxInf.RmtInf.Strd("+i+").AddtlRmtInf", null);
                    if (addtlRmtInfCount > 0) {
                        for (int j=0; j<addtlRmtInfCount; j++) {
                            String inf = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RmtInf.Strd("+i+").AddtlRmtInf("+j+")");
                            list.add(inf);
                        }
                    }
                }
            }
            if (list.size() > 0) {
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
