package com.brilliance.swift.mx2map;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2map.camt053.Mx2MapCamt053Creator;
import com.brilliance.swift.mx2map.camt054.Mx2MapCamt054Creator;
import com.brilliance.swift.mx2map.pacs008.Mx2MapPacs008Creator;
import com.brilliance.swift.mx2map.pacs009.Mx2MapPacs009Creator;
import com.brilliance.swift.util.XmlUtil;
import com.prowidesoftware.swift.model.MxId;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import java.util.Map;

public class Mx2MapCreatorManager {

    public Map<String, Object> mx2Map(String xml, String localCode) throws SwiftException {
        xml = XmlUtil.handlingXml(xml);
        MxId mxId = XmlUtil.getMxMessageType(xml);
        if (mxId == null) {
            throw new SwiftException("找不到MX报文类型");
        }
        String messageType = (mxId.getBusinessProcess().name()
                + mxId.getFunctionality()
                + mxId.getVariant())
                //+ abstractMX.getMxId().getVersion())
                .trim();
        AbstractMx2MapCreator creator = getCreator(messageType);
        creator.setXmlStr(xml);
        creator.setLocalCode(localCode);
        return creator.mx2Map();
    }

    public AbstractMx2MapCreator getCreator(String messageType) {
        if ("camt053001".equals(messageType)) {
            return new Mx2MapCamt053Creator();
        } else if ("pacs008001".equals(messageType)) {
            return new Mx2MapPacs008Creator();
        } else if ("pacs009001".equals(messageType)) {
            return new Mx2MapPacs009Creator();
        } else if ("camt054001".equals(messageType)) {
            return new Mx2MapCamt054Creator();
        } else {
            throw new SwiftException("无效的报文类型");
        }
    }
}
