package com.brilliance.swift.mx2map.camt053;

import com.brilliance.swift.SwiftTransfer;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2map.AbstractMx2MapCreator;
import com.brilliance.swift.vo.common.CdtDbtCode;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

public class Mx2MapCamt053Creator extends AbstractMx2MapCreator {
    @Override
    public Map<String, Object> mx2Map() throws SwiftException {
        Map<String, Object> elementMaps = SwiftTransfer.mx2ElementMaps(xmlStr);
        if (elementMaps.get("frBic") != null) {
            maps.put(getPropertyValue("app.header.sendBic"), elementMaps.get("frBic"));
        }
        if (elementMaps.get("toBic") != null) {
            maps.put(getPropertyValue("app.header.receiverBic"), elementMaps.get("toBic"));
        }
        String messageType = addSuffixWithMessageType(elementMaps);
        if (messageType != null) {
            maps.put(getPropertyValue("app.header.msgDefId"), messageType);
        }
        if (elementMaps.get("bizSvc") != null) {
            maps.put(getPropertyValue("app.header.bizSvc"), elementMaps.get("bizSvc"));
        }
        if (elementMaps.get("creDt") != null) {
            maps.put(getPropertyValue("app.header.creDt"), elementMaps.get("creDt"));
        }
        if (elementMaps.get("bizMsgIdr") != null) {
            maps.put(getPropertyValue("statement.id"), elementMaps.get("bizMsgIdr"));
        }
        if (elementMaps.get("acctIdIban") != null) {
            maps.put(getPropertyValue("statement.account"), elementMaps.get("acctIdIban"));
        }
        if (elementMaps.get("acctId") != null) {
            maps.put(getPropertyValue("statement.account"), elementMaps.get("acctId"));
        }
        if (elementMaps.get("acctCcy") != null) {
            maps.put(getPropertyValue("statement.account.ccy"), elementMaps.get("acctCcy"));
        }
        if (elementMaps.get("lglSeqNb") != null) {
            maps.put(getPropertyValue("statement.sequence.number"), elementMaps.get("lglSeqNb"));
        }
        if (elementMaps.get("pgNb") != null) {
            maps.put(getPropertyValue("statement.page.number"), elementMaps.get("pgNb"));
        }
        if (elementMaps.get("lastPgInd") != null) {
            Boolean lastPgInd = (Boolean)elementMaps.get("lastPgInd");
            maps.put(getPropertyValue("statement.lastPgInd"), lastPgInd ? getPropertyValue("yes") : getPropertyValue("no"));
        } else {
            maps.put(getPropertyValue("statement.lastPgInd"), getPropertyValue("no"));
        }
        //期初余额
        if (elementMaps.get("opbdBalCdtDbtInd") != null) {
            String cdtDbtInd = String.valueOf(elementMaps.get("opbdBalCdtDbtInd"));
            if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.openingBooked.crdr"), getPropertyValue("credit"));
            } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.openingBooked.crdr"), getPropertyValue("debit"));
            }
        }
        if (elementMaps.get("opbdBalDt") != null) {
            maps.put(getPropertyValue("statement.openingBooked.date"), elementMaps.get("opbdBalDt"));
        }
        if (elementMaps.get("opbdBalCcy") != null) {
            maps.put(getPropertyValue("statement.openingBooked.ccy"), elementMaps.get("opbdBalCcy"));
        }
        if (elementMaps.get("opbdBalAmt") != null) {
            BigDecimal amt = (BigDecimal)elementMaps.get("opbdBalAmt");
            maps.put(getPropertyValue("statement.openingBooked.amt"), amt.toPlainString());
        }
        if (elementMaps.get("ntry") != null) {
            List<Map<String, Object>> list = (List<Map<String, Object>>)elementMaps.get("ntry");
            if (list.size() > 0) {
                for (int i=0; i<list.size(); i++) {
                    Map<String, Object> tmpMap = list.get(i);
                    Boolean reversalIndicator = false;
                    if (tmpMap.get("ntryRvslInd") != null) {
                        reversalIndicator = (Boolean)tmpMap.get("ntryRvslInd");
                    }
                    String creditDebitIndicator = "";
                    if (tmpMap.get("cdtDbtInd") != null) {
                        creditDebitIndicator = (String)tmpMap.get("cdtDbtInd");
                    }
                    if (reversalIndicator) {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("reversal.credit"));
                        } else {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("reversal.debit"));
                        }
                    } else {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("debit"));
                        } else {
                            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.entry.crdr")+"("+(i+1)+")", getPropertyValue("credit"));
                        }
                    }
                    if (tmpMap.get("ntryValDt") != null) {
                        maps.put(getPropertyValue("statement.entry.valueDate")+"("+(i+1)+")", tmpMap.get("ntryValDt"));
                    }
                    if (tmpMap.get("ntryCcy") != null) {
                        maps.put(getPropertyValue("statement.entry.ccy")+"("+(i+1)+")", tmpMap.get("ntryCcy"));
                    }
                    if (tmpMap.get("ntryAmt") != null) {
                        BigDecimal amt = (BigDecimal)tmpMap.get("ntryAmt");
                        maps.put(getPropertyValue("statement.entry.amt")+"("+(i+1)+")", amt.toPlainString());
                    }
                    if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                        if (tmpMap.get("instrId") != null) {
                            maps.put(getPropertyValue("statement.entry.txnRef")+"("+(i+1)+")", tmpMap.get("instrId"));
                        }
                    } else {
                        if (tmpMap.get("endToEndId") != null) {
                            maps.put(getPropertyValue("statement.entry.txnRef")+"("+(i+1)+")", tmpMap.get("endToEndId"));
                        }
                    }
                    if (tmpMap.get("ntryAcctSvcrRef") != null) {
                        maps.put(getPropertyValue("statement.entry.acctSvcrRef")+"("+(i+1)+")", tmpMap.get("ntryAcctSvcrRef"));
                    }
                    if (tmpMap.get("addtlTxInf") != null) {
                        maps.put(getPropertyValue("statement.entry.addtlTxInf")+"("+(i+1)+")", tmpMap.get("addtlTxInf"));
                    }
                }
            }
        }

        //期末余额
        if (elementMaps.get("clbdBalCdtDbtInd") != null) {
            String cdtDbtInd = String.valueOf(elementMaps.get("clbdBalCdtDbtInd"));
            if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.closingBooked.crdr"), getPropertyValue("credit"));
            } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("statement.closingBooked.crdr"), getPropertyValue("debit"));
            }
        }
        if (elementMaps.get("clbdBalDt") != null) {
            maps.put(getPropertyValue("statement.closingBooked.date"), elementMaps.get("clbdBalDt"));
        }
        if (elementMaps.get("clbdBalCcy") != null) {
            maps.put(getPropertyValue("statement.closingBooked.ccy"), elementMaps.get("clbdBalCcy"));
        }
        if (elementMaps.get("clbdBalAmt") != null) {
            BigDecimal amt = (BigDecimal) elementMaps.get("clbdBalAmt");
            maps.put(getPropertyValue("statement.closingBooked.amt"), amt.toPlainString());
        }
        return maps;
    }
}
