package com.brilliance.swift.mx2map.camt054;

import com.brilliance.swift.SwiftTransfer;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2map.AbstractMx2MapCreator;
import com.brilliance.swift.vo.common.CdtDbtCode;

import java.math.BigDecimal;
import java.util.Map;

public class Mx2MapCamt054Creator extends AbstractMx2MapCreator {
    @Override
    public Map<String, Object> mx2Map() throws SwiftException {
        Map<String, Object> elementMaps = SwiftTransfer.mx2ElementMaps(xmlStr);
        if (elementMaps.get("frBic") != null) {
            maps.put(getPropertyValue("app.header.sendBic"), elementMaps.get("frBic"));
        }
        if (elementMaps.get("toBic") != null) {
            maps.put(getPropertyValue("app.header.receiverBic"), elementMaps.get("toBic"));
        }
        String messageType = addSuffixWithMessageType(elementMaps);
        if (messageType != null) {
            maps.put(getPropertyValue("app.header.msgDefId"), messageType);
        }
        if (elementMaps.get("bizSvc") != null) {
            maps.put(getPropertyValue("app.header.bizSvc"), elementMaps.get("bizSvc"));
        }
        if (elementMaps.get("creDt") != null) {
            maps.put(getPropertyValue("app.header.creDt"), elementMaps.get("creDt"));
        }

        if (elementMaps.get("endToEndId") != null) {
            maps.put(getPropertyValue("endToEnd.id"), elementMaps.get("endToEndId"));
        }
        if (elementMaps.get("uetr") != null) {
            maps.put(getPropertyValue("uetr"), elementMaps.get("uetr"));
        }
        if (elementMaps.get("cdtDbtInd") != null) {
            String cdtDbtInd = (String) elementMaps.get("cdtDbtInd");
            if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                maps.put(getPropertyValue("cdtDbtInd"), getPropertyValue("credit"));
            } else {
                maps.put(getPropertyValue("cdtDbtInd"), getPropertyValue("debit"));
            }
        }
        if (elementMaps.get("sts") != null) {
            maps.put(getPropertyValue("status"), elementMaps.get("sts"));
        } else if (elementMaps.get("stsPrtry") != null) {
            maps.put(getPropertyValue("status"), elementMaps.get("stsPrtry"));
        }
        if (elementMaps.get("bookgDt") != null) {
            maps.put(getPropertyValue("bookingDate"), elementMaps.get("bookgDt"));
        }
        if (elementMaps.get("bizMsgIdr") != null) {
            maps.put(getPropertyValue("message.id"), elementMaps.get("bizMsgIdr"));
        }
        if (elementMaps.get("valDt") != null) {
            maps.put(getPropertyValue("valueDate"), elementMaps.get("valDt"));
        }
        if (elementMaps.get("ntryAmt") != null) {
            BigDecimal amt = (BigDecimal) elementMaps.get("ntryAmt");
            if (elementMaps.get("ntryCcy") != null) {
                maps.put(getPropertyValue("valueAmt"), elementMaps.get("ntryCcy") + " " + amt.toPlainString());
            } else {
                maps.put(getPropertyValue("valueAmt"), amt.toPlainString());
            }
        }
        if (elementMaps.get("ntfctnAcctIdIban") != null) {
            maps.put(getPropertyValue("acctIdIban"), elementMaps.get("ntfctnAcctIdIban"));
        }
        if (elementMaps.get("ntfctnAcctId") != null) {
            maps.put(getPropertyValue("acctId"), elementMaps.get("ntfctnAcctId"));
        }
        if (elementMaps.get("ntfctnAcctCcy") != null) {
            maps.put(getPropertyValue("accountCcy"), elementMaps.get("ntfctnAcctCcy"));
        }
        buildPartyInfo(maps,"dbtr", elementMaps);
        buildAgentInfo(maps, "dbtrAgt", elementMaps);
        buildAgentInfo(maps, "intrmyAgt1", elementMaps);
        if (elementMaps.get("addtlTxInf") != null) {
            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("txnRemark"), elementMaps.get("addtlTxInf"));
        }
        return maps;
    }
}
