package com.brilliance.swift.mx2map.pacs008;

import com.brilliance.swift.SwiftTransfer;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2map.AbstractMx2MapCreator;
import com.brilliance.swift.vo.common.SettlementMethodCode;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

public class Mx2MapPacs008Creator extends AbstractMx2MapCreator {
    @Override
    public Map<String, Object> mx2Map() throws SwiftException {
        Map<String, Object> elementMaps = SwiftTransfer.mx2ElementMaps(xmlStr);
        if (elementMaps.get("frBic") != null) {
            maps.put(getPropertyValue("app.header.sendBic"), elementMaps.get("frBic"));
        }
        if (elementMaps.get("toBic") != null) {
            maps.put(getPropertyValue("app.header.receiverBic"), elementMaps.get("toBic"));
        }
        String messageType = addSuffixWithMessageType(elementMaps);
        if (messageType != null) {
            maps.put(getPropertyValue("app.header.msgDefId"), messageType);
        }
        if (elementMaps.get("bizSvc") != null) {
            maps.put(getPropertyValue("app.header.bizSvc"), elementMaps.get("bizSvc"));
        }
        if (elementMaps.get("creDt") != null) {
            maps.put(getPropertyValue("app.header.creDt"), elementMaps.get("creDt"));
        }

        if (elementMaps.get("endToEndId") != null) {
            maps.put(getPropertyValue("endToEnd.id"), elementMaps.get("endToEndId"));
        }
        if (elementMaps.get("uetr") != null) {
            maps.put(getPropertyValue("uetr"), elementMaps.get("uetr"));
        }
        if (elementMaps.get("sttlmMtd") != null) {
            maps.put(getPropertyValue("settlement.method"), elementMaps.get("sttlmMtd"));
        }
        if (elementMaps.get("sttlmAcctIdIban") != null) {
            maps.put(getPropertyValue("settlement.acct"), elementMaps.get("sttlmAcctIdIban"));
        }
        if (elementMaps.get("sttlmAcctId") != null) {
            maps.put(getPropertyValue("settlement.acct"), elementMaps.get("sttlmAcctId"));
        }
        Map<String, Object> creditTransferMaps = new LinkedHashMap<>();
        maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("creditTransferInfo"), creditTransferMaps);
        if (elementMaps.get("bizMsgIdr") != null) {
            creditTransferMaps.put(getPropertyValue("message.id"), elementMaps.get("bizMsgIdr"));
        }
        if (elementMaps.get("intrBkSttlmDt") != null) {
            creditTransferMaps.put(getPropertyValue("settlement.date"), elementMaps.get("intrBkSttlmDt"));
        }
        if (elementMaps.get("intrBkSttlmAmt") != null) {
            BigDecimal amt = (BigDecimal) elementMaps.get("intrBkSttlmAmt");
            if (elementMaps.get("intrBkSttlmCcy") != null) {
                creditTransferMaps.put(getPropertyValue("settlement.amt"), elementMaps.get("intrBkSttlmCcy") + " " + amt.toPlainString());
            } else {
                creditTransferMaps.put(getPropertyValue("settlement.amt"), amt.toPlainString());
            }
        }
        if (elementMaps.get("instdAmt") != null) {
            BigDecimal amt = (BigDecimal) elementMaps.get("instdAmt");
            if (elementMaps.get("instdAmtCcy") != null) {
                creditTransferMaps.put(getPropertyValue("original.settlement.amt"), elementMaps.get("instdAmtCcy") + " " + amt.toPlainString());
            } else {
                creditTransferMaps.put(getPropertyValue("original.settlement.amt"), amt.toPlainString());
            }
        }
        if (elementMaps.get("xchgRate") != null) {
            BigDecimal xchgRate = (BigDecimal) elementMaps.get("xchgRate");
            creditTransferMaps.put(getPropertyValue("exchange.rate"), xchgRate.toPlainString());
        }
        buildPartyInfo(maps,"dbtr", elementMaps);
        buildAgentInfo(maps, "dbtrAgt", elementMaps);
        AbstractMT abstractMT = null;
        try {
            String mtMessage = SwiftTransfer.mx2Mt(xmlStr, null, null);
            abstractMT = AbstractMT.parse(mtMessage);
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
        if (SettlementMethodCode.INGA.value().equals(elementMaps.get("sttlmMtd"))
                || SettlementMethodCode.INDA.value().equals(elementMaps.get("sttlmMtd"))) {
            buildInstgRmbrsmntAgtInfo(maps, abstractMT);
        } else {
            buildAgentInfo(maps, "instgRmbrsmntAgt", elementMaps);
        }
        buildAgentInfo(maps, "instdRmbrsmntAgt", elementMaps);
        buildAgentInfo(maps, "thrdRmbrsmntAgt", elementMaps);
        buildAgentInfo(maps, "intrmyAgt1", elementMaps);
        buildAgentInfo(maps, "cdtrAgt", elementMaps);
        buildPartyInfo(maps, "cdtr", elementMaps);
        if (elementMaps.get("chrgBr") != null) {
            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("charge.by"), elementMaps.get("chrgBr"));
        }
        if (elementMaps.get("chrgsInf") != null) {
            List<Map<String, Object>> list = (List<Map<String, Object>>)elementMaps.get("chrgsInf");
            for (int i=0; i<list.size(); i++) {
                Map<String, Object> tmpMaps = list.get(i);
                BigDecimal amt = (BigDecimal) tmpMaps.get("amt");
                if (tmpMaps.get("ccy") != null) {
                    maps.put(getPropertyValue("charge.info") + "(" + (i+1) + ")", tmpMaps.get("ccy") + " " + amt.toPlainString());
                } else {
                    maps.put(getPropertyValue("charge.info") + "(" + (i+1) + ")", amt.toPlainString());
                }
            }
        }
        Tag tag = abstractMT.getSwiftMessage().getBlock4().getTagByName("70");
        if (tag != null) {
            maps.put(getPropertyValue("remittanceInformation"), tag.getValue());
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName("72");
        if (tag != null) {
            maps.put(getPropertyValue("txnRemark"), tag.getValue());
        }
        tag = abstractMT.getSwiftMessage().getBlock4().getTagByName("77B");
        if (tag != null) {
            maps.put(getPropertyValue("regulatoryReporting"), tag.getValue());
        }
        //判断MX103 是单报还是双报
        if ("Y".equals(doubleMessageFlag)) {
            maps.put(getPropertyValue("settlement.method"), elementMaps.get("sttlmMtd") + "("+getPropertyValue("doubleMessage")+")");
        } else {
            maps.put(getPropertyValue("settlement.method"), elementMaps.get("sttlmMtd") + "("+getPropertyValue("simpleMessage")+")");
        }
        return maps;
    }
}
