package com.brilliance.swift.mx2map.pacs009;

import com.brilliance.swift.SwiftTransfer;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2map.AbstractMx2MapCreator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.SettlementMethodCode;
import com.prowidesoftware.swift.model.SwiftTagListBlock;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.LinkedHashMap;
import java.util.Map;

public class Mx2MapPacs009Creator extends AbstractMx2MapCreator {
    @Override
    public Map<String, Object> mx2Map() throws SwiftException {
        Map<String, Object> elementMaps = SwiftTransfer.mx2ElementMaps(xmlStr);
        if (elementMaps.get("frBic") != null) {
            maps.put(getPropertyValue("app.header.sendBic"), elementMaps.get("frBic"));
        }
        if (elementMaps.get("toBic") != null) {
            maps.put(getPropertyValue("app.header.receiverBic"), elementMaps.get("toBic"));
        }
        String messageType = addSuffixWithMessageType(elementMaps);
        if (messageType != null) {
            maps.put(getPropertyValue("app.header.msgDefId"), messageType);
        }
        if (elementMaps.get("bizSvc") != null) {
            maps.put(getPropertyValue("app.header.bizSvc"), elementMaps.get("bizSvc"));
        }
        if (elementMaps.get("creDt") != null) {
            maps.put(getPropertyValue("app.header.creDt"), elementMaps.get("creDt"));
        }

        if (elementMaps.get("endToEndId") != null) {
            maps.put(getPropertyValue("endToEnd.id"), elementMaps.get("endToEndId"));
        }
        if (elementMaps.get("uetr") != null) {
            maps.put(getPropertyValue("uetr"), elementMaps.get("uetr"));
        }
        if (elementMaps.get("sttlmMtd") != null) {
            maps.put(getPropertyValue("settlement.method"), elementMaps.get("sttlmMtd"));
        }
        if (elementMaps.get("sttlmAcctIdIban") != null) {
            maps.put(getPropertyValue("settlement.acct"), elementMaps.get("sttlmAcctIdIban"));
        }
        if (elementMaps.get("sttlmAcctId") != null) {
            maps.put(getPropertyValue("settlement.acct"), elementMaps.get("sttlmAcctId"));
        }
        Map<String, Object> creditTransferMaps = new LinkedHashMap<>();
        maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("creditTransferInfo"), creditTransferMaps);
        if (elementMaps.get("bizMsgIdr") != null) {
            creditTransferMaps.put(getPropertyValue("message.id"), elementMaps.get("bizMsgIdr"));
        }
        if (elementMaps.get("intrBkSttlmDt") != null) {
            creditTransferMaps.put(getPropertyValue("settlement.date"), elementMaps.get("intrBkSttlmDt"));
        }
        if (elementMaps.get("intrBkSttlmAmt") != null) {
            BigDecimal amt = (BigDecimal) elementMaps.get("intrBkSttlmAmt");
            if (elementMaps.get("intrBkSttlmCcy") != null) {
                creditTransferMaps.put(getPropertyValue("settlement.amt"), elementMaps.get("intrBkSttlmCcy") + " " + amt.toPlainString());
            } else {
                creditTransferMaps.put(getPropertyValue("settlement.amt"), amt.toPlainString());
            }
        }
        buildAgentInfo(maps,"dbtr", elementMaps, "dbtrAgtInfo");
        AbstractMT abstractMT = null;
        try {
            String mtMessage = SwiftTransfer.mx2Mt(xmlStr, null, null);
            if (StringUtil.isNotEmpty(mtMessage)) {
                abstractMT = AbstractMT.parse(mtMessage);
            }
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
        if (SettlementMethodCode.INGA.value().equals(elementMaps.get("sttlmMtd"))
                || SettlementMethodCode.INDA.value().equals(elementMaps.get("sttlmMtd"))) {
            buildInstgRmbrsmntAgtInfo(maps, abstractMT);
        } else {
            buildAgentInfo(maps, "instgRmbrsmntAgt", elementMaps);
        }
        buildAgentInfo(maps,"instdRmbrsmntAgt", elementMaps);
        buildAgentInfo(maps,"intrmyAgt1", elementMaps);
        buildAgentInfo(maps,"cdtrAgt", elementMaps, "cdtrAgtAcctInfo");
        buildAgentInfo(maps,"cdtr", elementMaps, "cdtrAgtInfo");
        Tag tag = getTagByName(abstractMT, "72", "A");
        if (tag != null) {
            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("txnRemark"), tag.getValue());
        }
        //子交易信息
        if (elementMaps.get("undrlygCstmrCdtTrf") != null) {
            Map<String, Object> undrlygCstmrCdtTrfMaps = (Map<String, Object>)elementMaps.get("undrlygCstmrCdtTrf");
            Map<String, Object> undrlyTxnMaps = new LinkedHashMap<>();
            maps.put(Mx2MtConstants.NEW_LINE + getPropertyValue("undrlygCstmrCdtTrfInfo"), undrlyTxnMaps);
            buildPartyInfo(undrlyTxnMaps, "dbtr", undrlygCstmrCdtTrfMaps);
            buildAgentInfo(undrlyTxnMaps, "dbtrAgt", undrlygCstmrCdtTrfMaps);
            buildAgentInfo(undrlyTxnMaps, "intrmyAgt1", undrlygCstmrCdtTrfMaps);
            buildAgentInfo(undrlyTxnMaps, "cdtrAgt", undrlygCstmrCdtTrfMaps);
            buildPartyInfo(undrlyTxnMaps, "cdtr", undrlygCstmrCdtTrfMaps);
            tag = getTagByName(abstractMT, "70", "B");
            if (tag != null) {
                undrlyTxnMaps.put(getPropertyValue("remittanceInformation"), tag.getValue());
            }
            tag = getTagByName(abstractMT, "72", "B");
            if (tag != null) {
                undrlyTxnMaps.put(getPropertyValue("txnRemark"), tag.getValue());
            }
            if (undrlygCstmrCdtTrfMaps.get("instdAmt") != null) {
                BigDecimal amt = (BigDecimal) elementMaps.get("instdAmt");
                if (elementMaps.get("instdAmtCcy") != null) {
                    undrlyTxnMaps.put(getPropertyValue("original.settlement.amt"), elementMaps.get("instdAmtCcy") + " " + amt.toPlainString());
                } else {
                    undrlyTxnMaps.put(getPropertyValue("original.settlement.amt"), amt.toPlainString());
                }
            }
        }
        return maps;
    }

    protected Tag getTagByName(AbstractMT abstractMT, String tagName, String sequence) {
        if (abstractMT == null || abstractMT.getSwiftMessage() == null) return null;
        boolean isCov = abstractMT.getSwiftMessage().isCOV();
        if (isCov) {
            SwiftTagListBlock swiftTagListBlock = abstractMT.getSequence(sequence);
            if (swiftTagListBlock != null) {
                return swiftTagListBlock.getTagByName(tagName);
            }
        } else {
            return abstractMT.getSwiftMessage().getBlock4().getTagByName(tagName);
        }
        return null;
    }
}
