package com.brilliance.swift.mx2mt;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.SwiftTranslationErrorInfo;
import com.brilliance.swift.vo.SwiftTranslationReport;
import com.brilliance.swift.vo.common.TranslationResultCode;
import com.prowidesoftware.swift.io.ConversionService;
import com.prowidesoftware.swift.io.IConversionService;
import com.prowidesoftware.swift.io.writer.SwiftWriter;
import com.prowidesoftware.swift.model.*;
import com.prowidesoftware.swift.model.field.*;
import com.prowidesoftware.swift.model.mx.NamespaceReader;
import org.apache.commons.lang3.Validate;
import org.dom4j.*;
import org.dom4j.io.SAXReader;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.net.URL;
import java.util.*;

public abstract class AbstractMx2MtCreator implements Mx2MtCreator {

    protected Mx2MtContext context;

    public Mx2MtContext getContext() {
        return context;
    }

    public void setContext(Mx2MtContext context) {
        this.context = context;
    }

    /**
     * 封装报文转换详细报告
     * @param id
     * @param location
     * @param originalValue
     * @return
     */
    protected void buildSTErrorInfo(long id, String location, String originalValue) {
        SwiftTranslationReport str = context.get(SwiftTranslationReport.class);
        SwiftTranslationErrorInfo errorInfo = SwiftTransferUtil.getSwiftTranslationErrorInfoById(id);
        if (errorInfo == null) return;
        if (StringUtil.isEmpty(location)) {
            location = (String) context.get(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION,true);
        }
        errorInfo.setLocation(location);
        errorInfo.setOriginalValue(originalValue);
        List<SwiftTranslationErrorInfo> errorInfos = str.getErrorInfos();
        boolean existFlag = false;
        for (int i=0; i<errorInfos.size(); i++) {
            if (SwiftTransferUtil.compareStErrorInfo(errorInfo, errorInfos.get(i))) {
                existFlag = true;
                break;
            }
        }
        if (!existFlag) {
            str.addErrorInfo(errorInfo);
        }
    }
    /**
     * 出现中文字符替换成.
     * @param tag
     * @return
     */
    protected void mx_to_mtCharSet(Tag tag) {
        if (tag == null || StringUtil.isEmpty(tag.getValue())) {
            return;
        }
        String value = tag.getValue();
        boolean find = false;
        String originalValue = value;
        //表示出现了中文字符
        if (value.getBytes().length != value.length()) {
            find = true;
            char[] chars = value.toCharArray();
            for (char c : chars) {
                if (c > 127 || c < 0) {
                    value = value.replace(c,'.');
                }
            }
        }
        if (value.indexOf("&") > -1) {
            find = true;
            value = value.replace("&", ".");
        }
        if (value.indexOf("<") > -1) {
            find = true;
            value = value.replace("<", ".");
        }
        if (value.indexOf(">") > -1) {
            find = true;
            value = value.replace(">", ".");
        }
        if (value.indexOf("\"") > -1) {
            find = true;
            value = value.replace("\"", ".");
        }
        if (value.indexOf("\\") > -1) {
            find = true;
            value = value.replace("\\", ".");
        }
        tag.setValue(value);
        if (find) {
            if ("20".equals(tag.getName()) || "21".equals(tag.getName())) {
                buildSTErrorInfo(9, "Block4/:"+tag.getName()+":", originalValue);
            } else {
                buildSTErrorInfo(8, "Block4/:"+tag.getName()+":", originalValue);
            }
        }
    }

    protected String getRandomNumber(int length) {
        /*String randomNumber = "";
        Random random = new Random();
        for (int i=0; i<length; i++) {
            randomNumber += random.nextInt(9);
        }
        return randomNumber;*/
        String randomNumber = "";
        for (int i=0; i<length; i++) {
            randomNumber += "0";
        }
        return randomNumber;
    }

    protected String processBicCode(String bicCode) {
        String processedBicCode = "";
        if (!StringUtil.isEmpty(bicCode)) {
            if (bicCode.length() == 8) {
                processedBicCode = bicCode + Mx2MtConstants.BICSUFFIX;
            } else if (bicCode.length() == 11) {
                processedBicCode = bicCode.substring(0, 8) + Mx2MtConstants.BICMIDDLE + bicCode.substring(8);
            } else {
                throw new SwiftException("BicCode length is invalid.");
            }
        }
        return processedBicCode;
    }

    protected String getXmlNodeValue(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        String value = XmlUtil.getXmlNodeValue(document, path);
        if (StringUtil.isNotEmpty(value)) {
            Mx2MtListener mx2MtListener = (Mx2MtListener)context.get(Mx2MtContextIdentifier.MX_TO_MT_LISTENER_CLASS, true);
            if (mx2MtListener != null) {
                mx2MtListener.process(path); //如果存在监听器且得到的值不为空，则执行监听操作
            }
        }
        return value;
    }

    protected int getXmlNodeCounts(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        return XmlUtil.getChildrenCount(document, path, null);
    }

    /**
     * 过滤掉必填节点值，这些值不会在错误报告中显示
     * 过滤掉没用的节点
     * 过滤掉配置文件中忽略的节点
     * @param list
     * @param xml
     */
    public static List<String> filterMandatoryPath(List<String> list, String xml) {
        //1.过滤掉没用的节点  只包含 AppHdr Document
        List<String> newList = new ArrayList<>();
        for (int i=0; i<list.size(); i++) {
            String path = list.get(i);
            if (path.indexOf("AppHdr") > -1 || path.indexOf("Document") > -1) {
                newList.add(path);
            }
        }
        list = newList;
        newList = new ArrayList<>();
        //根据Document@xmlns获取版本对应的xsd文件
        String documentXsdName = "";
        Optional<String> namespace = NamespaceReader.findDocumentNamespace(xml);
        if (namespace.isPresent()) {
            MxId documentMxId = new MxId(namespace.get());
            documentXsdName = documentMxId.getBusinessProcess().name()
                    + documentMxId.getFunctionality()
                    + documentMxId.getVariant()
                    + documentMxId.getVersion();
        }
        //2.过滤掉配置文件中忽略的节点
        URL resource = AbstractMx2MtCreator.class.getResource("/xmlPathIgnore/" + documentXsdName + ".txt");
        if (resource != null) {
            try {
                List<String> ingorePaths = StringUtil.inputStreamToLines(resource.openStream());
                if (ingorePaths != null && ingorePaths.size() > 0) {
                    for (String path : list) {
                        String tmpPath = path.replaceAll("\\([0-9]+\\)", "");
                        boolean includeFlag = false;
                        for (String ignorePath : ingorePaths) {
                            if (StringUtil.isNotEmpty(ignorePath) && tmpPath.indexOf(ignorePath) > -1) {
                                includeFlag = true;
                                break;
                            }
                        }
                        if (!includeFlag) {
                            newList.add(path);
                        }
                    }
                    /*list = newList;
                    newList = new ArrayList<>();*/
                }
            } catch (IOException e) {
                throw new SwiftException(e.getMessage());
            }
        }

        //3.过滤掉必填节点值，这些值不会在错误报告中显示
        /*for (int i=0; i<list.size(); i++) {
            String path = list.get(i);
            boolean requiredFlag = false;
            if (path.indexOf("AppHdr") > -1) {
                requiredFlag = getPathMinOccurs(path, appHdrXsdName);
            } else if (path.indexOf("Document") > -1) {
                requiredFlag = getPathMinOccurs(path, documentXsdName);
            }
            if (!requiredFlag) {
                newList.add(path);
            }
        }*/
        return newList;
    }

    /**
     * 从对应的xsd文件中找到 MinOccurs 属性
     * 如果等于0 表示选填
     * 如果等于null或者大于0，表示必填
     * @param path
     * @param xsdName
     * @return
     */
    public static boolean getPathMinOccurs(String path, String xsdName) {
        try {
            String[] paths = path.split("\\.");
            SAXReader saxReader = new SAXReader();
            URL resource = AbstractMx2MtCreator.class.getResource("/xsd/" + xsdName + ".xsd");
            if (resource == null) return false;
            Document document = saxReader.read(resource);
            Element element = document.getRootElement();
            String minOccurs = null;
            for (int i=0; i<paths.length; i++) {
                String p = paths[i];
                if (p.indexOf("@") > -1) {
                    p = p.substring(0, p.indexOf("@"));
                }
                if (p.indexOf("(") > -1) {
                    p = p.substring(0, p.indexOf("("));
                }
                List<Node> nodeList = element.selectNodes(".//xs:element[@name='"+p+"']");
                if (nodeList == null || nodeList.size() == 0) {
                    continue;
                }
                element = (Element) nodeList.get(0);
                minOccurs = element.attributeValue("minOccurs");
                if (minOccurs != null && Integer.parseInt(minOccurs) == 0) {
                    break;  //如果出现非必填的节点，直接终止循环
                }
                String type = element.attributeValue("type");
                nodeList = element.selectNodes("//xs:complexType[@name='"+type+"']");
                if (nodeList != null && nodeList.size() > 0) {
                    element = (Element) nodeList.get(0);
                }
            }
            if (minOccurs == null || Integer.parseInt(minOccurs) > 0) {
                return true;
            } else {
                return false;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    /**
     * 将xml所有节点全路径放在list里面
     * 除了AppHdr以外
     * @param list
     * @param element
     * @param path
     */
    public static void parseDocument(List<String> list, Element element, String path) {
        if (element != null) {
            if (element.isTextOnly()) {
                list.add(path);
                List<Attribute> attributes = element.attributes();
                if (attributes != null && attributes.size() > 0) {
                    for (Attribute attribute : attributes) {
                        list.add(path + "@" + attribute.getName());
                    }
                }
            } else {
                List<Element> elementList = element.elements();
                Map<String, List<Element>> maps = new LinkedHashMap<>();
                for (Element e : elementList) {
                    if (maps.containsKey(e.getName())) {
                        List<Element> eList = maps.get(e.getName());
                        eList.add(e);
                    } else {
                        List<Element> eList = new ArrayList<>();
                        eList.add(e);
                        maps.put(e.getName(), eList);
                    }
                }
                for (List<Element> eList : maps.values()) {
                    if (eList.size() == 1) {
                        parseDocument(list, eList.get(0), path + "." + eList.get(0).getName());
                    } else {
                        for (int i=0; i<eList.size(); i++) {
                            if (i == 0) {
                                parseDocument(list, eList.get(i), path + "." + eList.get(i).getName()); //第一条的数据不带下标
                            } else {
                                parseDocument(list, eList.get(i), path + "." + eList.get(i).getName() + "(" + i + ")");
                            }
                        }
                    }
                }
            }
        }
    }

    public abstract List<Mx2MtTagsGenerate> getGenerateTagList();

    protected abstract String getMtType();

    @Override
    public void preProcess() throws SwiftException {
        SwiftMessage swiftMessage = new SwiftMessage();
        context.set(swiftMessage);
        SwiftTranslationReport str = new SwiftTranslationReport();
        context.set(str);
    }

    @Override
    public void withBlock1() throws SwiftException {
        SwiftBlock1 block1 = new SwiftBlock1();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String appHdrParentPath = (String)context.get(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, true);
        String senderBic = (String)context.get(Mx2MtConstants.SENDERS_ADDRESS, true);
        if (StringUtil.isEmpty(senderBic)) {
            senderBic = getXmlNodeValue(appHdrParentPath, document, "AppHdr.Fr.FIId.FinInstnId.BICFI");
        }
        context.set(Mx2MtContextIdentifier.MX_SENDER_BIC, senderBic);

        String receiverBic = (String)context.get(Mx2MtConstants.RECEIVERS_ADDRESS, true);
        if (StringUtil.isEmpty(receiverBic)) {
            receiverBic = getXmlNodeValue(appHdrParentPath, document, "AppHdr.To.FIId.FinInstnId.BICFI");
        }
        context.set(Mx2MtContextIdentifier.MX_RECEIVER_BIC, receiverBic);
        String applicationMode = (String)context.get(Mx2MtConstants.APPLICATION_MODE, true);
        if ("O".equalsIgnoreCase(applicationMode)) {
            block1.setLogicalTerminal(processBicCode(receiverBic));
        } else {
            block1.setLogicalTerminal(processBicCode(senderBic));
        }
        block1.setSessionNumber(getRandomNumber(4));//mapping文档中给的是0000
        block1.setSequenceNumber(getRandomNumber(6));//mapping文档中给的是000000
        context.get(SwiftMessage.class).setBlock1(block1);
    }

    @Override
    public void withBlock2() throws SwiftException {
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String appHdrParentPath = (String)context.get(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, true);
        String senderBic = (String)context.get(Mx2MtContextIdentifier.MX_SENDER_BIC, true);
        String receiverBic = (String)context.get(Mx2MtContextIdentifier.MX_RECEIVER_BIC, true);
        String messagePriority = (String)context.get(Mx2MtConstants.MESSAGE_PRIORITY, true);
        /*if (StringUtil.isEmpty(messagePriority)) {
            String xmlMessagePriority = getXmlNodeValue(appHdrParentPath, document, "AppHdr.Prty");
            messagePriority = MessagePriority.HIGH.equals(xmlMessagePriority) ? "U" : "N";
        }*/
        Date inputDate = (Date)context.get(Mx2MtConstants.INTPUT_DATE, true);
        if (inputDate == null) {
            String createDateStr = getXmlNodeValue(appHdrParentPath, document, "AppHdr.CreDt");
            if (StringUtil.isNotEmpty(createDateStr)) {
                try {
                    XMLGregorianCalendar createDate = DatatypeFactory.newInstance().newXMLGregorianCalendar(createDateStr);
                    inputDate = DateUtil.parseDate(createDate);
                } catch (DatatypeConfigurationException e) {
                    throw new SwiftException(e.getMessage());
                }
            }
        }
        Date outputDate = (Date)context.get(Mx2MtConstants.OUTPUT_DATE, true);
        if (outputDate == null) {
            outputDate = new Date();
        }
        String applicationMode = (String)context.get(Mx2MtConstants.APPLICATION_MODE, true);
        if ("O".equalsIgnoreCase(applicationMode)) {
            SwiftBlock2Output block2 = new SwiftBlock2Output();
            block2.setMessageType(getMtType());
            block2.setSenderInputTime(DateUtil.format(inputDate, "HHmm"));
            block2.setMIRDate(DateUtil.format(inputDate, "yyMMdd"));
            block2.setMIRLogicalTerminal(processBicCode(senderBic));
            block2.setMIRSessionNumber(getRandomNumber(4));
            block2.setMIRSequenceNumber(getRandomNumber(6));
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(outputDate);
            block2.setReceiverOutputDateTime(calendar);
            //block2.setMessagePriority(messagePriority);
            context.get(SwiftMessage.class).setBlock2(block2);
        } else {
            SwiftBlock2Input block2 = new SwiftBlock2Input();
            block2.setMessageType(getMtType());
            block2.setReceiverAddress(processBicCode(receiverBic));
            //block2.setMessagePriority(messagePriority);
            if ("U".equalsIgnoreCase(messagePriority)) {
                block2.setDeliveryMonitoring("1");
            }
            context.get(SwiftMessage.class).setBlock2(block2);
        }
    }

    @Override
    public void withBlock3() throws SwiftException {
        SwiftBlock3 block3 = new SwiftBlock3();
        String block3_103 = (String)context.get(Mx2MtConstants.BLOCK3_103, true);
        if (StringUtil.isNotEmpty(block3_103)) {
            Field103 field103 = new Field103(block3_103);
            block3.builder().setField103(field103);
        }
        String block3_108 = (String)context.get(Mx2MtConstants.BLOCK3_108, true);
        if (StringUtil.isNotEmpty(block3_108)) {
            Field108 field108 = new Field108(block3_108);
            block3.builder().setField108(field108);
        }
        String block3_165 = (String)context.get(Mx2MtConstants.BLOCK3_165, true);
        if (StringUtil.isNotEmpty(block3_165)) {
            Field165 field165 = new Field165(block3_165);
            block3.builder().setField165(field165);
        }
        String block3_433 = (String)context.get(Mx2MtConstants.BLOCK3_433, true);
        if (StringUtil.isNotEmpty(block3_433)) {
            Field433 field433 = new Field433(block3_433);
            block3.builder().setField433(field433);
        }
        String block3_434 = (String)context.get(Mx2MtConstants.BLOCK3_434, true);
        if (StringUtil.isNotEmpty(block3_434)) {
            Field434 field434 = new Field434(block3_434);
            block3.builder().setField434(field434);
        }
        context.get(SwiftMessage.class).setBlock3(block3);
    }

    @Override
    public void withBlock4() throws SwiftException {
        List<Mx2MtTagsGenerate> list = getGenerateTagList();
        if (list != null) {
            List<Tag> tags = new ArrayList<>();
            SwiftBlock4 block4 = new SwiftBlock4(tags);
            context.get(SwiftMessage.class).setBlock4(block4);
            for (int i=0; i<list.size(); i++) {
                AbstractMx2MtTagsGenerate mx2MtTagsGenerate = (AbstractMx2MtTagsGenerate)list.get(i);
                mx2MtTagsGenerate.setContext(context).tagGenerate();
            }
        }
    }

    @Override
    public void withBlock5() throws SwiftException {
        SwiftBlock5 swiftBlock5 = new SwiftBlock5();
        Boolean block5_TNG = (Boolean)context.get(Mx2MtConstants.BLOCK5_TNG, true);
        if (Boolean.TRUE.equals(block5_TNG)) {
            swiftBlock5.setTag(SwiftBlock5Field.TNG, null);
        }
        Boolean block5_PDE = (Boolean)context.get(Mx2MtConstants.BLOCK5_PDE, true);
        if (!Boolean.TRUE.equals(block5_PDE)) {
            Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
            String appHdrParentPath = (String)context.get(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, true);
            String xmlPossibleDuplicate = getXmlNodeValue(appHdrParentPath, document, "AppHdr.PssblDplct");
            block5_PDE = "true".equalsIgnoreCase(xmlPossibleDuplicate)?Boolean.TRUE:Boolean.FALSE;
        }
        if (Boolean.TRUE.equals(block5_PDE)) {
            swiftBlock5.setPDE();
        }
        context.get(SwiftMessage.class).setBlock5(swiftBlock5);
    }

    @Override
    public void postProcess() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        if (tags.size() > 0) {
            for (Tag tag : tags) {
                mx_to_mtCharSet(tag);
            }
        }
        IConversionService srv = new ConversionService();
        String mtStr = srv.getFIN(swiftMessage);
        SwiftTranslationReport str = context.get(SwiftTranslationReport.class);
        MxId mxId = (MxId)context.get(Mx2MtContextIdentifier.MX_TYPE_OBJ, true);
        if (mxId != null) {
            str.setMxType(mxId.getBusinessProcess().name()
                    + mxId.getFunctionality()
                    + mxId.getVariant()
                    + mxId.getVersion());
        }
        str.setMtType(getMtType());
        str.setMessage(mtStr);
        String outputFilePath = (String)context.get(Mx2MtContextIdentifier.MX_TO_MT_OUTPUT_FILE_PATH, true);
        if (StringUtil.isNotEmpty(outputFilePath)) {
            write(swiftMessage, new File(outputFilePath));
        }
        //处理没翻译节点值的警告信息
        Mx2MtListener mx2MtListener = (Mx2MtListener)context.get(Mx2MtContextIdentifier.MX_TO_MT_LISTENER_CLASS, true);
        if (mx2MtListener != null) {
            Map<String, Boolean> maps = mx2MtListener.getMaps();
            List<String> pathList = new ArrayList<>();
            String xml = (String) context.get(Mx2MtContextIdentifier.MX_XMl, true);
            Document document = null;
            try {
                document = DocumentHelper.parseText(xml);
            } catch (DocumentException e) {
                throw new SwiftException(e.getMessage());
            }
            parseDocument(pathList, document.getRootElement(), document.getRootElement().getName());
            if (pathList.size() > 0) {
                pathList = filterMandatoryPath(pathList, xml);
                for(String path : pathList) {
                    if (!maps.containsKey(path)) {
                        String originalValue = XmlUtil.getXmlNodeValue(document, path);
                        if (StringUtil.isNotEmpty(originalValue)) {
                            if (path.indexOf("AppHdr") > -1) {
                                path = path.substring(path.indexOf("AppHdr"));
                            }
                            if (path.indexOf("Document") > -1) {
                                path = path.substring(path.indexOf("Document"));
                            }
                            path = path.replace(".", "/");
                            buildSTErrorInfo(7, path, originalValue);
                        }
                    }
                }
            }
        }
        summaryTranslationResult(str);
    }

    public void write(SwiftMessage swiftMessage, File file) throws SwiftException {
        try {
            Validate.notNull(file, "the file to write cannot be null");
            Validate.notNull(swiftMessage, "the message to write cannot be null");
            if(!file.exists()) {
                file.createNewFile();
            }
            FileWriter fw = new FileWriter(file.getAbsoluteFile());
            SwiftWriter.writeMessage(swiftMessage, fw, true);
            fw.close();
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    /**
     * 根据转换报告总结最终的转换结果
     * TRNK   出现failure
     * TRFR   引用字段出现截取
     * TRNR   非引用字段出现截取
     * TRAK   出现IGNORED.T0000M(转换过程中存在忽略的xml节点(非必填))
     * TROK   只出现warning
     * @param str
     */
    public void summaryTranslationResult(SwiftTranslationReport str) {
        List<SwiftTranslationErrorInfo> errorInfos = str.getErrorInfos();
        if (errorInfos == null || errorInfos.size() == 0) {
            str.setTranslationResult(TranslationResultCode.TROK.value());
        } else {
            boolean failureFlag = false;
            boolean truncRFlag = false;
            boolean truncNFlag = false;
            boolean ignoredFlag = false;
            for (SwiftTranslationErrorInfo errorInfo : errorInfos) {
                String category = errorInfo.getCategory();
                if ("FAILURE".equals(category)) {
                    failureFlag = true;
                }
                if ("TRUNC_R".equals(category)) {
                    truncRFlag = true;
                }
                if ("TRUNC_N".equals(category)) {
                    truncNFlag = true;
                }
                if ("IGNORED".equals(category)) {
                    ignoredFlag = true;
                }
            }
            if (failureFlag) {
                str.setTranslationResult(TranslationResultCode.TRNK.value());
            } else if (truncRFlag) {
                str.setTranslationResult(TranslationResultCode.TRFR.value());
            } else if (truncNFlag) {
                str.setTranslationResult(TranslationResultCode.TRNR.value());
            } else if (ignoredFlag) {
                str.setTranslationResult(TranslationResultCode.TRAK.value());
            } else {
                str.setTranslationResult(TranslationResultCode.TROK.value());
            }
        }
    }
}
