package com.brilliance.swift.mx2mt;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.*;
import com.brilliance.swift.vo.MxMtReasonCodeInfo;
import com.brilliance.swift.vo.SwiftTranslationErrorInfo;
import com.brilliance.swift.vo.SwiftTranslationReport;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import org.dom4j.Document;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractMx2MtTagsGenerate implements Mx2MtTagsGenerate {

    protected Mx2MtContext context;

    protected Document document = null;

    protected String appHdrParentElementName;

    protected String grpHdrParentElementName;

    protected String bodyHdrParentElementName;

    public Mx2MtContext getContext() {
        return context;
    }

    public AbstractMx2MtTagsGenerate setContext(Mx2MtContext context) {
        this.context = context;
        document = (Document) context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        appHdrParentElementName = (String) context.get(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, true);
        grpHdrParentElementName = (String) context.get(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, true);
        bodyHdrParentElementName = (String) context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        return this;
    }

    protected String getXmlNodeValue(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        String value = XmlUtil.getXmlNodeValue(document, path);
        if (StringUtil.isNotEmpty(value)) {
            Mx2MtListener mx2MtListener = (Mx2MtListener)context.get(Mx2MtContextIdentifier.MX_TO_MT_LISTENER_CLASS, true);
            if (mx2MtListener != null) {
                mx2MtListener.process(path); //如果存在监听器且得到的值不为空，则执行监听操作
            }
        }
        return value;
    }

    protected int getXmlNodeCounts(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        return XmlUtil.getChildrenCount(document, path, null);
    }

    /**
     * 封装报文转换详细报告
     * @param id
     * @param location
     * @param originalValue
     * @return
     */
    protected void buildSTErrorInfo(long id, String location, String originalValue) {
        SwiftTranslationReport str = context.get(SwiftTranslationReport.class);
        SwiftTranslationErrorInfo errorInfo = SwiftTransferUtil.getSwiftTranslationErrorInfoById(id);
        if (errorInfo == null) return;
        if (StringUtil.isEmpty(location)) {
            location = (String) context.get(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION,true);
        }
        errorInfo.setLocation(location);
        errorInfo.setOriginalValue(originalValue);
        List<SwiftTranslationErrorInfo> errorInfos = str.getErrorInfos();
        boolean existFlag = false;
        for (int i=0; i<errorInfos.size(); i++) {
            if (SwiftTransferUtil.compareStErrorInfo(errorInfo, errorInfos.get(i))) {
                existFlag = true;
                break;
            }
        }
        if (!existFlag) {
            str.addErrorInfo(errorInfo);
        }
    }
    /**
     * 如何第二行以 : 或者 - 开始，替换成 .
     * @param value
     * @param location
     * @return
     */
    protected String mx_to_mtStartingLineCharacter(String value, String location) {
        if (StringUtil.isEmpty(value)) {
            return value;
        }
        String[] values = value.split(Mx2MtConstants.NEW_LINE);
        if (values.length == 1) return value;
        String newValue = values[0];
        boolean flag = false;
        for (int i=1; i<values.length; i++) {
            if (values[i].startsWith(":") || values[i].startsWith("-")) {
                flag = true;
                newValue += Mx2MtConstants.NEW_LINE + "." + values[i].substring(1);
            } else {
                newValue += Mx2MtConstants.NEW_LINE + values[i];
            }
        }
        if (flag) {
            buildSTErrorInfo(3, location, value);
        }
        return newValue;
    }

    //转换函数方法区开始
    /**
     * MX InstructionForCreditorAgent转23域
     * 前提就是code在{HOLD,CHQB,PHOB,TELB}里面
     * @return
     */
    protected List<String> mx_to_mt23E(String code, String instructionInformation) {
        List<String> list = new ArrayList<>();
        String chqbCode = ExternalCreditorAgentInstructionCode.CHQB.value();
        String holdCode = ExternalCreditorAgentInstructionCode.HOLD.value();
        String phobCode = ExternalCreditorAgentInstructionCode.PHOB.value();
        String telbCode = ExternalCreditorAgentInstructionCode.TELB.value();
        if (!chqbCode.equals(code) && !holdCode.equals(code) && !phobCode.equals(code) && !telbCode.equals(code)) {
            return list;
        }
        if (StringUtil.isEmpty(instructionInformation)) {
            list.add(code);
        } else {
            String[] instrInfos = instructionInformation.split("(?=/"+chqbCode+"/|/"+holdCode+"/|/"+phobCode+"/|/"+telbCode+"/)");
            for (String ins : instrInfos) {
                if (ins.startsWith("/"+chqbCode+"/") || ins.startsWith("/"+holdCode+"/")
                        || ins.startsWith("/"+phobCode+"/") || ins.startsWith("/"+telbCode+"/")) {
                    String tmpCode = ins.substring(1, 5);
                    String tmpInstrInf = ins.substring(6);
                    if (StringUtil.isNotEmpty(tmpInstrInf)) {
                        if (tmpInstrInf.length() > 30) {
                            buildSTErrorInfo(12, null, tmpInstrInf);
                            tmpInstrInf = tmpInstrInf.substring(0, 29) + "+";
                        }
                        list.add(tmpCode + "/" + tmpInstrInf);
                    } else {
                        list.add(tmpCode);
                    }
                } else {
                    if (chqbCode.equals(code)) {
                        list.add(code);
                    } else {
                        list.add(code + "/" + ins);
                    }
                }
            }
        }
        return list;
    }


    /**
     * MX InstructionForCreditorAgent转23域
     * 前提就是code不存在，只有instructionInformation
     * @return
     */
    protected List<String> mx_to_mt23E_BIS(String instructionInformation) {
        List<String> list = new ArrayList<>();
        String chqbCode = ExternalCreditorAgentInstructionCode.CHQB.value();
        String holdCode = ExternalCreditorAgentInstructionCode.HOLD.value();
        String phobCode = ExternalCreditorAgentInstructionCode.PHOB.value();
        String telbCode = ExternalCreditorAgentInstructionCode.TELB.value();
        String[] instrInfos = instructionInformation.split("(?=/"+chqbCode+"/|/"+holdCode+"/|/"+phobCode+"/|/"+telbCode+"/)");
        for (String ins : instrInfos) {
            if (ins.startsWith("/"+chqbCode+"/") || ins.startsWith("/"+holdCode+"/")
                    || ins.startsWith("/"+phobCode+"/") || ins.startsWith("/"+telbCode+"/")) {
                String tmpCode = ins.substring(1, 5);
                String tmpInstrInf = ins.substring(6);
                if (StringUtil.isNotEmpty(tmpInstrInf)) {
                    if (tmpInstrInf.length() > 30) {
                        buildSTErrorInfo(12, null, tmpInstrInf);
                        tmpInstrInf = tmpInstrInf.substring(0, 29) + "+";
                    }
                    list.add(tmpCode + "/" + tmpInstrInf);
                } else {
                    list.add(tmpCode);
                }
            }
        }
        return list;
    }
    /**
     * 返回代理行下面的bicCode
     * @param agtPath
     * @return
     */
    protected String mx_to_mtBICFI(String agtPath) {
        String bicCode = getXmlNodeValue(null, document, agtPath + ".FinInstnId.BICFI");
        return bicCode;
    }
    /**
     * 返回账号行下面的bicCode
     * @param partyPath
     * @return
     */
    protected String mx_to_mtAnyBIC(String partyPath) {
        String bicCode = getXmlNodeValue(null, document, partyPath + ".Id.OrgId.AnyBIC");
        return bicCode;
    }
    /**
     *
     * @param settlementMethod
     * @param accountPath
     * @return
     */
    protected String mx_to_mtSettlementAccount(String settlementMethod, String accountPath) {
        String mtAccount = mx_to_mtAccount(accountPath);
        if (StringUtil.isNotEmpty(mtAccount) && SettlementMethodCode.INGA.value().equals(settlementMethod)) {
            mtAccount = "/C" + mtAccount;
        }
        return mtAccount;
    }
    /**
     * 如果CashAccount38.Id.iban有值，account = "/" + CashAccount38.Id.iban
     *    否则 如果CashAccount38.Id.Othr.Id有值，
     *                      如果CashAccount38.Id.Othr.SchmeNm.Cd = CUID 并且 CashAccount38.Id.Othr.Id长度等于6
     *                account = "//CH" + CashAccount38.Id.Othr.Id
     *            否则 account = "/" + CashAccount38.Id.Othr.Id
     * @param accountPath
     * @return
     */
    protected String mx_to_mtAccount(String accountPath) {
        String mtAccount = "";
        String ibanAcct = getXmlNodeValue(null, document, accountPath + ".Id.IBAN");
        if (StringUtil.isNotEmpty(ibanAcct)) {
            mtAccount = "/" +  ibanAcct;
        } else {
            String account = getXmlNodeValue(null, document, accountPath + ".Id.Othr.Id");
            if (StringUtil.isNotEmpty(account)) {
                String schemeNameType = getXmlNodeValue(null, document, accountPath + ".Id.Othr.SchmeNm.Cd");
                if (AcctSehemeTypeCode.CUID.value().equals(schemeNameType) && account.length() == 6) {
                    mtAccount = "//CH" + account;
                } else {
                    mtAccount = "/" + account;
                }
            }
        }
        return mtAccount;
    }

    /**
     * 清算代码逻辑取值，MX_To_MTClearingIdentifier(ClearingSystemMemberIdentification2，BIC)
     * MTClearingSystem取值
     * 1.如果ClearingSystemMemberIdentification2.ClrSysId.Cd能mapping到MT的clearingSystemCode，则取MTClearingSystemCode，否则MTClearingSystemCode直接取ClearingSystemMemberIdentification2.ClrSysId.Cd
     * MTClearingSystem = //+MTClearingSystemCode + ClearingSystemMemberIdentification2.MmbId
     * （MTClearingSytemCode和MXClearingSystemCode Mapping规则参考word文档Annex章节）
     * 2.如果BIC存在，MTClearingSystem包含FW，最终取值为//FW
     *   如果BIC存在，MTClearingSystem包含CP或者RU或者SW，最终取值为空
     * 3.如果BIC不存在，最终取值就是MTClearingSystem
     * @return
     */
    protected String mx_to_mtClearingIdentifier(String agtPath) {
        String mxClearingSystemCode = getXmlNodeValue(null, document, agtPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isEmpty(mxClearingSystemCode)) {
            return null;
        }
        String mtClearingSystem = "";
        String mxClearingSystemId = getXmlNodeValue(null, document, agtPath + ".FinInstnId.ClrSysMmbId.MmbId");
        ClearingSystemMemberCode clearingSystemMemberCode = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystemCode);
        if (clearingSystemMemberCode != null) {
            mtClearingSystem = "//" + clearingSystemMemberCode.desc() + mxClearingSystemId;
        } else {
            mtClearingSystem = "//" + mxClearingSystemCode + mxClearingSystemId;
        }
        String bicCode = mx_to_mtBICFI(agtPath);
        if (StringUtil.isNotEmpty(bicCode)) {
            if (mtClearingSystem.indexOf("FW") > -1) {
                mtClearingSystem = "";
                buildSTErrorInfo(18, null, null);
            } else if (mtClearingSystem.indexOf("CP") > -1
                    || mtClearingSystem.indexOf("RU") > -1
                    || mtClearingSystem.indexOf("SW") > -1) {
                mtClearingSystem = "";
                buildSTErrorInfo(19, null, null);
            }
        }
        return mtClearingSystem;
    }

    /**
     * MX_To_MTClearingIdentifierAndChannel（BranchAndFinancialInstitutionIdentification6 agt）
     * 前提是CdtTrfTxInf.PmtTpInf.ClrChanl = RTGS
     *
     * 1.如果agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd能mapping到MT的clearingSystemCode，则取MTClearingSystemCode，否则MTClearingSystemCode直接取agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd
     * MTClearingSystem = //+MTClearingSystemCode + agt.FinInstnId.ClrSysMmbId.MmbId
     * （MTClearingSytemCode和MXClearingSystemCode Mapping规则参考word文档Annex章节）
     * 2如果agt.FinInstnId.BICFI存在，
     *    如果BIC的5-6位等于US，MTAccount=//FW，如果agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd存在，报T20075警告
     *    否则MTAccount=//RT，如果agt.FinInstnId.ClrSysMmbId.ClrSysId.Cd存在，报T20077警告
     *  如果agt.FinInstnId.BICFI不存在，
     *    MTClearingSystem第3-4包含FW，MTAccount=MTClearingSystem
     *    否则如果MTClearingSystem长度小于32，MTAccount=//RT+MTClearingSystem，否则MTAccount=MTClearingSystem
     * @param agtPath
     * @return
     */
    protected String mx_to_mtClearingIdentifierAndChannel(String agtPath, String clearingChannelPath) {
        String clearingChannelCode = getXmlNodeValue(null, document, clearingChannelPath);
        if (!ClearingChannelCode.RTGS.value().equals(clearingChannelCode)) {
            return null;
        }
        String mtClearingSystem = "";
        String mxClearingSystemCode = getXmlNodeValue(null, document, agtPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isNotEmpty(mxClearingSystemCode)) {
            String mxClearingSystemId = getXmlNodeValue(null, document, agtPath + ".FinInstnId.ClrSysMmbId.MmbId");
            ClearingSystemMemberCode clearingSystemMemberCode = SwiftTransferUtil.getClsSysMemberByValue(mxClearingSystemCode);
            if (clearingSystemMemberCode != null) {
                mtClearingSystem = "//" + clearingSystemMemberCode.desc() + mxClearingSystemId;
            } else {
                mtClearingSystem = "//" + mxClearingSystemCode + mxClearingSystemId;
            }
        }
        String mtAccount = "";
        String bicCode = mx_to_mtBICFI(agtPath);
        if (StringUtil.isNotEmpty(bicCode)) {
            if ("US".equals(bicCode.substring(4, 6))) {
                mtAccount = "//FW";
                if (StringUtil.isNotEmpty(mxClearingSystemCode)) {
                    buildSTErrorInfo(18, null, null);
                }
            } else {
                mtAccount = "//RT";
                if (StringUtil.isNotEmpty(mxClearingSystemCode)) {
                    buildSTErrorInfo(20, null, null);
                }
            }
        } else {
            if (mtClearingSystem.indexOf("FW") > -1) {
                mtAccount = mtClearingSystem;
            } else if (mtClearingSystem.length() < 32) {
                mtAccount = "//RT" + mtClearingSystem;
            } else {
                mtAccount = mtClearingSystem;
            }
        }
        return mtAccount;
    }

    /**
     * 无结构性地址的取值规则：MX_To_MTFinancialInstitutionNameAndUnstructuredAddress(AgentObj)
     * addressCount =AgentObj.FinInstnId.PostalAddress.AddressLine
     * 1.先组装Name
     *   Name = AgentObj.FinInstnId.Nm
     *   如果Name.length<1,Name = "NOTPROVIDED"
     *   如果addrescount >= 3，并且Name长度大于35，Name只截取到34位，最后一位用+表示
     *   否则 如果Name长度大于70，Name只截取到69位，最后一位用+表示（表示name Address中name最多占2行）
     * 2.再组装address
     *   address = AgentObj.FinInstnId.PostalAddress.AddressLine(i),如果长度超过35位就截取到35位
     * 3.最后name address 组成 4 *35 格式
     * @param nameAddressPrefixPath  名字和地址的前缀路径
     * @return
     */
    protected String mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(String nameAddressPrefixPath) {
        String mxName = getXmlNodeValue(null, document, nameAddressPrefixPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) {
            mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        int addressLineCount = XmlUtil.getChildrenCount(document, nameAddressPrefixPath + ".PstlAdr.AdrLine", null);
        String addressLine1 = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.AdrLine");
        if (Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
            addressLineCount = 0;
        }
        if (addressLineCount >= 3) {
            if (mxName.length() > 35) {
                buildSTErrorInfo(12, null, mxName);
                mxName = mxName.substring(0, 34) + "+";
            }
        } else {
            if (mxName.length() > 70) {
                buildSTErrorInfo(12, null, mxName);
                mxName = mxName.substring(0, 69) + "+";
            }
        }
        int addressRemainLine = 3;//address剩余的行数
        if (mxName.length() > 35) addressRemainLine = 2;
        String mtNameAddress = StringUtil.getStringByEnter(mxName, 35, 4-addressRemainLine);
        if (addressLineCount > 0) {
            for (int i=0; i<addressLineCount; i++) {
                if (i == addressRemainLine) break;
                String mxAddress = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.AdrLine("+i+")");
                if (mxAddress.length() > 35) {
                    buildSTErrorInfo(12, null, mxAddress);
                    mxAddress = mxAddress.substring(0, 34) + "+";
                }
                mtNameAddress += Mx2MtConstants.NEW_LINE + mxAddress;
            }
        }
        return mtNameAddress;
    }

    /**
     * 有结构性地址的取值规则
     * MX_To_MTFinancialInstitutionNameAndStructuredAddress(AgentObj)
     * 前提是AgentObj.FinInstnId.PostalAddress.Ctry有值
     * 1.先组装Name
     *   Name = AgentObj.FinInstnId.Nm
     *   如果Name.length<1,Name = "NOTPROVIDED"
     *   如果Name长度大于70，Name只截取到69位，最后一位用+表示（表示name Address中name最多占2行）
     * 2.再组装address
     *   MXTable2[1] = StreetName（AgentObj.FinInstnId.PstlAdr.StrtNm）
     *   MXTable2[2] = BuildingNumber（AgentObj.FinInstnId.PstlAdr.BldgNb）
     *   MXTable2[3] = BuildingName（AgentObj.FinInstnId.PstlAdr.BldgNm）
     *   MXTable2[4] = Floor（AgentObj.FinInstnId.PstlAdr.Flr）
     *   MXTable2[5] = PostBox（AgentObj.FinInstnId.PstlAdr.PstBx）
     *   MXTable2[6] = Room（AgentObj.FinInstnId.PstlAdr.Room）
     *   MXTable2[7] = Department（AgentObj.FinInstnId.PstlAdr.Dept）
     *   MXTable2[8] = SubDepartment（AgentObj.FinInstnId.PstlAdr.SubDept）
     *   MxAddress2 = MXTable2[1] + "," + MXTable2[2] + "," + ... MXTable2[8]
     *
     *   MXTable3[1] = Country（AgentObj.FinInstnId.PstlAdr.Ctry）
     *   MXTable3[2] = TownName（AgentObj.FinInstnId.PstlAdr.TwnNm）
     *   MXTable3[3] = PostCode（AgentObj.FinInstnId.PstlAdr.PstCd）
     *   MXTable3[4] = CountrySubdivision（AgentObj.FinInstnId.PstlAdr.CtrySubDvsn）
     *   MXTable3[5] = TownNameLocation（AgentObj.FinInstnId.PstlAdr.TwnLctnNm）
     *   MXTable3[6] = DistrictName（AgentObj.FinInstnId.PstlAdr.DstrctNm）
     *   MxAddress3 = MXTable3[1] + "/" + MXTable3[2] + "," + MXTable3[3] + ... + MXTable3[6]
     * 3.NameAddress取值规则 4*35
     *   ①如果Name只占一行，
     *      如果MxAddress2存在，MxAddress3最多占2行，MxAddress2最多占2行；如果MxAddress2不存在，直接取MxAddress3
     *   ②如果Name占2行，
     *      如果MxAddress2存在，MxAddress3和MxAddress2最多占1行；如果MxAddress2不存在，直接取MxAddress3
     *   最后按照规则拼接成4*35
     */
    protected String mx_to_mtFinancialInstitutionNameAndStructuredAddress(String nameAddressPrefixPath) {
        String mtNameAddress = "";
        String mxName = getXmlNodeValue(null, document, nameAddressPrefixPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) {
            mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        int addressRemainLine = 0;//address剩余的行数
        if (mxName.length() > 70) {
            buildSTErrorInfo(12, null, mxName);
            mtNameAddress = mxName.substring(0, 35)
                    + Mx2MtConstants.NEW_LINE
                    + mxName.substring(35, 69) + "+";
            addressRemainLine = 2;
        } else if (mxName.length() > 35) {
            mtNameAddress = mxName.substring(0, 35)
                    + Mx2MtConstants.NEW_LINE
                    + mxName.substring(35);
            addressRemainLine = 2;
        } else {
            mtNameAddress = mxName;
            addressRemainLine = 3;
        }
        //组装address
        String country = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Ctry");
        if (StringUtil.isNotEmpty(country)) {
            String mxAddress2 = "";
            String mxAddress2StrtNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.StrtNm");
            if (StringUtil.isNotEmpty(mxAddress2StrtNm)) {
                mxAddress2 += mxAddress2StrtNm + ",";
            }
            String mxAddress2BldgNb = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.BldgNb");
            if (StringUtil.isNotEmpty(mxAddress2BldgNb)) {
                mxAddress2 += mxAddress2BldgNb + ",";
            }
            String mxAddress2BldgNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.BldgNm");
            if (StringUtil.isNotEmpty(mxAddress2BldgNm)) {
                mxAddress2 += mxAddress2BldgNm + ",";
            }
            String mxAddress2Flr = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Flr");
            if (StringUtil.isNotEmpty(mxAddress2Flr)) {
                mxAddress2 += mxAddress2Flr + ",";
            }
            String mxAddress2PstBx = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.PstBx");
            if (StringUtil.isNotEmpty(mxAddress2PstBx)) {
                mxAddress2 += mxAddress2PstBx + ",";
            }
            String mxAddress2Room = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Room");
            if (StringUtil.isNotEmpty(mxAddress2Room)) {
                mxAddress2 += mxAddress2Room + ",";
            }
            String mxAddress2Dept = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Dept");
            if (StringUtil.isNotEmpty(mxAddress2Dept)) {
                mxAddress2 += mxAddress2Dept + ",";
            }
            String mxAddress2SubDept = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.SubDept");
            if (StringUtil.isNotEmpty(mxAddress2SubDept)) {
                mxAddress2 += mxAddress2SubDept + ",";
            }
            if (mxAddress2.length() > 0) mxAddress2 = mxAddress2.substring(0, mxAddress2.length()-1);

            String mxAddress3 = country;
            String mxAddress3TwnNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.TwnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnNm)) {
                mxAddress3 += "/" + mxAddress3TwnNm;
            }
            String mxAddress3PstCd = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.PstCd");
            if (StringUtil.isNotEmpty(mxAddress3PstCd)) {
                mxAddress3 += "," + mxAddress3PstCd;
            }
            String mxAddress3CtrySubDvsn = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.CtrySubDvsn");
            if (StringUtil.isNotEmpty(mxAddress3CtrySubDvsn)) {
                mxAddress3 += "," + mxAddress3CtrySubDvsn;
            }
            String mxAddress3TwnLctnNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.TwnLctnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnLctnNm)) {
                mxAddress3 += "," + mxAddress3TwnLctnNm;
            }
            String mxAddress3DstrctNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.DstrctNm");
            if (StringUtil.isNotEmpty(mxAddress3DstrctNm)) {
                mxAddress3 += "," + mxAddress3DstrctNm;
            }
            //根据剩余行数来拼接mxAddress2和mxAddress3
            String mtAddress2 = "";
            String mtAddress3 = "";
            if (addressRemainLine == 3) { //表示name只占1行
                if (mxAddress2.length() > 0) { //mxAddress2存在，优先计算mxAddress3长度
                    if (mxAddress3.length() > 70) { //mxAddress3最多占2行 mxaddress2最多占1行
                        buildSTErrorInfo(12, null, mxAddress3);
                        mtAddress3 = mxAddress3.substring(0, 35)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(35, 69) + "+";
                        if (mxAddress2.length() > 35) {
                            buildSTErrorInfo(12, null, mtAddress2);
                            mtAddress2 = mxAddress2.substring(0, 34) + "+";
                        }
                    } else if (mxAddress3.length() > 35) { //mxAddress3占2行 mxaddress2最多占1行
                        mtAddress3 = mxAddress3.substring(0, 35)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(35);
                        if (mxAddress2.length() > 35) {
                            buildSTErrorInfo(12, null, mtAddress2);
                            mtAddress2 = mxAddress2.substring(0, 34) + "+";
                        }
                    } else {//mxAddress3占1行 mxaddress2最多占2行
                        mtAddress3 =  mxAddress3;
                        if (mxAddress2.length() > 70) {
                            buildSTErrorInfo(12, null, mxAddress2);
                            mtAddress2 = mxAddress2.substring(0, 35)
                                    + Mx2MtConstants.NEW_LINE
                                    + mxAddress2.substring(35, 69) + "+";
                        } else if (mxAddress2.length() > 35) {
                            mtAddress2 = mxAddress2.substring(0, 35)
                                    + Mx2MtConstants.NEW_LINE
                                    + mxAddress2.substring(35);
                        } else {
                            mtAddress2 = mxAddress2;
                        }
                    }
                } else { //mxAddress2不存在，只读取mxAddress3
                    if (mxAddress3.length() > 105) {
                        buildSTErrorInfo(12, null, mxAddress3);
                        mtAddress3 = mxAddress3.substring(0, 35)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(35, 70)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(70, 104) + "+";
                    } else if (mxAddress3.length() > 70) {
                        mtAddress3 = mxAddress3.substring(0, 35)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(35, 70)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(70);
                    } else if (mxAddress3.length() > 35) {
                        mtAddress3 = mxAddress3.substring(0, 35)
                                + Mx2MtConstants.NEW_LINE
                                +  mxAddress3.substring(35);
                    } else {
                        mtAddress3 = mxAddress3;
                    }
                }
            } else {  //表示name占了2行
                if (mxAddress2.length() > 0) { //mxAddress2存在，mxaddress2和mxaddress3算一行
                    if (mxAddress2.length() > 35) {
                        buildSTErrorInfo(12, null, mxAddress2);
                        mtAddress2 = mxAddress2.substring(0, 34) + "+";
                    } else {
                        mtAddress2 = mxAddress2;
                    }
                    if (mxAddress3.length() > 35) {
                        buildSTErrorInfo(12, null, mxAddress3);
                        mtAddress3 = mxAddress3.substring(0, 34) + "+";
                    } else {
                        mtAddress3 = mxAddress3;
                    }
                } else { //mxAddress2不存在，只读取mxAddress3
                    if (mxAddress3.length() > 70) {
                        mtAddress3 = mxAddress3.substring(0, 35)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(35, 70)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(70);
                    } else if (mxAddress3.length() > 33) {
                        mtAddress3 = mxAddress3.substring(0, 35)
                                + Mx2MtConstants.NEW_LINE
                                + mxAddress3.substring(35);
                    } else {
                        mtAddress3 = mxAddress3;
                    }
                }
            }
            if (mtAddress2.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress2;
            }
            if (mtAddress3.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress3;
            }
        }
        return mtNameAddress;
    }

    protected String mx_to_mtPartyNameAndStructuredAddress(String nameAddressPrefixPath) {
        String mtNameAddress = "";
        String mxName = getXmlNodeValue(null, document, nameAddressPrefixPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) {
            mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            buildSTErrorInfo(34, null, null);
        }
        int addressRemainLine = 0;//address剩余的行数
        String mxLei = getXmlNodeValue(null, document, nameAddressPrefixPath + ".LEI");
        if (StringUtil.isNotEmpty(mxLei)) {
            if (mxName.length() > 33) mxName = "1/" + mxName.substring(0, 32) + "+";
            mtNameAddress = mxName;
            addressRemainLine = 2;
        } else {
            if (mxName.length() > 66) {
                buildSTErrorInfo(12, null, mxName);
                mtNameAddress = "1/" + mxName.substring(0, 33)
                        + Mx2MtConstants.NEW_LINE
                        + "1/" + mxName.substring(33, 65) + "+";
                addressRemainLine = 2;
            } else if (mxName.length() > 33) {
                mtNameAddress = "1/" + mxName.substring(0, 33)
                        + Mx2MtConstants.NEW_LINE
                        + "1/" + mxName.substring(33);
                addressRemainLine = 2;
            } else {
                mtNameAddress = "1/" + mxName;
                addressRemainLine = 3;
            }
        }
        //组装address
        String country = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Ctry");
        if (StringUtil.isNotEmpty(country)) {
            String mxAddress2 = "";
            String mxAddress2StrtNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.StrtNm");
            if (StringUtil.isNotEmpty(mxAddress2StrtNm)) {
                mxAddress2 += mxAddress2StrtNm + ",";
            }
            String mxAddress2BldgNb = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.BldgNb");
            if (StringUtil.isNotEmpty(mxAddress2BldgNb)) {
                mxAddress2 += mxAddress2BldgNb + ",";
            }
            String mxAddress2BldgNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.BldgNm");
            if (StringUtil.isNotEmpty(mxAddress2BldgNm)) {
                mxAddress2 += mxAddress2BldgNm + ",";
            }
            String mxAddress2Flr = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Flr");
            if (StringUtil.isNotEmpty(mxAddress2Flr)) {
                mxAddress2 += mxAddress2Flr + ",";
            }
            String mxAddress2PstBx = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.PstBx");
            if (StringUtil.isNotEmpty(mxAddress2PstBx)) {
                mxAddress2 += mxAddress2PstBx + ",";
            }
            String mxAddress2Room = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Room");
            if (StringUtil.isNotEmpty(mxAddress2Room)) {
                mxAddress2 += mxAddress2Room + ",";
            }
            String mxAddress2Dept = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Dept");
            if (StringUtil.isNotEmpty(mxAddress2Dept)) {
                mxAddress2 += mxAddress2Dept + ",";
            }
            String mxAddress2SubDept = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.SubDept");
            if (StringUtil.isNotEmpty(mxAddress2SubDept)) {
                mxAddress2 += mxAddress2SubDept + ",";
            }
            if (mxAddress2.length() > 0) mxAddress2 = mxAddress2.substring(0, mxAddress2.length()-1);

            String mxAddress3 = country;
            String mxAddress3TwnNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.TwnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnNm)) {
                mxAddress3 += "/" + mxAddress3TwnNm;
            }
            String mxAddress3PstCd = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.PstCd");
            if (StringUtil.isNotEmpty(mxAddress3PstCd)) {
                mxAddress3 += "," + mxAddress3PstCd;
            }
            String mxAddress3CtrySubDvsn = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.CtrySubDvsn");
            if (StringUtil.isNotEmpty(mxAddress3CtrySubDvsn)) {
                mxAddress3 += "," + mxAddress3CtrySubDvsn;
            }
            String mxAddress3TwnLctnNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.TwnLctnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnLctnNm)) {
                mxAddress3 += "," + mxAddress3TwnLctnNm;
            }
            String mxAddress3DstrctNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.DstrctNm");
            if (StringUtil.isNotEmpty(mxAddress3DstrctNm)) {
                mxAddress3 += "," + mxAddress3DstrctNm;
            }
            //根据剩余行数来拼接mxAddress2和mxAddress3
            String mtAddress2 = "";
            String mtAddress3 = "";
            if (addressRemainLine == 3) { //表示name只占1行
                if (mxAddress2.length() > 0) { //mxAddress2存在，优先计算mxAddress3长度
                    if (mxAddress3.length() > 66) { //mxAddress3最多占2行 mxaddress2最多占1行
                        buildSTErrorInfo(12, null, mxAddress3);
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33, 65) + "+";
                        if (mxAddress2.length() > 33) {
                            buildSTErrorInfo(12, null, mtAddress2);
                            mtAddress2 = "2/" + mxAddress2.substring(0, 32) + "+";
                        }
                    } else if (mxAddress3.length() > 33) { //mxAddress3占2行 mxaddress2最多占1行
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33);
                        if (mxAddress2.length() > 33) {
                            buildSTErrorInfo(12, null, mtAddress2);
                            mtAddress2 = "2/" + mxAddress2.substring(0, 32) + "+";
                        }
                    } else {//mxAddress3占1行 mxaddress2最多占2行
                        mtAddress3 = "3/" + mxAddress3;
                        if (mxAddress2.length() > 66) {
                            buildSTErrorInfo(12, null, mxAddress2);
                            mtAddress2 = "2/" + mxAddress2.substring(0, 33)
                                    + Mx2MtConstants.NEW_LINE
                                    + "2/" + mxAddress2.substring(33, 65) + "+";
                        } else if (mxAddress2.length() > 33) {
                            mtAddress2 = "2/" + mxAddress2.substring(0, 33)
                                    + Mx2MtConstants.NEW_LINE
                                    + "2/" + mxAddress2.substring(33);
                        } else {
                            mtAddress2 = "2/" + mxAddress2;
                        }
                    }
                } else { //mxAddress2不存在，只读取mxAddress3
                    if (mxAddress3.length() > 99) {
                        buildSTErrorInfo(12, null, mxAddress3);
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33, 66)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(66, 98) + "+";
                    } else if (mxAddress3.length() > 66) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33, 66)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(66);
                    } else if (mxAddress3.length() > 33) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33);
                    } else {
                        mtAddress3 = "3/" + mxAddress3;
                    }
                }
            } else {  //表示name占了2行
                if (mxAddress2.length() > 0) { //mxAddress2存在，mxaddress2和mxaddress3算一行
                    if (mxAddress2.length() > 33) {
                        buildSTErrorInfo(12, null, mxAddress2);
                        mtAddress2 = "2/" + mxAddress2.substring(0, 32) + "+";
                    } else {
                        mtAddress2 = "2/" + mxAddress2;
                    }
                    if (mxAddress3.length() > 33) {
                        buildSTErrorInfo(12, null, mxAddress3);
                        mtAddress3 = "3/" + mxAddress3.substring(0, 32) + "+";
                    } else {
                        mtAddress3 = "3/" + mxAddress3;
                    }
                } else { //mxAddress2不存在，只读取mxAddress3
                    if (mxAddress3.length() > 66) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33, 66)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(66);
                    } else if (mxAddress3.length() > 33) {
                        mtAddress3 = "3/" + mxAddress3.substring(0, 33)
                                + Mx2MtConstants.NEW_LINE
                                + "3/" + mxAddress3.substring(33);
                    } else {
                        mtAddress3 = "3/" + mxAddress3;
                    }
                }
            }
            if (mtAddress2.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress2;
            }
            if (mtAddress3.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress3;
            }
        }
        return mtNameAddress;
    }

    protected String mx_to_mtPartyNameAndStructuredAddress1(String nameAddressPrefixPath) {
        String mtNameAddress = "";
        String mxName = getXmlNodeValue(null, document, nameAddressPrefixPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) {
            mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            buildSTErrorInfo(34, null, null);
        }
        //组装address
        String country = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Ctry");
        if (StringUtil.isNotEmpty(country)) {
            String mxAddress2 = "";
            String mxAddress2StrtNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.StrtNm");
            if (StringUtil.isNotEmpty(mxAddress2StrtNm)) {
                mxAddress2 += mxAddress2StrtNm + ",";
            }
            String mxAddress2BldgNb = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.BldgNb");
            if (StringUtil.isNotEmpty(mxAddress2BldgNb)) {
                mxAddress2 += mxAddress2BldgNb + ",";
            }
            String mxAddress2BldgNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.BldgNm");
            if (StringUtil.isNotEmpty(mxAddress2BldgNm)) {
                mxAddress2 += mxAddress2BldgNm + ",";
            }
            String mxAddress2Flr = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Flr");
            if (StringUtil.isNotEmpty(mxAddress2Flr)) {
                mxAddress2 += mxAddress2Flr + ",";
            }
            String mxAddress2PstBx = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.PstBx");
            if (StringUtil.isNotEmpty(mxAddress2PstBx)) {
                mxAddress2 += mxAddress2PstBx + ",";
            }
            String mxAddress2Room = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Room");
            if (StringUtil.isNotEmpty(mxAddress2Room)) {
                mxAddress2 += mxAddress2Room + ",";
            }
            String mxAddress2Dept = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.Dept");
            if (StringUtil.isNotEmpty(mxAddress2Dept)) {
                mxAddress2 += mxAddress2Dept + ",";
            }
            String mxAddress2SubDept = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.SubDept");
            if (StringUtil.isNotEmpty(mxAddress2SubDept)) {
                mxAddress2 += mxAddress2SubDept + ",";
            }
            if (mxAddress2.length() > 0) mxAddress2 = mxAddress2.substring(0, mxAddress2.length()-1);

            String mxAddress3 = country;
            String mxAddress3TwnNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.TwnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnNm)) {
                mxAddress3 += "/" + mxAddress3TwnNm;
            }
            String mxAddress3PstCd = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.PstCd");
            if (StringUtil.isNotEmpty(mxAddress3PstCd)) {
                mxAddress3 += "," + mxAddress3PstCd;
            }
            String mxAddress3CtrySubDvsn = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.CtrySubDvsn");
            if (StringUtil.isNotEmpty(mxAddress3CtrySubDvsn)) {
                mxAddress3 += "," + mxAddress3CtrySubDvsn;
            }
            String mxAddress3TwnLctnNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.TwnLctnNm");
            if (StringUtil.isNotEmpty(mxAddress3TwnLctnNm)) {
                mxAddress3 += "," + mxAddress3TwnLctnNm;
            }
            String mxAddress3DstrctNm = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.DstrctNm");
            if (StringUtil.isNotEmpty(mxAddress3DstrctNm)) {
                mxAddress3 += "," + mxAddress3DstrctNm;
            }
            boolean mxNumber2Present = false;
            String mtName = "";
            String mtAddress2 = "";
            String mtAddress3 = "";
            if (mxAddress2.length() > 0) {
                mxNumber2Present = true;
            }
            if (mxNumber2Present) {
                if (mxName.length() > 33) {
                    buildSTErrorInfo(12, null, mxName);
                    mtName += "1/" + mxName.substring(0, 32) + "+";
                } else {
                    mtName += "1/" + mxName;
                }
                if (mxAddress2.length() > 33) {
                    buildSTErrorInfo(12, null, mxAddress2);
                    mtAddress2 += "2/" + mxAddress2.substring(0, 32) + "+";
                } else {
                    mtAddress2 += "2/" + mxAddress2;
                }
                if (mxAddress3.length() > 33) {
                    buildSTErrorInfo(12, null, mxAddress3);
                    mtAddress3 += "3/" + mxAddress3.substring(0, 32) + "+";
                } else {
                    mtAddress3 += "3/" + mxAddress3;
                }
            } else {
                if (mxName.length() > 66) {
                    buildSTErrorInfo(12, null, mxName);
                    mtName += "1/" + mxName.substring(0, 33)
                              + Mx2MtConstants.NEW_LINE
                              + "1/" + mxName.substring(33, 65) + "+";
                } else if (mxName.length() > 33) {
                    mtName += "1/" + mxName.substring(0, 33)
                             + Mx2MtConstants.NEW_LINE
                             + "1/" + mxName.substring(33);
                } else {
                    mtName += "1/" + mxName;
                }
                if (mxAddress3.length() > 33) {
                    buildSTErrorInfo(12, null, mxAddress3);
                    mtAddress3 += "3/" + mxAddress3.substring(0, 32) + "+";
                } else {
                    mtAddress3 += "3/" + mxAddress3;
                }
            }
            mtNameAddress = mtName;
            if (mtAddress2.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress2;
            }
            if (mtAddress3.length() > 0) {
                mtNameAddress += Mx2MtConstants.NEW_LINE + mtAddress3;
            }
        }
        return mtNameAddress;
    }

    protected String mx_to_mtPartyNameAndUnstructuredAddress(String nameAddressPrefixPath) {
        String mxName = getXmlNodeValue(null, document, nameAddressPrefixPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) {
            mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            buildSTErrorInfo(34, null, null);
        }
        int addressLineCount = XmlUtil.getChildrenCount(document, nameAddressPrefixPath + ".PstlAdr.AdrLine", null);
        String addressLine1 = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.AdrLine");
        if (Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
            addressLineCount = 0;
        }
        if (addressLineCount >= 3) {
            if (mxName.length() > 35) {
                buildSTErrorInfo(12, null, mxName);
                mxName = mxName.substring(0, 34) + "+";
            }
        } else {
            if (mxName.length() > 70) {
                buildSTErrorInfo(12, null, mxName);
                mxName = mxName.substring(0, 69) + "+";
            }
        }
        int addressRemainLine = 3;//address剩余的行数
        if (mxName.length() > 35) addressRemainLine = 2;
        String mtNameAddress = StringUtil.getStringByEnter(mxName, 35, 4-addressRemainLine);
        if (addressLineCount > 0) {
            for (int i=0; i<addressLineCount; i++) {
                if (i == addressRemainLine) break;
                String mxAddress = getXmlNodeValue(null, document, nameAddressPrefixPath + ".PstlAdr.AdrLine("+i+")");
                if (mxAddress.length() > 35) {
                    buildSTErrorInfo(12, null, mxAddress);
                    mxAddress = mxAddress.substring(0, 34) + "+";
                }
                mtNameAddress += Mx2MtConstants.NEW_LINE + mxAddress;
            }
        }
        return mtNameAddress;
    }
    /**
     *
     * @param path
     * @return
     */
    protected String mx_to_mt53A(String path) {
        String bicCode53 = "";
        int pathCount = XmlUtil.getChildrenCount(document, path, null);
        if (pathCount > 0) {
            String mtInstruction = getXmlNodeValue(null, document, path + "(0).InstrInf");
            for (int i=0; i<pathCount; i++) {
                if (i == 0) continue;
                String instrInf = getXmlNodeValue(null, document, path + "("+i+").InstrInf");
                if (StringUtil.isNotEmpty(instrInf)) {
                    if (instrInf.length() < 35 && !instrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                        mtInstruction += "/TEMPREC/" + instrInf;
                    } else {
                        mtInstruction += instrInf;
                    }
                }
            }
            if (!mtInstruction.matches("/[A-Z0-9]{1,8}/.*")) {
                mtInstruction = "/TEMPREC/" + mtInstruction;
            }
            //提取 /GenericMax8c/
            String mtType = context.get(SwiftMessage.class).getBlock2().getMessageType();
            String[] mxInstrInfs = StringUtil.splitAndKeepSeparator(mtInstruction, "/[A-Z0-9]{1,8}/");
            for (int i=0; i<mxInstrInfs.length; i++) {
                String mxIns = mxInstrInfs[i];
                if (mxIns.startsWith("/FIN53/")) {
                    String bicCode = mxIns.substring(7);
                    if (Mx2MtConstants.MT_TYPE_103.equals(mtType)) {
                        String acccount = mx_to_mtAccount(grpHdrParentElementName + ".GrpHdr.SttlmInf.SttlmAcct");
                        if (StringUtil.isEmpty(acccount)) {
                            String senderBic = (String)context.get(Mx2MtContextIdentifier.MX_SENDER_BIC, true);
                            String receiverBic = (String)context.get(Mx2MtContextIdentifier.MX_RECEIVER_BIC, true);
                            if ((StringUtil.isNotEmpty(senderBic) && senderBic.substring(0, 6).equals(bicCode.substring(0, 6)))
                                    || (StringUtil.isNotEmpty(receiverBic) && receiverBic.substring(0, 6).equals(bicCode.substring(0, 6)))) {
                                bicCode53 = bicCode;
                            }
                        } else {
                            bicCode53 = bicCode;
                        }
                    } else {
                        bicCode53 = bicCode;
                    }
                }
            }
        }
        if (StringUtil.isNotEmpty(bicCode53) && SwiftTransferUtil.isBIC(bicCode53)) {
            return bicCode53;
        } else {
            return null;
        }
    }

    /**
     *
     * @param path
     * @return
     */
    protected String mx_to_mt54A(String path) {
        String bicCode = "";
        int pathCount = XmlUtil.getChildrenCount(document, path, null);
        if (pathCount > 0) {
            String mtInstruction = getXmlNodeValue(null, document, path + "(0).InstrInf");
            for (int i=0; i<pathCount; i++) {
                if (i == 0) continue;
                String instrInf = getXmlNodeValue(null, document, path + "("+i+").InstrInf");
                if (StringUtil.isNotEmpty(instrInf)) {
                    if (instrInf.length() < 35 && !instrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                        mtInstruction += "/TempREC/" + instrInf;
                    } else {
                        mtInstruction += instrInf;
                    }
                }
            }
            String regex = ".*/FIN54/(.*)/[A-Z0-9]{1,8}/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mtInstruction);
            if (m.find()) {
                /**
                 * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                 */
                bicCode = m.group(1);
            }
        }
        if (StringUtil.isNotEmpty(bicCode) && SwiftTransferUtil.isBIC(bicCode)) {
            return bicCode;
        } else {
            return null;
        }
    }

    /**
     * mtNameAddress取值逻辑:
     * MxLei = party.Id.OrgId.LEI
     * 如果MxLei存在，并且party.PstlAdr.Ctry存在，MtLei = 3/ + party.PstlAdr.Ctry + /LEIC/ + MxLei;
     * 如果MxLei存在，并且party.PstlAdr.Ctry不存在，MtLei = 3/ + CH + /LEIC/ + MxLei;
     * mtNameAddress = MX_To_MTPartyNameAndStructuredAddress(party);
     * 如果MX_To_MTPartyNameAndStructuredAddress(party)行数小于4行，那么mtNameAddress = mtNameAddress + (回车换行) + mtNameAddress
     * @param partyPath
     * @return
     */
    protected String mx_to_mtPartyNameAndAddressLEI1(String partyPath) {
        String mtNameAddress = "";
        String mxLei = getXmlNodeValue(null, document, partyPath + ".Id.OrgId.LEI");
        String countryCode = getXmlNodeValue(null, document, partyPath + ".PstlAdr.Ctry");
        String mtLei = "";
        if (StringUtil.isNotEmpty(mxLei)) {
            if (StringUtil.isEmpty(countryCode)) countryCode = "CH";
            mtLei = "3/" + countryCode + "/LEIC/" + mxLei;
        }
        if (mtLei.length() > 0) {
            mtNameAddress = mx_to_mtPartyNameAndStructuredAddress1(partyPath);
        } else {
            mtNameAddress = mx_to_mtPartyNameAndStructuredAddress(partyPath);
        }
        String[] mtNameAddressLines = mtNameAddress.split(Mx2MtConstants.NEW_LINE);
        if (mtNameAddressLines.length < 4 && StringUtil.isNotEmpty(mtLei)) {
            mtNameAddress += Mx2MtConstants.NEW_LINE + mtLei;
        }
        return mtNameAddress;
    }

    /**
     * 前提是party.PstlAdr.AdrLine是结构性地址，以2/，3/开始。
     * mtNameAddress取值逻辑:
     * MxName = party.Nm
     * 1.如果MxName不存在，MxName = "NOTPROVIDED";
     * 2.找countryCode，找到第一个以3/开始的countryCode，如果找不到countryCode=CH;
     * 3.MtLei = 3/ + countryCode + /LEIC/ + MxLei;
     * 4.如果party.PstlAdr.AdrLine行数大于等于3
     *   ①如果MxName长度大于33，那么MxName = 1/ + MxName截取到32位，最后一位给 +;
     *   ②否则MxName = 1/ + MxName
     *   mtNameAddress = MxName + party.PstlAdr.AdrLine(取前3行)
     * 5.如果party.PstlAdr.AdrLine行数等于2
     *   ①如果MtLei长度大于0，
     *    如果MxName长度大于33，那么MxName = 1/ + MxName截取到32位，最后一位给 +,否则MxName = 1/ + MxName
     *    mtNameAddress = MxName + party.PstlAdr.AdrLine(取前2行) + MtLei;
     *   ②如果MtLei长度等于0，
     *    如果MxName长度大于66，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到65位，最后一位给 +;
     *    如果MxName长度大于33，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到最后一位
     *    否则MxName = 1/ + MxName
     *    mtNameAddress = MxName + party.PstlAdr.AdrLine(取前2行)
     * 6.如果party.PstlAdr.AdrLine行数等于1
     *    如果MxName长度大于66，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到65位，最后一位给 +;
     *    如果MxName长度大于33，那么MxName = 1/ + MxName截取到33位 + 回车换行 + 1/ + MxName截取到最后一位
     *    否则MxName = 1/ + MxName
     *    如果MtLei长度大于0，
     *    mtNameAddress = MxName + party.PstlAdr.AdrLine(取1行) + MtLei;
     *    否则mtNameAddress = MxName + party.PstlAdr.AdrLine(取1行)
     * @param partyPath
     * @return
     */
    protected String mx_to_mtPartyNameAndAddressLEI2(String partyPath, String leiPrefix) {
        String mtNameAddress = "";
        String mxName = getXmlNodeValue(null, document, partyPath + ".Nm");
        if (StringUtil.isEmpty(mxName)) mxName = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        String mxLei = getXmlNodeValue(null, document, partyPath + ".Id.OrgId.LEI");
        String countryCode = "CH";
        int addressLineCount = XmlUtil.getChildrenCount(document, partyPath + ".PstlAdr.AdrLine", null);
        if (addressLineCount > 0) {
            for (int i=0; i<addressLineCount; i++) {
                String addressLine = getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+i+")");
                if (addressLine.startsWith("3/")) {
                    String addressCountryCode = addressLine.substring(2, 4);
                    if (addressCountryCode.matches("[A-Z]{2}")) {
                        countryCode = addressCountryCode;
                    }
                    break;
                }
            }
        }
        String mtLei = "";
        if (StringUtil.isNotEmpty(mxLei)) {
            mtLei = leiPrefix + countryCode + "/LEIC/" + mxLei;
        }
        if (addressLineCount >= 3) {
            if (mxName.length() > 33) {
                buildSTErrorInfo(12, null, mxName);
                mxName = "1/" + mxName.substring(0, 32) + "+";
            }
            mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                    + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                    + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+1+")") + Mx2MtConstants.NEW_LINE
                    + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+2+")");
        } else if (addressLineCount == 2){
            if (StringUtil.isNotEmpty(mtLei)) {
                if (mxName.length() > 33) {
                    buildSTErrorInfo(12, null, mxName);
                    mxName = "1/" + mxName.substring(0, 32) + "+";
                }
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                        + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                        + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+1+")") + Mx2MtConstants.NEW_LINE
                        + mtLei;
            } else {
                if (mxName.length() > 66) {
                    buildSTErrorInfo(12, null, mxName);
                    mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                            + "1/" + mxName.substring(33, 65) + "+";
                } else if (mxName.length() > 33) {
                    mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                            + "1/" + mxName.substring(33);
                } else {
                    mxName = "1/" + mxName;
                }
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                        + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                        + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+1+")");
            }
        } else { //addressLineCount == 1
            if (mxName.length() > 66) {
                buildSTErrorInfo(12, null, mxName);
                mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                        + "1/" + mxName.substring(33, 65) + "+";
            } else if (mxName.length() > 33) {
                mxName = "1/" + mxName.substring(0, 33) + Mx2MtConstants.NEW_LINE
                        + "1/" + mxName.substring(33);
            } else {
                mxName = "1/" + mxName;
            }
            if (StringUtil.isNotEmpty(mtLei)) {
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                        + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+0+")") + Mx2MtConstants.NEW_LINE
                        + mtLei;
            } else {
                mtNameAddress = mxName + Mx2MtConstants.NEW_LINE
                        + getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+0+")");
            }
        }
        return mtNameAddress;
    }

    /**
     * 该方法用于判断party.PstlAdr.AdrLine是否是结构性地址(以2/，3/开始)
     * 判断条件
     * ①每行开始以2/或者3/
     * ②至少有一行包含3/
     * ③第一行3/后面2个字符必须是countryCode
     * ④2/不能在3/后面
     * 如果都满足以上条件就返回true否则返回false
     * @param partyPath
     * @return
     */
    protected boolean mx_to_mtAddressLineType(String partyPath) {
        boolean flag = true;
        int addressLineCount = XmlUtil.getChildrenCount(document, partyPath + ".PstlAdr.AdrLine", null);
        if (addressLineCount == 0) flag = false;
        String countryCode = "";
        int count = 0;
        for (int i=0; i<addressLineCount; i++) {
            String addressLine = getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+i+")");
            if (addressLine.startsWith("3/")) {
                countryCode = addressLine.substring(2, 4);
                break;
            }
        }
        if (!countryCode.matches("[A-Z]{2}")) flag = false; //③第一行3/后面2个字符必须是countryCode
        for (int i=0; i<addressLineCount; i++) {
            String addressLine = getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+i+")");
            if (!addressLine.startsWith("2/") && !addressLine.startsWith("3/")) { //每行开始以2/或者3/
                flag = false;
                break;
            }
            if (addressLine.startsWith("3/")) {
                count++;
                for (int j=i+1; j<addressLineCount; j++) {
                    String addressLineTmp = getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+j+")");
                    if (addressLineTmp.startsWith("2/")) {
                        flag = false; //④2/不能在3/后面
                        break;
                    }
                }
            }
        }
        if (count == 0) flag = false; //②至少有一行包含3/
        return flag;
    }

    /**
     * MxBic = party.Id.OrgId.AnyBIC
     * MxName = party.Nm
     * MxCountry = party.PstlAdr.Ctry
     * MxTownName = party.PstlAdr.TwnNm
     * MxIden = party.Id.OrgId.Othr.Id  否则 取party.Id.PrvtId.Othr.Id
     * 1.如果MxBic有值，MTUltimateParty = MxBic
     * 2.如果MxName有值
     *    如果MxCountry有值，MTUltimateParty = MxName + "/"+ MxCountry + "/" + MxTownName
     *    否则如果MxIden有值，MTUltimateParty = MxName + "/"+ MxIden
     *    否则 MTUltimateParty = MxName
     * 3.如果MxName没有值  MTUltimateParty = MxIden
     * @param partyPath
     * @return
     */
    protected String mx_to_mtUltimateParty(String partyPath) {
        String bicCode = mx_to_mtAnyBIC(partyPath);
        if (StringUtil.isNotEmpty(bicCode)) {
            return bicCode;
        } else {
            String mtUltimateParty = "";
            String mxIdentification = getXmlNodeValue(null, document, partyPath+".Id.OrgId.Othr.Id");
            if (StringUtil.isEmpty(mxIdentification)) {
                mxIdentification = getXmlNodeValue(null, document, partyPath+".Id.PrvtId.Othr.Id");
            }
            String mxName = getXmlNodeValue(null, document, partyPath+".Nm");
            String mxCountry = getXmlNodeValue(null, document, partyPath+".PstlAdr.Ctry");
            String mxTownName = getXmlNodeValue(null, document, partyPath+".PstlAdr.TwnNm");
            if (StringUtil.isNotEmpty(mxName)) {
                if (StringUtil.isNotEmpty(mxCountry)) {
                    if (StringUtil.isNotEmpty(mxTownName)) {
                        mtUltimateParty = mxName + "/" + mxCountry + "/" + mxTownName;
                    } else {
                        mtUltimateParty = mxName + "/" + mxCountry;
                    }
                } else {
                    if (StringUtil.isNotEmpty(mxIdentification)) {
                        mtUltimateParty = mxName + "/" + mxIdentification;
                    } else {
                        mtUltimateParty = mxName;
                    }
                }
            } else {
                mtUltimateParty = mxIdentification;
            }
            return mtUltimateParty;
        }
    }

    /**
     * MX_To_MTAgent(BranchAndFinancialInstitutionIdentification6, MXCodeLength)
     * 举例：MxCode = /INTA/   MxCodeLength = 6
     * MTAgent取值逻辑：（最多占2行，换行需要用//拼接）
     * MXBic = agt.FinInstnId.BICFI
     * MxName=agt.FinInstnId.Nm
     * MxCountryCode=agt.FinInstnId.PstlAdr.Ctry
     * MxTownName=agt.FinInstnId.PstlAdr.TwnNm
     * MxClearingId=agt.FinInstnId.ClrSysMmbId
     * 1.如果MxBic存在，MTAgent = MxBic
     * 2.如果MxName存在，格式:Name(Country(TownName
     *     MaxCCNameLength = 35 - MxCodeLength + 33 - 2-2-MxTownName.length
     *     MaxNameLength =  35 - MxCodeLength + 33
     *     ①如果MxCountryCode存在，
     *            如果MxName.Length > MaxCCNameLength，MTAgent = MxName.substring（0，MaxCCNameLength-1），最后一位用+代替 否则MTAgent = MxName
     *            MTAgent = MxName + "(" + MxCountryCode + "(" + MxTownName
     *     ②如果MxCountryCode不存在，
     *            如果MxName.Length > MaxNameLength，MTAgent = MxName.substring（0，MaxNameLength-1），最后一位用+代替 否则MTAgent = MxName
     * 3.如果MxClearingId存在，MTAgent = MxClearingId.ClrSysId.Cd + MxClearingId.MmbId
     * @param agentPath
     * @return
     */
    protected String mx_to_mtAgent(String agentPath, int mxCodeLength) {
        String mtAgent = "";
        String mxBic = getXmlNodeValue(null, document, agentPath + ".FinInstnId.BICFI");
        String mxName = getXmlNodeValue(null, document, agentPath + ".FinInstnId.Nm");
        String mxCountryCode = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.Ctry");
        String mxTownName = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.TwnNm");
        String mxClearingCode = getXmlNodeValue(null, document, agentPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isNotEmpty(mxBic)) {
            mtAgent = mxBic;
        } else if (StringUtil.isNotEmpty(mxName)) {
            int maxCCNameLength = 35 - mxCodeLength + 33 - 2 - 2 - (StringUtil.isNotEmpty(mxTownName)?mxTownName.length():0);
            int maxNameLength =  35 - mxCodeLength + 33;
            if (StringUtil.isNotEmpty(mxCountryCode)) {
                if (mxName.length() > maxCCNameLength) {
                    buildSTErrorInfo(12, null, mxName);
                    mtAgent = mxName.substring(0, maxCCNameLength-1) + "+";
                } else {
                    if (StringUtil.isNotEmpty(mxTownName)) {
                        mtAgent = mxName + "(" + mxCountryCode + "(" + mxTownName;
                    } else {
                        mtAgent = mxName + "(" + mxCountryCode;
                    }
                }
            } else {
                if (mxName.length() > maxNameLength) {
                    buildSTErrorInfo(12, null, mxName);
                    mtAgent = mxName.substring(0, maxNameLength-1) + "+";
                } else {
                    mtAgent = mxName;
                }
            }
        } else if (StringUtil.isNotEmpty(mxClearingCode)) {
            mtAgent = mxClearingCode + getXmlNodeValue(null, document, agentPath + ".FinInstnId.ClrSysMmbId.MmbId");
        }
        return mtAgent;
    }

    /**
     * MTAgent取值逻辑:
     * MXBic = agt.FinInstnId.BICFI
     * MxName=agt.FinInstnId.Nm
     * MxClearingId=agt.FinInstnId.ClrSysMmbId
     * 1.如果MxBic存在，MTAgent = MxBic
     * 2.如果MxName存在
     *     如果MxName.Length > MaxLength，MTAgent = MxName.substring（0，MaxNameLength-1），最后一位用+代替 否则MTAgent = MxName
     * 3.如果MxClearingId存在，MTAgent = MxClearingId.ClrSysId.Cd + MxClearingId.MmbId
     *    如果MTAgent.Length > MaxLength，MTAgent = MTAgent.substring（0，MaxNameLength-1），最后一位用+代替 否则不变
     * @param agentPath
     * @param maxLength
     * @return
     */
    protected String mx_to_mtBICNameAgent(String agentPath, int maxLength) {
        String mtAgent = "";
        String mxBic = getXmlNodeValue(null, document, agentPath + ".FinInstnId.BICFI");
        String mxName = getXmlNodeValue(null, document, agentPath + ".FinInstnId.Nm");
        String mxClearingCode = getXmlNodeValue(null, document, agentPath + ".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        if (StringUtil.isNotEmpty(mxBic)) {
            mtAgent = mxBic;
        } else if (StringUtil.isNotEmpty(mxName)) {
            mtAgent = mxName;
        } else if (StringUtil.isNotEmpty(mxClearingCode)) {
            mtAgent = mxClearingCode + getXmlNodeValue(null, document, agentPath + ".FinInstnId.ClrSysMmbId.MmbId");
        }
        if (StringUtil.isNotEmpty(mtAgent)) {
            if (mtAgent.length() > maxLength) {
                buildSTErrorInfo(12, null, mtAgent);
                mtAgent = mtAgent.substring(0, maxLength-1) + "+";
            }
        }
        return mtAgent;
    }

    /**
     * subfunctionInstructionForNextAgent取值逻辑:
     * 1.将所有存在的InstrInf值加起来，注意如果InstrInf不以/[A-Z0-9]{1,8}/开始并且上一条InstrInf长度小于35，那么中间需要加/TempREC/
     * 2.如果结果1中存在/FIN53/BIC，则需要删掉/FIN53/BIC
     * 3.将结果2中的/TempREC/xxx，全部拿出来组装在一起(mtNoCode)，并删除掉/TempREC/xxx
     * 4.如果InstrInf中包含/REC/,需要将mtNoCode放在REC后面；否则在InstrInf后面加/REC/mtNoCode
     * @param agentPath
     * @return
     */
    protected List<String> subFunctionInstructionForNextAgent(String agentPath, String settlementMethod) {
        String tmpRec = "/TEMPREC/";
        int instrCount = XmlUtil.getChildrenCount(document, agentPath, null);
        List<String> mtInstrInfs = new ArrayList<>();
        if (instrCount > 0) {
            String mxInstrInf = "";
            for (int i=0; i<instrCount; i++) {
                String instrInf = getXmlNodeValue(null, document, agentPath + "("+i+").InstrInf");
                if (StringUtil.isNotEmpty(instrInf)) {
                    if (i == 0) {
                        mxInstrInf += instrInf;
                    } else {
                        String lastInstrInf = getXmlNodeValue(null, document, agentPath + "("+(i-1)+").InstrInf");
                        if (StringUtil.isNotEmpty(lastInstrInf)
                                && lastInstrInf.length() < 35
                                && !instrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                            mxInstrInf += tmpRec + instrInf;
                        } else {
                            mxInstrInf += instrInf;
                        }
                    }
                }
            }
            if (!mxInstrInf.matches("/[A-Z0-9]{1,8}/.*")) {
                mxInstrInf = tmpRec + mxInstrInf;
            }
            //提取 /GenericMax8c/
            List<String> list = new ArrayList<>();
            String[] mxInstrInfs = StringUtil.splitAndKeepSeparator(mxInstrInf, "/[A-Z0-9]{1,8}/");
            for (int i=0; i<mxInstrInfs.length; i++) {
                String mxIns = mxInstrInfs[i];
                if (mxIns.startsWith("/FIN53/")) {
                    String bicCode = mxIns.substring(7);
                    boolean bicCodeFlag = false;
                    if (SwiftTransferUtil.isBIC(bicCode)
                            && (SettlementMethodCode.INGA.value().equals(settlementMethod)
                            || SettlementMethodCode.INDA.value().equals(settlementMethod))) {
                        String acccount = mx_to_mtAccount(grpHdrParentElementName + ".GrpHdr.SttlmInf.SttlmAcct");
                        if (StringUtil.isEmpty(acccount)) {
                            String senderBic = (String)context.get(Mx2MtContextIdentifier.MX_SENDER_BIC, true);
                            String receiverBic = (String)context.get(Mx2MtContextIdentifier.MX_RECEIVER_BIC, true);
                            if ((StringUtil.isNotEmpty(senderBic) && senderBic.substring(0, 6).equals(bicCode.substring(0, 6)))
                                    || (StringUtil.isNotEmpty(receiverBic) && receiverBic.substring(0, 6).equals(bicCode.substring(0, 6)))) {
                                bicCodeFlag = true;
                            }
                        } else {
                            bicCodeFlag = true;
                        }
                    }
                    if (!bicCodeFlag) {
                        list.add(mxIns);
                    }
                } else {
                    list.add(mxIns);
                }
            }
            String tempRecStr = "";
            //找到以TEMPREC 开头的信息
            for (int i=0; i<list.size(); i++) {
                String str = list.get(i);
                if (str.startsWith(tmpRec)) {
                    if (StringUtil.isEmpty(tempRecStr)) {
                        tempRecStr += "/REC/" + str.substring(9);
                    } else {
                        tempRecStr += " " + str.substring(9);
                    }
                }
            }
            //过滤掉以TEMPREC 开头的信息
            for (int i=0; i<list.size(); i++) {
                String str = list.get(i);
                if (!str.startsWith(tmpRec)) {
                    mtInstrInfs.add(str);
                }
            }
            //是否包含/REC/信息
            int recIndex = -1;
            for (int i=0; i<mtInstrInfs.size(); i++) {
                if (mtInstrInfs.get(i).startsWith("/REC/")) {
                    recIndex = i;
                    break;
                }
            }
            if (StringUtil.isNotEmpty(tempRecStr)) {
                if (recIndex > -1) {
                    String tmpStr = mtInstrInfs.get(recIndex);
                    mtInstrInfs.remove(recIndex);
                    mtInstrInfs.add(recIndex, tmpStr + " " + tempRecStr.substring(5));
                } else {
                    mtInstrInfs.add(tempRecStr);
                }
            }
        }
        return mtInstrInfs;
    }

    /**
     * 提取PHOB,TELB,UDLC和无CODE的instrInfo
     * @param agentPath
     * @return
     */
    protected List<String> subFunctionInstructionForCreditorAgent(String agentPath) {
        int creditorAgentCount = XmlUtil.getChildrenCount(document, agentPath, null);
        List<String> list = new ArrayList<>();
        if (creditorAgentCount > 0) {
            //UDLC PHOB TELB
            String udlcInstrInf = "";
            String accInstrInf = "";
            List<String> phobList = new ArrayList<>();
            List<String> telbList = new ArrayList<>();
            for (int i=0; i<creditorAgentCount; i++) {
                if (i == 2) break;
                String code = getXmlNodeValue(null, document, agentPath + "("+i+").Cd");
                String instrInf = getXmlNodeValue(null, document, agentPath + "("+i+").InstrInf");
                String remainInstrInf = "";
                if (StringUtil.isNotEmpty(instrInf)) {
                    String[] instrInfs = instrInf.split("(?=/UDLC/|/TELB/|/PHOB/)");
                    for (int j=0; j<instrInfs.length; j++) {
                        String str = instrInfs[j];
                        if (str.startsWith("/UDLC/")) {
                            udlcInstrInf += str.substring(6) + " ";
                        } else if (str.startsWith("/PHOB/")) {
                            phobList.add("/PHONBEN/"+str.substring(6));
                        } else if (str.startsWith("/TELB/")) {
                            telbList.add("/TELEBEN/"+str.substring(6));
                        } else if (StringUtil.isNotEmpty(str)){
                            remainInstrInf = str;
                        }
                    }
                }
                if (StringUtil.isEmpty(code)) {
                    if (StringUtil.isNotEmpty(remainInstrInf)) {
                        accInstrInf += remainInstrInf + " ";
                    }
                } else if (ExternalCreditorAgentInstructionCode.PHOB.value().equals(code)) {
                    if (StringUtil.isNotEmpty(remainInstrInf)) {
                        phobList.add("/PHONBEN/"+remainInstrInf);
                    } else {
                        phobList.add("/PHONBEN/");
                    }
                }  else if (ExternalCreditorAgentInstructionCode.TELB.value().equals(code)) {
                    if (StringUtil.isNotEmpty(remainInstrInf)) {
                        phobList.add("/TELEBEN/"+remainInstrInf);
                    } else {
                        phobList.add("/TELEBEN/");
                    }
                }
            }
            udlcInstrInf = udlcInstrInf.trim();
            if (StringUtil.isNotEmpty(udlcInstrInf)) {
                list.add("/UDLC/"+udlcInstrInf);
            }
            accInstrInf = accInstrInf.trim();
            if (StringUtil.isNotEmpty(accInstrInf)) {
                list.add("/ACC/"+accInstrInf);
            }
            if (phobList.size() > 0) {
                list.addAll(phobList);
            }
            if (telbList.size() > 0) {
                list.addAll(telbList);
            }
        }
        return list;
    }

    /**
     * pacs008001转MT103 70域的第5个参数使用
     * 提取CHQB 和无CODE的instrInfo
     * @param agentPath
     * @return
     */
    protected String subFunctionInstructionForCreditorAgentAndJP(String agentPath) {
        int creditorAgentCount = XmlUtil.getChildrenCount(document, agentPath, null);
        String mtInstrInf = "";
        if (creditorAgentCount > 0) {
            for (int i=0; i<creditorAgentCount; i++) {
                if (i == 2) break;
                String code = getXmlNodeValue(null, document, agentPath + "("+i+").Cd");
                String instrInf = getXmlNodeValue(null, document, agentPath + "("+i+").InstrInf");
                if (StringUtil.isEmpty(code) || ExternalCreditorAgentInstructionCode.CHQB.value().equals(code)) {
                    if (StringUtil.isNotEmpty(instrInf)) {
                        String[] instrInfs = instrInf.split("(?=/PHOB/|/HOLD/|/TELB/|/CHQB/)");
                        for (String str : instrInfs) {
                            if (str.startsWith("/CHQB/")) {
                                mtInstrInf += " " + str.substring(6);
                            } else if (!str.startsWith("/PHOB/") && !str.startsWith("/HOLD/") && !str.startsWith("/TELB/")) {
                                mtInstrInf += " " + str;
                            }
                        }
                    }
                }
            }
            mtInstrInf = "/ACC/" + mtInstrInf.trim();
            /*String regex = "(/(PHOB|HOLD|TELB)/[0-9a-zA-Z\\-\\?:\\(\\)\\.,'\\+]*)";
            mtInstrInf = mtInstrInf.replaceAll(regex, "");
            if (mtInstrInf.indexOf("/CHQB/") > -1) {
                mtInstrInf = mtInstrInf.replace("/CHQB/", " ");
            }*/
        }
        return mtInstrInf;
    }

    /**
     * 取值逻辑：
     * 1.mxRemitInfo = CdtTrfTxInf.RmtInf.Ustrd(0),取第一条记录
     * 2.提取/BNF/xxxx，作为bnfInfo，并在mxRemitInfo删除掉对应的内容
     * 3.提取/TSU/xxxx，作为tsuInfo，并在mxRemitInfo删除掉对应的内容
     * 4.如果bnfInfo存在，那么直接在后面加上mxRemitInfo剩余的内容；否则bnfInfo = /BNF/ + mxRemitInfo剩余的内容
     * 5.MT72 = bnfInfo + tsuInfo
     * @param remittanceInfoPath
     * @return
     */
    protected String subFunctionRemittanceInformation(String remittanceInfoPath) {
        String mtRemittanceInfo = "";
        int remitInfoUstrdCount = XmlUtil.getChildrenCount(document, remittanceInfoPath + ".Ustrd", null);
        if (remitInfoUstrdCount > 0) {
            String mxRemittanceInfo = getXmlNodeValue(null, document, remittanceInfoPath + ".Ustrd(0)");
            String bnfInfo = "";
            String regex = ".*/BNF/(.*)/TSU/.*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mxRemittanceInfo);
            if (m.find()) {
                bnfInfo += "/BNF/" + m.group(1);
                mxRemittanceInfo.replace(bnfInfo, "");
            }
            String tsuInfo = "";
            regex = ".*/TSU/(.*)/BNF/.*";
            p = Pattern.compile(regex);
            m = p.matcher(mxRemittanceInfo);
            if (m.find()) {
                tsuInfo += "/TSU/" + m.group(1);
                mxRemittanceInfo.replace(tsuInfo, "");
            }
            if (StringUtil.isNotEmpty(bnfInfo)) {
                bnfInfo += mxRemittanceInfo;
            } else {
                bnfInfo += "/BNF/" + mxRemittanceInfo;
            }
            mtRemittanceInfo = bnfInfo + tsuInfo;
        }
        return mtRemittanceInfo;
    }

    protected String mx_to_mtFATFIdentification(String partyPath, boolean structuredAddressIndicator) {
        String identificationPath = partyPath + ".Id";
        String countryCode = getXmlNodeValue(null, document, partyPath+".PstlAdr.Ctry");
        if (structuredAddressIndicator) {
            int addressLineCount = XmlUtil.getChildrenCount(document, partyPath + ".PstlAdr.AdrLine", null);
            if (addressLineCount > 0) {
                for (int i=0; i<addressLineCount; i++) {
                    String addressLine = getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine("+i+")");
                    if (addressLine.startsWith("3/")) {
                        String addressCountryCode = addressLine.substring(2, 4);
                        if (addressCountryCode.matches("[A-Z]{2}")) {
                            countryCode = addressCountryCode;
                        }
                        break;
                    }
                }
            }
        }
        String countryOfResidence = getXmlNodeValue(null, document, partyPath+".CtryOfRes");
        boolean hasNodeFlag = false; //表示OrgId或者PrvtId 有值
        boolean successfulFATF = false;
        String mxCode = "";
        String mxIssuer = "";
        String mtIdentifier = "";
        String mtCountryCode = "";
        String mtSchemeCode = "";
        String mtIssuer = "";
        int orgIdenOtherCount = XmlUtil.getChildrenCount(document, identificationPath + ".OrgId.Othr", null);
        if (orgIdenOtherCount > 0) {
            hasNodeFlag = true;
            for (int i=0; i<orgIdenOtherCount; i++) {
                mxCode = getXmlNodeValue(null, document, identificationPath + ".OrgId.Othr("+i+").SchmeNm.Cd");
                mxIssuer = getXmlNodeValue(null, document, identificationPath + ".OrgId.Othr("+i+").Issr");
                mtIdentifier = getXmlNodeValue(null, document, identificationPath + ".OrgId.Othr("+i+").Id");
                if (StringUtil.isNotEmpty(mxIssuer)) {
                    if (mxIssuer.matches("[A-Z]{2}")) { //国家代号
                        mtCountryCode = mxIssuer;
                        mxIssuer = "";
                    } else if (mxIssuer.length() > 4){
                        String subMxIssuer = mxIssuer.substring(0, 2);
                        if (subMxIssuer.matches("[A-Z]{2}")
                                && "/".equals(mxIssuer.substring(2, 3))) {
                            mtCountryCode = subMxIssuer;
                            mxIssuer = mxIssuer.substring(3);
                        }
                    }
                }
                if (OrganisationIdentificationCode.GS1G.value().equals(mxCode)
                        || OrganisationIdentificationCode.DUNS.value().equals(mxCode)) {
                    mtSchemeCode = "CUST";
                    if (mxIssuer.length() > 0) {
                        mtIssuer = mxCode + " " + mxIssuer;
                    } else {
                        mtIssuer = mxCode;
                    }
                    if (StringUtil.isNotEmpty(mtCountryCode)) {
                        successfulFATF = true;
                        break;
                    }
                } else if (OrganisationIdentificationCode.TXID.value().equals(mxCode)) {
                    if (StringUtil.isNotEmpty(mtCountryCode)
                            && Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(mtIdentifier)) {
                        if (StringUtil.isNotEmpty(mtCountryCode)) {
                            successfulFATF = true;
                            break;
                        }
                    }
                }
                if (SwiftTransferUtil.getOrganisationIdentificationCodeByCode(mxCode) != null
                        && !OrganisationIdentificationCode.CUST.value().equals(mxCode)
                        && !OrganisationIdentificationCode.EMPL.value().equals(mxCode)
                        && !OrganisationIdentificationCode.TXID.value().equals(mxCode)) {
                    mtSchemeCode = "CUST";
                    if (mxIssuer.length() > 0) {
                        mtIssuer = mxCode + " " + mxIssuer;
                    } else {
                        mtIssuer = mxCode;
                    }
                    if (StringUtil.isNotEmpty(mtCountryCode)) {
                        successfulFATF = true;
                        break;
                    }
                } else if (OrganisationIdentificationCode.CUST.value().equals(mxCode) || OrganisationIdentificationCode.EMPL.value().equals(mxCode)) {
                    mtSchemeCode = mxCode;
                    if (StringUtil.isEmpty(mxIssuer)) {
                        mtIssuer = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    } else {
                        mtIssuer = mxIssuer;
                    }
                    if (StringUtil.isNotEmpty(mtCountryCode)) {
                        successfulFATF = true;
                        break;
                    }
                } else if (OrganisationIdentificationCode.TXID.value().equals(mxCode)) {
                    mtSchemeCode = mxCode;
                    mtIssuer = "";
                    if (StringUtil.isNotEmpty(mtCountryCode) && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(mtIdentifier)) {
                        successfulFATF = true;
                        break;
                    }
                }
            }
            if (SwiftTransferUtil.getOrganisationIdentificationCodeByCode(mxCode) != null) {
                if (StringUtil.isNotEmpty(countryCode)) {
                    mtCountryCode = countryCode;
                    successfulFATF = true;
                    buildSTErrorInfo(26, null, null);
                }
            } else {
                buildSTErrorInfo(35, null, null);
            }
        } else {
            int privateIdenOtherCount = XmlUtil.getChildrenCount(document, identificationPath + ".PrvtId.Othr", null);
            if (privateIdenOtherCount > 0) {
                hasNodeFlag = true;
                for (int i=0; i<privateIdenOtherCount; i++) {
                    mtSchemeCode = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+i+").SchmeNm.Cd");
                    mtIssuer = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+i+").Issr");
                    mtIdentifier = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+i+").Id");
                    PersonIdentificationCode personIdenCode = SwiftTransferUtil.getPersonIdentificationCodeByCode(mtSchemeCode);
                    if (personIdenCode != null) {
                        if (StringUtil.isNotEmpty(mtIssuer)) {
                            if (mtIssuer.matches("[A-Z]{2}")) { //国家代号
                                mtCountryCode = mtIssuer;
                                mtIssuer = "";
                                successfulFATF = true;
                                break;
                            } else if (mtIssuer.length() > 4){
                                String subMxIssuer = mtIssuer.substring(0, 2);
                                if (subMxIssuer.matches("[A-Z]{2}")
                                        && "/".equals(mtIssuer.substring(2, 3))) {
                                    mtCountryCode = subMxIssuer;
                                    mtIssuer = mtIssuer.substring(3);
                                    successfulFATF = true;
                                    break;
                                }
                            }
                        }
                    }
                }
                if (SwiftTransferUtil.getPersonIdentificationCodeByCode(mtSchemeCode) != null) {
                    if (StringUtil.isNotEmpty(countryCode)) {
                        mtCountryCode = countryCode;
                        successfulFATF = true;
                        buildSTErrorInfo(26, null, null);
                    } else if (StringUtil.isNotEmpty(countryOfResidence)) {
                        mtCountryCode = countryOfResidence;
                        successfulFATF = true;
                        buildSTErrorInfo(27, null, null);
                    }
                } else {
                    buildSTErrorInfo(28, null, null);
                }
                if (PersonIdentificationCode.ARNU.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.CCPT.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.NIDN.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.SOSE.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.TXID.value().equals(mtSchemeCode)) {
                    mtIssuer = "";
                } else if (PersonIdentificationCode.TELE.value().equals(mtSchemeCode)) {
                    if (mtIssuer.length() > 0) {
                        mtIssuer = mtSchemeCode + " " + mtIssuer;
                    } else {
                        mtIssuer = mtSchemeCode;
                    }
                    mtSchemeCode = "CUST";
                } else if (PersonIdentificationCode.CUST.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.DRLC.value().equals(mtSchemeCode)
                        || PersonIdentificationCode.EMPL.value().equals(mtSchemeCode)) {
                    if (StringUtil.isEmpty(mtIssuer)) {
                        mtIssuer = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                }
            }
        }
        if (successfulFATF) {
            String mtFATFId = "";
            if (StringUtil.isEmpty(mtIssuer)) {
                mtFATFId = mtSchemeCode + "/" + mtCountryCode + "/" + mtIdentifier;
            } else if (Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(mtIssuer)) {
                mtFATFId = mtSchemeCode + "/" + mtCountryCode + "//" + mtIdentifier;
            } else {
                mtFATFId = mtSchemeCode + "/" + mtCountryCode + "/" + mtIssuer + "/" + mtIdentifier;
            }
            if ("EMPL".equals(mtSchemeCode)
                    || "CUST".equals(mtSchemeCode)
                    || "DRLC".equals(mtSchemeCode)) {
                if (mtFATFId.length() > 68) {
                    buildSTErrorInfo(12, null, mtFATFId);
                    int issuerLength = 59 - mtIdentifier.length();
                    mtIssuer = mtIssuer.substring(0, issuerLength-1) + "+";
                    mtFATFId = mtSchemeCode + "/" + mtCountryCode + "/" + mtIssuer + "/" + mtIdentifier;
                }
            }
            return mtFATFId;
        } else {
            if (hasNodeFlag) { //存在结点但是找不到的时候才会出转换报告
                buildSTErrorInfo(29, null, null);
            }
        }
        return null;
    }

    /**
     * 有2部分组成
     * 4/ + Id.PrvtId.DtAndPlcOfBirth.BirthDt
     * 5/ + Id.PrvtId.DtAndPlcOfBirth.CtryOfBirth + / + Id.PrvtId.DtAndPlcOfBirth.CityOfBirth
     * @param partyPath
     * @return
     */
    protected String[] mx_to_mtBirthInformation(String partyPath) {
        try {
            String mxBirthDateStr = getXmlNodeValue(null, document, partyPath  + ".Id.PrvtId.DtAndPlcOfBirth.BirthDt");
            String mxBirthPlace = getXmlNodeValue(null, document, partyPath  + ".Id.PrvtId.DtAndPlcOfBirth.CityOfBirth");
            String mxBirthCountry = getXmlNodeValue(null, document, partyPath  + ".Id.PrvtId.DtAndPlcOfBirth.CtryOfBirth");
            String mtBirthDate = "";
            if (StringUtil.isNotEmpty(mxBirthDateStr)) {
                Date mxBirthDate = DateUtil.parseDate(mxBirthDateStr, "yyyy-MM-dd");
                mtBirthDate = "4/" + DateUtil.format(mxBirthDate, "yyyyMMdd");
            }
            if (StringUtil.isNotEmpty(mxBirthPlace)) {
                if (mxBirthPlace.length() > 30) {
                    buildSTErrorInfo(12, null, mxBirthPlace);
                    mxBirthPlace = mxBirthPlace.substring(0, 29) + "+";
                }
            }
            String mtCountryandPlaceOfBirth = "5/" + mxBirthCountry + "/" + mxBirthPlace;
            if (StringUtil.isNotEmpty(mtBirthDate) && StringUtil.isNotEmpty(mtCountryandPlaceOfBirth)) {
                return new String[]{mtBirthDate, mtCountryandPlaceOfBirth};
            }
            return null;
        } catch (ParseException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    /**
     *
     * @param partyPath
     * @return
     */
    protected Map<String, String> mx_to_mtFATFID_CUST_NIDN(String partyPath) {
        Map<String, String> maps = new HashMap<>();
        int index6 = -1;
        int index7 = -1;
        String countryCode = getXmlNodeValue(null, document, partyPath+".PstlAdr.Ctry");
        String countryOfResidence = getXmlNodeValue(null, document, partyPath+".CtryOfRes");
        String identificationPath = partyPath + ".Id";
        int privateIdenOtherCount = XmlUtil.getChildrenCount(document, identificationPath + ".PrvtId.Othr", null);
        if (privateIdenOtherCount > 0) {
            for (int i=0; i<privateIdenOtherCount; i++) {
                String mxSchemeCode = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+i+").SchmeNm.Cd");
                if (PersonIdentificationCode.CUST.value().equals(mxSchemeCode)) {
                    index6 = i;
                }
                if (PersonIdentificationCode.NIDN.value().equals(mxSchemeCode)) {
                    index7 = i;
                }
            }
        }
        String mtCode6 = "";
        if (index6 > -1) {
            boolean successfulFATF = false;
            String mxIssuer = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+index6+").Issr");
            String mxIdentifier = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+index6+").Id");
            if (StringUtil.isNotEmpty(mxIdentifier)
                    && !("/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE).equals(mxIdentifier)
                    && !mxIdentifier.startsWith("CUST")) {
                String mtCountryCode = "";
                String mtIssuer = "";
                if (StringUtil.isNotEmpty(mxIssuer)) {
                    if (mxIssuer.matches("[A-Z]{2}")) {
                        mtCountryCode = mxIssuer;
                        successfulFATF = true;
                    } else if (mxIssuer.length() >= 4 && mxIssuer.substring(0, 2).matches("[A-Z]{2}") && "/".equals(mxIssuer.substring(2, 3))) {
                        mtCountryCode = mxIssuer.substring(0, 2);
                        mtIssuer = mxIssuer.substring(3);
                        successfulFATF = true;
                    } else {
                        mtIssuer = mxIssuer;
                        if (StringUtil.isNotEmpty(countryCode)) {
                            mtCountryCode = countryCode;
                            successfulFATF = true;
                        } else if (StringUtil.isNotEmpty(countryOfResidence)) {
                            mtCountryCode = countryOfResidence;
                            successfulFATF = true;
                        }
                    }
                }
                if (successfulFATF) {
                    mtCode6 = "6/" + mtCountryCode + "/" + mtIssuer + "/" + mxIdentifier;
                    if (mtCode6.length() > 35) {
                        buildSTErrorInfo(12, null, mtCode6);
                        mtCode6 = mtCode6.substring(0, 34) + "+";
                    }
                    maps.put("MTCODE6", mtCode6);
                } else {
                    buildSTErrorInfo(30, null, null);
                }
            }
        }
        String mtCode7 = "";
        if (index7 > -1) {
            boolean successfulFATF = false;
            String mxIssuer = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+index7+").Issr");
            String mxIdentifier = getXmlNodeValue(null, document, identificationPath + ".PrvtId.Othr("+index7+").Id");
            if (StringUtil.isNotEmpty(mxIdentifier)
                    && !("/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE).equals(mxIdentifier)
                    && !mxIdentifier.startsWith("NIDN")) {
                String mtCountryCode = "";
                if (StringUtil.isNotEmpty(mxIssuer)) {
                    if (mxIssuer.matches("[A-Z]{2}")) {
                        mtCountryCode = mxIssuer;
                        successfulFATF = true;
                    }
                } else {
                    if (StringUtil.isNotEmpty(countryCode)) {
                        mtCountryCode = countryCode;
                        successfulFATF = true;
                    } else if (StringUtil.isNotEmpty(countryOfResidence)) {
                        mtCountryCode = countryOfResidence;
                        successfulFATF = true;
                    }
                }
                if (successfulFATF) {
                    mtCode7 = "7/" + mtCountryCode + "/" + mxIdentifier;
                    if (mtCode7.length() > 35) {
                        buildSTErrorInfo(12, null, mtCode7);
                        mtCode7 = mtCode7.substring(0, 34) + "+";
                    }
                    maps.put("MTCODE7", mtCode7);
                } else {
                    buildSTErrorInfo(30, null, null);
                }
            }
        }
        return maps;
    }

    /**
     *
     * @param partyPath
     * @return
     */
    protected String mx_to_mtFATFNameAndAddress(String partyPath) {
        String mtNameAndAddress = mx_to_mtPartyNameAndStructuredAddress(partyPath);
        String mtPartyIdentifier = mx_to_mtFATFIdentification(partyPath, false);
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && mtPartyIdentifier.length() > 35) {
            mtCode8 = "8/" + mtPartyIdentifier.substring(35);
        }
        String mtCode4 = "";
        String mtCode5 = "";
        String[] mtBrithInfos = mx_to_mtBirthInformation(partyPath);
        if (mtBrithInfos != null && mtBrithInfos.length == 2) {
            mtCode4 = mtBrithInfos[0];
            mtCode5 = mtBrithInfos[1];
        }
        String mtCode6 = "";
        String mtCode7 = "";
        Map<String, String> maps = mx_to_mtFATFID_CUST_NIDN(partyPath);
        if (maps != null) {
            mtCode6 = maps.get("MTCODE6");
            mtCode7 = maps.get("MTCODE7");
        }
        String mxLei = getXmlNodeValue(null, document, partyPath + ".Id.OrgId.LEI");
        if (StringUtil.isNotEmpty(mxLei)) {
            String countryCode = getXmlNodeValue(null, document, partyPath + ".PstlAdr.Ctry");
            if (StringUtil.isEmpty(countryCode)) {
                countryCode = "CH";
            }
            mtCode6 = "6/" + countryCode + "/LEIC/" + mxLei;
        }
        if (StringUtil.isNotEmpty(mtNameAndAddress)) {
            int remainLines = 4 - mtNameAndAddress.split(Mx2MtConstants.NEW_LINE).length;
            if (remainLines > 0) {
                int addLines = 0;
                if (StringUtil.isNotEmpty(mtCode4) && StringUtil.isNotEmpty(mtCode5) && addLines < remainLines && remainLines >=2) {
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode4 + Mx2MtConstants.NEW_LINE + mtCode5;
                    addLines += 2;
                }
                if (StringUtil.isNotEmpty(mtCode6) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode6;
                }
                if (StringUtil.isNotEmpty(mtCode7) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode7;
                }
                if (StringUtil.isNotEmpty(mtCode8) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode8;
                }
            }
        }
        return mtNameAndAddress;
    }

    protected String mx_to_mtFATFNameAndAddress2(String partyPath) {
        String mtNameAndAddress = mx_to_mtPartyNameAndAddressLEI2(partyPath, "6/");
        String mtPartyIdentifier = mx_to_mtFATFIdentification(partyPath, true);
        String mtCode8 = "";
        if (StringUtil.isNotEmpty(mtPartyIdentifier) && mtPartyIdentifier.length() > 35) {
            mtCode8 = "8/" + mtPartyIdentifier.substring(35);
        }
        String mtCode4 = "";
        String mtCode5 = "";
        String[] mtBrithInfos = mx_to_mtBirthInformation(partyPath);
        if (mtBrithInfos != null && mtBrithInfos.length == 2) {
            mtCode4 = mtBrithInfos[0];
            mtCode5 = mtBrithInfos[1];
        }
        String mtCode6 = "";
        String mtCode7 = "";
        Map<String, String> maps = mx_to_mtFATFID_CUST_NIDN(partyPath);
        if (maps != null) {
            mtCode6 = maps.get("MTCODE6");
            mtCode7 = maps.get("MTCODE7");
        }
        if (StringUtil.isNotEmpty(mtNameAndAddress)) {
            int remainLines = 4 - mtNameAndAddress.split(Mx2MtConstants.NEW_LINE).length;
            if (remainLines > 0) {
                int addLines = 0;
                if (StringUtil.isNotEmpty(mtCode4) && StringUtil.isNotEmpty(mtCode5) && addLines < remainLines && remainLines >=2) {
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode4 + Mx2MtConstants.NEW_LINE + mtCode5;
                    addLines += 2;
                }
                if (StringUtil.isNotEmpty(mtCode8) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode8;
                }
                if (StringUtil.isNotEmpty(mtCode6) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode6;
                }
                if (StringUtil.isNotEmpty(mtCode7) && addLines < remainLines) {
                    addLines++;
                    mtNameAndAddress += Mx2MtConstants.NEW_LINE + mtCode7;
                }
            }
        }
        return mtNameAndAddress;
    }

    protected String subFunctionReasonCodeTranslation(String mxReasonCode, List<MxMtReasonCodeInfo> mxMtReasonCodeInfos) {
        String mtFixedCode = "/XT99/";
        String mtReasonCode = "";
        boolean isMtErrorCodePresent = false;
        if (mxMtReasonCodeInfos != null && mxMtReasonCodeInfos.size() > 0) {
            for (int i=0; i<mxMtReasonCodeInfos.size(); i++) {
                MxMtReasonCodeInfo mxMtReasonCodeInfo = mxMtReasonCodeInfos.get(i);
                if (mxReasonCode.equals(mxMtReasonCodeInfo.getIsoCode())) {
                    isMtErrorCodePresent = mxMtReasonCodeInfo.isMtErrorCodePresent();
                    mtReasonCode = mxMtReasonCodeInfo.getMtCode();
                    break;
                }
            }
        }
        if (isMtErrorCodePresent) {
            return "/" + mtReasonCode + "/";
        } else {
            return mtFixedCode + mxReasonCode + "/";
        }
    }

    protected String subFunctionIDTruncation(String mxId, boolean isInstructionId) {
        if (StringUtil.isEmpty(mxId)) {
            if (isInstructionId) {
                buildSTErrorInfo(73, null, null);
            } else {
                buildSTErrorInfo(112, null, null);
            }
            return Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        if (mxId.length() > 16) {
            buildSTErrorInfo(12, null, mxId);
            mxId = mxId.substring(0, 15) + "+";
        }
        String mtId = mxId;
        if (mtId.startsWith("/") || mtId.endsWith("/") || mtId.contains("//")) {
            if (isInstructionId) {
                buildSTErrorInfo(43, null, null);
            } else {
                buildSTErrorInfo(42, null, null);
            }
            mtId = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
        }
        return mtId;
    }

    protected String subFunctionChargeCalculation(String chargesInfoPath) {
        BigDecimal totalAmt = BigDecimal.ZERO;
        String ccy = "";
        boolean errorFlag = false;
        int chrgsInfCount = XmlUtil.getChildrenCount(document, chargesInfoPath, null);
        if (chrgsInfCount > 0) {
            ccy = getXmlNodeValue(null, document, chargesInfoPath + "(0).Amt@Ccy");
            String amt = getXmlNodeValue(null, document, chargesInfoPath + "(0).Amt");
            totalAmt = totalAmt.add(new BigDecimal(amt));
            if (chrgsInfCount > 1) {
                for (int i = 1; i < chrgsInfCount; i++) {
                    if (ccy.equals(getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.ChrgsInf(" + i + ").Amt@Ccy"))) {
                        BigDecimal tmpAmt = new BigDecimal(getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.ChrgsInf(" + i + ").Amt"));
                        totalAmt = totalAmt.add(tmpAmt);
                    } else {
                        errorFlag = true;
                        buildSTErrorInfo(41, null, null);
                        break;
                    }
                }
            }
        }
        if (totalAmt.compareTo(BigDecimal.ZERO) > 0 && !errorFlag) {
            return "/CHGS/" + ccy + NumberUtil.formatAmt(totalAmt, ccy);
        } else {
            return null;
        }
    }


    /**
     * Agent 转 mt 的 公共方法
     * OPTION A B C D
     * @param tagName
     * @param agentPath
     * @param accountPath
     * @param isAllowedOptionB
     * @param isAllowedOptionC
     * @param isAllowedClearingChannel
     * @param clearingChannelPath
     * @return
     */
    protected Tag mx_to_mtAgentGeneric(String tagName, String agentPath, String accountPath,
                   boolean isAllowedOptionB, boolean isAllowedOptionC,
                   boolean isAllowedClearingChannel, String clearingChannelPath) {
        Tag tag = null;
        int agentCount = getXmlNodeCounts(null, document, agentPath);
        int accountCount = getXmlNodeCounts(null, document, accountPath);
        if (agentCount == 0 && accountCount == 0) {
            return tag;
        }
        String value = "";
        String bicCode = mx_to_mtBICFI(agentPath);
        String name = getXmlNodeValue(null, document, agentPath + ".FinInstnId.Nm");
        String clearingSystemMemberId = getXmlNodeValue(null, document, agentPath + ".FinInstnId.ClrSysMmbId.MmbId");
        int addressLineCount = getXmlNodeCounts(null, document, agentPath + ".FinInstnId.PstlAdr.AdrLine");
        String addressLine1 = "";
        if (addressLineCount > 0) {
            addressLine1 = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.AdrLine(0)");
        }
        String account = mx_to_mtAccount(accountPath);
        String clearingChannal = "";
        if (isAllowedClearingChannel) {
            clearingChannal = getXmlNodeValue(null, document, clearingChannelPath);
        }
        if (StringUtil.isNotEmpty(bicCode)) {
            if (StringUtil.isEmpty(account) && isAllowedClearingChannel) {
                account = mx_to_mtClearingIdentifierAndChannel(agentPath, clearingChannelPath);
            }
            if (StringUtil.isEmpty(account)) {
                account = mx_to_mtClearingIdentifier(agentPath);
            }
            if (StringUtil.isEmpty(account)) {
                value = bicCode;
            } else {
                value = account + Mx2MtConstants.NEW_LINE + bicCode;
            }
            tag = new Tag(tagName+"A", value);
        } else if (StringUtil.isEmpty(clearingSystemMemberId)
                && StringUtil.isNotEmpty(name) && name.equals(addressLine1)
                && name.length() <= 35 && !name.equals(Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE)
                && name.startsWith("//") && addressLineCount < 3) {
            String addressLine2 = "";
            if (addressLineCount >= 2) {
                addressLine2 = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.AdrLine(1)");
            }
            if (StringUtil.isEmpty(addressLine2)) {
                if (isAllowedOptionC) {
                    tag = new Tag(tagName + "C", name);
                } else if (isAllowedOptionB) {
                    tag = new Tag(tagName + "B", name);
                } else {
                    buildSTErrorInfo(103, null, null);
                }
            } else {
                if (isAllowedOptionB) {
                    value = name + Mx2MtConstants.NEW_LINE + addressLine2;
                    tag = new Tag(tagName + "B", value);
                } else {
                    buildSTErrorInfo(103, null, null);
                }
            }
        } else if (StringUtil.isNotEmpty(clearingSystemMemberId)
                && (StringUtil.isEmpty(name) || (Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(name) && addressLineCount == 1))) {
            String clearingIdentifierGeneric = "";
            if (isAllowedClearingChannel) {
                clearingIdentifierGeneric = mx_to_mtClearingIdentifierAndChannel(agentPath, clearingChannelPath);
            }
            if (StringUtil.isEmpty(clearingIdentifierGeneric)){
                clearingIdentifierGeneric = mx_to_mtClearingIdentifier(agentPath);
            }
            if (StringUtil.isNotEmpty(addressLine1) && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
                if (isAllowedOptionB) {
                    value = clearingIdentifierGeneric + Mx2MtConstants.NEW_LINE + addressLine1;
                    tag = new Tag(tagName + "B", value);
                } else {
                    buildSTErrorInfo(103, null, null);
                }
            } else {
                if (isAllowedOptionC) {
                    tag = new Tag(tagName + "C", clearingIdentifierGeneric);
                } else if (isAllowedOptionB) {
                    tag = new Tag(tagName + "B", clearingIdentifierGeneric);
                } else {
                    value = clearingIdentifierGeneric + Mx2MtConstants.NEW_LINE + clearingIdentifierGeneric;
                    tag = new Tag(tagName + "D", value);
                }
            }
        } else if (StringUtil.isEmpty(clearingSystemMemberId) && StringUtil.isNotEmpty(account)
                && Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(name) && addressLineCount == 1) {
            if (StringUtil.isNotEmpty(addressLine1) && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
                 if (isAllowedOptionB) {
                     value = account + Mx2MtConstants.NEW_LINE + addressLine1;
                     tag = new Tag(tagName + "B", value);
                 } else {
                     buildSTErrorInfo(103, null, null);
                 }
             } else {
                if (isAllowedOptionC) {
                    tag = new Tag(tagName + "C", account);
                } else if (isAllowedOptionB) {
                    tag = new Tag(tagName + "B", account);
                } else {
                    buildSTErrorInfo(103, null, null);
                }
            }
        } else if (StringUtil.isEmpty(clearingSystemMemberId) && StringUtil.isEmpty(account)
                && Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(name)
                && addressLineCount == 1
                && (!Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1) || (isAllowedClearingChannel && "RTGS".equals(clearingChannal) && Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)))) {
             if (!Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
                 if (isAllowedOptionB) {
                     if (isAllowedClearingChannel && "RTGS".equals(clearingChannal)) {
                        String clearingIdentifierGeneric = mx_to_mtClearingIdentifierAndChannel(agentPath, clearingChannelPath);
                        value = clearingIdentifierGeneric + Mx2MtConstants.NEW_LINE + addressLine1;
                     } else {
                         value = addressLine1;
                     }
                     tag = new Tag(tagName + "B", value);
                 } else {
                     buildSTErrorInfo(103, null, null);
                 }
             } else { // isAllowedClearingChannel = true 且 clearingChannal = RTGS
                 String clearingIdentifierGeneric = mx_to_mtClearingIdentifierAndChannel(agentPath, clearingChannelPath);
                 if (isAllowedOptionC) {
                     tag = new Tag(tagName + "C", clearingIdentifierGeneric);
                 } else if (isAllowedOptionB) {
                     tag = new Tag(tagName + "B", clearingIdentifierGeneric);
                 } else {
                     buildSTErrorInfo(103, null, null);
                 }
             }
        } else {
            String nameAndAddress = "";
            String partyIdentifier = "";
            String countryCode = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.Ctry");
            if (addressLineCount > 0) {
                nameAndAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agentPath + ".FinInstnId");
            } else if (StringUtil.isNotEmpty(countryCode)) {
                nameAndAddress = mx_to_mtFinancialInstitutionNameAndStructuredAddress(agentPath + ".FinInstnId");
            } else if (StringUtil.isNotEmpty(name)){
                nameAndAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agentPath + ".FinInstnId");
            }  else {
                nameAndAddress = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            }
            if (StringUtil.isNotEmpty(clearingSystemMemberId)) {
                if (isAllowedClearingChannel && "RTGS".equals(clearingChannal)) {
                    partyIdentifier = mx_to_mtClearingIdentifierAndChannel(agentPath, clearingChannelPath);
                } else {
                    partyIdentifier = mx_to_mtClearingIdentifier(agentPath);
                }
            } else if (StringUtil.isNotEmpty(account)){
                partyIdentifier = account;
            } else if (isAllowedClearingChannel && "RTGS".equals(clearingChannal)){
                partyIdentifier = mx_to_mtClearingIdentifierAndChannel(agentPath, clearingChannelPath);
            }
            if (StringUtil.isEmpty(partyIdentifier)) {
                tag = new Tag(tagName + "D", nameAndAddress);
            } else {
                tag = new Tag(tagName + "D", partyIdentifier + Mx2MtConstants.NEW_LINE + nameAndAddress);
            }
        }
        return tag;
    }
    //转换函数方法区结束
}
