package com.brilliance.swift.mx2mt.mt103;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt103.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.util.XmlUtil;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.field.Field111;
import com.prowidesoftware.swift.model.field.Field119;
import com.prowidesoftware.swift.model.field.Field121;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class Mx2Mt103Creator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("CdtTrfTxInf"));
        String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
        int counts = getXmlNodeCounts(bodyParentPath, document, "CdtTrfTxInf");
        if (counts > 1) {
            buildSTErrorInfo(62, "CdtTrfTxInf", String.valueOf(counts));
        }
    }

    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String serviceType = "";
        int serviceLevelCount = getXmlNodeCounts(bodyParentPath, document, "CdtTrfTxInf.PmtTpInf.SvcLvl");
        if (serviceLevelCount > 0) {
            for (int i=0; i<serviceLevelCount; i++) {
                String serviceLevelCode = getXmlNodeValue(bodyParentPath, document, "CdtTrfTxInf.PmtTpInf.SvcLvl("+i+").Cd");
                if (StringUtil.isNotEmpty(serviceLevelCode) && serviceLevelCode.startsWith("G00")) {
                    serviceType = serviceLevelCode.substring(1);
                    break;
                }
            }
        }
        if (StringUtil.isNotEmpty(serviceType)) {
            Field111 field111 = new Field111(serviceType);
            block3.builder().setField111(field111);
        }
        String uetr = getXmlNodeValue(bodyParentPath, document, "CdtTrfTxInf.PmtId.UETR");
        if (StringUtil.isNotEmpty(uetr)) {
            Field121 field121 = new Field121(uetr);
            block3.builder().setField121(field121);
        }
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field13CGenerate());
        fieldsGenerateList.add(new Field23BGenerate());
        fieldsGenerateList.add(new Field23EGenerate());
        fieldsGenerateList.add(new Field26TGenerate());
        fieldsGenerateList.add(new Field32AGenerate());
        fieldsGenerateList.add(new Field33BGenerate());
        fieldsGenerateList.add(new Field36Generate());
        fieldsGenerateList.add(new Field50AGenerate());
        fieldsGenerateList.add(new Field51AGenerate());
        fieldsGenerateList.add(new Field52AGenerate());
        fieldsGenerateList.add(new Field53AGenerate());
        fieldsGenerateList.add(new Field54AGenerate());
        fieldsGenerateList.add(new Field55AGenerate());
        fieldsGenerateList.add(new Field56AGenerate());
        fieldsGenerateList.add(new Field57AGenerate());
        fieldsGenerateList.add(new Field59Generate());
        fieldsGenerateList.add(new Field70Generate());
        fieldsGenerateList.add(new Field71AGenerate());
        fieldsGenerateList.add(new Field72Generate());
        fieldsGenerateList.add(new Field77BGenerate());
        return fieldsGenerateList;
    }

    @Override
    public void postProcess() throws SwiftException {
        if (isStp()) {
            SwiftMessage swiftMessage = (SwiftMessage)context.get(SwiftMessage.class);
            Field119 field119 = new Field119("STP");
            swiftMessage.getBlock3().builder().setField119(field119);
        }
        super.postProcess();
    }

    @Override
    protected String getMtType() {
        return Mx2MtConstants.MT_TYPE_103;
    }

    /**
     * 通过官网的pacs00800108STP版本的XSD进行校验xml是否是STP版本
     * 这样MT就会在block3加{119:STP}
     * @return
     */
    private boolean isStp() {
        boolean stpFlag = true;
        try {
            String xml = (String) context.get(Mx2MtContextIdentifier.MX_XMl, true);
            String regex = "(\\<Document[\\w\\W]*\\<\\/Document\\>)";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(xml);
            String documentXml = "";
            if (m.find()) {
                documentXml = m.group(1);
            }
            if (StringUtil.isNotEmpty(documentXml)) {
                SwiftTransferUtil.schemaValidate("pacs00800108_STP", documentXml);
            }
        } catch (Exception e) {
            stpFlag = false;
        }
        return stpFlag;
    }
}
