package com.brilliance.swift.mx2mt.mt103.impl;


import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.util.List;

public class Field13CGenerate extends AbstractMx2MtTagsGenerate {

    private static String name = "13C";

    @Override
    public void tagGenerate() throws SwiftException {
        try {
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            String dbtDtTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmIndctn.DbtDtTm");
            if (StringUtil.isNotEmpty(dbtDtTmStr)) {
                XMLGregorianCalendar dbtDtTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(dbtDtTmStr);
                String timeOff = dbtDtTmStr.substring(dbtDtTmStr.length()-6);
                String[] timeOffs = timeOff.split(":");
                if (timeOffs.length == 2) {
                    String value = "/SNDTIME/" + (dbtDtTm.getHour()<10?"0"+dbtDtTm.getHour():dbtDtTm.getHour()) + (dbtDtTm.getMinute()<10?"0"+dbtDtTm.getMinute():dbtDtTm.getMinute()) + timeOffs[0] + timeOffs[1];
                    tags.add(new Tag(name, value));
                }
            }
            String cdtDtTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmIndctn.CdtDtTm");
            if (StringUtil.isNotEmpty(cdtDtTmStr)) {
                XMLGregorianCalendar cdtDtTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(cdtDtTmStr);
                String timeOff = cdtDtTmStr.substring(cdtDtTmStr.length()-6);
                String[] timeOffs = timeOff.split(":");
                if (timeOffs.length == 2) {
                    String value = "/RNCTIME/" + (cdtDtTm.getHour()<10?"0"+cdtDtTm.getHour():cdtDtTm.getHour()) + (cdtDtTm.getMinute()<10?"0"+cdtDtTm.getMinute():cdtDtTm.getMinute()) + timeOffs[0] + timeOffs[1];
                    tags.add(new Tag(name, value));
                }
            }
            String clsTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmReq.CLSTm");
            if (StringUtil.isNotEmpty(clsTmStr)) {
                XMLGregorianCalendar clsTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(clsTmStr);
                String timeOff = clsTmStr.substring(clsTmStr.length()-6);
                String[] timeOffs = timeOff.split(":");
                if (timeOffs.length == 2) {
                    String value = "/CLSTIME/" + (clsTm.getHour()<10?"0"+clsTm.getHour():clsTm.getHour()) + (clsTm.getMinute()<10?"0"+clsTm.getMinute():clsTm.getMinute()) + timeOffs[0] + timeOffs[1];
                    tags.add(new Tag(name, value));
                }
            }
            String tillTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmReq.TillTm");
            if (StringUtil.isNotEmpty(tillTmStr)) {
                XMLGregorianCalendar tillTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(tillTmStr);
                String timeOff = tillTmStr.substring(tillTmStr.length()-6);
                String[] timeOffs = timeOff.split(":");
                if (timeOffs.length == 2) {
                    String value = "/TILTIME/" + (tillTm.getHour()<10?"0"+tillTm.getHour():tillTm.getHour()) + (tillTm.getMinute()<10?"0"+tillTm.getMinute():tillTm.getMinute()) + timeOffs[0] + timeOffs[1];
                    tags.add(new Tag(name, value));
                }
            }
            String frTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmReq.FrTm");
            if (StringUtil.isNotEmpty(frTmStr)) {
                XMLGregorianCalendar frTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(frTmStr);
                String timeOff = frTmStr.substring(frTmStr.length()-6);
                String[] timeOffs = timeOff.split(":");
                if (timeOffs.length == 2) {
                    String value = "/FROTIME/" + (frTm.getHour()<10?"0"+frTm.getHour():frTm.getHour()) + (frTm.getMinute()<10?"0"+frTm.getMinute():frTm.getMinute()) + timeOffs[0] + timeOffs[1];
                    tags.add(new Tag(name, value));
                }
            }
            String rejTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmReq.RjctTm");
            if (StringUtil.isNotEmpty(rejTmStr)) {
                XMLGregorianCalendar rejTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(rejTmStr);
                String timeOff = rejTmStr.substring(rejTmStr.length()-6);
                String[] timeOffs = timeOff.split(":");
                if (timeOffs.length == 2) {
                    String value = "/REJTIME/" + (rejTm.getHour()<10?"0"+rejTm.getHour():rejTm.getHour()) + (rejTm.getMinute()<10?"0"+rejTm.getMinute():rejTm.getMinute()) + timeOffs[0] + timeOffs[1];
                    tags.add(new Tag(name, value));
                }
            }
        } catch(DatatypeConfigurationException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
