package com.brilliance.swift.mx2mt.mt103.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.CategoryPurposeCode;
import com.brilliance.swift.vo.common.ExternalCreditorAgentInstructionCode;
import com.brilliance.swift.vo.common.ServiceLevelCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.*;
import java.util.stream.Collectors;

/**
 *
 */
public class Field23EGenerate extends AbstractMx2MtTagsGenerate {

    private static String name = "23E";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/:23E:");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        List<String> code23EList = new ArrayList<>();
        boolean sdvcFlag = false;
        boolean intcCortFlag = false;
        //CdtTrfTxInf.PmtTpInf.SvcLvl
        int svcLvlCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.SvcLvl");
        if (svcLvlCount > 0) {
            for (int i=0; i<svcLvlCount; i++) {
                String code = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.SvcLvl("+i+").Cd");
                if (ServiceLevelCode.SDVA.value().equals(code)) {
                    code23EList.add(code);
                    sdvcFlag = true;
                    break;
                }
            }
        }
        //CdtTrfTxInf.PmtTpInf.CtgyPurp.Cd
        String ctgyPurpCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.CtgyPurp.Cd");
        String ctgyPurpProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.CtgyPurp.Prtry");
        if (CategoryPurposeCode.INTC.value().equals(ctgyPurpCode) || CategoryPurposeCode.CORT.value().equals(ctgyPurpCode)) {
            code23EList.add(ctgyPurpCode);
            intcCortFlag = true;
        } else {
            String proprietary = CategoryPurposeCode.INTC.value() + " " + CategoryPurposeCode.CORT.value();
            if (proprietary.equalsIgnoreCase(ctgyPurpProprietary)) {
                code23EList.add(CategoryPurposeCode.INTC.value());
                code23EList.add(CategoryPurposeCode.CORT.value());
                intcCortFlag = true;
            }
        }
        //CdtTrfTxInf.InstrForCdtrAgt
        int instrForCdtrAgtCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForCdtrAgt");
        if (instrForCdtrAgtCount > 0) {
            for (int i=0; i<instrForCdtrAgtCount; i++) {
                if (i == 2) break;//只取2个CdtrAgt
                String code = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForCdtrAgt("+i+").Cd");
                String instrInf = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForCdtrAgt("+i+").InstrInf");
                if (StringUtil.isNotEmpty(code)) {
                    code23EList.addAll(mx_to_mt23E(code, instrInf));
                } else if (StringUtil.isNotEmpty(instrInf)){
                    code23EList.addAll(mx_to_mt23E_BIS(instrInf));
                }
            }
        }
        //mapping转换文档 Translation Post Conditions -> POSTC0010
        code23EList = removeRepeatCode(code23EList);
        String errorLocation = "Block4/:23E:";
        List<String> list = new ArrayList<>();
        //mapping转换文档 Translation Post Conditions -> POSTC001
        //mapping转换文档 Translation Post Conditions -> POSTC002
        if (sdvcFlag || intcCortFlag) {
            boolean errorFlag = false;
            for (int i=0; i<code23EList.size(); i++) {
                if (code23EList.get(i).startsWith(ExternalCreditorAgentInstructionCode.HOLD.value()) || code23EList.get(i).startsWith(ExternalCreditorAgentInstructionCode.CHQB.value())) {
                    errorFlag = true;
                } else {
                    list.add(code23EList.get(i));
                }
            }
            if (errorFlag) {
                if (sdvcFlag) {
                    buildSTErrorInfo(44, errorLocation, null);
                }
                if (intcCortFlag) {
                    buildSTErrorInfo(45, errorLocation, null);
                }
            }
        } else {
            for (String code : code23EList) {
                list.add(code);
            }
        }
        //mapping转换文档 Translation Post Conditions -> POSTC005
        list = removeConflictCode(list, ExternalCreditorAgentInstructionCode.PHOB.value(), ExternalCreditorAgentInstructionCode.TELB.value(), 46, errorLocation);
        list = removeConflictCode(list, ExternalCreditorAgentInstructionCode.HOLD.value(), ExternalCreditorAgentInstructionCode.CHQB.value(), 47, errorLocation);
        if (list.size() > 0) {
            //排序 HOLD CHQB PHOB TELB
            list = list.stream().sorted((o1, o2) -> {
                if (getCodeOrder(o1) <= getCodeOrder(o2)) {
                    return -1;
                } else {
                    return 1;
                }
            }).collect(Collectors.toList());
            for (String value : list) {
                tags.add(new Tag(name, value));
            }
        }
    }

    private int getCodeOrder(String code) {
        if (code.startsWith(ExternalCreditorAgentInstructionCode.HOLD.value())) {
            return 0;
        } else if (code.startsWith(ExternalCreditorAgentInstructionCode.CHQB.value())) {
            return 1;
        } else if (code.startsWith(ExternalCreditorAgentInstructionCode.PHOB.value())) {
            return 2;
        } else if (code.startsWith(ExternalCreditorAgentInstructionCode.TELB.value())) {
            return 3;
        } else {
            return 4;
        }
    }

    /**
     * 移除冲突的code
     * code1 和 code2 冲突
     * @param list
     * @param code1
     * @param code2
     * @param errorId
     * @param location
     * @return
     */
    private List<String> removeConflictCode(List<String> list, String code1, String code2, long errorId, String location) {
        List<String> newList = new ArrayList<>();
        boolean existCode1Flag = false;
        for (String code : list) {
            if (code.startsWith(code1)) {
                existCode1Flag = true;
                break;
            }
        }
        if (existCode1Flag) {
            boolean errorFlag = false;
            for (String code : list) {
                if (code.startsWith(code2)) {
                    errorFlag = true;
                } else {
                    newList.add(code);
                }
            }
            if (errorFlag) {
                buildSTErrorInfo(errorId, location, null);
            }
            return newList;
        } else {
            return list;
        }
    }

    /**
     * 移除重复的code
     * "SDVA", "INTC", "CORT", "HOLD", "CHQB", "PHOB", "TELB"
     * @param code23EList
     * @return
     */
    private List<String> removeRepeatCode(List<String> code23EList) {
        Map<String, String> maps = new LinkedHashMap<>();
        for (String code : code23EList) {
            if (code.length() == 4) {
                maps.put(code, code);
            } else {
                if (!maps.containsKey(code.substring(0,5))) {
                    maps.put(code.substring(0,5), code);
                }
            }
        }
        String[] repeatCodes = new String[]{"SDVA", "INTC", "CORT", "HOLD", "CHQB", "PHOB", "TELB"};
        for (String repeatCode : repeatCodes) {
            if (maps.containsKey(repeatCode) && maps.containsKey(repeatCode+"/")) {
                maps.remove(repeatCode);
            }
        }
        List<String> list = new ArrayList<>();
        Set<String> keySets =  maps.keySet();
        for (String key : keySets) {
            list.add(maps.get(key));
        }
        return list;
    }
}
