package com.brilliance.swift.mx2mt.mt103.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field57A;
import com.prowidesoftware.swift.model.field.Field57B;
import com.prowidesoftware.swift.model.field.Field57D;

import java.util.List;

/**
 *对于所有代理行，如果xml报文中有代理行的bic，并且账户和清算代码都存在，则MT账号取账户；
 *  * 如果代理行没有bic，MT账号优先取清算代码，没有的话再取账户。
 */
public class Field57AGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "57A";

    private static String name_B = "57B";

    private static String name_C = "57C";

    private static String name_D = "57D";

    private static String name = "57";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/57a");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String agentPath = bodyHdrParentElementName + ".CdtTrfTxInf.CdtrAgt";
        String accountPath = bodyHdrParentElementName + ".CdtTrfTxInf.CdtrAgtAcct";
        String clearingChannelPath = bodyHdrParentElementName + ".CdtTrfTxInf.PmtTpInf.ClrChanl";
        Tag tag = mx_to_mtAgentGeneric(name, agentPath, accountPath,
                true, true, true, clearingChannelPath);
        if (tag != null) {
            if (name_D.equals(tag.getName())) {
                String value = mx_to_mtStartingLineCharacter(tag.getValue(), "Block4/:"+name_D+":");
                tag.setValue(value);
            }
            //mapping转换文档 Translation Post Conditions -> POSTC007
            String value = tag.getValue();
            String tagName = tag.getName();
            boolean flag = exist56aStartWithFWRT(tags);
            if (flag && (value.startsWith("//FW") || value.startsWith("//RT"))) {
                String tmp57aPartyIdentifier = mx_to_mtClearingIdentifier(agentPath);
                if (StringUtil.isEmpty(tmp57aPartyIdentifier) || tmp57aPartyIdentifier.startsWith("//FW")) {
                     if (tagName.equals(name_A)) {
                         Field57A field57A = (Field57A)tag.asField();
                         tag = new Tag(name_A, field57A.getBIC());
                         buildSTErrorInfo(105, "Block4/:"+tagName+":", null);
                     } else if (tagName.equals(name_D)) {
                         Field57D field57D = (Field57D)tag.asField();
                         if (!field57D.getNameAndAddress().startsWith("//")) {
                             tag = new Tag(name_D, field57D.getNameAndAddress());
                             buildSTErrorInfo(105, "Block4/:"+tagName+":", null);
                         } else if (StringUtil.isNotEmpty(tmp57aPartyIdentifier)) {
                             tag = new Tag(name_D, tmp57aPartyIdentifier + Mx2MtConstants.NEW_LINE + field57D.getNameAndAddress());
                         }
                     } else {
                         buildSTErrorInfo(106, "Block4/:"+tagName+":", null);
                     }
                } else {
                    if (tagName.equals(name_A)) {
                        Field57A field57A = (Field57A)tag.asField();
                        tag = new Tag(name_A, tmp57aPartyIdentifier + Mx2MtConstants.NEW_LINE + field57A.getBIC());
                    } else if (tagName.equals(name_B)) {
                        Field57B field57B = (Field57B)tag.asField();
                        tag = new Tag(name_B, tmp57aPartyIdentifier + Mx2MtConstants.NEW_LINE + field57B.getLocation());
                    } else if (tagName.equals(name_D)) {
                        Field57D field57D = (Field57D)tag.asField();
                        tag = new Tag(name_D, tmp57aPartyIdentifier + Mx2MtConstants.NEW_LINE + field57D.getNameAndAddress());
                    } else {
                        tag.setValue(tmp57aPartyIdentifier);
                    }
                }
            }
            tags.add(tag);
        }
    }

    /**
     * 56a 是否以 //FW or //RT 开始
     * @param tags
     * @return
     */
    private boolean exist56aStartWithFWRT(List<Tag> tags) {
        boolean flag = false;
        if (tags != null && tags.size() > 0) {
            for (int i=0; i<tags.size(); i++) {
                Tag tag = tags.get(i);
                if (tag.getName().matches("56[ACD]")) {
                    String value = tag.getValue();
                    if (value.startsWith("//FW") || value.startsWith("//RT")) {
                        flag = true;
                        break;
                    }
                }
            }
        }
        return flag;
    }
}
