package com.brilliance.swift.mx2mt.mt103.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.ChargeForEnum;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.math.BigDecimal;
import java.util.List;

/**
 *
 */
public class Field71AGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "71A";

    private static String name_F = "71F";

    private static String name_G = "71G";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String chrgBr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgBr");
        if (StringUtil.isNotEmpty(chrgBr)) {
            if (ChargeForEnum.CRED.value().equals(chrgBr)) {
                tags.add(new Tag(name_A, "BEN"));
            } else if (ChargeForEnum.DEBT.value().equals(chrgBr)) {
                tags.add(new Tag(name_A, "OUR"));
            } else if (ChargeForEnum.SHAR.value().equals(chrgBr)) {
                tags.add(new Tag(name_A, "SHA"));
            }
        }
        int chrgsInfCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf");
        if (chrgsInfCount > 0) {
            if (ChargeForEnum.CRED.value().equals(chrgBr) || ChargeForEnum.SHAR.value().equals(chrgBr)) {
                for (int i=0; i<chrgsInfCount; i++) {
                    String amt = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf("+i+").Amt");
                    String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf("+i+").Amt@Ccy");
                    if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                        tags.add(new Tag(name_F, ccy + NumberUtil.formatAmt(new BigDecimal(amt), ccy)));
                    }
                }
            } else {
                //mapping转换文档 Translation Post Conditions -> POSTC006
                String intrBkSttlmAmtCcy = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.IntrBkSttlmAmt@Ccy");
                BigDecimal sumAmt = BigDecimal.ZERO;
                for (int i=0; i<chrgsInfCount; i++) {
                    if (intrBkSttlmAmtCcy.equals(getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf("+i+").Amt@Ccy"))) {
                        BigDecimal tmpAmt = new BigDecimal(getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf("+i+").Amt"));
                        sumAmt = sumAmt.add(tmpAmt);
                    } else {
                        buildSTErrorInfo(39, "Block4/:"+name_G+":", null);
                        return;
                    }
                }
                if (NumberUtil.judgeAmtStrExceedLength(sumAmt.toPlainString(), 14)) {
                    buildSTErrorInfo(40, "Block4/:"+name_G+":", sumAmt.toPlainString());
                }
                tags.add(new Tag(name_G, intrBkSttlmAmtCcy + NumberUtil.formatAmt(sumAmt, intrBkSttlmAmtCcy)));
            }
        }
    }
}
