package com.brilliance.swift.mx2mt.mt103.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**
 *MTRegulatoryReportingConcatenated
 * 1.将报文中所有CdtTrfTxInf.RgltryRptg.Dtls.Inf有值的拼接起来组成MTRegulatoryReportingConcatenated
 * 2.如果MTRegulatoryReportingConcatenated不包含/ORDERRES/，并且CdtTrfTxInf.Dbtr.CtryOfRes有值，
 *   remainSpace = 105 - MTRegulatoryReportingConcatenated - 10(/ORDERRES/的长度)
 *   ①如果remainSpace长度大于0，但是remainSpace长度大于CdtTrfTxInf.Dbtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /ORDERRES/ + CdtTrfTxInf.Dbtr.CtryOfRes
 *   ②如果remainSpace长度大于0，但是remainSpace长度不大于CdtTrfTxInf.Dbtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /ORDERRES/ + CdtTrfTxInf.Dbtr.CtryOfRes截取到remainSpace-1位，最后一位给+
 * 2.如果MTRegulatoryReportingConcatenated不包含/BENEFRES/，并且CdtTrfTxInf.Cdtr.CtryOfRes有值，
 *   remainSpace = 105 - MTRegulatoryReportingConcatenated - 10(/BENEFRES/的长度)
 *   ①如果remainSpace长度大于0，但是remainSpace长度大于CdtTrfTxInf.Cdtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /BENEFRES/ + CdtTrfTxInf.Cdtr.CtryOfRes
 *   ②如果remainSpace长度大于0，但是remainSpace长度不大于CdtTrfTxInf.Cdtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /BENEFRES/ + CdtTrfTxInf.Cdtr.CtryOfRes截取到remainSpace-1位，最后一位给+
 * 3.如果MTRegulatoryReportingConcatenated长度大于105，MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated截取到104位，最后一位给+
 * 4.将MTRegulatoryReportingConcatenated组装成3*35
 */
public class Field77BGenerate extends AbstractMx2MtTagsGenerate {

    private static String name = "77B";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/:77B:");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String mtRegulatoryReporting = "";
        int mxRegulatoryReportingCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.RgltryRptg");
        if (mxRegulatoryReportingCount > 0) {
            for (int i=0; i<mxRegulatoryReportingCount; i++) {
                int mxRegulatoryReportingDetailCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.RgltryRptg("+i+").Dtls");
                if (mxRegulatoryReportingDetailCount > 0) {
                    for (int j=0; j<mxRegulatoryReportingDetailCount; j++) {
                        int mxRegulatoryReportingDetailInfCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Inf");
                        if (mxRegulatoryReportingDetailInfCount > 0) {
                            for (int k=0; k<mxRegulatoryReportingDetailInfCount; k++) {
                                if (StringUtil.isEmpty(mtRegulatoryReporting)) {
                                    mtRegulatoryReporting = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Inf("+k+")");
                                } else {
                                    mtRegulatoryReporting += " " + getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Inf("+k+")");
                                }
                            }
                        }
                    }
                }
            }
        }
        if (mtRegulatoryReporting.indexOf("/ORDERRES/") == -1) {
            int remainLength = 105 - mtRegulatoryReporting.length() - 10;
            if (remainLength > 0) {
                String ctryOfRes = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.Dbtr.CtryOfRes");
                if (StringUtil.isNotEmpty(ctryOfRes)) {
                    if (remainLength < ctryOfRes.length()) {
                        mtRegulatoryReporting = mtRegulatoryReporting + "/ORDERRES/" + ctryOfRes.substring(0, remainLength-1) + "+";
                    } else {
                        mtRegulatoryReporting = mtRegulatoryReporting + "/ORDERRES/" + ctryOfRes;
                    }
                }
            }
        }
        if (mtRegulatoryReporting.indexOf("/BENEFRES/") == -1) {
            int remainLength = 105 - mtRegulatoryReporting.length() - 10;
            if (remainLength > 0) {
                String ctryOfRes = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.Cdtr.CtryOfRes");
                if (StringUtil.isNotEmpty(ctryOfRes)) {
                    if (remainLength < ctryOfRes.length()) {
                        mtRegulatoryReporting = mtRegulatoryReporting + "/BENEFRES/" + ctryOfRes.substring(0, remainLength-1) + "+";
                    } else {
                        mtRegulatoryReporting = mtRegulatoryReporting + "/BENEFRES/" + ctryOfRes;
                    }
                }
            }
        }
        if (mtRegulatoryReporting.length() > 105) {
            buildSTErrorInfo(12, "Block4/:77B:", mtRegulatoryReporting);
            mtRegulatoryReporting = mtRegulatoryReporting.substring(0, 104) + "+";
        }
        if (StringUtil.isNotEmpty(mtRegulatoryReporting)) {
            String value = StringUtil.getStringByEnter(mtRegulatoryReporting, 35, 3);
            value = mx_to_mtStartingLineCharacter(value, "Block4/:77B:");
            tags.add(new Tag(name, value));
        }
    }
}

