package com.brilliance.swift.mx2mt.mt103Retn.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**
 *
 */
public class Field50AGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "50A";

    private static String name_F = "50F";

    private static String name_K = "50K";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/50a");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        int partyCount = getXmlNodeCounts(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty");
        int agtCount = getXmlNodeCounts(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Agt");
        if (partyCount > 0) {
            String partyPath = bodyHdrParentElementName + ".TxInf.RtrChain.Dbtr.Pty";
            String bicCode = mx_to_mtAnyBIC(partyPath);
            String countryCode = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.PstlAdr.Ctry");
            String name = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.Nm");
            int addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.PstlAdr.AdrLine");
            String addressLine1 = "";
            if (addressLineCount > 0) {
                addressLine1 = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.PstlAdr.AdrLine(0)");
            }
            if (StringUtil.isNotEmpty(bicCode)) {
                tags.add(new Tag(name_A, bicCode));
            } else if (StringUtil.isNotEmpty(countryCode)) {
                String nameAddress = mx_to_mtFATFNameAndAddress(partyPath);
                String account = mx_to_mtFATFIdentification(partyPath, false);
                if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                    account = account.substring(0, 35);
                }
                if (StringUtil.isEmpty(account)) {
                    account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                tags.add(new Tag(name_F, account + Mx2MtConstants.NEW_LINE + nameAddress));
            } else if (addressLineCount > 0 && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
                boolean structuredAddressIndicator = mx_to_mtAddressLineType(partyPath);
                if (structuredAddressIndicator) {
                    String nameAddress = mx_to_mtFATFNameAndAddress2(partyPath);
                    String account = mx_to_mtFATFIdentification(partyPath, true);
                    if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                        account = account.substring(0, 35);
                    }
                    if (StringUtil.isEmpty(account)) {
                        account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                    tags.add(new Tag(name_F, account + Mx2MtConstants.NEW_LINE + nameAddress));
                } else {
                    String mtNameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                    mtNameAddress = mx_to_mtStartingLineCharacter(mtNameAddress, "Block4/:50k:");
                    tags.add(new Tag(name_K, mtNameAddress));
                }
            } else /*if (StringUtil.isNotEmpty(name))*/ {
                String mtNameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                mtNameAddress = mx_to_mtStartingLineCharacter(mtNameAddress, "Block4/:50k:");
                tags.add(new Tag(name_K, mtNameAddress));
            }
        } else if (agtCount > 0) {
            String agtPath = bodyHdrParentElementName + ".TxInf.RtrChain.Dbtr.Agt";
            String bicCode = mx_to_mtBICFI(agtPath);
            String countryCode = getXmlNodeValue(null, document, agtPath + ".FinInstnId.PstlAdr.Ctry");
            String agtName = getXmlNodeValue(null, document, agtPath + ".FinInstnId.Nm");
            String clearingMemberId = getXmlNodeValue(null, document, agtPath + ".FinInstnId.ClrSysMmbId.MmbId");
            int addressLineCount = getXmlNodeCounts(null, document, agtPath + ".FinInstnId.PstlAdr.AdrLine");
            if (StringUtil.isNotEmpty(bicCode)) {
                tags.add(new Tag(name_A, bicCode));
            } else if (StringUtil.isNotEmpty(countryCode)) {
                String nameAddress = mx_to_mtFinancialInstitutionNameAndStructuredAddress(agtPath + ".FinInstnId");
                nameAddress = mx_to_mtStartingLineCharacter(nameAddress, "Block4/:50k:");
                tags.add(new Tag(name_K, nameAddress));
            } else if (addressLineCount > 0 || StringUtil.isNotEmpty(agtName)) {
                String nameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agtPath + ".FinInstnId");
                nameAddress = mx_to_mtStartingLineCharacter(nameAddress, "Block4/:50k:");
                tags.add(new Tag(name_K, nameAddress));
            } else if (StringUtil.isNotEmpty(clearingMemberId)) {
                buildSTErrorInfo(32, "Block4/:50k:", null);
                String value = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE + Mx2MtConstants.NEW_LINE + mx_to_mtClearingIdentifier(agtPath);
                value = mx_to_mtStartingLineCharacter(value, "Block4/:50k:");
                tags.add(new Tag(name_K, value));
            }
        }
    }
}
