package com.brilliance.swift.mx2mt.mt103Retn.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**
 *1.如果bicCode = MX_To_MTAnyBIC(CdtTrfTxInf.Cdtr)有值，就是59A，account = MX_To_MTAccount(CdtTrfTxInf.CdtrAcct)
 * 2.如果CdtTrfTxInf.Cdtr.PstlAdr.Ctry有值，就是59F，nameAddress = MX_To_MTPartyNameAndAddressLEI1(CdtTrfTxInf.Cdtr),account = MX_To_MTAccount(CdtTrfTxInf.CdtrAcct)
 * 3.如果CdtTrfTxInf.Cdtr.PstlAdr.AdrLine有值,StructuredAddressIndicator = MX_To_MTAddressLineType(CdtTrfTxInf.Cdtr)
 *   如果StructuredAddressIndicator = true, 就是59F,nameAddress = MX_To_MTPartyNameAndAddressLEI2(CdtTrfTxInf.Cdtr),account = MX_To_MTAccount(CdtTrfTxInf.CdtrAcct)
 *   如果StructuredAddressIndicator = false, 就是59, nameAddress = MX_To_MTPartyNameAndUnstructuredAddress(CdtTrfTxInf.Cdtr),account = MX_To_MTAccount(CdtTrfTxInf.CdtrAcct)
 * 4.如果CdtTrfTxInf.Cdtr.Nm有值，就是59, nameAddress = MX_To_MTPartyNameAndUnstructuredAddress(CdtTrfTxInf.Cdtr),account = MX_To_MTAccount(CdtTrfTxInf.CdtrAcct)
 *
 * **/
public class Field59Generate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "59A";

    private static String name_F = "59F";

    private static String name = "59";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/59a");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        int partyCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".TxInf.RtrChain.Cdtr.Pty");
        int agentCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".TxInf.RtrChain.Cdtr.Agt");
        if (partyCount > 0) {
            String partyPath = bodyHdrParentElementName + ".TxInf.RtrChain.Cdtr.Pty";
            String bicCode = mx_to_mtAnyBIC(partyPath);
            String countryCode = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Cdtr.Pty.PstlAdr.Ctry");
            int addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "TxInf.RtrChain.Cdtr.Pty.PstlAdr.AdrLine");
            String addressLine1 = "";
            if (addressLineCount > 0) {
                addressLine1 = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Cdtr.Pty.PstlAdr.AdrLine(0)");
            }
            String partyName = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Cdtr.Pty.Nm");
            if (StringUtil.isNotEmpty(bicCode)) {
                tags.add(new Tag(name_A, bicCode));
            } else if (StringUtil.isNotEmpty(countryCode)){
                String nameAddress = mx_to_mtPartyNameAndAddressLEI1(partyPath);
                tags.add(new Tag(name_F, nameAddress));
            } else if (addressLineCount > 0 && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)){
                boolean structuredAddressIndicator = mx_to_mtAddressLineType(partyPath);
                if (structuredAddressIndicator) {
                    String nameAddress = mx_to_mtPartyNameAndAddressLEI2(partyPath, "3/");
                    tags.add(new Tag(name_F, nameAddress));
                } else {
                    String nameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                    nameAddress = mx_to_mtStartingLineCharacter(nameAddress, "Block4/:59:");
                    tags.add(new Tag(name, nameAddress));
                }
            } else /*if (StringUtil.isNotEmpty(partyName))*/{
                String nameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                nameAddress = mx_to_mtStartingLineCharacter(nameAddress, "Block4/:59:");
                tags.add(new Tag(name, nameAddress));
            }
        } else if (agentCount > 0) {
            String agtPath = bodyHdrParentElementName + "TxInf.RtrChain.Cdtr.Agt";
            String value = "";
            String bicCode = mx_to_mtBICFI(agtPath);
            String countryCode = getXmlNodeValue(null, document, agtPath + ".FinInstnId.PstlAdr.Ctry");
            String agtName = getXmlNodeValue(null, document, agtPath + ".FinInstnId.Nm");
            String clearingMemberId = getXmlNodeValue(null, document, agtPath + ".FinInstnId.ClrSysMmbId.MmbI");
            int addressLineCount = getXmlNodeCounts(null, document, agtPath + ".FinInstnId.PstlAdr.AdrLine");
            if (StringUtil.isNotEmpty(bicCode)) {
                value = bicCode;
                tags.add(new Tag(name_A, value));
            } else if (StringUtil.isNotEmpty(countryCode)) {
                value = mx_to_mtFinancialInstitutionNameAndStructuredAddress(agtPath + ".FinInstnId");
                value = mx_to_mtStartingLineCharacter(value, "Block4/:59:");
                tags.add(new Tag(name, value));
            } else if (addressLineCount > 0 || StringUtil.isNotEmpty(agtName)) {
                value = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agtPath + ".FinInstnId");
                value = mx_to_mtStartingLineCharacter(value, "Block4/:59:");
                tags.add(new Tag(name, value));
            } else if (StringUtil.isNotEmpty(clearingMemberId)) {
                buildSTErrorInfo(33, "Block4/:59:", null);
                value = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE + Mx2MtConstants.NEW_LINE + mx_to_mtClearingIdentifier(agtPath);
                value = mx_to_mtStartingLineCharacter(value, "Block4/:59:");
                tags.add(new Tag(name, value));
            }
        }
    }
}
