package com.brilliance.swift.mx2mt.mt103Retn.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**
 *MTRegulatoryReportingConcatenated
 * 1.将报文中所有CdtTrfTxInf.RgltryRptg.Dtls.Inf有值的拼接起来组成MTRegulatoryReportingConcatenated
 * 2.如果MTRegulatoryReportingConcatenated不包含/ORDERRES/，并且CdtTrfTxInf.Dbtr.CtryOfRes有值，
 *   remainSpace = 105 - MTRegulatoryReportingConcatenated - 10(/ORDERRES/的长度)
 *   ①如果remainSpace长度大于0，但是remainSpace长度大于CdtTrfTxInf.Dbtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /ORDERRES/ + CdtTrfTxInf.Dbtr.CtryOfRes
 *   ②如果remainSpace长度大于0，但是remainSpace长度不大于CdtTrfTxInf.Dbtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /ORDERRES/ + CdtTrfTxInf.Dbtr.CtryOfRes截取到remainSpace-1位，最后一位给+
 * 2.如果MTRegulatoryReportingConcatenated不包含/BENEFRES/，并且CdtTrfTxInf.Cdtr.CtryOfRes有值，
 *   remainSpace = 105 - MTRegulatoryReportingConcatenated - 10(/BENEFRES/的长度)
 *   ①如果remainSpace长度大于0，但是remainSpace长度大于CdtTrfTxInf.Cdtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /BENEFRES/ + CdtTrfTxInf.Cdtr.CtryOfRes
 *   ②如果remainSpace长度大于0，但是remainSpace长度不大于CdtTrfTxInf.Cdtr.CtryOfRes长度
 *   MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated + /BENEFRES/ + CdtTrfTxInf.Cdtr.CtryOfRes截取到remainSpace-1位，最后一位给+
 * 3.如果MTRegulatoryReportingConcatenated长度大于105，MTRegulatoryReportingConcatenated = MTRegulatoryReportingConcatenated截取到104位，最后一位给+
 * 4.将MTRegulatoryReportingConcatenated组装成3*35
 */
public class Field77BGenerate extends AbstractMx2MtTagsGenerate {

    private static String name = "77B";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String value = "";
        String cdtrCtryOfRes = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Cdtr.Pty.CtryOfRes");
        if (StringUtil.isNotEmpty(cdtrCtryOfRes)) {
            value= "/BENEFRES/" + cdtrCtryOfRes;
        }
        String dbtrCtryOfRes = getXmlNodeValue(bodyHdrParentElementName, document, "TxInf.RtrChain.Dbtr.Pty.CtryOfRes");
        if (StringUtil.isNotEmpty(dbtrCtryOfRes)) {
            if (StringUtil.isNotEmpty(value)) {
                value += Mx2MtConstants.NEW_LINE + dbtrCtryOfRes;
            } else {
                value= "/ORDERRES/" + dbtrCtryOfRes;
            }
        }
        if (StringUtil.isNotEmpty(value)) {
            value = mx_to_mtStartingLineCharacter(value, "Block4/:77B:");
            tags.add(new Tag(name, value));
        }
    }
}

