package com.brilliance.swift.mx2mt.mt202cov202.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.CategoryPurposeCode;
import com.brilliance.swift.vo.common.ServiceLevelCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.ArrayList;
import java.util.List;

/**
 * MX_To_MT72FullField2
 * 参数列表
 * 参数1：CdtTrfTxInf.IntrmyAgt2/CdtTrfTxInf.IntrmyAgt3
 * 参数2：CdtTrfTxInf.PmtTpInf.SvcLvl
 * 参数3：CdtTrfTxInf.PmtTpInf.LclInstrm
 * 参数4：CdtTrfTxInf.PmtTpInf.CtgyPurp
 * 参数5：CdtTrfTxInf.InstrForCdtrAgt
 * 参数6：CdtTrfTxInf.Purp
 * 参数7：CdtTrfTxInf.InstrForNxtAgt
 * 参数8：CdtTrfTxInf.DbtrAgt
 * 参数9：CdtTrfTxInf.PrvsInstgAgt1/CdtTrfTxInf.PrvsInstgAgt2/CdtTrfTxInf.PrvsInstgAgt3
 * 参数10：CdtTrfTxInf.RmtInf
 * MT72取值逻辑：
 *  1.如果传入参数1，MT72=/INTA/MX_To_MTAgent(参数1)
 *  2.如果传入参数2，并且CdtTrfTxInf.PmtTpInf.SvcLvl.Cd 不是SDVA也不是G00n（n代表0-9数字）或者CdtTrfTxInf.PmtTpInf.SvcLvl.Prtry有值，MT72=/SVCLVL/+CdtTrfTxInf.PmtTpInf.SvcLvl.Prtry或者/SVCLVL/+CdtTrfTxInf.PmtTpInf.SvcLvl.Cd,最多找前3条
 *  3.如果传入参数3，并且CdtTrfTxInf.PmtTpInf.LclInstrm.Cd有值或者CdtTrfTxInf.PmtTpInf.LclInstrm.Prtry且不在{CRED,CRTS,SPAY,SPRI, SSTD}里面，MT72=/LOCINS/+CdtTrfTxInf.PmtTpInf.LclInstrm.Prtry或者CdtTrfTxInf.PmtTpInf.LclInstrm.Cd
 *  4.如果传入参数4，并且CdtTrfTxInf.PmtTpInf.CtgyPurp.Cd不在{INTC, CORT}或者CdtTrfTxInf.PmtTpInf.CtgyPurp.Prtry不在{“INTC CORT”，INTC, CORT}，MT72=/CATPURP/+CdtTrfTxInf.PmtTpInf.CtgyPurp.Prtry或者/CATPURP/+CdtTrfTxInf.PmtTpInf.CtgyPurp.Cd
 *  5.如果传入参数5，CdtTrfTxInf.InstrForCdtrAgt.Cd过滤掉HOLD/PHOB/TELB，MT72=/ACC/+CdtTrfTxInf.InstrForCdtrAgt.InstrInf
 *  6.如果传入参数6，MT72=/PURP/+CdtTrfTxInf.Purp.Prtry 或者/PURP/+CdtTrfTxInf.Purp.Cd
 *  7.如果传入参数7，CdtTrfTxInf.InstrForNxtAgt.InstrInf过滤掉“/FIN53/BIC” 结构，MT72=/REC/+CdtTrfTxInf.InstrForNxtAgt.InstrInf
 *  8.如果传入参数8，MT72= /INS/+MX_To_MTBICNameAgent(CdtTrfTxInf.DbtrAgt, 210)
 *  9.如果传入参数9，
 *    ①如果CdtTrfTxInf.PrvsInstgAgt1存在，MT72=/INS/+MX_To_MTBICNameAgent(CdtTrfTxInf.PrvsInstgAgt1, 210)
 *    ②如果CdtTrfTxInf.PrvsInstgAgt2存在，MT72=/INS/+MX_To_MTBICNameAgent(CdtTrfTxInf.PrvsInstgAgt2, 210)
 *    ③如果CdtTrfTxInf.PrvsInstgAgt3存在，MT72=/INS/+MX_To_MTBICNameAgent(CdtTrfTxInf.PrvsInstgAgt3, 210)
 *    组装MT72：根据优先级最多取到7条MT72，每条MT72每行取35字符，分行用//连接，最多取6*35
 *  10.如果传入参数10，MT72 = SubfunctionRemittanceInformation(参数10)
 */
public class Field72Generate extends AbstractMx2MtTagsGenerate {

    private static String name = "72";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/:72:");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        List<String> mt72List = new ArrayList<>();
        //参数1
        String mtIntrmyAgt = mx_to_mtAgent(bodyHdrParentElementName + ".CdtTrfTxInf.IntrmyAgt2", 6);
        if (StringUtil.isEmpty(mtIntrmyAgt)) {
            mtIntrmyAgt = mx_to_mtAgent(bodyHdrParentElementName + ".CdtTrfTxInf.IntrmyAgt3", 6);
        }
        if (StringUtil.isNotEmpty(mtIntrmyAgt)) {
            mt72List.add("/INTA/" + mtIntrmyAgt);
        }
        //参数2
        int svcLvlCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.SvcLvl");
        if (svcLvlCount > 0) {
            for (int i=0; i<svcLvlCount; i++) {
                if (i == 3) break;
                String svcLvlCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.SvcLvl(" + i + ").Cd");
                String svcLvlProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.SvcLvl(" + i + ").Prtry");
                if (StringUtil.isNotEmpty(svcLvlProprietary)) {
                    mt72List.add("/SVCLVL/" + svcLvlProprietary);
                } else {
                    if (!ServiceLevelCode.SDVA.value().equals(svcLvlCode) && svcLvlCode.indexOf("G00") == -1) {
                        mt72List.add("/SVCLVL/" + svcLvlCode);
                    }
                }
            }
        }
        //参数3
        String localInstrumentCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.LclInstrm.Cd");
        String localInstrumentProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.LclInstrm.Prtry");
        if (StringUtil.isNotEmpty(localInstrumentProprietary)
                && !"CRED".equalsIgnoreCase(localInstrumentProprietary)
                && !"CRTS".equalsIgnoreCase(localInstrumentProprietary)
                && !"SPAY".equalsIgnoreCase(localInstrumentProprietary)
                && !"SPRI".equalsIgnoreCase(localInstrumentProprietary)
                && !"SSTD".equalsIgnoreCase(localInstrumentProprietary)) {
            mt72List.add("/LOCINS/" + localInstrumentProprietary);
        } else if (StringUtil.isNotEmpty(localInstrumentCode)){
            mt72List.add("/LOCINS/" + localInstrumentCode);
        }

        //参数4
        String ctgyPurpCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.CtgyPurp.Cd");
        String ctgyPurpProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtTpInf.CtgyPurp.Prtry");
        if (StringUtil.isNotEmpty(ctgyPurpProprietary)
                && !"INTC CORT".equalsIgnoreCase(ctgyPurpProprietary)
                && !"INTC".equalsIgnoreCase(ctgyPurpProprietary)
                && !"CORT".equalsIgnoreCase(ctgyPurpProprietary)) {
            mt72List.add("/CATPURP/" + ctgyPurpProprietary);
        } else if (StringUtil.isNotEmpty(ctgyPurpCode)
                && !CategoryPurposeCode.INTC.value().equalsIgnoreCase(ctgyPurpCode)
                && !CategoryPurposeCode.CORT.value().equalsIgnoreCase(ctgyPurpCode)) {
            mt72List.add("/CATPURP/" + ctgyPurpCode);
        }

        //参数5
        List<String> mtCreditorAgts = subFunctionInstructionForCreditorAgent(bodyHdrParentElementName + ".CdtTrfTxInf.InstrForCdtrAgt");
        if (mtCreditorAgts.size() > 0) {
            mt72List.addAll(mtCreditorAgts);
        }
        //参数6
        String mxPurposeCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.Purp.Cd");
        String mxPurposeProprietary = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.Purp.Prtry");
        if (StringUtil.isNotEmpty(mxPurposeProprietary)) {
            mt72List.add("/PURP/" + mxPurposeProprietary);
        } else if (StringUtil.isNotEmpty(mxPurposeCode)) {
            mt72List.add("/PURP/" + mxPurposeCode);
        }
        //参数7
        String settlementMethod = getXmlNodeValue(grpHdrParentElementName, document, "GrpHdr.SttlmInf.SttlmMtd");
        List<String> mtNextAgts = subFunctionInstructionForNextAgent(bodyHdrParentElementName + ".CdtTrfTxInf.InstrForNxtAgt", settlementMethod);
        if (mtNextAgts.size() > 0) {
            mt72List.addAll(mtNextAgts);
        }
        //参数8
        String mtDbtrAgt = mx_to_mtBICNameAgent(bodyHdrParentElementName + ".CdtTrfTxInf.DbtrAgt", 210);
        if (StringUtil.isNotEmpty(mtDbtrAgt)) {
            mt72List.add("/INS/" + mtDbtrAgt);
        }
        //参数9
        String mtPrvsInstgAgt = mx_to_mtBICNameAgent(bodyHdrParentElementName + ".CdtTrfTxInf.PrvsInstgAgt1", 210);
        if (StringUtil.isEmpty(mtPrvsInstgAgt)) {
            mtPrvsInstgAgt = mx_to_mtBICNameAgent(bodyHdrParentElementName + ".CdtTrfTxInf.PrvsInstgAgt2", 210);
        }
        if (StringUtil.isEmpty(mtPrvsInstgAgt)) {
            mtPrvsInstgAgt = mx_to_mtBICNameAgent(bodyHdrParentElementName + ".CdtTrfTxInf.PrvsInstgAgt3", 210);
        }
        if (StringUtil.isNotEmpty(mtPrvsInstgAgt)) {
            mt72List.add("/INS/" + mtPrvsInstgAgt);
        }

        //参数10
        String mtRemittanceInfo = subFunctionRemittanceInformation(bodyHdrParentElementName + ".CdtTrfTxInf.RmtInf");
        if (StringUtil.isNotEmpty(mtRemittanceInfo)) {
            mt72List.add(mtRemittanceInfo);
        }
        if (mt72List.size() > 0) {
            List<String> list = new ArrayList<>();
            for (int i=0; i<mt72List.size(); i++) {
                String mt72FullField = mt72List.get(i);
                List<String> tmplist = StringUtil.outStringList(mt72FullField, 35, "//");
                list.addAll(tmplist);
            }
            String value = "";
            for (int i=0; i<list.size(); i++) {
                if (i == 6) break;
                if (i == 0) {
                    value = list.get(i);
                } else {
                    value += Mx2MtConstants.NEW_LINE + list.get(i);
                }
            }
            value = mx_to_mtStartingLineCharacter(value, "Block4/:72:");
            tags.add(new Tag(name, value));
        }
    }
}
