package com.brilliance.swift.mx2mt.mt210.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**

 */
public class Field50aGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_ = "50";

    private static String name_C = "50C";

    private static String name_F = "50F";


    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/50a");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String partyPath = "";
        int partyCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".Ntfctn.Dbtr.Pty");
        if (partyCount > 0) {
            partyPath = bodyHdrParentElementName + ".Ntfctn.Dbtr.Pty";
        } else {
            partyCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".Ntfctn.Itm.Dbtr.Pty");
            if (partyCount > 0) {
                partyPath = bodyHdrParentElementName + ".Ntfctn.Itm.Dbtr.Pty";
            }
        }
        String agentPath = "";
        int agentCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".Ntfctn.Dbtr.Agt");
        if (agentCount > 0) {
            agentPath = bodyHdrParentElementName + ".Ntfctn.Dbtr.Agt";
        } else {
            agentCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".Ntfctn.Itm.Dbtr.Agt");
            if (agentCount > 0) {
                agentPath = bodyHdrParentElementName + ".Ntfctn.Itm.Dbtr.Agt";
            }
        }
        if (partyCount == 0 && agentCount == 0) {
            return;
        }
        int otherAgtPathCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".Ntfctn.DbtrAgt");
        if (otherAgtPathCount == 0) {
            otherAgtPathCount = getXmlNodeCounts(null, document, bodyHdrParentElementName + ".Ntfctn.Itm.DbtrAgt");
        }
        if (partyCount > 0) {
            String bicCode = mx_to_mtAnyBIC(partyPath);
            String countryCode = getXmlNodeValue(null, document, partyPath + ".PstlAdr.Ctry");
            int addressLineCount = getXmlNodeCounts(null, document, partyPath + ".PstlAdr.AdrLine");
            String partyName = getXmlNodeValue(null, document, partyPath + ".Nm");
            if (StringUtil.isNotEmpty(bicCode)) {
                tags.add(new Tag(name_C, bicCode));
            } else if (StringUtil.isNotEmpty(countryCode)) {
                String nameAddress = mx_to_mtFATFNameAndAddress(partyPath);
                String account = mx_to_mtFATFIdentification(partyPath, false);
                if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                    account = account.substring(0, 35);
                }
                if (StringUtil.isEmpty(account)) {
                    account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                tags.add(new Tag(name_F, account + Mx2MtConstants.NEW_LINE + nameAddress));
            } else if (addressLineCount > 0) {
                boolean structuredAddressIndicator = mx_to_mtAddressLineType(partyPath);
                if (structuredAddressIndicator) {
                    String nameAddress = mx_to_mtFATFNameAndAddress2(partyPath);
                    String account = mx_to_mtFATFIdentification(partyPath, true);
                    if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                        account = account.substring(0, 35);
                    }
                    if (StringUtil.isEmpty(account)) {
                        account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                    tags.add(new Tag(name_F, account + Mx2MtConstants.NEW_LINE + nameAddress));
                } else {
                    String mtNameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                    mtNameAddress = mx_to_mtStartingLineCharacter(mtNameAddress, "Block4/:50:");
                    tags.add(new Tag(name_, mtNameAddress));
                }
            } else if (StringUtil.isNotEmpty(partyName)) {
                String mtNameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                mtNameAddress = mx_to_mtStartingLineCharacter(mtNameAddress, "Block4/:50:");
                tags.add(new Tag(name_, mtNameAddress));
            }
            if (otherAgtPathCount > 0) {
                buildSTErrorInfo(82, "Block4/50a", null);
            }
        } else if (agentCount > 0) {
            String bicCode = mx_to_mtBICFI(agentPath);
            String countryCode = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.Ctry");
            String agtName = getXmlNodeValue(null, document, agentPath + ".FinInstnId.Nm");
            String clearingMemberId = getXmlNodeValue(null, document, agentPath + ".FinInstnId.ClrSysMmbId.MmbId");
            int addressLineCount = getXmlNodeCounts(null, document, agentPath + ".FinInstnId.PstlAdr.AdrLine");
            if (StringUtil.isNotEmpty(bicCode)) {
                tags.add(new Tag(name_C, bicCode));
            } else if (StringUtil.isNotEmpty(countryCode)) {
                String nameAddress = mx_to_mtFinancialInstitutionNameAndStructuredAddress(agentPath + ".FinInstnId");
                nameAddress = mx_to_mtStartingLineCharacter(nameAddress, "Block4/:50:");
                tags.add(new Tag(name_, nameAddress));
            } else if (addressLineCount > 0 || StringUtil.isNotEmpty(agtName)) {
                String nameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agentPath + ".FinInstnId");
                nameAddress = mx_to_mtStartingLineCharacter(nameAddress, "Block4/:50:");
                tags.add(new Tag(name_, nameAddress));
            } else if (StringUtil.isNotEmpty(clearingMemberId)) {
                buildSTErrorInfo(32, "Block4/:50:", null);
                String value = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE + Mx2MtConstants.NEW_LINE + mx_to_mtClearingIdentifier(agentPath);
                value = mx_to_mtStartingLineCharacter(value, "Block4/:50:");
                tags.add(new Tag(name_, value));
            }
            if (otherAgtPathCount > 0) {
                buildSTErrorInfo(82, "Block4/50a", null);
            }
        }
    }
}
