package com.brilliance.swift.mx2mt.mt900910.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mx.dic.CreditDebitCode;

import java.util.List;

/**
 * 50A
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><Dbtr><Pty><Id><OrgId><AnyBIC>
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><DbtrAcct><Id><IBAN>
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><DbtrAcct><Id><Othr><Id>
 *
 * 50K
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><Dbtr><Pty><Nm>
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><Dbtr><Pty><PstlAdr><AdrLine>
 */
public class Field50aGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "50A";

    private static String name_F = "50F";

    private static String name_K = "50K";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/50a");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String cdtDbtInd = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.CdtDbtInd");
        if (!CreditDebitCode.CRDT.value().equals(cdtDbtInd)) {
            return;
        }
        String accountPath = bodyHdrParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.DbtrAcct";
        String partyPath = bodyHdrParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty";
        String agentPath = bodyHdrParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt";
        int partyCount = getXmlNodeCounts(null, document, partyPath);
        int agtCount = getXmlNodeCounts(null, document, agentPath);
        String value = "";
        String bicCode = "";
        String countryCode = "";
        String name = "";
        int addressLineCount = 0;
        String addressLine1 = "";
        String account =  mx_to_mtAccount(accountPath);
        if (partyCount > 0) {
            bicCode = mx_to_mtAnyBIC(partyPath);
            countryCode = getXmlNodeValue(null, document, partyPath + ".PstlAdr.Ctry");
            name = getXmlNodeValue(null, document, partyPath + ".Nm");
            addressLineCount = getXmlNodeCounts(null, document, partyPath + ".PstlAdr.AdrLine");
            if (addressLineCount > 0) {
                addressLine1 = getXmlNodeValue(null, document, partyPath + ".PstlAdr.AdrLine(0)");
            }
            if (StringUtil.isNotEmpty(bicCode)) {
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + bicCode;
                } else {
                    value = bicCode;
                }
                tags.add(new Tag(name_A, value));
            } else if (addressLineCount > 0 && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
                boolean structuredAddressIndicator = mx_to_mtAddressLineType(partyPath);
                if (structuredAddressIndicator) {
                    String nameAddress = mx_to_mtFATFNameAndAddress2(partyPath);
                    if (StringUtil.isEmpty(account)) {
                        account = mx_to_mtFATFIdentification(partyPath, true);
                        if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                            account = account.substring(0, 35);
                        }
                    }
                    if (StringUtil.isEmpty(account)) {
                        account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                    }
                    value = account + Mx2MtConstants.NEW_LINE + nameAddress;
                    tags.add(new Tag(name_F, value));
                } else {
                    String mtNameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                    if (StringUtil.isNotEmpty(account)) {
                        value = account + Mx2MtConstants.NEW_LINE + mtNameAddress;
                    } else {
                        value = mtNameAddress;
                    }
                    tags.add(new Tag(name_K, value));
                }
            } else if (StringUtil.isNotEmpty(countryCode)) {
                String nameAddress = mx_to_mtFATFNameAndAddress(partyPath);
                if (StringUtil.isEmpty(account)) {
                    account = mx_to_mtFATFIdentification(partyPath, false);
                    if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                        account = account.substring(0, 35);
                    }
                }
                if (StringUtil.isEmpty(account)) {
                    account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                value = account + Mx2MtConstants.NEW_LINE + nameAddress;
                tags.add(new Tag(name_F, value));
            } else if (StringUtil.isNotEmpty(name)) {
                String mtNameAddress = mx_to_mtPartyNameAndUnstructuredAddress(partyPath);
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + mtNameAddress;
                } else {
                    value = mtNameAddress;
                }
                tags.add(new Tag(name_K, value));
            } else {
                buildSTErrorInfo(113, "Block4/50a", null);
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                } else {
                    value = Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                tags.add(new Tag(name_K, value));
            }
        } else if (agtCount > 0) {
            bicCode = mx_to_mtBICFI(agentPath);
            name = getXmlNodeValue(null, document, agentPath + ".FinInstnId.Nm");
            countryCode = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.Ctry");
            addressLineCount = getXmlNodeCounts(null, document, agentPath + ".FinInstnId.PstlAdr.AdrLine");
            if (addressLineCount > 0) {
                addressLine1 = getXmlNodeValue(null, document, agentPath + ".FinInstnId.PstlAdr.AdrLine(0)");
            }
            if (StringUtil.isNotEmpty(bicCode)) {
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + bicCode;
                } else {
                    value = bicCode;
                }
                tags.add(new Tag(name_A, value));
            } else {
                String mtNameAddress = "";
                if (addressLineCount > 0 && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(addressLine1)) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agentPath + ".FinInstnId");
                } else if (StringUtil.isNotEmpty(countryCode)) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndStructuredAddress(agentPath + ".FinInstnId");
                } else if (StringUtil.isNotEmpty(name)) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(agentPath + ".FinInstnId");
                } else {
                    mtNameAddress = mx_to_mtClearingIdentifier(agentPath);
                    if (StringUtil.isNotEmpty(mtNameAddress)) {
                        if (StringUtil.isEmpty(account)) {
                            account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                        }
                        buildSTErrorInfo(32, "Block4/50a", null);
                    }
                }
                if (StringUtil.isEmpty(mtNameAddress)) return; //取不到name address 直接返回
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + mtNameAddress;
                } else {
                    value = mtNameAddress;
                }
                tags.add(new Tag(name_K, value));
            }
        }
    }
}
