package com.brilliance.swift.mx2mt.mt940950;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt940950.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2Mt940950Creator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("Stmt"));
        String bodyParentPath = parentElementMaps.get("Stmt");
        //Translation Preconditions/PREC007
        int entryCount = getXmlNodeCounts(bodyParentPath, document, "Stmt.Ntry");
        if (entryCount > 190) {
            buildSTErrorInfo(90, "Stmt/Ntry", String.valueOf(entryCount));
        }
        //Translation Preconditions/PREC009
        int balanceTypeCount = getXmlNodeCounts(bodyParentPath, document, "Stmt.Bal");
        int index = -1;
        if (balanceTypeCount > 0) {
            for (int i=0; i<balanceTypeCount; i++) {
                String balanceType = getXmlNodeValue(bodyParentPath, document, "Stmt.Bal("+i+").Tp.CdOrPrtry.Cd");
                if (BalanceTypeCode.OPBD.value().equals(balanceType)) {
                    index = i;
                }
            }
            if (index > -1) {
                String opbdCcy = getXmlNodeValue(bodyParentPath, document, "Stmt.Bal("+index+").Amt@Ccy");
                if (StringUtil.isEmpty(opbdCcy)) {
                    buildSTErrorInfo(91, null, null);
                } else {
                    for (int i=0; i<balanceTypeCount; i++) {
                        String balanceType = getXmlNodeValue(bodyParentPath, document, "Stmt.Bal("+i+").Tp.CdOrPrtry.Cd");
                        if (BalanceTypeCode.CLBD.value().equals(balanceType)
                            || BalanceTypeCode.CLAV.value().equals(balanceType)
                            || BalanceTypeCode.FWAV.value().equals(balanceType)) {
                            String balanceCcy = getXmlNodeValue(bodyParentPath, document, "Stmt.Bal("+i+").Amt@Ccy");
                            if (StringUtil.isEmpty(balanceCcy) || (StringUtil.isNotEmpty(balanceCcy) && !opbdCcy.substring(0,2).equals(balanceCcy.substring(0,2)))) {
                                buildSTErrorInfo(91, null, null);
                            }
                        }
                    }
                }
            }
        }
    }

    @Override
    public void withBlock2() throws SwiftException {
        //block2逻辑放在postProcess方法中
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field21Generate());
        fieldsGenerateList.add(new Field25aGenerate());
        fieldsGenerateList.add(new Field28CGenerate());
        fieldsGenerateList.add(new Field60Generate());
        fieldsGenerateList.add(new Field61Generate());
        fieldsGenerateList.add(new Field62Generate());
        fieldsGenerateList.add(new Field64Generate());
        fieldsGenerateList.add(new Field65Generate());
        fieldsGenerateList.add(new Field86Generate());

        return fieldsGenerateList;
    }

    @Override
    public void postProcess() throws SwiftException {
        super.withBlock2();
        super.postProcess();
    }

    @Override
    protected String getMtType() {
        String mtType940Flag = (String) context.get(Mx2MtContextIdentifier.MT_TYPE_940_FLAG, true);
        if (Mx2MtConstants.YES.equals(mtType940Flag)) {
            return Mx2MtConstants.MT_TYPE_940;
        } else {
            return Mx2MtConstants.MT_TYPE_950;
        }
    }
}
