package com.brilliance.swift.mx2mt.mt940950.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.BalanceSubTypeCode;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**
 * <Stmt><Bal>[i]<Tp><CdOrPrtry><Cd>
 * <Stmt><Bal>[i]<CdtDbtInd>
 * <Stmt><Bal>[i]<Dt><Dt>
 * <Stmt><Bal>[i]<Amt Ccy=“XXX”>
 * i = 1
 */
public class Field60Generate extends AbstractMx2MtTagsGenerate {

    private static String name_F = "60F";

    private static String name_M = "60M";

    @Override
    public void tagGenerate() throws SwiftException{
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        int balanceTypeCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Stmt.Bal");
        int index = -1;
        int counter = 0;
        if (balanceTypeCount > 0) {
            for (int i=0; i<balanceTypeCount; i++) {
                String balanceType = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+i+").Tp.CdOrPrtry.Cd");
                if (BalanceTypeCode.OPBD.value().equals(balanceType)) {
                    index = i;
                    counter++;
                }
            }
        }
        if (counter != 1) { //没有OPBD 或者 OPBD不止一条数据
            buildSTErrorInfo(84, "Block4/60a", null);
        }
        if (index == -1) {
            return;
        }
        String pageNumber = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.StmtPgntn.PgNb");
        if (StringUtil.isNotEmpty(pageNumber)) {
            int pgNb = Integer.parseInt(pageNumber);
            if (pgNb == 1) {
                String subTypeCode = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Tp.SubTp.Cd");
                if (BalanceSubTypeCode.INTM.value().equals(subTypeCode)) {
                    buildSTErrorInfo(85, "Block4/60a", null);
                }
            } else if (pgNb > 1) {
                String subTypeCode = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Tp.SubTp.Cd");
                if (!BalanceSubTypeCode.INTM.value().equals(subTypeCode)) {
                    buildSTErrorInfo(86, "Block4/60a", null);
                }
            }
        }
        try {
            String crdr = "";
            String cdtDbtInd = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").CdtDbtInd");
            if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                crdr = "C";
            } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                crdr = "D";
            }
            String balanceDate = "";
            String dateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Dt.Dt");
            if (StringUtil.isEmpty(dateStr)) {
                dateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Dt.DtTm");
            }
            if (StringUtil.isNotEmpty(dateStr)) {
                XMLGregorianCalendar date = DatatypeFactory.newInstance().newXMLGregorianCalendar(dateStr);
                balanceDate = DateUtil.format(date, "yyMMdd");
            }
            String balanceAmt = "";
            String balanceCcy = "";
            String amt = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Amt");
            String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Amt@Ccy");
            if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                if (NumberUtil.judgeAmtStrExceedLength(amt, 14)) {
                    buildSTErrorInfo(92, "Block4/60a",amt);
                }
                balanceAmt = NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                balanceCcy = ccy;
            }
            String value = crdr + balanceDate + balanceCcy + balanceAmt;
            //String pageNumber = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.StmtPgntn.PgNb");
            if (StringUtil.isNotEmpty(pageNumber) && Integer.parseInt(pageNumber) == 1) {
                tags.add(new Tag(name_F, value));
            } else {
                tags.add(new Tag(name_M, value));
            }
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
