package com.brilliance.swift.mx2mt.mt940950.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**
 * <Stmt><Ntry>[j]<ValDt><Dt>
 * <Stmt><Ntry>[j]<BookgDt><Dt>
 * <Stmt><Ntry>[j]<CdtDbtInd>
 * <Stmt><Ntry>[j]<RvslInd>
 * <Stmt><Ntry>[j]<Sts>
 * <Stmt><Ntry>[j]<Amt Ccy=“XXX”>
 * <Stmt><Ntry>[j]<BkTxCd><Prtry><Cd>
 * <Stmt><Ntry>[j]<NtryDtls><TxDtls><Refs><EndToEndId>
 * <Stmt><Ntry>[j]<AcctSvcrRef>
 * <Stmt><Ntry>[j]<NtryDtls><TxDtls><AddtlTxInf>
 */
public class Field61Generate extends AbstractMx2MtTagsGenerate {

    private static String name_61 = "61";

    private static String name_86 = "86";

    @Override
    public void tagGenerate() throws SwiftException{
        try {
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            String acctCcy =  getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Acct.Ccy");
            int entryCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Stmt.Ntry");
            if (entryCount > 0) {
                for (int i=0; i<entryCount; i++) {
                    if (i > 189) break;
                    String value = "";
                    String valueDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").ValDt.Dt");
                    if (StringUtil.isEmpty(valueDateStr)) {
                        valueDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").ValDt.DtTm");
                    }
                    if (StringUtil.isNotEmpty(valueDateStr)) {
                        XMLGregorianCalendar valueDate = DatatypeFactory.newInstance().newXMLGregorianCalendar(valueDateStr);
                        value += DateUtil.format(valueDate, "yyMMdd");
                    }
                    String bookDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").BookgDt.Dt");
                    if (StringUtil.isEmpty(bookDateStr)) {
                        bookDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").BookgDt.DtTm");
                    }
                    if (StringUtil.isNotEmpty(bookDateStr)) {
                        XMLGregorianCalendar bookDate = DatatypeFactory.newInstance().newXMLGregorianCalendar(bookDateStr);
                        value += DateUtil.format(bookDate, "MMdd");
                    }
                    String reversalIndicator = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").RvslInd");
                    String creditDebitIndicator = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").CdtDbtInd");
                    if (StringUtil.isNotEmpty(reversalIndicator) && Boolean.valueOf(reversalIndicator)) {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            value += "RC";
                        } else {
                            value += "RD";
                        }
                    } else {
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            value += "D";
                        } else {
                            value += "C";
                        }
                    }
                    String amt = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").Amt");
                    String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").Amt@Ccy");
                    if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                        //Translation Preconditions/PREC008
                        if (StringUtil.isNotEmpty(acctCcy) && !acctCcy.equals(ccy)) {
                            buildSTErrorInfo(95, "Block4/61/"+(i+1), null);
                        }
                        if (NumberUtil.judgeAmtStrExceedLength(amt, 14)) {
                            buildSTErrorInfo(93, "Block4/61/"+(i+1), amt);
                        }
                        value += NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                    } else {
                        //Translation Preconditions/PREC008
                        if (StringUtil.isNotEmpty(acctCcy) && !acctCcy.equals(ccy)) {
                            buildSTErrorInfo(95, "Block4/61/"+(i+1), null);
                        }
                    }
                    value += "NTRF";

                    if (CdtDbtCode.CRDT.value().equals(creditDebitIndicator)) {
                        String endToEndId = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").NtryDtls.TxDtls.Refs.EndToEndId");
                        /* if (endToEndId.length() > 16) {
                            endToEndId = endToEndId.substring(0, 15) + "+";
                        }*/ //950可能需要此值完成103 202对账，故此版本不作截取
                        if (StringUtil.isNotEmpty(endToEndId) && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(endToEndId)) {
                            value += endToEndId;
                        } else {
                            value += Mx2MtConstants.MT_21_DEFAULT_VALUE;
                        }
                    } else { //DBIT
                        String instrId = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").NtryDtls.TxDtls.Refs.InstrId");
                        /* if (instrId.length() > 16) {
                            instrId = instrId.substring(0, 15) + "+";
                        }*/ //950可能需要此值完成103 202对账，故此版本不作截取
                        if (StringUtil.isNotEmpty(instrId) && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(instrId)) {
                            value += instrId;
                        } else {
                            value += Mx2MtConstants.MT_21_DEFAULT_VALUE;
                        }
                    }
                    //MX转MT mapping文档中不翻译以下信息,PSBC版本需要此逻辑完成MT103 MX950对账关联勾销
                    String accountServicerReference = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").AcctSvcrRef");
                    if (StringUtil.isNotEmpty(accountServicerReference)) {
                        if (accountServicerReference.length() > 16) {
                            buildSTErrorInfo(12, "Block4/:61:", accountServicerReference);
                            accountServicerReference = accountServicerReference.substring(0, 15) + "+";
                        }
                        value += "//" + accountServicerReference;
                    }
                    String additionalInformation = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").NtryDtls.TxDtls.AddtlTxInf");
                    if (StringUtil.isNotEmpty(additionalInformation)) {
                        if (additionalInformation.length() > 34) {
                            buildSTErrorInfo(12, "Block4/:61:", additionalInformation);
                            additionalInformation = additionalInformation.substring(0, 33) + "+";
                        }
                        value += Mx2MtConstants.NEW_LINE + additionalInformation;
                    }
                    value = mx_to_mtStartingLineCharacter(value, "Block4/61");
                    tags.add(new Tag(name_61, value));

                    String additionalEntryInformation = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Ntry("+i+").AddtlNtryInf");
                    if (StringUtil.isNotEmpty(additionalEntryInformation)) {
                        if (additionalEntryInformation.length() > 390) {
                            buildSTErrorInfo(12, "Block4/61", additionalEntryInformation);
                            additionalEntryInformation = additionalEntryInformation.substring(0, 389) + "+";
                        }
                        String value86 = StringUtil.getStringByEnter(additionalEntryInformation, 65, 6);
                        value86 = mx_to_mtStartingLineCharacter(value86, "Block4/61/86");
                        tags.add(new Tag(name_86, value86));
                        context.set(Mx2MtContextIdentifier.MT_TYPE_940_FLAG, Mx2MtConstants.YES);
                    }
                }
            }
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
