package com.brilliance.swift.mx2mt.mt940950.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.BalanceTypeCode;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**
 * <Stmt><Bal>[i]<Tp><CdOrPrtry><Cd>
 * <Stmt><Bal>[i]<CdtDbtInd>
 * <Stmt><Bal>[i]<Dt><Dt>
 * <Stmt><Bal>[i]<Amt Ccy=“XXX”
 * LOOP BAL
 * IF CLAV == <Bal><Tp><CdOrPrtry><Cd> means exist 64
 */
public class Field64Generate extends AbstractMx2MtTagsGenerate {

    private static String name = "64";

    @Override
    public void tagGenerate() throws SwiftException{
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        int balanceTypeCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Stmt.Bal");
        int index = -1;
        int counter = 0;
        if (balanceTypeCount > 0) {
            for (int i=0; i<balanceTypeCount; i++) {
                String balanceType = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+i+").Tp.CdOrPrtry.Cd");
                if (BalanceTypeCode.CLAV.value().equals(balanceType)) {
                    index = i;
                    counter++;
                }
            }
        }
        if (counter > 1) { //CLAV不止一条数据
            buildSTErrorInfo(89, "Block4/64", null);
        }
        if (index > -1) {
            try {
                String crdr = "";
                String cdtDbtInd = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").CdtDbtInd");
                if (CdtDbtCode.CRDT.value().equals(cdtDbtInd)) {
                    crdr = "C";
                } else {//if (CdtDbtCode.DBIT.value().equals(cdtDbtInd)) {
                    crdr = "D";
                }
                String balanceDate = "";
                String dateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Dt.Dt");
                if (StringUtil.isEmpty(dateStr)) {
                    dateStr = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Dt.DtTm");
                }
                if (StringUtil.isNotEmpty(dateStr)) {
                    XMLGregorianCalendar date = DatatypeFactory.newInstance().newXMLGregorianCalendar(dateStr);
                    balanceDate = DateUtil.format(date, "yyMMdd");
                }
                String balanceAmt = "";
                String balanceCcy = "";
                String amt = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Amt");
                String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "Stmt.Bal("+index+").Amt@Ccy");
                if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                    if (NumberUtil.judgeAmtStrExceedLength(amt, 14)) {
                        buildSTErrorInfo(92, "Block4/60a",amt);
                    }
                    balanceAmt = NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                    balanceCcy = ccy;
                }
                String value = crdr + balanceDate + balanceCcy + balanceAmt;
                tags.add(new Tag(name, value));
            } catch (DatatypeConfigurationException e) {
                throw new SwiftException(e.getMessage());
            }
        }
    }
}
