package com.brilliance.swift.mx2mt.mt941942;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt941942.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2Mt942Creator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("Rpt"));
        String bodyParentPath = parentElementMaps.get("Rpt");
        //Translation Preconditions/PREC002
        int entryCount = getXmlNodeCounts(bodyParentPath, document, "Rpt.Ntry");
        if (entryCount > 190) {
            buildSTErrorInfo(90, "Rpt/Ntry", String.valueOf(entryCount));
        }
        //Preconditions PREC003
        String creditEntryNum = getXmlNodeValue(bodyParentPath, document, "Rpt.TxsSummry.TtlCdtNtries.NbOfNtries");
        String creditEntrySum = getXmlNodeValue(bodyParentPath, document, "Rpt.TxsSummry.TtlCdtNtries.Sum");
        String debitEntryNum = getXmlNodeValue(bodyParentPath, document, "Rpt.TxsSummry.TtlDbtNtries.NbOfNtries");
        String debitEntrySum = getXmlNodeValue(bodyParentPath, document, "Rpt.TxsSummry.TtlDbtNtries.Sum");
        if (entryCount == 0
            && StringUtil.isEmpty(creditEntryNum) && StringUtil.isEmpty(creditEntrySum)
            && StringUtil.isEmpty(debitEntryNum) && StringUtil.isEmpty(debitEntrySum)) {
            buildSTErrorInfo(94, null, null);
        }
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field21Generate());
        fieldsGenerateList.add(new Field25Generate());
        fieldsGenerateList.add(new Field28CGenerate());
        fieldsGenerateList.add(new Field34FGenerate());
        fieldsGenerateList.add(new Field13DGenerate());
        fieldsGenerateList.add(new Field61Generate());
        fieldsGenerateList.add(new Field90DGenerate());
        fieldsGenerateList.add(new Field90CGenerate());
        fieldsGenerateList.add(new Field86Generate());
        return fieldsGenerateList;
    }

    @Override
    protected String getMtType() {
        return Mx2MtConstants.MT_TYPE_942;
    }
}
