package com.brilliance.swift.mx2swiftdto.bankcdbcdnf;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2swiftdto.AbstractMx2SwiftDtoCreator;
import com.brilliance.swift.mx2swiftdto.Mx2SwiftDtoContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.BankToCustomerDebitCreditNotification;
import com.brilliance.swift.vo.common.*;
import org.dom4j.Document;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.math.BigDecimal;
import java.text.ParseException;
import java.util.Date;
import java.util.Map;


public class Mx2SwiftDtoBTCDCNCreator extends AbstractMx2SwiftDtoCreator {

    private BankToCustomerDebitCreditNotification bankToCustomerDebitCreditNotification = null;

    private String defaultFormate = "yyyy-MM-dd HH:mm:ss,SSS";

    @Override
    public void preProcess() throws SwiftException {
        document = (Document)context.get(Mx2SwiftDtoContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        appHdrParentElementName = parentElementMaps.get("AppHdr");
        grpHdrParentElementName = parentElementMaps.get("GrpHdr");
        bodyHdrParentElementName = parentElementMaps.get("Ntfctn");
        bankToCustomerDebitCreditNotification = new BankToCustomerDebitCreditNotification();
    }

    @Override
    public void appHeader() throws SwiftException {
        super.appHeader();
        swiftHeader.setMessageType("camt.054.001");
        String version = (String)context.get(Mx2SwiftDtoContextIdentifier.MX_VERSION, true);
        swiftHeader.setVersion(StringUtil.isEmpty(version)?"08":version);
        bankToCustomerDebitCreditNotification.setSwiftHeader(swiftHeader);
    }

    @Override
    public void groupHeader() throws SwiftException {

    }

    @Override
    public void messageBody() throws SwiftException {
        try {
            String cdtDbtInd = getXmlNodeValue(bodyHdrParentElementName,document,"Ntfctn.Ntry.CdtDbtInd");
            bankToCustomerDebitCreditNotification.setCdtDbtCode(cdtDbtInd);
            TransactionReference txnRef = new TransactionReference();
            txnRef.setInstructionId(getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.Refs.InstrId"));
            txnRef.setEndToEndId(getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.Refs.EndToEndId"));
            txnRef.setUetr(getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.Refs.UETR"));
            bankToCustomerDebitCreditNotification.setTxnRef(txnRef);
           
            //<Ntfctn><Acct><Id><IBAN>
            //<Ntfctn><Acct><Id><<Othr><Id>
            String iban = getXmlNodeValue(bodyHdrParentElementName,document,"Ntfctn.Acct.Id.IBAN");
            String id = getXmlNodeValue(bodyHdrParentElementName,document,"Ntfctn.Acct.Id.Othr.Id");
            PartyAccount partyAccount = new PartyAccount();
            if(StringUtil.isNotEmpty(iban)){
                partyAccount.setIbanAcct(iban);
            }else {
                partyAccount.setAccount(id);
            }
            bankToCustomerDebitCreditNotification.setAccount(partyAccount);
            //<Ntfctn><Ntry><ValDt><Dt>
            //<Ntfctn><Ntry><Amt Ccy="XXX">
            String dateStr = getXmlNodeValue(bodyHdrParentElementName,document,"Ntfctn.Ntry.ValDt.Dt");
            String amtStr = getXmlNodeValue(bodyHdrParentElementName,document,"Ntfctn.Ntry.Amt");
            String ccyStr = getXmlNodeValue(bodyHdrParentElementName,document,"Ntfctn.Ntry.Amt@Ccy");
            if (StringUtil.isNotEmpty(dateStr)) {
                XMLGregorianCalendar dt = DatatypeFactory.newInstance().newXMLGregorianCalendar(dateStr);
                Date date = DateUtil.formatAndParseDate(dt.toGregorianCalendar().getTime(), defaultFormate);
                bankToCustomerDebitCreditNotification.setValueDate(date);
            }
            if (StringUtil.isNotEmpty(amtStr)&&StringUtil.isNotEmpty(ccyStr)) {
                CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                ccyFormatAmount.setCcy(ccyStr);
                ccyFormatAmount.setAmt(new BigDecimal(amtStr));
                bankToCustomerDebitCreditNotification.setValueAmount(ccyFormatAmount);
            }
            if("CRDT".equals(cdtDbtInd)){
                PartyDto debitParty = convertPartyDto(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty", "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.DbtrAcct");
                bankToCustomerDebitCreditNotification.setDebitAgtParty(debitParty);
                if(debitParty==null){
                    PartyDto debitAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdAgts.DbtrAgt", "Ntfctn.Ntry.NtryDtls.TxDtls.RltdAgts.DbtrAgt");
                    bankToCustomerDebitCreditNotification.setDebitAgtParty(debitAgtParty);
                }
                PartyDto intrmyAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdAgts.IntrmyAgt1", "Ntfctn.Ntry.NtryDtls.TxDtls.RltdAgts.IntrmyAgt1");
                bankToCustomerDebitCreditNotification.setIntrmyAgtParty(intrmyAgtParty);
            }else if("DBIT".equals(cdtDbtInd)){
                PartyDto debitAgtParty = convertPartyDto(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty", "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.DbtrAcct");
                bankToCustomerDebitCreditNotification.setDebitAgtParty(debitAgtParty);
            }
            //<Ntfctn><Ntry><NtryDtls><TxDtls><AddtlTxInf>
            String addtlTxInf = getXmlNodeValue(bodyHdrParentElementName,document,"Ntfctn.Ntry.NtryDtls.TxDtls.AddtlTxInf");
            bankToCustomerDebitCreditNotification.setAddtlTxInf(addtlTxInf);
        } catch (Exception e){
            throw new SwiftException(e.getMessage());
        }
    }
    @Override
    public void postProcess() throws SwiftException {
        try {
            context.set(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OBJ, bankToCustomerDebitCreditNotification);
            String outputFilePath = (String)context.get(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                bankToCustomerDebitCreditNotification.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }


}
