package com.brilliance.swift.mx2swiftdto.custcdttsf;

import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2swiftdto.AbstractMx2SwiftDtoCreator;
import com.brilliance.swift.mx2swiftdto.Mx2SwiftDtoContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.SwiftDto;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.ChargeInfo;
import org.dom4j.Document;

import java.io.File;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * CCT -- VoCustomerCreditTransfer
 */
public class Mx2SwiftDtoCCTCreator extends AbstractMx2SwiftDtoCreator {

    private VoCustomerCreditTransfer customerCreditTransfer = null;

    @Override
    public void preProcess() throws SwiftException {
        document = (Document)context.get(Mx2SwiftDtoContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        appHdrParentElementName = parentElementMaps.get("AppHdr");
        grpHdrParentElementName = parentElementMaps.get("GrpHdr");
        bodyHdrParentElementName = parentElementMaps.get("CdtTrfTxInf");
    }

    @Override
    public void appHeader() throws SwiftException {

    }

    @Override
    public void groupHeader() throws SwiftException {

    }

    @Override
    public void messageBody() throws SwiftException {
    }

    private void fillChargeInfos() {
        int chargeInfoCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf");
        if (chargeInfoCount > 0) {
            List<ChargeInfo> chargeInfos = new ArrayList<>();
            for (int i=0; i<chargeInfoCount; i++) {
                ChargeInfo chargeInfo = new ChargeInfo();
                String chrgAmtStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf("+i+").Amt");
                String chrgCcy = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf("+i+").Amt@Ccy");
                if (StringUtil.isNotEmpty(chrgCcy) && StringUtil.isNotEmpty(chrgAmtStr)) {
                    CcyFormatAmount chrgCfa = new CcyFormatAmount();
                    chrgCfa.setCcy(chrgCcy);
                    chrgCfa.setAmt(new BigDecimal(chrgAmtStr));
                    chargeInfo.setAmt(chrgCfa);
                }
                chargeInfo.setPartyDto(agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.ChrgsInf("+i+").Agt", null));
                chargeInfos.add(chargeInfo);
            }
            maps.put("chargeInfos", chargeInfos);
        }
    }

    @Override
    public void postProcess() throws SwiftException {
        try {
            Map<String, Object> swiftHeader = new HashMap<>();
            String messageType = (String)context.get(Mx2SwiftDtoContextIdentifier.MX_MESSAGETYPE, true);
            swiftHeader.put("messageType", messageType);
            String version = (String)context.get(Mx2SwiftDtoContextIdentifier.MX_VERSION, true);
            swiftHeader.put("version", StringUtil.isEmpty(version)?"09":version);
            maps.put("swiftHeader", swiftHeader);
            String propertyFileName = messageType.replace(".", "") + ".Properties";
            readPropertyFile(propertyFileName);
            fillChargeInfos();//配置文件无法满足Charge Info的赋值,写函数方法特殊处理
            String swiftGsonStr = new JSONObject(maps).toJSONString();
            customerCreditTransfer = (VoCustomerCreditTransfer) SwiftDto.fromJson(swiftGsonStr);
            context.set(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OBJ, customerCreditTransfer);
            String outputFilePath = (String)context.get(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                customerCreditTransfer.write(new File(outputFilePath));
            }
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
