package com.brilliance.swift.mx2swiftdto.fininstcdttsf;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2swiftdto.AbstractMx2SwiftDtoCreator;
import com.brilliance.swift.mx2swiftdto.Mx2SwiftDtoContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.mx.dic.Instruction4Code;
import org.dom4j.Document;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.math.BigDecimal;
import java.text.ParseException;
import java.util.Date;
import java.util.Map;

public class Mx2SwiftDtoFICTCreator extends AbstractMx2SwiftDtoCreator {

    VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = null;

    @Override
    public void preProcess() throws SwiftException {
        document = (Document)context.get(Mx2SwiftDtoContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        appHdrParentElementName = parentElementMaps.get("AppHdr");
        grpHdrParentElementName = parentElementMaps.get("GrpHdr");
        bodyHdrParentElementName = parentElementMaps.get("CdtTrfTxInf");
        financialInstitutionCreditTransfer = new VoFinancialInstitutionCreditTransfer();
    }

    @Override
    public void appHeader() throws SwiftException {
        super.appHeader();
        swiftHeader.setMessageType("pacs.009.001");
        String version = (String)context.get(Mx2SwiftDtoContextIdentifier.MX_VERSION, true);
        swiftHeader.setVersion(StringUtil.isEmpty(version)?"09":version);
        financialInstitutionCreditTransfer.setSwiftHeader(swiftHeader);
    }

    @Override
    public void groupHeader() throws SwiftException {
        PartyDto instgAgtParty = agtConvertPartyDto(grpHdrParentElementName, document, "GrpHdr.SttlmInf.InstgRmbrsmntAgt", "GrpHdr.SttlmInf.InstgRmbrsmntAgtAcct");
        PartyDto instdAgtParty = agtConvertPartyDto(grpHdrParentElementName, document, "GrpHdr.SttlmInf.InstdRmbrsmntAgt", "GrpHdr.SttlmInf.InstdRmbrsmntAgtAcct");
        PartyAccount settleAccount = acctConvertPartyAcct(grpHdrParentElementName, document, "GrpHdr.SttlmInf.SttlmAcct");
        financialInstitutionCreditTransfer.setInstgAgtParty(instgAgtParty);
        financialInstitutionCreditTransfer.setInstdAgtParty(instdAgtParty);
        financialInstitutionCreditTransfer.setSettleAccount(settleAccount);
    }

    @Override
    public void messageBody() throws SwiftException {
        try {
            TransactionReference txnRef = new TransactionReference();
            txnRef.setInstructionId(getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtId.InstrId"));
            txnRef.setEndToEndId(getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtId.EndToEndId"));
            txnRef.setUetr(getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtId.UETR"));
            financialInstitutionCreditTransfer.setTxnRef(txnRef);
            //party
            PartyDto debitParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.Dbtr", "CdtTrfTxInf.DbtrAcct");
            PartyDto intrmyAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.IntrmyAgt1", "CdtTrfTxInf.IntrmyAgt1Acct");
            PartyDto creditAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.CdtrAgt", "CdtTrfTxInf.CdtrAgtAcct");
            PartyDto creditParty = convertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.Cdtr", "CdtTrfTxInf.CdtrAcct");
            PartyDto preInstgAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.PrvsInstgAgt1", "CdtTrfTxInf.PrvsInstgAgt1Acct");
            financialInstitutionCreditTransfer.setDebitParty(debitParty);
            financialInstitutionCreditTransfer.setIntrmyAgtParty(intrmyAgtParty);
            financialInstitutionCreditTransfer.setCreditAgtParty(creditAgtParty);
            financialInstitutionCreditTransfer.setCreditParty(creditParty);
            financialInstitutionCreditTransfer.setPreInstgAgtParty(preInstgAgtParty);

            //debitDate
            String dbtDtTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmIndctn.DbtDtTm");
            if (StringUtil.isNotEmpty(dbtDtTmStr)) {
                XMLGregorianCalendar dbtDtTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(dbtDtTmStr);
                Date debitDate = DateUtil.formatAndParseDate(dbtDtTm.toGregorianCalendar().getTime(), defaultFormate);
                financialInstitutionCreditTransfer.setDebitDate(debitDate);
            }
            //creditDate
            String cdtDtTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmIndctn.CdtDtTm");
            if (StringUtil.isNotEmpty(cdtDtTmStr)) {
                XMLGregorianCalendar cdtDtTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(cdtDtTmStr);
                Date creditDate = DateUtil.formatAndParseDate(cdtDtTm.toGregorianCalendar().getTime(), defaultFormate);
                financialInstitutionCreditTransfer.setCreditDate(creditDate);
            }
            //clsDate
            String clsDtTmStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.SttlmTmReq.CLSTm");
            if (StringUtil.isNotEmpty(clsDtTmStr)) {
                XMLGregorianCalendar clsDtTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(clsDtTmStr);
                Date clsDate = DateUtil.formatAndParseDate(clsDtTm.toGregorianCalendar().getTime(), defaultFormate);
                financialInstitutionCreditTransfer.setClsDate(clsDate);
            }
            //settledDate  settledCcyFormatAmount
            String intrBkSttlmDtStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.IntrBkSttlmDt");
            if (StringUtil.isNotEmpty(intrBkSttlmDtStr)) {
                XMLGregorianCalendar intrBkSttlmDt = DatatypeFactory.newInstance().newXMLGregorianCalendar(intrBkSttlmDtStr);
                Date settledDate = DateUtil.formatAndParseDate(intrBkSttlmDt.toGregorianCalendar().getTime(), defaultFormate);
                financialInstitutionCreditTransfer.setSettledDate(settledDate);
            }
            String intrBkSttlmCcy = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.IntrBkSttlmAmt@Ccy");
            String intrBkSttlmAmtStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.IntrBkSttlmAmt");
            if (StringUtil.isNotEmpty(intrBkSttlmCcy) && StringUtil.isNotEmpty(intrBkSttlmAmtStr)) {
                CcyFormatAmount settledCfa = new CcyFormatAmount();
                settledCfa.setCcy(intrBkSttlmCcy);
                settledCfa.setAmt(new BigDecimal(intrBkSttlmAmtStr));
                financialInstitutionCreditTransfer.setSettledCcyFormatAmount(settledCfa);
            }
            //InstructionForCreditAgent
            String instForCdtAgentCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForCdtrAgt.Cd");
            String instForCdtAgentInstrInf = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForCdtrAgt.InstrInf");
            if (StringUtil.isNotEmpty(instForCdtAgentCode) || StringUtil.isNotEmpty(instForCdtAgentInstrInf)) {
                InstructionForCreditAgent instForCdtAgt = new InstructionForCreditAgent();
                if (StringUtil.isNotEmpty(instForCdtAgentCode)) {
                    instForCdtAgt.setCode(ExternalCreditorAgentInstructionCode.valueOf(instForCdtAgentCode));
                }
                instForCdtAgt.setInstrInf(instForCdtAgentInstrInf);
                financialInstitutionCreditTransfer.setInstForCrdAgt(instForCdtAgt);
            }
            //InstructionForNextAgent
            String instForNxtAgentCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForNxtAgt.Cd");
            String instForNxtAgentInstrInf = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.InstrForNxtAgt.InstrInf");
            if (StringUtil.isNotEmpty(instForNxtAgentCode) || StringUtil.isNotEmpty(instForNxtAgentInstrInf)) {
                InstructionForNextAgent instForNxtAgt = new InstructionForNextAgent();
                if (StringUtil.isNotEmpty(instForNxtAgentCode)) {
                    instForNxtAgt.setCode(Instruction4Code.valueOf(instForNxtAgentCode));
                }
                instForNxtAgt.setInstrInf(instForNxtAgentInstrInf);
                financialInstitutionCreditTransfer.setInstForNxtAgt(instForNxtAgt);
            }
            coverMessageBody();
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException(e.getMessage());
        } catch (ParseException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public void coverMessageBody() throws SwiftException {
        //party
        PartyDto debitParty = convertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.Dbtr", "CdtTrfTxInf.UndrlygCstmrCdtTrf.DbtrAcct");
        if (debitParty == null) return;
        VoCustomerCreditTransfer customerCreditTransfer = new VoCustomerCreditTransfer();
        PartyDto debitAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.DbtrAgt", "CdtTrfTxInf.UndrlygCstmrCdtTrf.DbtrAgtAcct");
        PartyDto intrmyAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.IntrmyAgt1", "CdtTrfTxInf.UndrlygCstmrCdtTrf.IntrmyAgt1Acct");
        PartyDto creditAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.CdtrAgt", "CdtTrfTxInf.UndrlygCstmrCdtTrf.CdtrAgtAcct");
        PartyDto creditParty = convertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.Cdtr", "CdtTrfTxInf.UndrlygCstmrCdtTrf.CdtrAcct");
        PartyDto preInstgAgtParty = agtConvertPartyDto(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.PrvsInstgAgt1", "CdtTrfTxInf.UndrlygCstmrCdtTrf.PrvsInstgAgt1Acct");
        customerCreditTransfer.setDebitParty(debitParty);
        customerCreditTransfer.setDebitAgtParty(debitAgtParty);
        customerCreditTransfer.setIntrmyAgtParty(intrmyAgtParty);
        customerCreditTransfer.setCreditAgtParty(creditAgtParty);
        customerCreditTransfer.setCreditParty(creditParty);
        customerCreditTransfer.setPreInstgAgtParty(preInstgAgtParty);

        //InstructedCcyFormatAmount
        String instdAmtCcy = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.InstdAmt@Ccy");
        String instdAmtStr = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.InstdAmt");
        if (StringUtil.isNotEmpty(instdAmtCcy) && StringUtil.isNotEmpty(instdAmtStr)) {
            CcyFormatAmount instdCfa = new CcyFormatAmount();
            instdCfa.setCcy(instdAmtCcy);
            instdCfa.setAmt(new BigDecimal(instdAmtStr));
            customerCreditTransfer.setInstructedCcyFormatAmount(instdCfa);
        }
        //RemittanceInformation
        int ustrdCounts = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.RmtInf.Ustrd");
        if (ustrdCounts > 0) {
            RemittanceInformation remittanceInformation = new RemittanceInformation();
            for (int i=0; i<ustrdCounts; i++) {
                String ustrd = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.RmtInf.Ustrd("+i+")");
                remittanceInformation.addUnstructured(ustrd);
            }
            customerCreditTransfer.setRemittanceInfo(remittanceInformation);
        }
        //InstructionForCreditAgent
        String instForCdtAgentCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.InstrForCdtrAgt.Cd");
        String instForCdtAgentInstrInf = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.InstrForCdtrAgt.InstrInf");
        if (StringUtil.isNotEmpty(instForCdtAgentCode) || StringUtil.isNotEmpty(instForCdtAgentInstrInf)) {
            InstructionForCreditAgent instForCdtAgt = new InstructionForCreditAgent();
            if (StringUtil.isNotEmpty(instForCdtAgentCode)) {
                instForCdtAgt.setCode(ExternalCreditorAgentInstructionCode.valueOf(instForCdtAgentCode));
            }
            instForCdtAgt.setInstrInf(instForCdtAgentInstrInf);
            customerCreditTransfer.setInstForCrdAgt(instForCdtAgt);
        }
        //InstructionForNextAgent
        String instForNxtAgentCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.InstrForNxtAgt.Cd");
        String instForNxtAgentInstrInf = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.UndrlygCstmrCdtTrf.InstrForNxtAgt.InstrInf");
        if (StringUtil.isNotEmpty(instForNxtAgentCode) || StringUtil.isNotEmpty(instForNxtAgentInstrInf)) {
            InstructionForNextAgent instForNxtAgt = new InstructionForNextAgent();
            if (StringUtil.isNotEmpty(instForNxtAgentCode)) {
                instForNxtAgt.setCode(Instruction4Code.valueOf(instForNxtAgentCode));
            }
            instForNxtAgt.setInstrInf(instForNxtAgentInstrInf);
            customerCreditTransfer.setInstForNxtAgt(instForNxtAgt);
        }
        financialInstitutionCreditTransfer.setUnderCustomerCreditTransfer(customerCreditTransfer);

    }

    @Override
    public void postProcess() throws SwiftException {
        try {
            context.set(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OBJ, financialInstitutionCreditTransfer);
            String outputFilePath = (String)context.get(Mx2SwiftDtoContextIdentifier.MX_TO_SWIFTDTO_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                financialInstitutionCreditTransfer.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException(e.getMessage());
        }
    }
}