package com.brilliance.swift.swiftdto2mt;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftDto;
import com.brilliance.swift.vo.common.MessagePriority;
import com.prowidesoftware.swift.io.ConversionService;
import com.prowidesoftware.swift.io.IConversionService;
import com.prowidesoftware.swift.io.writer.SwiftWriter;
import com.prowidesoftware.swift.model.*;
import org.apache.commons.lang3.Validate;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.*;

public abstract class AbstractSwiftDto2MtCreator implements SwiftDto2MtCreator{

    protected SwiftDto2MtContext context;

    public SwiftDto2MtContext getContext() {
        return context;
    }

    public AbstractSwiftDto2MtCreator setContext(SwiftDto2MtContext context) {
        this.context = context;
        return this;
    }

    //TODO
    protected String getRandomNumber(int length) {
        String randomNumber = "";
        Random random = new Random();
        for (int i=0; i<length; i++) {
            randomNumber += random.nextInt(9);
        }
        return randomNumber;
    }

    protected String processBicCode(String bicCode) {
        String processedBicCode = "";
        if (!StringUtil.isEmpty(bicCode)) {
            if (bicCode.length() == 8) {
                processedBicCode = bicCode + Mx2MtConstants.BICSUFFIX;
            } else if (bicCode.length() == 11) {
                processedBicCode = bicCode.substring(0, 8) + Mx2MtConstants.BICMIDDLE + bicCode.substring(8);
            } else {
                throw new SwiftException("BicCode length is invalid.");
            }
        }
        return processedBicCode;
    }

    public abstract List<SwiftDto2MtTagGenerate> getGenerateTagList();

    protected abstract String getMtType();

    @Override
    public void preProcess() throws SwiftException {
        SwiftMessage swiftMessage = new SwiftMessage();
        context.set(swiftMessage);
    }

    @Override
    public void withBlock1() throws SwiftException {
        SwiftBlock1 block1 = new SwiftBlock1();
        SwiftDto swiftDto = (SwiftDto)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ);
        String senderBic = (String)context.get(Mx2MtConstants.SENDERS_ADDRESS, true);
        if (StringUtil.isEmpty(senderBic) && swiftDto.getSwiftHeader() != null) {
            senderBic = swiftDto.getSwiftHeader().getSenderBic();
        }
        String receiverBic = (String)context.get(Mx2MtConstants.RECEIVERS_ADDRESS, true);
        if (StringUtil.isEmpty(receiverBic) && swiftDto.getSwiftHeader() != null) {
            receiverBic = swiftDto.getSwiftHeader().getReceiverBic();
        }
        String applicationMode = (String)context.get(Mx2MtConstants.APPLICATION_MODE, true);
        if ("O".equalsIgnoreCase(applicationMode)) {
            block1.setLogicalTerminal(processBicCode(receiverBic));
        } else {
            block1.setLogicalTerminal(processBicCode(senderBic));
        }
        block1.setSessionNumber(getRandomNumber(4));//mapping文档中给的是0000
        block1.setSequenceNumber(getRandomNumber(6));//mapping文档中给的是000000
        context.get(SwiftMessage.class).setBlock1(block1);
    }

    @Override
    public void withBlock2() throws SwiftException {
        SwiftDto swiftDto = (SwiftDto)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ);
        String senderBic = (String)context.get(Mx2MtConstants.SENDERS_ADDRESS, true);
        if (StringUtil.isEmpty(senderBic) && swiftDto.getSwiftHeader() != null) {
            senderBic = swiftDto.getSwiftHeader().getSenderBic();
        }
        String receiverBic = (String)context.get(Mx2MtConstants.RECEIVERS_ADDRESS, true);
        if (StringUtil.isEmpty(receiverBic) && swiftDto.getSwiftHeader() != null) {
            receiverBic = swiftDto.getSwiftHeader().getReceiverBic();
        }
        String messagePriority = (String)context.get(Mx2MtConstants.MESSAGE_PRIORITY, true);
        if (StringUtil.isEmpty(messagePriority) && swiftDto.getSwiftHeader() != null) {
            messagePriority = MessagePriority.NORM.equals(swiftDto.getSwiftHeader().getMessagePriority()) ? "N" : "U";
        }
        Date inputDate = (Date)context.get(Mx2MtConstants.INTPUT_DATE, true);
        if (inputDate == null && swiftDto.getSwiftHeader() != null) {
            inputDate = swiftDto.getSwiftHeader().getCreateDate();
        }
        Date outputDate = (Date)context.get(Mx2MtConstants.OUTPUT_DATE, true);
        if (outputDate == null) {
            outputDate = new Date();
        }
        String applicationMode = (String)context.get(Mx2MtConstants.APPLICATION_MODE, true);
        if ("O".equalsIgnoreCase(applicationMode)) {
            SwiftBlock2Output block2 = new SwiftBlock2Output();
            block2.setMessageType(getMtType());
            block2.setSenderInputTime(DateUtil.format(inputDate, "HHmm"));
            block2.setMIRDate(DateUtil.format(inputDate, "yyMMdd"));
            block2.setMIRLogicalTerminal(processBicCode(senderBic));
            block2.setMIRSessionNumber(getRandomNumber(4));
            block2.setMIRSequenceNumber(getRandomNumber(6));
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(outputDate);
            block2.setReceiverOutputDateTime(calendar);
            block2.setMessagePriority(messagePriority);
            context.get(SwiftMessage.class).setBlock2(block2);
        } else {
            SwiftBlock2Input block2 = new SwiftBlock2Input();
            block2.setMessageType(getMtType());
            block2.setReceiverAddress(processBicCode(receiverBic));
            block2.setMessagePriority(messagePriority);
            if ("U".equalsIgnoreCase(messagePriority)) {
                block2.setDeliveryMonitoring("1");
            }
            context.get(SwiftMessage.class).setBlock2(block2);
        }
    }

    @Override
    public void withBlock3() throws SwiftException {
        List<Tag> tags = new ArrayList<>();
        SwiftBlock3 block3 = new SwiftBlock3();
        block3.setTags(tags);
        String block3_103 = (String)context.get(Mx2MtConstants.BLOCK3_103, true);
        if (StringUtil.isNotEmpty(block3_103)) {
            tags.add(new Tag("103", block3_103));
        }
        String block3_108 = (String)context.get(Mx2MtConstants.BLOCK3_108, true);
        if (StringUtil.isNotEmpty(block3_108)) {
            tags.add(new Tag("108", block3_108));
        }
        String block3_165 = (String)context.get(Mx2MtConstants.BLOCK3_165, true);
        if (StringUtil.isNotEmpty(block3_165)) {
            tags.add(new Tag("165", block3_165));
        }
        String block3_433 = (String)context.get(Mx2MtConstants.BLOCK3_433, true);
        if (StringUtil.isNotEmpty(block3_433)) {
            tags.add(new Tag("433", block3_433));
        }
        String block3_434 = (String)context.get(Mx2MtConstants.BLOCK3_434, true);
        if (StringUtil.isNotEmpty(block3_434)) {
            tags.add(new Tag("434", block3_434));
        }
        context.get(SwiftMessage.class).setBlock3(block3);
    }

    @Override
    public void withBlock4() throws SwiftException {
        List<SwiftDto2MtTagGenerate> list = getGenerateTagList();
        if (list != null) {
            List<Tag> tags = new ArrayList<>();
            SwiftBlock4 block4 = new SwiftBlock4(tags);
            context.get(SwiftMessage.class).setBlock4(block4);
            for (int i=0; i<list.size(); i++) {
                AbstractSwiftDto2MtTagGenerate swiftDto2MtTagGenerate = (AbstractSwiftDto2MtTagGenerate)list.get(i);
                swiftDto2MtTagGenerate.setContext(context).tagGenerate();
            }
        }
    }

    @Override
    public void withBlock5() throws SwiftException {
        SwiftBlock5 swiftBlock5 = new SwiftBlock5();
        Boolean block5_TNG = (Boolean)context.get(Mx2MtConstants.BLOCK5_TNG, true);
        if (Boolean.TRUE.equals(block5_TNG)) {
            swiftBlock5.setTag(SwiftBlock5Field.TNG, null);
        }
        Boolean block5_PDE = (Boolean)context.get(Mx2MtConstants.BLOCK5_PDE, true);
        SwiftDto swiftDto = (SwiftDto)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ);
        if (!Boolean.TRUE.equals(block5_PDE) && swiftDto.getSwiftHeader() != null) {
            block5_PDE = swiftDto.getSwiftHeader().getPossibleDuplicate();
        }
        if (Boolean.TRUE.equals(block5_PDE)) {
            swiftBlock5.setPDE();
        }
        context.get(SwiftMessage.class).setBlock5(swiftBlock5);
    }

    @Override
    public void postProcess() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        IConversionService srv = new ConversionService();
        String mtStr = srv.getFIN(swiftMessage);
        context.set(SwiftDto2MtContextIdentifier.MT_TXT, mtStr);
        String outputFilePath = (String)context.get(SwiftDto2MtContextIdentifier.MT_OUTPUT_FILE_PATH, true);
        if (StringUtil.isNotEmpty(outputFilePath)) {
            write(swiftMessage, new File(outputFilePath));
        }
    }

    public void write(SwiftMessage swiftMessage, File file) throws SwiftException {
        try {
            Validate.notNull(file, "the file to write cannot be null");
            Validate.notNull(swiftMessage, "the message to write cannot be null");
            if(!file.exists()) {
                file.createNewFile();
            }
            FileWriter fw = new FileWriter(file.getAbsoluteFile());
            SwiftWriter.writeMessage(swiftMessage, fw, true);
            fw.close();
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }

}
