package com.brilliance.swift.swiftdto2mt.mt940950;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mt.AbstractSwiftDto2MtCreator;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtContextIdentifier;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtTagGenerate;
import com.brilliance.swift.swiftdto2mt.mt940950.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.ReportEntry;
import com.brilliance.swift.vo.common.TransactionReference;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.ArrayList;
import java.util.List;

public class SwiftDto2Mt940950Creator extends AbstractSwiftDto2MtCreator {

    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        BankToCustomerStatement bankToCustomerStatement = (BankToCustomerStatement)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ, true);
        TransactionReference txnRef = bankToCustomerStatement.getTxnRef();
        if (txnRef != null && StringUtil.isNotEmpty(txnRef.getUetr())) {
            block3.getTags().add(new Tag("121", txnRef.getUetr()));
        }
    }

    @Override
    public List<SwiftDto2MtTagGenerate> getGenerateTagList() {
        List<SwiftDto2MtTagGenerate> list = new ArrayList<>();
        list.add(new Tag20Generate());
        list.add(new Tag21Generate());
        list.add(new Tag25aGenerate());
        list.add(new Tag28CGenerate());
        list.add(new Tag60aGenerate());
        list.add(new Tag61Generate());
        list.add(new Tag62aGenerate());
        list.add(new Tag64Generate());
        list.add(new Tag65Generate());
        list.add(new Tag86Generate());
        return list;
    }

    @Override
    protected String getMtType() {
        BankToCustomerStatement bankToCustomerStatement = (BankToCustomerStatement)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ, true);
        if (bankToCustomerStatement.getForwardAvailableBalances().size() > 0) {
            return "940";
        }
        if (StringUtil.isNotEmpty(bankToCustomerStatement.getAdditionalStatementInformation())) {
            return "940";
        }
        List<ReportEntry> reportEntries = bankToCustomerStatement.getReportEntries();
        if (reportEntries.size() > 0) {
            for (ReportEntry reportEntry : reportEntries) {
                if (StringUtil.isNotEmpty(reportEntry.getAddtlNtryInf())) {
                    return "940";
                }
            }
        }
        return "950";
    }
}
