package com.brilliance.swift.swiftdto2mt.mt940950.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mt.AbstractSwiftDto2MtTagGenerate;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.brilliance.swift.vo.common.ReportEntry;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;


public class Tag61Generate extends AbstractSwiftDto2MtTagGenerate {

    private String name_61 = "61";
    private String name_86 = "86";

    @Override
    public void tagGenerate() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = (BankToCustomerStatement)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ, true);
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            List<ReportEntry> reportEntries = bankToCustomerStatement.getReportEntries();
            if(reportEntries.size() > 0){
                for (ReportEntry reportEntry : reportEntries) {
                    String valueDateStr = "";
                    String bookDateStr = "";
                    String drCrMark = "";
                    String amt = "";
                    String ccy = "";
                    String txnCode = "NTRF";
                    String endToEndId = reportEntry.getEndToEndId();
                    String addtlTxInf = reportEntry.getAddtlTxInf();
                    String acctSvcrRef = reportEntry.getAcctSvcrRef();
                    if (reportEntry.getValueDate() != null) {
                        valueDateStr = DateUtil.format(reportEntry.getValueDate(), "yyMMdd");
                    }
                    if (reportEntry.getBookDate() != null) {
                        bookDateStr = DateUtil.format(reportEntry.getBookDate(), "yyMMdd");
                    }
                    if (CdtDbtCode.CRDT.equals(reportEntry.getCdtDbtCode())) {
                        if (Boolean.TRUE.equals(reportEntry.getReversalIndicator())) {
                            drCrMark = Mx2MtConstants.DRCRMARK_RD;
                        } else {
                            drCrMark = Mx2MtConstants.DRCRMARK_C;
                        }
                    } else if (CdtDbtCode.DBIT.equals(reportEntry.getCdtDbtCode())) {
                        if (Boolean.TRUE.equals(reportEntry.getReversalIndicator())) {
                            drCrMark = Mx2MtConstants.DRCRMARK_RC;
                        } else {
                            drCrMark = Mx2MtConstants.DRCRMARK_D;
                        }
                    }
                    CcyFormatAmount ccyFormatAmount = reportEntry.getAmt();
                    if (ccyFormatAmount != null) {
                        amt = NumberUtil.formatAmt(ccyFormatAmount.getAmt(), ccyFormatAmount.getCcy());
                        ccy = ccyFormatAmount.getCcy();
                    }
                    StringBuilder sb = new StringBuilder();
                    sb.append(valueDateStr)
                            .append(bookDateStr)
                            .append(drCrMark)
                            .append(ccy)
                            .append(amt)
                            .append(txnCode)
                            .append(endToEndId);
                    if (StringUtil.isNotEmpty(acctSvcrRef)) {
                        sb.append("//"+acctSvcrRef);
                    }
                    if (StringUtil.isNotEmpty(addtlTxInf)) {
                        sb.append(Mx2MtConstants.NEW_LINE+addtlTxInf);
                    }
                    tags.add(new Tag(name_61, sb.toString()));
                    String addtlNtryInf = reportEntry.getAddtlNtryInf();
                    if (StringUtil.isNotEmpty(addtlNtryInf)) {
                        tags.add(new Tag(name_86, addtlNtryInf));
                    }
                }
            }
        }catch (Exception e){
            throw new SwiftException(e.getMessage());
        }
    }
}
