package com.brilliance.swift.swiftdto2mt.mt940950.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mt.AbstractSwiftDto2MtTagGenerate;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.CashBalance;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mx.dic.CreditDebitCode;

import java.util.List;

import static com.brilliance.swift.constants.Mx2MtConstants.DRCRMARK_C;
import static com.brilliance.swift.constants.Mx2MtConstants.DRCRMARK_D;

public class Tag65Generate extends AbstractSwiftDto2MtTagGenerate {

    private String name = "65";

    @Override
    public void tagGenerate() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = (BankToCustomerStatement)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ, true);
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            List<CashBalance> forwardAvailableBalances = bankToCustomerStatement.getForwardAvailableBalances();
            if(forwardAvailableBalances.size() > 0){
                for (CashBalance cashBalance : forwardAvailableBalances) {
                    String value = "";
                    String dcMark = "";
                    if(CdtDbtCode.CRDT.equals(cashBalance.getCdtDbtCode())){
                        dcMark = DRCRMARK_C;
                    }else if(CreditDebitCode.DBIT.equals(cashBalance.getCdtDbtCode())){
                        dcMark = DRCRMARK_D;
                    }
                    String dateStr = "";
                    if (cashBalance.getDate() != null) {
                        dateStr = DateUtil.format(cashBalance.getDate(), "yyMMdd");
                    }
                    CcyFormatAmount ccyFormatAmount = cashBalance.getAmt();
                    String ccy = "";
                    String amtStr = "";
                    if (ccyFormatAmount != null) {
                        ccy = ccyFormatAmount.getCcy();
                        amtStr = NumberUtil.formatAmt(ccyFormatAmount.getAmt(), ccyFormatAmount.getCcy());
                    }
                    value = dcMark + dateStr + ccy + amtStr;
                    tags.add(new Tag(name, value));
                }
            }
        }catch (Exception e){
            throw new SwiftException(e.getMessage());
        }
    }
}
