package com.brilliance.swift.swiftdto2mx;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.mx.dic.*;

import javax.xml.datatype.DatatypeConfigurationException;
import java.text.ParseException;
import java.util.Date;

public abstract class AbstractSwiftDto2MxCreator implements SwiftDto2MxCreator{

    protected SwiftDto2MxContext context;

    public SwiftDto2MxContext getContext() {
        return context;
    }

    public AbstractSwiftDto2MxCreator setContext(SwiftDto2MxContext context) {
        this.context = context;
        return this;
    }

    protected BranchAndFinancialInstitutionIdentification6 partyDtoConvertAgt(PartyDto partyDto) {
        BranchAndFinancialInstitutionIdentification6 agt = new BranchAndFinancialInstitutionIdentification6();
        FinancialInstitutionIdentification18 finInstnId = new FinancialInstitutionIdentification18();
        finInstnId.setBICFI(partyDto.getPartyBic());
        finInstnId.setNm(partyDto.getPartyName());
        if (partyDto.getAddressList().size() > 0) {
            PostalAddress24 pstlAdr = new PostalAddress24();
            for (int i=0; i<partyDto.getAddressList().size(); i++) {
                pstlAdr.addAdrLine(partyDto.getAddressList().get(i));
            }
            finInstnId.setPstlAdr(pstlAdr);
        }
        if (partyDto.getClrSysMmb() != null) {
            ClearingSystemMember clrSysMmb = partyDto.getClrSysMmb();
            ClearingSystemMemberIdentification2 clrSysMmbId = new ClearingSystemMemberIdentification2();
            clrSysMmbId.setMmbId(clrSysMmb.getId());
            ClearingSystemIdentification2Choice clrSysId = new ClearingSystemIdentification2Choice();
            clrSysId.setCd(clrSysMmb.getCode());
            clrSysMmbId.setClrSysId(clrSysId);
            finInstnId.setClrSysMmbId(clrSysMmbId);
        }
        agt.setFinInstnId(finInstnId);
        return agt;
    }

    protected CashAccount38 partyDtoConvertAgtAccount(PartyAccount partyAcct) {
        if (partyAcct == null) return null;
        CashAccount38 cashAccount38 = null;
        String ibanAcct = partyAcct.getIbanAcct();
        String account = partyAcct.getAccount();
        if (StringUtil.isNotEmpty(ibanAcct) || StringUtil.isNotEmpty(account)) {
            cashAccount38 = new CashAccount38();
            cashAccount38.setCcy(partyAcct.getAcctCcy());
            cashAccount38.setNm(partyAcct.getAcctName());
            AccountIdentification4Choice id = new AccountIdentification4Choice();
            if (StringUtil.isNotEmpty(account)) {
                GenericAccountIdentification1 othr = new GenericAccountIdentification1();
                othr.setId(account);
                AcctSchemeType acctSehemeType = partyAcct.getAcctSehemeType();
                if (acctSehemeType != null) {
                    AccountSchemeName1Choice schmeNm = new AccountSchemeName1Choice();
                    if (acctSehemeType.getCode() != null) {
                        schmeNm.setCd(acctSehemeType.getCode().value());
                    }
                    schmeNm.setPrtry(acctSehemeType.getProprietary());
                    othr.setSchmeNm(schmeNm);
                }
                id.setOthr(othr);
            }
            if (StringUtil.isNotEmpty(ibanAcct)) {
                id.setIBAN(ibanAcct);
            }
            cashAccount38.setId(id);
            AcctType acctType = partyAcct.getAcctType();
            if (acctType != null) {
                CashAccountType2Choice tp = new CashAccountType2Choice();
                if (acctType.getCode() != null) {
                    tp.setCd(acctType.getCode().value());
                }
                tp.setPrtry(acctType.getProprietary());
                cashAccount38.setTp(tp);
            }
        }
        return cashAccount38;
    }

    protected PartyIdentification135 partyDtoConvertTr(PartyDto partyDto) {
        PartyIdentification135 tr = new PartyIdentification135();
        tr.setNm(partyDto.getPartyName());
        if (StringUtil.isNotEmpty(partyDto.getPartyBic())) {
            Party38Choice id = new Party38Choice();
            OrganisationIdentification29 orgId = new OrganisationIdentification29();
            orgId.setAnyBIC(partyDto.getPartyBic());
            id.setOrgId(orgId);
            tr.setId(id);
        }
        if (partyDto.getAddressList().size() > 0) {
            PostalAddress24 pstlAdr = new PostalAddress24();
            for (int i=0; i<partyDto.getAddressList().size(); i++) {
                pstlAdr.addAdrLine(partyDto.getAddressList().get(i));
            }
            tr.setPstlAdr(pstlAdr);
        }
        return tr;
    }

    /**
     * 将自定义对象CashBalance转Mx CashBalance8
     */
    protected CashBalance8 convertCashBalance8(CashBalance cashBalance) {
        try {
            if (cashBalance == null) return null;
            CashBalance8 cashBalance8 = new CashBalance8();
            BalanceTypeCode balanceTypeCode = cashBalance.getCode();
            String proprietary = cashBalance.getProprietary();
            CdtDbtCode cdtDbtCode = cashBalance.getCdtDbtCode();
            Date date = cashBalance.getDate();
            CcyFormatAmount ccyFormatAmount = cashBalance.getAmt();
            if (balanceTypeCode != null || StringUtil.isNotEmpty(proprietary)) {
                BalanceType13 tp = new BalanceType13();
                BalanceType10Choice cdOrPrtry = new BalanceType10Choice();
                if (balanceTypeCode != null) {
                    cdOrPrtry.setCd(balanceTypeCode.value());
                }
                cdOrPrtry.setPrtry(proprietary);
                tp.setCdOrPrtry(cdOrPrtry);
                cashBalance8.setTp(tp);
            }
            if (cdtDbtCode != null) {
                cashBalance8.setCdtDbtInd(CreditDebitCode.valueOf(cdtDbtCode.value()));
            }
            if (ccyFormatAmount != null) {
                ActiveOrHistoricCurrencyAndAmount amt = new ActiveOrHistoricCurrencyAndAmount();
                amt.setCcy(ccyFormatAmount.getCcy());
                amt.setValue(ccyFormatAmount.getAmt());
                cashBalance8.setAmt(amt);
            }
            if (date != null) {
                DateAndDateTime2Choice dt = new DateAndDateTime2Choice();
                dt.setDt(DateUtil.parseXMLGregorianCalendar(date));
                cashBalance8.setDt(dt);
            }
            return cashBalance8;
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException(e.getMessage());
        } catch (ParseException e) {
            throw new SwiftException(e.getMessage());
        }
    }

}
