package com.brilliance.swift.swiftdto2mx.pacs008001.v09;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mx.AbstractSwiftDto2MxCreator;
import com.brilliance.swift.swiftdto2mx.SwiftDto2MxContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.common.*;
import com.brilliance.swift.vo.common.PurposeChoice;
import com.prowidesoftware.swift.model.mx.BusinessAppHdrV02;
import com.prowidesoftware.swift.model.mx.MxPacs00800109;
import com.prowidesoftware.swift.model.mx.dic.*;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.io.IOException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.util.List;

public class SwiftDto2MxPacs008001Creator extends AbstractSwiftDto2MxCreator {
    @Override
    public void create() throws SwiftException {
        try {
            VoCustomerCreditTransfer customerCreditTransfer = (VoCustomerCreditTransfer)context.get(SwiftDto2MxContextIdentifier.SWIFT_DTO_OBJ, true);
            if (customerCreditTransfer == null) {
                return;
            }
            MxPacs00800109 mxPacs00800109 = new MxPacs00800109();
            PartyDto instructingReimbursementParty = customerCreditTransfer.getInstgAgtParty();//53
            PartyDto instructedReimbursementParty = customerCreditTransfer.getInstdAgtParty();//54
            PartyDto thirdReimbursementParty = customerCreditTransfer.getThridAgtParty();//55
            PartyDto dbtrParty = customerCreditTransfer.getDebitParty();//50
            PartyDto dbtrAgtParty = customerCreditTransfer.getDebitAgtParty();//52
            PartyDto intrmyAgt1Party = customerCreditTransfer.getIntrmyAgtParty();//56
            PartyDto cdtrAgtParty = customerCreditTransfer.getCreditAgtParty();//57
            PartyDto cdtrParty = customerCreditTransfer.getCreditParty();//59
            //set AppHdr
            SwiftHeader swiftHeader = customerCreditTransfer.getSwiftHeader();
            BusinessAppHdrV02 businessAppHdrV02 = new BusinessAppHdrV02();
            Party44Choice fr = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 frFiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 frFinInstnId = new FinancialInstitutionIdentification18();
            frFinInstnId.setBICFI(swiftHeader.getSenderBic());
            frFiId.setFinInstnId(frFinInstnId);
            fr.setFIId(frFiId);
            businessAppHdrV02.setFr(fr);

            Party44Choice to = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 toFiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 toFinInstnId = new FinancialInstitutionIdentification18();
            toFinInstnId.setBICFI(swiftHeader.getSenderBic());
            toFiId.setFinInstnId(toFinInstnId);
            to.setFIId(toFiId);
            businessAppHdrV02.setTo(to);

            XMLGregorianCalendar creDt = DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate());
            businessAppHdrV02.setCreDt(creDt);

            if (MessagePriority.NORM.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.NORM.value());
            } else if (MessagePriority.HIGH.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.HIGH.value());
            }
            businessAppHdrV02.setMsgDefIdr(swiftHeader.getMessageDefId());
            businessAppHdrV02.setBizMsgIdr(swiftHeader.getMessageId());
            businessAppHdrV02.setBizSvc(swiftHeader.getBusinessService());
            mxPacs00800109.setAppHdr(businessAppHdrV02);
            FIToFICustomerCreditTransferV09 fiToFICstmrCdtTrf = new FIToFICustomerCreditTransferV09();
            mxPacs00800109.setFIToFICstmrCdtTrf(fiToFICstmrCdtTrf);
            //set GroupHeader
            GroupHeader93 grpHdr = new GroupHeader93();
            grpHdr.setMsgId(swiftHeader.getMessageId());
            grpHdr.setCreDtTm(DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate()));
            grpHdr.setNbOfTxs("1");
            SettlementInstruction7 sttlmInf = new SettlementInstruction7();
            sttlmInf.setSttlmMtd(SettlementMethod1Code.INDA);
            if (instructingReimbursementParty != null) {
                BranchAndFinancialInstitutionIdentification6 instgRmbrsmntAgt = partyDtoConvertAgt(instructingReimbursementParty);
                sttlmInf.setInstgRmbrsmntAgt(instgRmbrsmntAgt);
                CashAccount38 instgRmbrsmntAgtAcct = partyDtoConvertAgtAccount(instructingReimbursementParty.getPartyAcct());
                sttlmInf.setInstgRmbrsmntAgtAcct(instgRmbrsmntAgtAcct);
            }
            if (instructedReimbursementParty != null) {
                BranchAndFinancialInstitutionIdentification6 instdRmbrsmntAgt = partyDtoConvertAgt(instructedReimbursementParty);
                sttlmInf.setInstdRmbrsmntAgt(instdRmbrsmntAgt);
                CashAccount38 instdRmbrsmntAgtAcct = partyDtoConvertAgtAccount(instructedReimbursementParty.getPartyAcct());
                sttlmInf.setInstdRmbrsmntAgtAcct(instdRmbrsmntAgtAcct);
            }
            if (thirdReimbursementParty != null) {
                BranchAndFinancialInstitutionIdentification6 thrdRmbrsmntAgt = partyDtoConvertAgt(thirdReimbursementParty);
                sttlmInf.setThrdRmbrsmntAgt(thrdRmbrsmntAgt);
                CashAccount38 thrdRmbrsmntAgtAcct = partyDtoConvertAgtAccount(thirdReimbursementParty.getPartyAcct());
                sttlmInf.setThrdRmbrsmntAgtAcct(thrdRmbrsmntAgtAcct);
            }
            grpHdr.setSttlmInf(sttlmInf);
            fiToFICstmrCdtTrf.setGrpHdr(grpHdr);
            //set CdtTrfTxInf
            CreditTransferTransaction43 cdtTrfTxInf = new CreditTransferTransaction43();
            fiToFICstmrCdtTrf.addCdtTrfTxInf(cdtTrfTxInf);
            //PmtId
            TransactionReference txnRef = customerCreditTransfer.getTxnRef();
            PaymentIdentification13 pmtId = new PaymentIdentification13();
            pmtId.setInstrId(txnRef.getInstructionId());
            pmtId.setEndToEndId("NOTPROVIDED");
            pmtId.setUETR(txnRef.getUetr());
            cdtTrfTxInf.setPmtId(pmtId);

            //SttlmTmIndctn SttlmTmReq
            SettlementDateTimeIndication1 sttlmTmIndctn = null;
            XMLGregorianCalendar debitDt = DateUtil.parseXMLGregorianCalendar(customerCreditTransfer.getDebitDate());
            if (debitDt != null) {
                if (sttlmTmIndctn == null) {
                    sttlmTmIndctn = new SettlementDateTimeIndication1();
                }
                sttlmTmIndctn.setDbtDtTm(debitDt);
            }
            XMLGregorianCalendar creditDt = DateUtil.parseXMLGregorianCalendar(customerCreditTransfer.getCreditDate());
            if (creditDt != null) {
                if (sttlmTmIndctn == null) {
                    sttlmTmIndctn = new SettlementDateTimeIndication1();
                }
                sttlmTmIndctn.setCdtDtTm(creditDt);
            }
            cdtTrfTxInf.setSttlmTmIndctn(sttlmTmIndctn);

            SettlementTimeRequest2 sttlmTmReq = null;
            XMLGregorianCalendar clsDt = DateUtil.parseXMLGregorianCalendar(customerCreditTransfer.getClsDate());
            if (clsDt != null) {
                sttlmTmReq = new SettlementTimeRequest2();
                sttlmTmReq.setCLSTm(clsDt);
            }
            cdtTrfTxInf.setSttlmTmReq(sttlmTmReq);

            //PmtTpInf (SvcLvl/CtgyPurp)
            ServiceLevel serviceLevel = customerCreditTransfer.getServiceLevel();
            CategoryPurpose categoryPurpose = customerCreditTransfer.getCategoryPurpose();
            if (serviceLevel != null || categoryPurpose != null) {
                PaymentTypeInformation28 pmtTpInf = new PaymentTypeInformation28();
                ServiceLevel8Choice svcLvl = new ServiceLevel8Choice();
                svcLvl.setCd(serviceLevel.getCode().value());
                svcLvl.setPrtry(serviceLevel.getProprietary());
                pmtTpInf.addSvcLvl(svcLvl);

                CategoryPurpose1Choice ctgyPurp = new CategoryPurpose1Choice();
                ctgyPurp.setCd(categoryPurpose.getCode().value());
                ctgyPurp.setPrtry(categoryPurpose.getProprietary());
                pmtTpInf.setCtgyPurp(ctgyPurp);
                cdtTrfTxInf.setPmtTpInf(pmtTpInf);
            }

            //Purp
            PurposeChoice purposeChoice = customerCreditTransfer.getPurposeChoice();
            if (purposeChoice != null) {
                Purpose2Choice purp = new Purpose2Choice();
                purp.setCd(purposeChoice.getCode());
                purp.setPrtry(purposeChoice.getProprietary());
                cdtTrfTxInf.setPurp(purp);
            }

            //IntrBkSttlmAmt
            CcyFormatAmount settledCfa = customerCreditTransfer.getSettledCcyFormatAmount();
            if (settledCfa != null) {
                ActiveCurrencyAndAmount intrBkSttlmAmt = new ActiveCurrencyAndAmount();
                intrBkSttlmAmt.setCcy(settledCfa.getCcy());
                intrBkSttlmAmt.setValue(settledCfa.getAmt());
                cdtTrfTxInf.setIntrBkSttlmAmt(intrBkSttlmAmt);
            }

            //IntrBkSttlmDt
            XMLGregorianCalendar xmlValueDate = DateUtil.parseXMLGregorianCalendar(customerCreditTransfer.getSettledDate());
            if (xmlValueDate != null) {
                cdtTrfTxInf.setIntrBkSttlmDt(xmlValueDate);
            }

            //InstdAmt
            CcyFormatAmount instructedCfa = customerCreditTransfer.getInstructedCcyFormatAmount();
            if (instructedCfa != null) {
                ActiveOrHistoricCurrencyAndAmount instdAmt = new ActiveOrHistoricCurrencyAndAmount();
                instdAmt.setCcy(instructedCfa.getCcy());
                instdAmt.setValue(instructedCfa.getAmt());
                cdtTrfTxInf.setInstdAmt(instdAmt);
            }

            //XchgRate
            BigDecimal exchangeRate = customerCreditTransfer.getExchangeRate();
            if (exchangeRate != null) {
                cdtTrfTxInf.setXchgRate(exchangeRate);
            }

            //Dbtr DbtrAcct
            if (dbtrParty != null) {
                PartyIdentification135 dbtr = partyDtoConvertTr(dbtrParty);
                cdtTrfTxInf.setDbtr(dbtr);
                CashAccount38 dbtrAcct = partyDtoConvertAgtAccount(dbtrParty.getPartyAcct());
                cdtTrfTxInf.setDbtrAcct(dbtrAcct);
            }

            //DbtrAgt DbtrAgtAcct
            if (dbtrAgtParty != null) {
                BranchAndFinancialInstitutionIdentification6 dbtrAgt = partyDtoConvertAgt(dbtrAgtParty);
                cdtTrfTxInf.setDbtrAgt(dbtrAgt);
                CashAccount38 dbtrAgtAcct = partyDtoConvertAgtAccount(dbtrAgtParty.getPartyAcct());
                cdtTrfTxInf.setDbtrAgtAcct(dbtrAgtAcct);
            }

            //IntrmyAgt1 IntrmyAgt1Acct
            if (intrmyAgt1Party != null) {
                BranchAndFinancialInstitutionIdentification6 intrmyAgt1 = partyDtoConvertAgt(intrmyAgt1Party);
                cdtTrfTxInf.setIntrmyAgt1(intrmyAgt1);
                CashAccount38 intrmyAgt1Acct = partyDtoConvertAgtAccount(intrmyAgt1Party.getPartyAcct());
                cdtTrfTxInf.setIntrmyAgt1Acct(intrmyAgt1Acct);
            }

            //CdtrAgt CdtrAgtAcct
            if (cdtrAgtParty != null) {
                BranchAndFinancialInstitutionIdentification6 cdtrAgt = partyDtoConvertAgt(cdtrAgtParty);
                cdtTrfTxInf.setCdtrAgt(cdtrAgt);
                CashAccount38 cdtrAgtAcct = partyDtoConvertAgtAccount(cdtrAgtParty.getPartyAcct());
                cdtTrfTxInf.setCdtrAgtAcct(cdtrAgtAcct);
            }

            //Cdtr CdtrAcct
            if (cdtrParty != null) {
                PartyIdentification135 cdtr = partyDtoConvertTr(cdtrParty);
                cdtTrfTxInf.setCdtr(cdtr);
                CashAccount38 cdtrAcct = partyDtoConvertAgtAccount(cdtrParty.getPartyAcct());
                cdtTrfTxInf.setCdtrAcct(cdtrAcct);
            }

            //RmtInf
            RemittanceInformation remittanceInfo = customerCreditTransfer.getRemittanceInfo();
            if (remittanceInfo != null && remittanceInfo.getUnstructured().size() > 0) {
                RemittanceInformation16 rmtInf = new RemittanceInformation16();
                for (String remitInfo : remittanceInfo.getUnstructured()) {
                    rmtInf.addUstrd(remitInfo);
                }
                cdtTrfTxInf.setRmtInf(rmtInf);
            }

            //ChrgBr ChrgsInf
            ChargeForEnum chargeForEnum = customerCreditTransfer.getChargeFor();
            if (chargeForEnum != null) {
                cdtTrfTxInf.setChrgBr(ChargeBearerType1Code.fromValue(chargeForEnum.value()));
            }
            List<ChargeInfo> chargeInfos = customerCreditTransfer.getChargeInfoList();
            if (chargeInfos.size() > 0) {
                for (ChargeInfo chargeInfo : chargeInfos) {
                    Charges7 chrgsInf = new Charges7();
                    CcyFormatAmount ccyFormatAmount = chargeInfo.getAmt();
                    if (ccyFormatAmount != null) {
                    ActiveOrHistoricCurrencyAndAmount amt = new ActiveOrHistoricCurrencyAndAmount();
                        amt.setCcy(ccyFormatAmount.getCcy());
                        amt.setValue(ccyFormatAmount.getAmt());
                        chrgsInf.setAmt(amt);
                    }
                    chrgsInf.setAgt(partyDtoConvertAgt(chargeInfo.getPartyDto()));
                    cdtTrfTxInf.addChrgsInf(chrgsInf);
                }
            }

            //PrvsInstgAgt1 InstrForCdtrAgt InstrForNxtAgt
            PartyDto preInstgAgtPartyDto = customerCreditTransfer.getPreInstgAgtParty();
            if (preInstgAgtPartyDto != null) {
                BranchAndFinancialInstitutionIdentification6 prvsInstgAgt1 = new BranchAndFinancialInstitutionIdentification6();
                FinancialInstitutionIdentification18 finInstnId = new FinancialInstitutionIdentification18();
                finInstnId.setBICFI(preInstgAgtPartyDto.getPartyBic());
                finInstnId.setNm(preInstgAgtPartyDto.getPartyName());
                prvsInstgAgt1.setFinInstnId(finInstnId);
                cdtTrfTxInf.setPrvsInstgAgt1(prvsInstgAgt1);
            }
            InstructionForCreditAgent instForCrdAgt = customerCreditTransfer.getInstForCrdAgt();
            if (instForCrdAgt != null) {
                InstructionForCreditorAgent3 instructionForCreditorAgent3 = new InstructionForCreditorAgent3();
                instructionForCreditorAgent3.setCd(instForCrdAgt.getCode().value());
                instructionForCreditorAgent3.setInstrInf(instForCrdAgt.getInstrInf());
                cdtTrfTxInf.addInstrForCdtrAgt(instructionForCreditorAgent3);
            }
            InstructionForNextAgent instForNxtAgt = customerCreditTransfer.getInstForNxtAgt();
            if (instForNxtAgt != null) {
                InstructionForNextAgent1 instructionForNextAgent1 = new InstructionForNextAgent1();
                instructionForNextAgent1.setCd(instForNxtAgt.getCode());
                instructionForNextAgent1.setInstrInf(instForNxtAgt.getInstrInf());
                cdtTrfTxInf.addInstrForNxtAgt(instructionForNextAgent1);
            }
            //RgltryRptg
            List<String> rpList = customerCreditTransfer.getRegulatoryReportingList();
            if (rpList != null && rpList.size() > 0) {
                for (String rp : rpList) {
                    RegulatoryReporting3 regulatoryReporting3 = new RegulatoryReporting3();
                    StructuredRegulatoryReporting3 dtl = new StructuredRegulatoryReporting3();
                    dtl.addInf(rp);
                    regulatoryReporting3.addDtls(dtl);
                    cdtTrfTxInf.addRgltryRptg(regulatoryReporting3);
                }
            }

            String xmlStr = mxPacs00800109.message();
            context.set(SwiftDto2MxContextIdentifier.MX_XML, xmlStr);
            String outputFilePath = (String)context.get(SwiftDto2MxContextIdentifier.MX_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                mxPacs00800109.write(new File(outputFilePath));
            }
        } catch (ParseException | DatatypeConfigurationException | IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
