package com.brilliance.swift.util;

import com.brilliance.swift.constants.ERROR;
import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.vo.SwiftTranslationErrorInfo;
import com.brilliance.swift.vo.SwiftTranslationReport;
import com.brilliance.swift.vo.common.TranslationResultCode;
import com.prowidesoftware.swift.model.*;
import com.prowidesoftware.swift.model.field.*;
import com.prowidesoftware.swift.model.mt.AbstractMT;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class MxMessageReader {

    /**
     * 对照着 MessageRead.getSwfMsgInfoViaMsg
     * 重写一遍关于MX报文的解析，供邮储国际支付前置使用
     * @param str
     * @return
     */
    public static Map<String, String> getSwfMsgInfoViaMsg(SwiftTranslationReport str) {
        try {
            String mtStr = str.getMessage();
            List<SwiftTranslationErrorInfo> errorInfos = str.getErrorInfos();
            if (StringUtil.isEmpty(mtStr)) {
                return null;
            }
            Map<String, String> infMap = new HashMap();
            infMap.put("swtMsg", str.getMessage());
            AbstractMT abstractMT = AbstractMT.parse(mtStr);
            SwiftBlock5 swiftBlock5 = abstractMT.getSwiftMessage().getBlock5();
            if (swiftBlock5 != null && swiftBlock5.getTags().size() > 0) {
                List<Tag> tags = swiftBlock5.getTags();
                String trl = "";
                for (Tag tag:tags) {
                    trl += "{";
                    if (StringUtil.isNotEmpty(tag.getName())) {
                        trl += tag.getName();
                    }
                    trl += ":";
                    if (StringUtil.isNotEmpty(tag.getValue())) {
                        trl += tag.getValue();
                    }
                    trl += "}";
                }
                infMap.put("trl", trl);
            }
            String ioFlag = "";
            SwiftBlock2 block2 = abstractMT.getSwiftMessage().getBlock2();
            if (block2 != null) {
                if (block2 instanceof SwiftBlock2Output) {
                    ioFlag = "O";
                    infMap.put("direct", ioFlag); //收到报文
                    SwiftBlock2Output swiftBlock2Output = (SwiftBlock2Output)block2;
                    infMap.put("sndbic", abstractMT.getSender());
                    String mir = "";
                    if (StringUtil.isNotEmpty(swiftBlock2Output.getMIRDate())) {
                        mir += swiftBlock2Output.getMIRDate() + " ";
                    }
                    if (StringUtil.isNotEmpty(swiftBlock2Output.getMIRLogicalTerminal())) {
                        mir += swiftBlock2Output.getMIRLogicalTerminal();
                    }
                    if (StringUtil.isNotEmpty(swiftBlock2Output.getMIRSessionNumber())) {
                        mir += swiftBlock2Output.getMIRSessionNumber();
                    }
                    if (StringUtil.isNotEmpty(swiftBlock2Output.getMIRSequenceNumber())) {
                        mir += swiftBlock2Output.getMIRSequenceNumber();
                    }
                    infMap.put("mir", mir);
                    infMap.put("prt", swiftBlock2Output.getMessagePriority());
                } else if (block2 instanceof SwiftBlock2Input) {
                    ioFlag = "I";
                    infMap.put("direct", ioFlag);  //发出报文
                    SwiftBlock2Input swiftBlock2Input = (SwiftBlock2Input)block2;
                    infMap.put("rcvbic", abstractMT.getReceiver());
                    infMap.put("prt", swiftBlock2Input.getMessagePriority());
                    infMap.put("tns", swiftBlock2Input.getDeliveryMonitoring());
                    infMap.put("dyt", swiftBlock2Input.getObsolescencePeriod());
                }
            }
            SwiftBlock1 swiftBlock1 = abstractMT.getSwiftMessage().getBlock1();
            if (swiftBlock1 != null) {
                String mor = "";
                if ("O".equals(ioFlag)) {
                    infMap.put("rcvbic", abstractMT.getReceiver());
                    SwiftBlock2Output swiftBlock2Output = (SwiftBlock2Output)block2;
                    if (StringUtil.isNotEmpty(swiftBlock2Output.getMIRDate())) {
                        mor += swiftBlock2Output.getMIRDate() + " ";
                    }
                    if (StringUtil.isNotEmpty(swiftBlock1.getLogicalTerminal())) {
                        mor += swiftBlock1.getLogicalTerminal();
                    }
                    if (StringUtil.isNotEmpty(swiftBlock1.getSessionNumber())) {
                        mor += swiftBlock1.getSessionNumber();
                    }
                    if (StringUtil.isNotEmpty(swiftBlock1.getSequenceNumber())) {
                        mor += swiftBlock1.getSequenceNumber();
                    }
                    infMap.put("mor", mor);
                } else if ("I".equals(ioFlag)) {
                    infMap.put("sndbic", abstractMT.getSender());
                }
            }
            String msgType = abstractMT.getMessageType();
            if (abstractMT.getSwiftMessage().isCOV()) {
                msgType += "COV";
            }
            infMap.put("mty", msgType);
            SwiftBlock3 swiftBlock3 = abstractMT.getSwiftMessage().getBlock3();
            if (swiftBlock3 != null) {
                Tag tag = swiftBlock3.getTagByName("108");
                if (tag != null) {
                    infMap.put("sndnum", tag.getValue());
                }
                tag = swiftBlock3.getTagByName("111");
                if (tag != null) {
                    infMap.put("gpiFlg", "GPI");
                    infMap.put("gpiVal", tag.getValue());
                }
                tag = swiftBlock3.getTagByName("121");
                if (tag != null) {
                    infMap.put("UETR", tag.getValue());
                }
            }
            infMap.put("std", "MT");
            //处理BLOCK4
            SwiftBlock4 swiftBlock4 = abstractMT.getSwiftMessage().getBlock4();
            if (swiftBlock4 != null) {
                Tag tag = swiftBlock4.getTagByName("20");
                if (tag != null) {
                    infMap.put("ref", tag.getValue());
                    if (errorInfos != null && errorInfos.size() > 0) {
                        for (SwiftTranslationErrorInfo errorInfo : errorInfos) {
                            if (ERROR.T0000T.equals(errorInfo.getCode())
                                && "Block4/:20:".equals(errorInfo.getLocation())
                                && StringUtil.isNotEmpty(errorInfo.getOriginalValue())) {
                                infMap.put("ref", errorInfo.getOriginalValue());
                            }
                        }
                    }
                }
                tag = swiftBlock4.getTagByName("21");
                if (tag != null) {
                    infMap.put("tscref", tag.getValue());
                    if (errorInfos != null && errorInfos.size() > 0) {
                        for (SwiftTranslationErrorInfo errorInfo : errorInfos) {
                            if (ERROR.T0000T.equals(errorInfo.getCode())
                                && "Block4/:21:".equals(errorInfo.getLocation())
                                && StringUtil.isNotEmpty(errorInfo.getOriginalValue())) {
                                infMap.put("tscref", errorInfo.getOriginalValue());
                            }
                        }
                    }
                }
                if ("910".equals(msgType)) {
                    tag = swiftBlock4.getTagByName("50A");
                    if (tag != null) {
                        infMap.put("f50", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("50F");
                    if (tag != null) {
                        infMap.put("f50", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("50K");
                    if (tag != null) {
                        infMap.put("f50", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("52A");
                    if (tag != null) {
                        infMap.put("f52", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("52D");
                    if (tag != null) {
                        infMap.put("f52", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("72");
                    if (tag != null) {
                        infMap.put("f72", tag.getValue());
                    }
                }
                tag = swiftBlock4.getTagByName("32A");
                if (tag != null) {
                    Field32A field32A = (Field32A)tag.asField();
                    infMap.put("vludat", field32A.getDate());
                    infMap.put("amt", field32A.getAmount().replace(",", "."));
                    infMap.put("cur", field32A.getCurrency());
                }
                tag = swiftBlock4.getTagByName("32B");
                if (tag != null) {
                    Field32B field32B = (Field32B)tag.asField();
                    infMap.put("itdamt", field32B.getAmount().replace(",", "."));
                    infMap.put("itdcur", field32B.getCurrency());
                }
                tag = swiftBlock4.getTagByName("30");
                if (tag != null) {
                    Field30 field30 = (Field30)tag.asField();
                    infMap.put("itdvludat", field30.getDate());
                }
                tag = swiftBlock4.getTagByName("62F");//940/950对账单
                if (tag != null) {
                    Field62F field62F = (Field62F)tag.asField();
                    infMap.put("vludat", field62F.getDate());
                    infMap.put("amt", field62F.getAmount().replace(",", "."));
                    infMap.put("cur", field62F.getCurrency());
                }
                tag = swiftBlock4.getTagByName("62M");//940/950对账单
                if (tag != null) {
                    Field62M field62M = (Field62M)tag.asField();
                    infMap.put("vludat", field62M.getDate());
                    infMap.put("amt", field62M.getAmount().replace(",", "."));
                    infMap.put("cur", field62M.getCurrency());
                }
                tag = swiftBlock4.getTagByName("25");
                if (tag != null) {
                    infMap.put("act", tag.getValue());
                }
                tag = swiftBlock4.getTagByName("25P");
                if (tag != null) {
                    Field25P field25P = (Field25P)tag.asField();
                    infMap.put("act", field25P.getAccount());
                }
                if ("O".equals(ioFlag)) {
                    tag = swiftBlock4.getTagByName("54A");
                    if (tag != null) {
                        Field54A field54A = (Field54A)tag.asField();
                        infMap.put("actbic", field54A.getBIC());
                    }
                    tag = swiftBlock4.getTagByName("53A");
                    if (tag != null) {
                        Field53A field53A = (Field53A)tag.asField();
                        infMap.put("t53bic", field53A.getBIC());
                    }
                } else if ("I".equals(ioFlag)) {
                    tag = swiftBlock4.getTagByName("53A");
                    if (tag != null) {
                        Field53A field53A = (Field53A)tag.asField();
                        infMap.put("actbic", field53A.getBIC());
                    }
                }
                tag = swiftBlock4.getTagByName("50A");
                if (tag != null) {
                    Field50A field50A = (Field50A) tag.asField();
                    if (!"910".equals(msgType) && StringUtil.isNotEmpty(field50A.getAccount())) {
                        infMap.put("act", field50A.getAccount());
                    }
                }
                tag = swiftBlock4.getTagByName("50K");
                if (tag != null) {
                    Field50K field50K = (Field50K) tag.asField();
                    if (!"910".equals(msgType) && StringUtil.isNotEmpty(field50K.getAccount())) {
                        infMap.put("act", field50K.getAccount());
                    }
                    infMap.put("ordnamadr", field50K.getNameAndAddress());
                }
                tag = swiftBlock4.getTagByName("50F");
                if (tag != null) {
                    Field50F field50F = (Field50F) tag.asField();
                    if (!"910".equals(msgType) && StringUtil.isNotEmpty(field50F.getPartyIdentifier())) {
                        infMap.put("act", field50F.getPartyIdentifier().startsWith("/")?field50F.getPartyIdentifier().substring(1):field50F.getPartyIdentifier());
                    }
                    String nameAddress = "";
                    List<String> lines = field50F.getLines();
                    for (int i=0; i<lines.size(); i++) {
                        if (i == 0) {
                            continue;
                        }
                        if (i == lines.size()-1) {
                            nameAddress += lines.get(i);
                        } else {
                            nameAddress += lines.get(i) + Mx2MtConstants.NEW_LINE;
                        }
                    }
                    infMap.put("ordnamadr", nameAddress);
                }
                //如果是202cov,需要取cov里面的57A bicCode
                boolean isCov = abstractMT.getSwiftMessage().isCOV();
                if (isCov) {
                    SwiftTagListBlock swiftTagListBlock = abstractMT.getSequence("B");
                    if (swiftTagListBlock != null) {
                        tag = swiftTagListBlock.getTagByName("57A");
                    }
                } else {
                    tag = swiftBlock4.getTagByName("57A");
                }
                if (tag != null) {
                    Field57A field57A = (Field57A) tag.asField();
                    infMap.put("corbic", field57A.getBIC());
                }
                tag = swiftBlock4.getTagByName("59");
                if (tag != null) {
                    Field59 field59 = (Field59) tag.asField();
                    if (!"910".equals(msgType) && StringUtil.isNotEmpty(field59.getAccount())) {
                        infMap.put("act", field59.getAccount());
                        infMap.put("benact", field59.getAccount());
                    }
                    infMap.put("bennamadr", field59.getNameAndAddress(Mx2MtConstants.NEW_LINE));
                }
                tag = swiftBlock4.getTagByName("59A");
                if (tag != null) {
                    Field59A field59A = (Field59A) tag.asField();
                    if (!"910".equals(msgType) && StringUtil.isNotEmpty(field59A.getAccount())) {
                        infMap.put("act", field59A.getAccount());
                        infMap.put("benact", field59A.getAccount());
                    }
                    infMap.put("bennamadr", field59A.getBIC());
                }
                tag = swiftBlock4.getTagByName("59F");
                if (tag != null) {
                    Field59F field59F = (Field59F) tag.asField();
                    if (!"910".equals(msgType) && StringUtil.isNotEmpty(field59F.getAccount())) {
                        infMap.put("act", field59F.getAccount());
                        infMap.put("benact", field59F.getAccount());
                    }
                    String nameAddress = "";
                    List<String> lines = field59F.getLines();
                    for (int i=0; i<lines.size(); i++) {
                        if (i == 0 && StringUtil.isNotEmpty(field59F.getAccount())) {
                            continue;
                        }
                        if (i == lines.size()-1) {
                            nameAddress += lines.get(i);
                        } else {
                            nameAddress += lines.get(i) + Mx2MtConstants.NEW_LINE;
                        }
                    }
                    if (StringUtil.isNotEmpty(nameAddress)) {
                        infMap.put("bennamadr", nameAddress);
                    }
                }
                tag = swiftBlock4.getTagByName("71A");
                if (tag != null) {
                    infMap.put("dtlchg", tag.getValue());
                }
                Tag[] tags = swiftBlock4.getTagsByName("71F");
                if (tags != null && tags.length > 0) {
                    String msg71F = "";
                    for (int i=0; i<tags.length; i++) {
                        Tag tmpTag = tags[i];
                        if (i == 0) {
                            msg71F += tmpTag.getValue().replace(",", ".");
                        } else {
                            msg71F += ";" + tmpTag.getValue().replace(",", ".");
                        }
                    }
                    if (StringUtil.isNotEmpty(msg71F)) {
                        infMap.put("71Fmsg", msg71F);
                    }
                }
                tag = swiftBlock4.getTagByName("22C");
                if (tag != null) {
                    Field22C field22C = (Field22C)tag.asField();
                    infMap.put("comref", field22C.getValue());
                }
                tag = swiftBlock4.getTagByName("33B");
                if (tag != null) {
                    Field33B field33B = (Field33B)tag.asField();
                    infMap.put("sellamt", field33B.getAmount().replace(",", "."));
                    infMap.put("sellcur", field33B.getCurrency());
                }
                tag = swiftBlock4.getTagByName("17R");
                if (tag != null) {
                    infMap.put("BorL", tag.getValue());
                }
                tag = swiftBlock4.getTagByName("34E");
                if (tag != null) {
                    Field34E field34E = (Field34E)tag.asField();
                    infMap.put("interest", field34E.getAmount().replace(",", "."));
                }
                tag = swiftBlock4.getTagByName("30V");
                if (tag != null) {
                    infMap.put("m3xValDate", tag.getValue());
                }
                tag = swiftBlock4.getTagByName("32B");
                if (tag != null) {
                    Field32B field32B = (Field32B)tag.asField();
                    infMap.put("buyamt", field32B.getAmount().replace(",", "."));
                    infMap.put("buycur", field32B.getCurrency());
                }
                tag = swiftBlock4.getTagByName("79");
                if (tag != null) {
                    infMap.put("addinfo", tag.getValue());
                }
                tag = swiftBlock4.getTagByName("76");
                if (tag != null) {
                    infMap.put("info76", tag.getValue());
                }
                if ("950".equals(msgType)) {
                    tag = swiftBlock4.getTagByName("28C");
                    if (tag != null) {
                        infMap.put("bilnum", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("60F");
                    if (tag != null) {
                        infMap.put("begamtf", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("60M");
                    if (tag != null) {
                        infMap.put("begamtm", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("62F");
                    if (tag != null) {
                        infMap.put("endamtf", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("62M");
                    if (tag != null) {
                        infMap.put("endamtm", tag.getValue());
                    }
                    tag = swiftBlock4.getTagByName("64");
                    if (tag != null) {
                        infMap.put("valamt", tag.getValue());
                    }
                }
            }
            boolean failureFlag = TranslationResultCode.TRNK.value().equals(str.getTranslationResult()) ? true : false;
            String errorDsp = "";
            if (errorInfos != null && errorInfos.size() > 0) {
                errorDsp += "Translation Result : " + str.getTranslationResult();
                for (int i=0; i<errorInfos.size(); i++) {
                    SwiftTranslationErrorInfo errorInfo = errorInfos.get(i);
                    errorDsp += Mx2MtConstants.NEW_LINE + errorInfo.toString();
                }

            }
            if (failureFlag) {
                infMap.put("errCde", "E"); //
            } else {
                infMap.put("errCde", "S"); //
            }
            infMap.put("errDsp", errorDsp);
            return infMap;
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
