package com.brilliance.swift.util;

import com.brilliance.swift.exception.SwiftException;
import org.apache.commons.io.IOUtils;

import java.io.*;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

/**
 * Properties文件工具
 * 
 * @author xiaoyuanzhen
 *
 */
public class PropertyUtil {

    private static final String XML_FILE_EXTENSION = ".xml";


    public static Properties loadProperties(String propertyFile) {
        return loadProperties(propertyFile, null);
    }

    public static Properties loadProperties(String propertyFile, String encode) {
        Properties props = new Properties();
        try {
            fillProperties(props, propertyFile, encode);
        } catch (IOException e) {
            throw new SwiftException("fill Properties occure exception,filePath=" + propertyFile + ",encode" + encode, e);
        }
        return props;
    }

    public static Properties loadProperties(URL url) throws IOException {
        Properties props = new Properties();
        try (InputStream is =url.openStream()){
            if (url.getFile().endsWith(XML_FILE_EXTENSION)) {
                props.loadFromXML(is);
            } else {
                props.load(is);
            }
        }
        return props;
    }

    static void fillProperties(Properties props, String propertyFile, String encode)
            throws IOException {
        InputStream is = null;
        Reader reader = null;
        try {
            URL url = FileUtil.getURL(propertyFile);
            if (propertyFile.endsWith(XML_FILE_EXTENSION)) {
                is = url.openStream();
                props.loadFromXML(is);
            } else if (encode != null) {
                reader = new InputStreamReader(url.openStream(), encode);
                props.load(reader);
            } else {
                is = url.openStream();
                props.load(is);
            }
        } finally {
            if (is != null) {
                is.close();
            }
            if (reader != null) {
                reader.close();
            }
        }
    }

    /**
     * 从properties文件中获取指定属性名对应的值
     * 
     * @param propertyFile
     * @param propertyName
     * @return
     */
    private static Map<String, Properties> map = new HashMap<String, Properties>();

    public static String getProperty(String propertyFile, String propertyName) {
        String propertyValue = "";
        InputStream is = null;
        try {
            Properties propertie = new Properties();
            if (!map.containsKey(propertyFile)) {
                is = Thread.currentThread().getContextClassLoader()
                        .getResourceAsStream(propertyFile);
                propertie.load(is);
                map.put(propertyFile, propertie);
            }
            propertyValue = map.get(propertyFile).getProperty(propertyName);
        } catch (Exception e) {
            e.printStackTrace();
            propertyValue = "";
        } finally {
            try {
                IOUtils.closeQuietly(is);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        return propertyValue;
    }

    /**
     * 设置properties文件的某个属性值
     * 
     * @param propertyFile
     * @param propertyName
     * @param propertyValue
     * @return
     */
    public synchronized static boolean setProperty(String propertyFile, String propertyName,
            String propertyValue) {
        boolean sav = false;
        InputStream is = null;
        OutputStream os = null;
        try {
            Properties propertie = new Properties();
            is = Thread.currentThread().getContextClassLoader().getResourceAsStream(propertyFile);
            propertie.load(is);
            propertie.setProperty(propertyName, propertyValue);
            String path = Thread.currentThread().getContextClassLoader().getResource(propertyFile)
                    .getPath();
            os = new FileOutputStream(new File(path));
            propertie.store(os, "");
            os.flush();
            sav = true;
        } catch (Exception e) {
            e.printStackTrace();
            sav = false;
        } finally {
            try {
                is.close();
                os.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return sav;
    }

    public synchronized static boolean setPropertyValue(String propertyFile, String propertyName,
            String propertyValue) {
        boolean sav = false;
        OutputStream os = null;
        InputStream is = null;
        try {
            Properties propertie = new Properties();
            is = new FileInputStream(new File(propertyFile));
            propertie.load(is);
            propertie.setProperty(propertyName, propertyValue);
            os = new FileOutputStream(new File(propertyFile));
            propertie.store(os, "");
            os.flush();
            sav = true;
        } catch (Exception e) {
            e.printStackTrace();
            propertyValue = "";
        } finally {
            try {
                is.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return sav;
    }

    private static Properties load(File f, String encoding) throws IOException {
        Properties propertie = new Properties();
        InputStreamReader is = new InputStreamReader(new FileInputStream(f), encoding);
        propertie.load(is);
        is.close();
        return propertie;
    }

    private static Properties load(File f) throws IOException {
        return load(f, "GBK");
    }

    public static Properties getProperties(String propertyFile)
            throws IOException {
        return getProperties(propertyFile,"GBK");
    }
    
    public static Properties getProperties(String propertyFile, String encoding)
            throws IOException {
        return load(new File(propertyFile), encoding);
    }

    public static String getPropertyValue(String propertyFile, String propertyName) {
        String propertyValue = "";
        // InputStream is = null;
        try {
            Properties propertie = load(new File(propertyFile));
            propertyValue = propertie.getProperty(propertyName);
        } catch (Exception e) {
            e.printStackTrace();
            propertyValue = "";
        }
        return propertyValue;
    }
}
