package com.brilliance.swift.util;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import org.apache.commons.io.IOUtils;

import java.io.*;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * 字符串处理工具类
 *
 * @author
 */
public abstract class StringUtil {

    public static boolean hasLength(String str) {
        return (str != null && !str.isEmpty());
    }

    public static boolean containsAny(String str, char... testChars) {
        if (!isEmpty(str)) {
            int len = str.length();

            for (int i = 0; i < len; ++i) {
                if (ArrayUtil.contains(testChars, str.charAt(i))) {
                    return true;
                }
            }
        }
        return false;
    }

    /**
     * 文件流转换成String字符串
     *
     * @throws IOException
     **/
    public static String toString(String path, String charset) throws IOException {
        FileInputStream fis = new FileInputStream(new File(path));
        String s = IOUtils.toString(fis);
        fis.close();
        return s;
    }

    /**
     * 替换最后一处字符串,此方法如果目标代码中出现特殊字符，会导致正则无法使用
     *
     * @param str
     * @param dest
     * @param replacement
     * @return
     */
    @Deprecated
    public static String replaceLast(String str, String dest, String replacement) {
        return str.replaceAll(dest + "(?!.*" + dest + ".*)", replacement);
    }

    /**
     * 判断是否为空
     **/
    public static boolean isEmpty(String content) {
        if (content != null && !content.trim().equals(""))
            return false;
        else
            return true;
    }

    /*
     * public static String getDocKey(String formatpath) { String str[] =
     * formatpath.split("\\/"); int len = str.length - 1; String s = str[len];
     * int length = s.length() - 4; s = s.substring(0, length); return s; }
     */

    public static String repeat(String sc, int num) {
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < num; i++)
            sb.append(sc);
        return sb.toString();
    }

    /**
     * 主要是解决在利用split分隔的时候，结尾如果为空，split分隔的数组将会忽略空串的问题
     *
     * @param regex
     * @param s
     * @return by hujun on 2013/10/12
     */
    public static String[] split(String regex, String s) {
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(s);
        int index = 0;
        while (m.find()) {
            index++;
        }
        return s.split(regex, index + 1);
    }

    /**
     * 分析使用","分隔的多个参数，类似函数的参数分析器
     *
     * @param str 如："abc,2,'cd'"
     * @return
     */
    public static String[] analyseArgs(String str) {
        int len = str.length();
        boolean inStr = false;
        List<String> args = new ArrayList<String>();
        StringBuffer tmpArg = new StringBuffer();
        for (int i = 0; i < len; i++) {
            char c = str.charAt(i);
            if (c == ' ') {
                if (inStr)
                    tmpArg.append(c);
            } else if (c == '\'') {
                inStr = !inStr;
                tmpArg.append(c);
            } else if (c == ',') {
                if (inStr)
                    tmpArg.append(c);
                else {
                    args.add(tmpArg.toString());
                    tmpArg = new StringBuffer();
                }
            } else
                tmpArg.append(c);
        }
        String lastStr = tmpArg.toString();
        if (!lastStr.equals(""))
            args.add(lastStr);
        return args.toArray(new String[args.size()]);
    }

    /**
     * @param db
     * @pattern 模式
     **/
    public static String formatDouble(double db, String pattern) {
        DecimalFormat df = new DecimalFormat(pattern);
        return df.format(db);
    }

    public static String formatDouble(double db) {
        String str = (db + "").toLowerCase();
        int index;
        if ((index = str.indexOf('e')) != -1) {
            int len = Integer.parseInt(str.substring(index + 1));
            int dotIndex = str.indexOf('.');
            int lackLen = len - (index - dotIndex - 1);
            if (len > 0) {
                if (lackLen > 0) {
                    return String.format("%.0f", db);
                }
                return str.substring(0, dotIndex) + str.substring(dotIndex + 1, dotIndex + len + 1) + "." + str.substring(dotIndex + len + 1, index);
            } else {
                return String.format("%." + (-lackLen) + "f", db);
            }
        } else
            return str;
    }

    public static String getFillChars(String str, String leftchars, String chars, String direct, int totalLen) {
        int left = totalLen - str.length();
        if (left > 0) {
            for (int i = 0; i < left; i++) {
                leftchars = leftchars + chars;
            }
        }
        if (direct.toLowerCase().equals("left")) {
            return leftchars + str;
        } else {
            return str + leftchars;
        }
    }

    public static String convertRightToLeftSlash(String content) {

        return content.replaceAll("\\\\", "/");// 用四个反斜杠来代替一个反斜杠

    }

    public static byte[] getBytes(String srcStr, String encoding) throws UnsupportedEncodingException {
        return srcStr.getBytes(encoding);
    }

    public static String bytesToString(byte[] bytes, String encoding) throws UnsupportedEncodingException {
        return new String(bytes, encoding);
    }

    public static String bytesToString(byte[] bytes) {
        return new String(bytes);
    }

    public static byte[] getBytes(String srcStr) {
        return srcStr.getBytes();
    }

    /**
     * 按照num指定的长度创建一个由数字组成的随机字符串
     *
     * @param num
     * @return
     */
    public static String createRandomNumStr(int num) {
        String str = String.format("%." + num + "f", Math.random());
        return str.substring(2);
    }

    /***
     * 字符串填充
     *
     * @param obj
     *            源数据 可以为String,doule(doule为两位小数类型),int
     * @param chars
     *            填充字符
     * @param totalLen
     *            包括left right两种情况
     * **/
    public static String fillWithChar(Object obj, String chars, String direct, int totalLen) {
        String leftchars = "";
        if (obj instanceof String) {
            String str = (String) obj;
            return StringUtil.getFillChars(str, leftchars, chars, direct, totalLen);
        } else if (obj instanceof Integer) {
            String str = String.valueOf(obj);
            return getFillChars(str, leftchars, chars, direct, totalLen);
        } else if (obj instanceof Long) {
            String str = String.valueOf(obj);
            return getFillChars(str, leftchars, chars, direct, totalLen);
        } else if (obj instanceof Double) {
            Double d = (Double) obj;
            double dd = d.doubleValue();
            String str = StringUtil.formatDouble(dd);
            str = str.replace(".", "");
            return getFillChars(str, leftchars, chars, direct, totalLen);
        } else if (obj instanceof BigDecimal) {
            BigDecimal b = (BigDecimal) obj;
            DecimalFormat df = new DecimalFormat();
            String st = df.format(b);
            return StringUtil.getFillChars(st, leftchars, chars, direct, totalLen);
        } else {
            return null;
        }
    }

    public static double round(double v, int scale) {
        if (scale < 0) {
            throw new IllegalArgumentException("The scale must be a positive integer or zero");

        }

        BigDecimal b = new BigDecimal(Double.toString(v));

        BigDecimal one = new BigDecimal("1");

        return b.divide(one, scale, BigDecimal.ROUND_HALF_UP).doubleValue();

    }

    // 转化字符串为十六进制编码
    public static String toHexString(String s) {
        String str = "";
        for (int i = 0; i < s.length(); i++) {
            int ch = (int) s.charAt(i);
            String s4 = Integer.toHexString(ch);
            str = str + s4;
        }

        return str;
    }

    public static List<String> match(String pattern, String target) {
        Pattern p = Pattern.compile(pattern, Pattern.DOTALL | Pattern.MULTILINE);
        Matcher matcher = p.matcher(target);
        List<String> groupsa = new ArrayList<String>();
        while (matcher.find()) {
            String paramName = matcher.group();
            groupsa.add(paramName);
        }
        return groupsa;
    }

    public static boolean isNotEmpty(String content) {
        return !isEmpty(content);
    }

    /**
     * <p>
     * <b>此函数在顺德项目中使用</b>
     * </p>
     *
     * @param str    原始字符串
     * @param subLen 子字符串长长度
     * @param num    切分个数
     * @return 分割后的子字符串数组
     * @throws UnsupportedEncodingException
     */
    public static String[] divideGBKStr(String str, int subLen, int num) throws UnsupportedEncodingException {
        str = str.replace("\r", "").replace("\n", "").trim();
        byte[] strBytes = str.getBytes("GBK");
        String[] strs = new String[num];
        int byteStartIdx = 0;
        int strStartIdx = 0;
        for (int i = 0; i < num; i++) {
            int copyLen = strBytes.length - byteStartIdx >= subLen ? subLen : strBytes.length - byteStartIdx;
            if (copyLen <= 0)
                strs[i] = " ";
            else {
                byte[] subBytes = new byte[copyLen];
                System.arraycopy(strBytes, byteStartIdx, subBytes, 0, copyLen);
                String subStr = new String(subBytes, "GBK");
                int subStrLen = subStr.length();
                int subStrOfStrLen = str.substring(strStartIdx, strStartIdx + subStrLen).getBytes("GBK").length;
                if (subStrOfStrLen > subLen) {
                    subBytes = new byte[copyLen - 1];
                    System.arraycopy(strBytes, byteStartIdx, subBytes, 0, copyLen - 1);
                    byteStartIdx += copyLen - 1;
                    strStartIdx += subStrLen - 1;
                } else {
                    byteStartIdx += copyLen;
                    strStartIdx += subStrLen;
                }
                strs[i] = new String(subBytes, "GBK");
            }
        }
        return strs;
    }

    /**
     * 返回一个代表当期日期是星期几的数字。1表示星期天、2表示星期一、7表示星期六
     **/
    public static int getDayOfWeek(String year, String month, String day) {
        Calendar cal = new GregorianCalendar(new Integer(year).intValue(), new Integer(month).intValue() - 1, new Integer(day).intValue());
        return cal.get(Calendar.DAY_OF_WEEK);
    }

    public static String toASCII(String str) {

        char[] chars = str.toCharArray(); // 把字符中转换为字符数组
        String asciiString = "";
        for (int i = 0; i < chars.length; i++) {// 输出结果
            asciiString = asciiString + Integer.toString((int) chars[i]);
        }
        return asciiString;
    }

    /**
     * 到固定长度换行
     *
     * @param length 每行的长度
     * @param rows   最多行数
     * @param string 需换行的字符串
     * @return
     * @throws
     */
    public static String getStringByEnter(String string, int length, int rows) {
        if (StringUtil.isEmpty(string))
            return string;
        if (--rows <= 0) {
            return string.length() > length ? string.substring(0, length) : string;
        }
        if (string.length() > length) {
            return string.substring(0, length) + Mx2MtConstants.NEW_LINE +
                    getStringByEnter(string.substring(length), length, rows);
        }
        return string;
    }

    public static String ASCIItoString(String str) {
        char a = (char) Integer.parseInt(str);
        return String.valueOf(a);
    }

    /**
     *
     * @param str
     * @param lineLength
     * @param separatorChar
     * @return
     */
    public static List<String> outStringList(String str, int lineLength, String separatorChar) {
        if (isEmpty(str)) {
            return null;
        }
        List<String> list = new ArrayList<>();
        while(str.length() > lineLength) {
            list.add(str.substring(0, lineLength));
            str = separatorChar + str.substring(lineLength);
        }
        list.add(str);
        return list;
    }

    public static List<String> inputStreamToLines(InputStream is) {
        BufferedReader bReader = new BufferedReader(new InputStreamReader(is));
        List<String> list = new ArrayList<>();
        String line = null;
        try {
            while((line = bReader.readLine())!=null){
                list.add(line);
            }
        } catch (IOException e) {
            throw new SwiftException(e.getMessage());
        } finally {
            try {
                bReader.close();
            } catch (IOException e) {
                throw new SwiftException(e.getMessage());
            }
        }
        return list;
    }

    /**
     * 分隔字符串并保留分隔符
     * @param str
     * @param separator
     * @return
     */
    public static String[] splitAndKeepSeparator(String str, String separator) {
        String[] strs = str.split(separator);
        List<String> list = new ArrayList<>();
        Pattern p = Pattern.compile("/[A-Z0-9]{1,8}/");
        Matcher m = p.matcher(str);
        while (m.find()) {
            list.add(m.group());
        }
        //过滤掉空字符串
        List<String> newList = new ArrayList<>();
        for (String s : strs) {
            if (StringUtil.isNotEmpty(s)) {
                newList.add(s);
            }
        }
        //split出来的LIST 和 正则提取出来的LIST size一样 则进行字符串连接
        if (newList.size() == list.size()) {
            String[] newStrs = new String[newList.size()];
            for (int i=0; i<newList.size(); i++) {
                newStrs[i] = list.get(i) + newList.get(i);
            }
            return newStrs;
        } else {
            return newList.toArray(new String[newList.size()]);
        }
    }

}
