package com.brilliance.swift.util;

import com.brilliance.swift.SwiftTransfer;
import com.prowidesoftware.swift.model.MxId;
import com.prowidesoftware.swift.model.mx.NamespaceReader;
import org.dom4j.*;
import org.dom4j.io.SAXReader;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.net.URL;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class XmlUtil {

    public static String getRelativeName(File f, String s) {
        String MAIN = "cfg\\main";
        if (!f.getPath().contains(s) && !f.getPath().contains(MAIN)) {
            return f.getName();
        }
        String path = f.getPath();
        int index = path.indexOf(s);
        String relativePath = null;
        if (index == -1) {
            index = path.indexOf(MAIN);
        }
        relativePath = path.substring(index);
        relativePath = relativePath.replace("\\", "/");
        relativePath = relativePath.substring(s.length() + 1);
        if (relativePath.endsWith(".xml"))
            relativePath = relativePath.substring(0, relativePath.length() - 4);
        return relativePath;
    }

    public static String getXmlNode(String xmlstr, String path) throws DocumentException {
        return getXmlNodeValue(DocumentHelper.parseText(xmlstr), path);
    }

    /**
     * key = child element name
     * value = parent element name
     * @param doc
     * @return
     */
    public static Map<String, String> getParentElementMaps(Document doc) {
        Map<String, String> maps = new HashMap<>();
        Element rootElement = doc.getRootElement();
        String rootElementName = rootElement.getName();
        processElementMaps(maps, rootElement.elements(), rootElementName);
        return maps;
    }

    public static void processElementMaps(Map maps, List elements, String parentElementName) {
        if (elements != null && elements.size() > 0) {
            for (int i=0; i<elements.size(); i++) {
                Element element = (Element)elements.get(i);
                maps.put(element.getName(), parentElementName);
                processElementMaps(maps, element.elements(), parentElementName+"."+element.getName());
            }
        }
    }
    /**
     * 获取文档对象的指定路径的值
     *
     * @param doc
     * @param path
     * @return
     */
    @SuppressWarnings("unchecked")
    public static String getXmlNodeValue(Document doc, String path) {
        String[] paths = path.split("@");
        String[] layers = paths[0].split("\\.");
        Element rootElement = doc.getRootElement();
        Element curElement = rootElement;
        if (layers[0].equals(rootElement.getName())) {
            for (int i = 1; i < layers.length; i++) {
                int startIndex = layers[i].indexOf('(');
                if (-1 != startIndex) {
                    int endIndex = layers[i].indexOf(')');
                    int num = Integer.parseInt(layers[i].substring(startIndex + 1, endIndex));
                    layers[i] = layers[i].substring(0, startIndex);
                    List<Element> subElements = curElement.elements(layers[i]);
                    Element subElement = subElements.get(num);
                    curElement = subElement;
                } else {
                    Element subElement = curElement.element(layers[i]);
                    if (subElement == null) {
                        return null;
                    }
                    curElement = subElement;
                }
            }
            if (paths.length > 1)
                return curElement.attributeValue(paths[paths.length - 1]);
            return curElement.getText();
        }
        return null;
    }

    public static String getXmlValue(String xmlStr, String etag) {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            return getXmlNodeValue(document, etag);
        } catch (DocumentException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return null;
    }



    /**
     * 获取配置文件Document对象
     *
     * @param url
     * @return
     */
    public static Document getDocument(URL url) {
        SAXReader saxReader = new SAXReader();
        try {
            Document doc = saxReader.read(url);
            return doc;
        } catch (DocumentException e) {
            throw new RuntimeException("get document [" + url + "] error.", e);
        }
    }

    /**
     * 由路径和文件名拼出资源路径
     *
     * @param path
     * @param filename
     * @return
     */
    public static String getPath(String path, String filename) {
        if (!filename.endsWith(".xml")) {
            filename += ".xml";
        }
        return path + "/" + filename;
    }

    public static boolean isXpath(String type) {
        return (!StringUtil.isEmpty(type) && type.equalsIgnoreCase("xpath")) ? true : false;
    }

    public static int getChildrenCount(Branch document, String path, String type) {
        if (StringUtil.isEmpty(path)) return 0;
        if (isXpath(type))
            return document.selectNodes(path).size();
        else {
            String[] paths = path.split("@");
            String[] layers = paths[0].split("\\.");
            Element rootElement = ((Document) document).getRootElement();
            Element curElement = rootElement;
            if (layers[0].equals(rootElement.getName())) {
                for (int i = 1; i < layers.length - 1; i++) {
                    int startIndex = layers[i].indexOf('(');
                    if (-1 != startIndex) {
                        int endIndex = layers[i].indexOf(')');
                        int num = Integer.parseInt(layers[i].substring(startIndex + 1, endIndex));
                        String mutiLayer = layers[i].substring(0, startIndex);
                        List<Element> subElements = curElement.elements(mutiLayer);
                        Element subElement = null;
                        int size = subElements.size();
                        if (num >= size) {
                            subElement = curElement.addElement(mutiLayer);
                        } else {
                            subElement = subElements.get(num);
                        }
                        curElement = subElement;
                    } else {
                        Element subElement = null;
                        if (layers[i].contains(":"))
                            subElement = curElement.element(layers[i].substring(layers[i].indexOf(':') + 1));
                        else
                            subElement = curElement.element(layers[i]);
                        if (subElement == null) {
                            subElement = curElement.addElement(layers[i]);
                        }
                        curElement = subElement;
                    }
                }
            }
            return curElement.elements(layers[layers.length - 1]).size();
        }

    }

    public static String clearXmlNamespacePrefix(String xmlStr) {
        String regex = "<([\\w]+):AppHdr";
        Pattern p = Pattern.compile(regex);
        Matcher m = p.matcher(xmlStr);
        while (m.find()) {
            String prefix = m.group(1);
            xmlStr =  xmlStr.replace("<" + prefix + ":", "<").replace("</" + prefix + ":", "</");
        }
        regex = "<([\\w]+):Document";
        p = Pattern.compile(regex);
        m = p.matcher(xmlStr);
        while (m.find()) {
            String prefix = m.group(1);
            xmlStr =  xmlStr.replace("<" + prefix + ":", "<").replace("</" + prefix + ":", "</");
        }
        return xmlStr;
    }

    /**
     * 如果传入的xml 没有报文头，导致dom4j无法解析
     * 提取xml里面的AppHdr和Document，重新组装成有效的xml报文
     */
    public static String handlingXml(String xmlStr) {
        boolean flag = true;
        try {
            DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
            DocumentBuilder documentBuilder = documentBuilderFactory.newDocumentBuilder();
            documentBuilder.parse(new ByteArrayInputStream(xmlStr.getBytes()));
        } catch (Exception e) {
            flag = false;
        }
        if (flag) { //如果是有效xml报文，直接返回
            return xmlStr;
        } else {
            return SwiftTransfer.fetchXmlFromMixMessage(xmlStr);
        }
    }

    /**
     * 找到MX报文的报文类型
     * @param xml
     * @return
     */
    public static MxId getMxMessageType(String xml) {
        Optional<String> namespace = NamespaceReader.findDocumentNamespace(xml);
        if (namespace.isPresent()) {
            return new MxId(namespace.get());
        }
        return null;
    }
}
